Class: Aws::RDS::AccountQuota
- Inherits:
-
Object
- Object
- Aws::RDS::AccountQuota
- Extended by:
- Deprecations
- Defined in:
- sig/account_quota.rbs,
lib/aws-sdk-rds/account_quota.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#max ⇒ Integer
The maximum allowed value for the quota.
- #name ⇒ String (also: #account_quota_name)
-
#used ⇒ Integer
The amount currently used toward the quota maximum.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::AccountQuota
Returns the data for this AccountQuota.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. - #identifiers ⇒ Object deprecated private Deprecated.
-
#initialize(*args) ⇒ AccountQuota
constructor
A new instance of AccountQuota.
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ AccountQuota #initialize(options = {}) ⇒ AccountQuota
Returns a new instance of AccountQuota.
13 14 15 |
# File 'sig/account_quota.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#data ⇒ Types::AccountQuota
Returns the data for this Aws::RDS::AccountQuota.
31 |
# File 'sig/account_quota.rbs', line 31
def data: () -> Types::AccountQuota
|
#data_loaded? ⇒ Boolean
34 |
# File 'sig/account_quota.rbs', line 34
def data_loaded?: () -> bool
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
181 182 183 |
# File 'lib/aws-sdk-rds/account_quota.rb', line 181 def identifiers { name: @name } end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
59 60 61 62 |
# File 'lib/aws-sdk-rds/account_quota.rb', line 59 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#max ⇒ Integer
The maximum allowed value for the quota.
25 |
# File 'sig/account_quota.rbs', line 25
def max: () -> ::Integer
|
#name ⇒ String Also known as: account_quota_name
18 |
# File 'sig/account_quota.rbs', line 18
def name: () -> String
|
#used ⇒ Integer
The amount currently used toward the quota maximum.
22 |
# File 'sig/account_quota.rbs', line 22
def used: () -> ::Integer
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/aws-sdk-rds/account_quota.rb', line 160 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |