Class: Aws::RDS::DBCluster
- Inherits:
-
Object
- Object
- Aws::RDS::DBCluster
- Extended by:
- Deprecations
- Defined in:
- sig/db_cluster.rbs,
lib/aws-sdk-rds/db_cluster.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#activity_stream_kinesis_stream_name ⇒ String
The name of the Amazon Kinesis data stream used for the database activity stream.
-
#activity_stream_kms_key_id ⇒ String
The Amazon Web Services KMS key identifier used for encrypting messages in the database activity stream.
-
#activity_stream_mode ⇒ String
The mode of the database activity stream.
-
#activity_stream_status ⇒ String
The status of the database activity stream.
-
#allocated_storage ⇒ Integer
AllocatedStoragespecifies the allocated storage size in gibibytes (GiB). -
#associated_roles ⇒ Array<Types::DBClusterRole>
A list of the Amazon Web Services Identity and Access Management (IAM) roles that are associated with the DB cluster.
-
#auto_minor_version_upgrade ⇒ Boolean
Indicates whether minor version patches are applied automatically.
-
#automatic_restart_time ⇒ Time
The time when a stopped DB cluster is restarted automatically.
-
#availability_zones ⇒ Array<String>
The list of Availability Zones (AZs) where instances in the DB cluster can be created.
-
#aws_backup_recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) of the recovery point in Amazon Web Services Backup.
-
#backtrack_consumed_change_records ⇒ Integer
The number of change records stored for Backtrack.
-
#backtrack_window ⇒ Integer
The target backtrack window, in seconds.
-
#backup_retention_period ⇒ Integer
The number of days for which automatic DB snapshots are retained.
-
#capacity ⇒ Integer
The current capacity of an Aurora Serverless v1 DB cluster.
-
#certificate_details ⇒ Types::CertificateDetails
The details of the DB instance’s server certificate.
-
#character_set_name ⇒ String
If present, specifies the name of the character set that this cluster is associated with.
-
#clone_group_id ⇒ String
The ID of the clone group with which the DB cluster is associated.
-
#cluster_create_time ⇒ Time
The time when the DB cluster was created, in Universal Coordinated Time (UTC).
-
#cluster_scalability_type ⇒ String
The scalability mode of the Aurora DB cluster.
-
#copy_tags_to_snapshot ⇒ Boolean
Indicates whether tags are copied from the DB cluster to snapshots of the DB cluster.
-
#cross_account_clone ⇒ Boolean
Indicates whether the DB cluster is a clone of a DB cluster owned by a different Amazon Web Services account.
-
#custom_endpoints ⇒ Array<String>
The custom endpoints associated with the DB cluster.
-
#database_insights_mode ⇒ String
The mode of Database Insights that is enabled for the DB cluster.
-
#database_name ⇒ String
The name of the initial database that was specified for the DB cluster when it was created, if one was provided.
-
#db_cluster_arn ⇒ String
The Amazon Resource Name (ARN) for the DB cluster.
-
#db_cluster_instance_class ⇒ String
The name of the compute and memory capacity class of the DB instance.
-
#db_cluster_members ⇒ Array<Types::DBClusterMember>
The list of DB instances that make up the DB cluster.
-
#db_cluster_option_group_memberships ⇒ Array<Types::DBClusterOptionGroupStatus>
The list of option group memberships for this DB cluster.
-
#db_cluster_parameter_group ⇒ String
The name of the DB cluster parameter group for the DB cluster.
-
#db_cluster_resource_id ⇒ String
The Amazon Web Services Region-unique, immutable identifier for the DB cluster.
-
#db_subnet_group ⇒ String
Information about the subnet group associated with the DB cluster, including the name, description, and subnets in the subnet group.
-
#db_system_id ⇒ String
Reserved for future use.
-
#deletion_protection ⇒ Boolean
Indicates whether the DB cluster has deletion protection enabled.
-
#domain_memberships ⇒ Array<Types::DomainMembership>
The Active Directory Domain membership records associated with the DB cluster.
-
#earliest_backtrack_time ⇒ Time
The earliest time to which a DB cluster can be backtracked.
-
#earliest_restorable_time ⇒ Time
The earliest time to which a database can be restored with point-in-time restore.
-
#enabled_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that this DB cluster is configured to export to CloudWatch Logs.
-
#endpoint ⇒ String
The connection endpoint for the primary instance of the DB cluster.
-
#engine ⇒ String
The database engine used for this DB cluster.
-
#engine_lifecycle_support ⇒ String
The lifecycle type for the DB cluster.
-
#engine_mode ⇒ String
The DB engine mode of the DB cluster, either
provisionedorserverless. -
#engine_version ⇒ String
The version of the database engine.
-
#global_cluster_identifier ⇒ String
Contains a user-supplied global database cluster identifier.
-
#global_write_forwarding_requested ⇒ Boolean
Indicates whether write forwarding is enabled for a secondary cluster in an Aurora global database.
-
#global_write_forwarding_status ⇒ String
The status of write forwarding for a secondary cluster in an Aurora global database.
-
#hosted_zone_id ⇒ String
The ID that Amazon Route 53 assigns when you create a hosted zone.
-
#http_endpoint_enabled ⇒ Boolean
Indicates whether the HTTP endpoint is enabled for an Aurora DB cluster.
-
#iam_database_authentication_enabled ⇒ Boolean
Indicates whether the mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.
- #id ⇒ String (also: #db_cluster_identifier)
-
#internet_access_gateway_enabled ⇒ Boolean
Indicates whether the DB cluster has internet-based connectivity enabled through an internet access gateway.
-
#io_optimized_next_allowed_modification_time ⇒ Time
The next time you can modify the DB cluster to use the
aurora-iopt1storage type. -
#iops ⇒ Integer
The Provisioned IOPS (I/O operations per second) value.
-
#kms_key_id ⇒ String
If
StorageEncryptedis enabled, the Amazon Web Services KMS key identifier for the encrypted DB cluster. -
#latest_restorable_time ⇒ Time
The latest time to which a database can be restored with point-in-time restore.
-
#limitless_database ⇒ Types::LimitlessDatabase
The details for Aurora Limitless Database.
-
#local_write_forwarding_status ⇒ String
Indicates whether an Aurora DB cluster has in-cluster write forwarding enabled, not enabled, requested, or is in the process of enabling it.
-
#master_user_secret ⇒ Types::MasterUserSecret
The secret managed by RDS in Amazon Web Services Secrets Manager for the master user password.
-
#master_username ⇒ String
The master username for the DB cluster.
-
#monitoring_interval ⇒ Integer
The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the DB cluster.
-
#monitoring_role_arn ⇒ String
The ARN for the IAM role that permits RDS to send Enhanced Monitoring metrics to Amazon CloudWatch Logs.
-
#multi_az ⇒ Boolean
Indicates whether the DB cluster has instances in multiple Availability Zones.
-
#network_type ⇒ String
The network type of the DB instance.
-
#pending_modified_values ⇒ Types::ClusterPendingModifiedValues
Information about pending changes to the DB cluster.
-
#percent_progress ⇒ String
The progress of the operation as a percentage.
-
#performance_insights_enabled ⇒ Boolean
Indicates whether Performance Insights is enabled for the DB cluster.
-
#performance_insights_kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for encryption of Performance Insights data.
-
#performance_insights_retention_period ⇒ Integer
The number of days to retain Performance Insights data.
-
#port ⇒ Integer
The port that the database engine is listening on.
-
#preferred_backup_window ⇒ String
The daily time range during which automated backups are created if automated backups are enabled, as determined by the
BackupRetentionPeriod. -
#preferred_maintenance_window ⇒ String
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
-
#publicly_accessible ⇒ Boolean
Indicates whether the DB cluster is publicly accessible.
-
#rds_custom_cluster_configuration ⇒ Types::RdsCustomClusterConfiguration
Reserved for future use.
-
#read_replica_identifiers ⇒ Array<String>
Contains one or more identifiers of the read replicas associated with this DB cluster.
-
#reader_endpoint ⇒ String
The reader endpoint for the DB cluster.
-
#replication_source_identifier ⇒ String
The identifier of the source DB cluster if this DB cluster is a read replica.
-
#scaling_configuration_info ⇒ Types::ScalingConfigurationInfo
The scaling configuration for an Aurora DB cluster in
serverlessDB engine mode. -
#serverless_v2_platform_version ⇒ String
The version of the Aurora Serverless V2 platform used by the DB cluster.
-
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfigurationInfo
The scaling configuration for an Aurora Serverless v2 DB cluster.
-
#status ⇒ String
The current state of this DB cluster.
-
#status_infos ⇒ Array<Types::DBClusterStatusInfo>
Reserved for future use.
-
#storage_encrypted ⇒ Boolean
Indicates whether the DB cluster is encrypted.
-
#storage_encryption_type ⇒ String
The type of encryption used to protect data at rest in the DB cluster.
-
#storage_throughput ⇒ Integer
The storage throughput for the DB cluster.
-
#storage_type ⇒ String
The storage type associated with the DB cluster.
-
#tag_list ⇒ Array<Types::Tag>
A list of tags.
-
#upgrade_rollout_order ⇒ String
This data type represents the order in which the clusters are upgraded.
-
#vpc_networking_enabled ⇒ Boolean
Indicates whether the DB cluster uses VPC-based networking.
-
#vpc_security_groups ⇒ Array<Types::VpcSecurityGroupMembership>
The list of VPC security groups that the DB cluster belongs to.
Actions collapse
- #create(options = {}) ⇒ DBCluster
- #create_snapshot(options = {}) ⇒ DBClusterSnapshot
- #delete(options = {}) ⇒ DBCluster
- #failover(options = {}) ⇒ DBCluster
- #modify(options = {}) ⇒ DBCluster
- #restore(options = {}) ⇒ DBCluster
Associations collapse
- #events(options = {}) ⇒ Event::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
- #members ⇒ DBInstance::Collection
- #option_groups ⇒ OptionGroup::Collection
- #parameter_group ⇒ DBClusterParameterGroup?
- #snapshots(options = {}) ⇒ DBClusterSnapshot::Collection
- #subnet_group ⇒ DBSubnetGroup?
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::DBCluster
Returns the data for this DBCluster.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ DBCluster
constructor
A new instance of DBCluster.
- #load ⇒ self (also: #reload)
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(id, options = {}) ⇒ DBCluster #initialize(options = {}) ⇒ DBCluster
Returns a new instance of DBCluster.
13 14 15 |
# File 'sig/db_cluster.rbs', line 13
def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#activity_stream_kinesis_stream_name ⇒ String
The name of the Amazon Kinesis data stream used for the database activity stream.
199 |
# File 'sig/db_cluster.rbs', line 199
def activity_stream_kinesis_stream_name: () -> ::String
|
#activity_stream_kms_key_id ⇒ String
The Amazon Web Services KMS key identifier used for encrypting messages in the database activity stream.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
196 |
# File 'sig/db_cluster.rbs', line 196
def activity_stream_kms_key_id: () -> ::String
|
#activity_stream_mode ⇒ String
The mode of the database activity stream. Database events such as a change or access generate an activity stream event. The database session can handle these events either synchronously or asynchronously.
190 |
# File 'sig/db_cluster.rbs', line 190
def activity_stream_mode: () -> ("sync" | "async")
|
#activity_stream_status ⇒ String
The status of the database activity stream.
193 |
# File 'sig/db_cluster.rbs', line 193
def activity_stream_status: () -> ("stopped" | "starting" | "started" | "stopping")
|
#allocated_storage ⇒ Integer
AllocatedStorage specifies the allocated storage size in gibibytes
(GiB). For Aurora, AllocatedStorage can vary because Aurora DB
cluster storage size adjusts as needed.
22 |
# File 'sig/db_cluster.rbs', line 22
def allocated_storage: () -> ::Integer
|
#associated_roles ⇒ Array<Types::DBClusterRole>
A list of the Amazon Web Services Identity and Access Management (IAM) roles that are associated with the DB cluster. IAM roles that are associated with a DB cluster grant permission for the DB cluster to access other Amazon Web Services on your behalf.
124 |
# File 'sig/db_cluster.rbs', line 124
def associated_roles: () -> ::Array[Types::DBClusterRole]
|
#auto_minor_version_upgrade ⇒ Boolean
Indicates whether minor version patches are applied automatically.
This setting is for Aurora DB clusters and Multi-AZ DB clusters.
For more information about automatic minor version upgrades, see Automatically upgrading the minor engine version.
181 |
# File 'sig/db_cluster.rbs', line 181
def auto_minor_version_upgrade: () -> bool
|
#automatic_restart_time ⇒ Time
The time when a stopped DB cluster is restarted automatically.
226 |
# File 'sig/db_cluster.rbs', line 226
def automatic_restart_time: () -> ::Time
|
#availability_zones ⇒ Array<String>
The list of Availability Zones (AZs) where instances in the DB cluster can be created.
25 |
# File 'sig/db_cluster.rbs', line 25
def availability_zones: () -> ::Array[::String]
|
#aws_backup_recovery_point_arn ⇒ String
The Amazon Resource Name (ARN) of the recovery point in Amazon Web Services Backup.
262 |
# File 'sig/db_cluster.rbs', line 262
def aws_backup_recovery_point_arn: () -> ::String
|
#backtrack_consumed_change_records ⇒ Integer
The number of change records stored for Backtrack.
142 |
# File 'sig/db_cluster.rbs', line 142
def backtrack_consumed_change_records: () -> ::Integer
|
#backtrack_window ⇒ Integer
The target backtrack window, in seconds. If this value is set to 0,
backtracking is disabled for the DB cluster. Otherwise, backtracking
is enabled.
139 |
# File 'sig/db_cluster.rbs', line 139
def backtrack_window: () -> ::Integer
|
#backup_retention_period ⇒ Integer
The number of days for which automatic DB snapshots are retained.
28 |
# File 'sig/db_cluster.rbs', line 28
def backup_retention_period: () -> ::Integer
|
#capacity ⇒ Integer
The current capacity of an Aurora Serverless v1 DB cluster. The
capacity is 0 (zero) when the cluster is paused.
For more information about Aurora Serverless v1, see Using Amazon Aurora Serverless v1 in the Amazon Aurora User Guide.
148 |
# File 'sig/db_cluster.rbs', line 148
def capacity: () -> ::Integer
|
#certificate_details ⇒ Types::CertificateDetails
The details of the DB instance’s server certificate.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.
271 |
# File 'sig/db_cluster.rbs', line 271
def certificate_details: () -> Types::CertificateDetails
|
#character_set_name ⇒ String
If present, specifies the name of the character set that this cluster is associated with.
31 |
# File 'sig/db_cluster.rbs', line 31
def character_set_name: () -> ::String
|
#clone_group_id ⇒ String
The ID of the clone group with which the DB cluster is associated. For newly created clusters, the ID is typically null.
If you clone a DB cluster when the ID is null, the operation populates the ID value for the source cluster and the clone because both clusters become part of the same clone group. Even if you delete the clone cluster, the clone group ID remains for the lifetime of the source cluster to show that it was used in a cloning operation.
For PITR, the clone group ID is inherited from the source cluster. For snapshot restore operations, the clone group ID isn't inherited from the source cluster.
130 |
# File 'sig/db_cluster.rbs', line 130
def clone_group_id: () -> ::String
|
#cluster_create_time ⇒ Time
The time when the DB cluster was created, in Universal Coordinated Time (UTC).
133 |
# File 'sig/db_cluster.rbs', line 133
def cluster_create_time: () -> ::Time
|
#cluster_scalability_type ⇒ String
The scalability mode of the Aurora DB cluster. When set to
limitless, the cluster operates as an Aurora Limitless Database.
When set to standard (the default), the cluster uses normal DB
instance creation.
268 |
# File 'sig/db_cluster.rbs', line 268
def cluster_scalability_type: () -> ("standard" | "limitless")
|
#copy_tags_to_snapshot ⇒ Boolean
Indicates whether tags are copied from the DB cluster to snapshots of the DB cluster.
202 |
# File 'sig/db_cluster.rbs', line 202
def copy_tags_to_snapshot: () -> bool
|
#create_snapshot(options = {}) ⇒ DBClusterSnapshot
390 |
# File 'sig/db_cluster.rbs', line 390
def create_snapshot: (
|
#cross_account_clone ⇒ Boolean
Indicates whether the DB cluster is a clone of a DB cluster owned by a different Amazon Web Services account.
205 |
# File 'sig/db_cluster.rbs', line 205
def cross_account_clone: () -> bool
|
#custom_endpoints ⇒ Array<String>
The custom endpoints associated with the DB cluster.
58 |
# File 'sig/db_cluster.rbs', line 58
def custom_endpoints: () -> ::Array[::String]
|
#data ⇒ Types::DBCluster
Returns the data for this Aws::RDS::DBCluster. Calls
Client#describe_db_clusters if #data_loaded? is false.
289 |
# File 'sig/db_cluster.rbs', line 289
def data: () -> Types::DBCluster
|
#data_loaded? ⇒ Boolean
292 |
# File 'sig/db_cluster.rbs', line 292
def data_loaded?: () -> bool
|
#database_insights_mode ⇒ String
The mode of Database Insights that is enabled for the DB cluster.
241 |
# File 'sig/db_cluster.rbs', line 241
def database_insights_mode: () -> ("standard" | "advanced")
|
#database_name ⇒ String
The name of the initial database that was specified for the DB cluster when it was created, if one was provided. This same name is returned for the life of the DB cluster.
34 |
# File 'sig/db_cluster.rbs', line 34
def database_name: () -> ::String
|
#db_cluster_arn ⇒ String
The Amazon Resource Name (ARN) for the DB cluster.
121 |
# File 'sig/db_cluster.rbs', line 121
def db_cluster_arn: () -> ::String
|
#db_cluster_instance_class ⇒ String
The name of the compute and memory capacity class of the DB instance.
This setting is only for non-Aurora Multi-AZ DB clusters.
163 |
# File 'sig/db_cluster.rbs', line 163
def db_cluster_instance_class: () -> ::String
|
#db_cluster_members ⇒ Array<Types::DBClusterMember>
The list of DB instances that make up the DB cluster.
100 |
# File 'sig/db_cluster.rbs', line 100
def db_cluster_members: () -> ::Array[Types::DBClusterMember]
|
#db_cluster_option_group_memberships ⇒ Array<Types::DBClusterOptionGroupStatus>
The list of option group memberships for this DB cluster.
79 |
# File 'sig/db_cluster.rbs', line 79
def db_cluster_option_group_memberships: () -> ::Array[Types::DBClusterOptionGroupStatus]
|
#db_cluster_parameter_group ⇒ String
The name of the DB cluster parameter group for the DB cluster.
37 |
# File 'sig/db_cluster.rbs', line 37
def db_cluster_parameter_group: () -> ::String
|
#db_cluster_resource_id ⇒ String
The Amazon Web Services Region-unique, immutable identifier for the DB cluster. This identifier is found in Amazon Web Services CloudTrail log entries whenever the KMS key for the DB cluster is accessed.
118 |
# File 'sig/db_cluster.rbs', line 118
def db_cluster_resource_id: () -> ::String
|
#db_subnet_group ⇒ String
Information about the subnet group associated with the DB cluster, including the name, description, and subnets in the subnet group.
40 |
# File 'sig/db_cluster.rbs', line 40
def db_subnet_group: () -> ::String
|
#db_system_id ⇒ String
Reserved for future use.
253 |
# File 'sig/db_cluster.rbs', line 253
def db_system_id: () -> ::String
|
#deletion_protection ⇒ Boolean
Indicates whether the DB cluster has deletion protection enabled. The database can't be deleted when deletion protection is enabled.
184 |
# File 'sig/db_cluster.rbs', line 184
def deletion_protection: () -> bool
|
#domain_memberships ⇒ Array<Types::DomainMembership>
The Active Directory Domain membership records associated with the DB cluster.
208 |
# File 'sig/db_cluster.rbs', line 208
def domain_memberships: () -> ::Array[Types::DomainMembership]
|
#earliest_backtrack_time ⇒ Time
The earliest time to which a DB cluster can be backtracked.
136 |
# File 'sig/db_cluster.rbs', line 136
def earliest_backtrack_time: () -> ::Time
|
#earliest_restorable_time ⇒ Time
The earliest time to which a database can be restored with point-in-time restore.
49 |
# File 'sig/db_cluster.rbs', line 49
def earliest_restorable_time: () -> ::Time
|
#enabled_cloudwatch_logs_exports ⇒ Array<String>
A list of log types that this DB cluster is configured to export to CloudWatch Logs.
Log types vary by DB engine. For information about the log types for each DB engine, see Amazon RDS Database Log Files in the Amazon Aurora User Guide.
145 |
# File 'sig/db_cluster.rbs', line 145
def enabled_cloudwatch_logs_exports: () -> ::Array[::String]
|
#endpoint ⇒ String
The connection endpoint for the primary instance of the DB cluster.
52 |
# File 'sig/db_cluster.rbs', line 52
def endpoint: () -> ::String
|
#engine ⇒ String
The database engine used for this DB cluster.
64 |
# File 'sig/db_cluster.rbs', line 64
def engine: () -> ::String
|
#engine_lifecycle_support ⇒ String
The lifecycle type for the DB cluster.
For more information, see CreateDBCluster.
274 |
# File 'sig/db_cluster.rbs', line 274
def engine_lifecycle_support: () -> ::String
|
#engine_mode ⇒ String
The DB engine mode of the DB cluster, either provisioned or
serverless.
For more information, see CreateDBCluster.
154 |
# File 'sig/db_cluster.rbs', line 154
def engine_mode: () -> ::String
|
#engine_version ⇒ String
The version of the database engine.
67 |
# File 'sig/db_cluster.rbs', line 67
def engine_version: () -> ::String
|
#global_cluster_identifier ⇒ String
Contains a user-supplied global database cluster identifier. This identifier is the unique key that identifies a global database cluster.
214 |
# File 'sig/db_cluster.rbs', line 214
def global_cluster_identifier: () -> ::String
|
#global_write_forwarding_requested ⇒ Boolean
Indicates whether write forwarding is enabled for a secondary cluster
in an Aurora global database. Because write forwarding takes time to
enable, check the value of GlobalWriteForwardingStatus to confirm
that the request has completed before using the write forwarding
feature for this cluster.
220 |
# File 'sig/db_cluster.rbs', line 220
def global_write_forwarding_requested: () -> bool
|
#global_write_forwarding_status ⇒ String
The status of write forwarding for a secondary cluster in an Aurora global database.
217 |
# File 'sig/db_cluster.rbs', line 217
def global_write_forwarding_status: () -> ("enabled" | "disabled" | "enabling" | "disabling" | "unknown")
|
#hosted_zone_id ⇒ String
The ID that Amazon Route 53 assigns when you create a hosted zone.
106 |
# File 'sig/db_cluster.rbs', line 106
def hosted_zone_id: () -> ::String
|
#http_endpoint_enabled ⇒ Boolean
Indicates whether the HTTP endpoint is enabled for an Aurora DB cluster.
When enabled, the HTTP endpoint provides a connectionless web service API (RDS Data API) for running SQL queries on the DB cluster. You can also query your database from inside the RDS console with the RDS query editor.
For more information, see Using RDS Data API in the Amazon Aurora User Guide.
187 |
# File 'sig/db_cluster.rbs', line 187
def http_endpoint_enabled: () -> bool
|
#iam_database_authentication_enabled ⇒ Boolean
Indicates whether the mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.
127 |
# File 'sig/db_cluster.rbs', line 127
def iam_database_authentication_enabled: () -> bool
|
#id ⇒ String Also known as: db_cluster_identifier
18 |
# File 'sig/db_cluster.rbs', line 18
def id: () -> String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3677 3678 3679 |
# File 'lib/aws-sdk-rds/db_cluster.rb', line 3677 def identifiers { id: @id } end |
#internet_access_gateway_enabled ⇒ Boolean
Indicates whether the DB cluster has internet-based connectivity enabled through an internet access gateway.
This setting is applicable only for Aurora PostgreSQL clusters created through express configuration.
280 |
# File 'sig/db_cluster.rbs', line 280
def internet_access_gateway_enabled: () -> bool
|
#io_optimized_next_allowed_modification_time ⇒ Time
The next time you can modify the DB cluster to use the aurora-iopt1
storage type.
This setting is only for Aurora DB clusters.
175 |
# File 'sig/db_cluster.rbs', line 175
def io_optimized_next_allowed_modification_time: () -> ::Time
|
#iops ⇒ Integer
The Provisioned IOPS (I/O operations per second) value.
This setting is only for non-Aurora Multi-AZ DB clusters.
169 |
# File 'sig/db_cluster.rbs', line 169
def iops: () -> ::Integer
|
#kms_key_id ⇒ String
If StorageEncrypted is enabled, the Amazon Web Services KMS key
identifier for the encrypted DB cluster.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
115 |
# File 'sig/db_cluster.rbs', line 115
def kms_key_id: () -> ::String
|
#latest_restorable_time ⇒ Time
The latest time to which a database can be restored with point-in-time restore.
70 |
# File 'sig/db_cluster.rbs', line 70
def latest_restorable_time: () -> ::Time
|
#limitless_database ⇒ Types::LimitlessDatabase
The details for Aurora Limitless Database.
265 |
# File 'sig/db_cluster.rbs', line 265
def limitless_database: () -> Types::LimitlessDatabase
|
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::RDS::DBCluster.
Returns self making it possible to chain methods.
db_cluster.reload.data
285 |
# File 'sig/db_cluster.rbs', line 285
def load: () -> self
|
#local_write_forwarding_status ⇒ String
Indicates whether an Aurora DB cluster has in-cluster write forwarding enabled, not enabled, requested, or is in the process of enabling it.
259 |
# File 'sig/db_cluster.rbs', line 259
def local_write_forwarding_status: () -> ("enabled" | "disabled" | "enabling" | "disabling" | "requested")
|
#master_user_secret ⇒ Types::MasterUserSecret
The secret managed by RDS in Amazon Web Services Secrets Manager for the master user password.
For more information, see Password management with Amazon Web Services Secrets Manager in the Amazon RDS User Guide and Password management with Amazon Web Services Secrets Manager in the Amazon Aurora User Guide.
256 |
# File 'sig/db_cluster.rbs', line 256
def master_user_secret: () -> Types::MasterUserSecret
|
#master_username ⇒ String
The master username for the DB cluster.
76 |
# File 'sig/db_cluster.rbs', line 76
def master_username: () -> ::String
|
#members ⇒ DBInstance::Collection
570 |
# File 'sig/db_cluster.rbs', line 570
def members: () -> DBInstance::Collection
|
#monitoring_interval ⇒ Integer
The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the DB cluster.
This setting is only for -Aurora DB clusters and Multi-AZ DB clusters.
235 |
# File 'sig/db_cluster.rbs', line 235
def monitoring_interval: () -> ::Integer
|
#monitoring_role_arn ⇒ String
The ARN for the IAM role that permits RDS to send Enhanced Monitoring metrics to Amazon CloudWatch Logs.
This setting is only for Aurora DB clusters and Multi-AZ DB clusters.
238 |
# File 'sig/db_cluster.rbs', line 238
def monitoring_role_arn: () -> ::String
|
#multi_az ⇒ Boolean
Indicates whether the DB cluster has instances in multiple Availability Zones.
61 |
# File 'sig/db_cluster.rbs', line 61
def multi_az: () -> bool
|
#network_type ⇒ String
The network type of the DB instance.
The network type is determined by the DBSubnetGroup specified for
the DB cluster. A DBSubnetGroup can support only the IPv4 protocol
or the IPv4 and the IPv6 protocols (DUAL).
For more information, see Working with a DB instance in a VPC in the Amazon Aurora User Guide.
This setting is only for Aurora DB clusters.
Valid Values: IPV4 | DUAL
223 |
# File 'sig/db_cluster.rbs', line 223
def network_type: () -> ::String
|
#option_groups ⇒ OptionGroup::Collection
573 |
# File 'sig/db_cluster.rbs', line 573
def option_groups: () -> OptionGroup::Collection
|
#parameter_group ⇒ DBClusterParameterGroup?
576 |
# File 'sig/db_cluster.rbs', line 576
def parameter_group: () -> DBClusterParameterGroup?
|
#pending_modified_values ⇒ Types::ClusterPendingModifiedValues
Information about pending changes to the DB cluster. This information is returned only when there are pending changes. Specific changes are identified by subelements.
151 |
# File 'sig/db_cluster.rbs', line 151
def pending_modified_values: () -> Types::ClusterPendingModifiedValues
|
#percent_progress ⇒ String
The progress of the operation as a percentage.
46 |
# File 'sig/db_cluster.rbs', line 46
def percent_progress: () -> ::String
|
#performance_insights_enabled ⇒ Boolean
Indicates whether Performance Insights is enabled for the DB cluster.
This setting is only for Aurora DB clusters and Multi-AZ DB clusters.
244 |
# File 'sig/db_cluster.rbs', line 244
def performance_insights_enabled: () -> bool
|
#performance_insights_kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for encryption of Performance Insights data.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
This setting is only for Aurora DB clusters and Multi-AZ DB clusters.
247 |
# File 'sig/db_cluster.rbs', line 247
def performance_insights_kms_key_id: () -> ::String
|
#performance_insights_retention_period ⇒ Integer
The number of days to retain Performance Insights data.
This setting is only for Aurora DB clusters and Multi-AZ DB clusters.
Valid Values:
-
7 -
month * 31, where month is a number of months from 1-23. Examples:
93(3 months * 31),341(11 months * 31),589(19 months * 31) -
731
Default: 7 days
250 |
# File 'sig/db_cluster.rbs', line 250
def performance_insights_retention_period: () -> ::Integer
|
#port ⇒ Integer
The port that the database engine is listening on.
73 |
# File 'sig/db_cluster.rbs', line 73
def port: () -> ::Integer
|
#preferred_backup_window ⇒ String
The daily time range during which automated backups are created if
automated backups are enabled, as determined by the
BackupRetentionPeriod.
82 |
# File 'sig/db_cluster.rbs', line 82
def preferred_backup_window: () -> ::String
|
#preferred_maintenance_window ⇒ String
The weekly time range during which system maintenance can occur, in Universal Coordinated Time (UTC).
85 |
# File 'sig/db_cluster.rbs', line 85
def preferred_maintenance_window: () -> ::String
|
#publicly_accessible ⇒ Boolean
Indicates whether the DB cluster is publicly accessible.
When the DB cluster is publicly accessible and you connect from outside of the DB cluster's virtual private cloud (VPC), its Domain Name System (DNS) endpoint resolves to the public IP address. When you connect from within the same VPC as the DB cluster, the endpoint resolves to the private IP address. Access to the DB cluster is ultimately controlled by the security group it uses. That public access isn't permitted if the security group assigned to the DB cluster doesn't permit it.
When the DB cluster isn't publicly accessible, it is an internal DB cluster with a DNS name that resolves to a private IP address.
For more information, see CreateDBCluster.
This setting is only for non-Aurora Multi-AZ DB clusters.
178 |
# File 'sig/db_cluster.rbs', line 178
def publicly_accessible: () -> bool
|
#rds_custom_cluster_configuration ⇒ Types::RdsCustomClusterConfiguration
Reserved for future use.
160 |
# File 'sig/db_cluster.rbs', line 160
def rds_custom_cluster_configuration: () -> Types::RdsCustomClusterConfiguration
|
#read_replica_identifiers ⇒ Array<String>
Contains one or more identifiers of the read replicas associated with this DB cluster.
94 |
# File 'sig/db_cluster.rbs', line 94
def read_replica_identifiers: () -> ::Array[::String]
|
#reader_endpoint ⇒ String
The reader endpoint for the DB cluster. The reader endpoint for a DB cluster load-balances connections across the Aurora Replicas that are available in a DB cluster. As clients request new connections to the reader endpoint, Aurora distributes the connection requests among the Aurora Replicas in the DB cluster. This functionality can help balance your read workload across multiple Aurora Replicas in your DB cluster.
If a failover occurs, and the Aurora Replica that you are connected to is promoted to be the primary instance, your connection is dropped. To continue sending your read workload to other Aurora Replicas in the cluster, you can then reconnect to the reader endpoint.
55 |
# File 'sig/db_cluster.rbs', line 55
def reader_endpoint: () -> ::String
|
#replication_source_identifier ⇒ String
The identifier of the source DB cluster if this DB cluster is a read replica.
91 |
# File 'sig/db_cluster.rbs', line 91
def replication_source_identifier: () -> ::String
|
#scaling_configuration_info ⇒ Types::ScalingConfigurationInfo
The scaling configuration for an Aurora DB cluster in serverless DB
engine mode.
For more information, see Using Amazon Aurora Serverless v1 in the Amazon Aurora User Guide.
157 |
# File 'sig/db_cluster.rbs', line 157
def scaling_configuration_info: () -> Types::ScalingConfigurationInfo
|
#serverless_v2_platform_version ⇒ String
The version of the Aurora Serverless V2 platform used by the DB cluster. For more information, see Using Aurora Serverless v2 in the Amazon Aurora User Guide.
232 |
# File 'sig/db_cluster.rbs', line 232
def serverless_v2_platform_version: () -> ::String
|
#serverless_v2_scaling_configuration ⇒ Types::ServerlessV2ScalingConfigurationInfo
The scaling configuration for an Aurora Serverless v2 DB cluster.
For more information, see Using Amazon Aurora Serverless v2 in the Amazon Aurora User Guide.
229 |
# File 'sig/db_cluster.rbs', line 229
def serverless_v2_scaling_configuration: () -> Types::ServerlessV2ScalingConfigurationInfo
|
#snapshots(options = {}) ⇒ DBClusterSnapshot::Collection
579 |
# File 'sig/db_cluster.rbs', line 579
def snapshots: (
|
#status ⇒ String
The current state of this DB cluster.
43 |
# File 'sig/db_cluster.rbs', line 43
def status: () -> ::String
|
#status_infos ⇒ Array<Types::DBClusterStatusInfo>
Reserved for future use.
97 |
# File 'sig/db_cluster.rbs', line 97
def status_infos: () -> ::Array[Types::DBClusterStatusInfo]
|
#storage_encrypted ⇒ Boolean
Indicates whether the DB cluster is encrypted.
109 |
# File 'sig/db_cluster.rbs', line 109
def storage_encrypted: () -> bool
|
#storage_encryption_type ⇒ String
The type of encryption used to protect data at rest in the DB cluster. Possible values:
-
none- The DB cluster is not encrypted. -
sse-rds- The DB cluster is encrypted using an Amazon Web Services owned KMS key. -
sse-kms- The DB cluster is encrypted using a customer managed KMS key or Amazon Web Services managed KMS key.
112 |
# File 'sig/db_cluster.rbs', line 112
def storage_encryption_type: () -> ("none" | "sse-kms" | "sse-rds")
|
#storage_throughput ⇒ Integer
The storage throughput for the DB cluster. The throughput is automatically set based on the IOPS that you provision, and is not configurable.
This setting is only for non-Aurora Multi-AZ DB clusters.
172 |
# File 'sig/db_cluster.rbs', line 172
def storage_throughput: () -> ::Integer
|
#storage_type ⇒ String
The storage type associated with the DB cluster.
166 |
# File 'sig/db_cluster.rbs', line 166
def storage_type: () -> ::String
|
#subnet_group ⇒ DBSubnetGroup?
595 |
# File 'sig/db_cluster.rbs', line 595
def subnet_group: () -> DBSubnetGroup?
|
#tag_list ⇒ Array<Types::Tag>
A list of tags.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.
211 |
# File 'sig/db_cluster.rbs', line 211
def tag_list: () -> ::Array[Types::Tag]
|
#upgrade_rollout_order ⇒ String
This data type represents the order in which the clusters are upgraded.
-
[first] - Typically used for development or testing environments.
-
[second] - Default order for resources not specifically configured.
-
[last] - Usually reserved for production environments.
88 |
# File 'sig/db_cluster.rbs', line 88
def upgrade_rollout_order: () -> ("first" | "second" | "last")
|
#vpc_networking_enabled ⇒ Boolean
Indicates whether the DB cluster uses VPC-based networking.
This setting is applicable only for Aurora PostgreSQL clusters created through express configuration.
277 |
# File 'sig/db_cluster.rbs', line 277
def vpc_networking_enabled: () -> bool
|
#vpc_security_groups ⇒ Array<Types::VpcSecurityGroupMembership>
The list of VPC security groups that the DB cluster belongs to.
103 |
# File 'sig/db_cluster.rbs', line 103
def vpc_security_groups: () -> ::Array[Types::VpcSecurityGroupMembership]
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
945 946 947 948 949 950 951 952 953 954 955 956 957 958 959 960 961 962 |
# File 'lib/aws-sdk-rds/db_cluster.rb', line 945 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |