Class: Aws::RDS::DBClusterParameterGroup

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/db_cluster_parameter_group.rbs,
lib/aws-sdk-rds/db_cluster_parameter_group.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ DBClusterParameterGroup #initialize(options = {}) ⇒ DBClusterParameterGroup

Returns a new instance of DBClusterParameterGroup.

Overloads:



13
14
15
# File 'sig/db_cluster_parameter_group.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



61
# File 'lib/aws-sdk-rds/db_cluster_parameter_group.rb', line 61

def client: () -> Client

#create(options = {}) ⇒ DBClusterParameterGroup

Examples:

Request syntax with placeholder values


dbclusterparametergroup = db_cluster_parameter_group.create({
  db_parameter_group_family: "String", # required
  description: "String", # required
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :db_parameter_group_family (required, String)

    The DB cluster parameter group family name. A DB cluster parameter group can be associated with one and only one DB cluster parameter group family, and can be applied only to a DB cluster running a database engine and engine version compatible with that DB cluster parameter group family.

    Aurora MySQL

    Example: aurora-mysql5.7, aurora-mysql8.0

    Aurora PostgreSQL

    Example: aurora-postgresql14

    RDS for MySQL

    Example: mysql8.0

    RDS for PostgreSQL

    Example: postgres13

    To list all of the available parameter group families for a DB engine, use the following command:

    aws rds describe-db-engine-versions --query "DBEngineVersions[].DBParameterGroupFamily" --engine <engine>

    For example, to list all of the available parameter group families for the Aurora PostgreSQL DB engine, use the following command:

    aws rds describe-db-engine-versions --query "DBEngineVersions[].DBParameterGroupFamily" --engine aurora-postgresql

    The output contains duplicates.

    The following are the valid DB engine values:

    • aurora-mysql

    • aurora-postgresql

    • mysql

    • postgres

  • :description (required, String)

    The description for the DB cluster parameter group.

  • :tags (Array<Types::Tag>)

    Tags to assign to the DB cluster parameter group.

Returns:



44
# File 'sig/db_cluster_parameter_group.rbs', line 44

def create: (

#dataTypes::DBClusterParameterGroup



37
# File 'sig/db_cluster_parameter_group.rbs', line 37

def data: () -> Types::DBClusterParameterGroup

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



40
# File 'sig/db_cluster_parameter_group.rbs', line 40

def data_loaded?: () -> bool

#db_cluster_parameter_group_arnString

The Amazon Resource Name (ARN) for the DB cluster parameter group.

Returns:

  • (String)


28
# File 'sig/db_cluster_parameter_group.rbs', line 28

def db_cluster_parameter_group_arn: () -> ::String

#db_parameter_group_familyString

The name of the DB parameter group family that this DB cluster parameter group is compatible with.

Returns:

  • (String)


22
# File 'sig/db_cluster_parameter_group.rbs', line 22

def db_parameter_group_family: () -> ::String

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


db_cluster_parameter_group.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


57
# File 'sig/db_cluster_parameter_group.rbs', line 57

def delete: (

#descriptionString

Provides the customer-specified description for this DB cluster parameter group.

Returns:

  • (String)


25
# File 'sig/db_cluster_parameter_group.rbs', line 25

def description: () -> ::String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


381
382
383
# File 'lib/aws-sdk-rds/db_cluster_parameter_group.rb', line 381

def identifiers
  { name: @name }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::RDS::DBClusterParameterGroup. Returns self making it possible to chain methods.

db_cluster_parameter_group.reload.data

Returns:

  • (self)


33
# File 'sig/db_cluster_parameter_group.rbs', line 33

def load: () -> self

#modify(options = {}) ⇒ DBClusterParameterGroup

Examples:

Request syntax with placeholder values


dbclusterparametergroup = db_cluster_parameter_group.modify({
  parameters: [ # required
    {
      parameter_name: "String",
      parameter_value: "PotentiallySensitiveParameterValue",
      description: "String",
      source: "String",
      apply_type: "String",
      data_type: "String",
      allowed_values: "String",
      is_modifiable: false,
      minimum_engine_version: "String",
      apply_method: "immediate", # accepts immediate, pending-reboot
      supported_engine_modes: ["String"],
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :parameters (required, Array<Types::Parameter>)

    A list of parameters in the DB cluster parameter group to modify.

    Valid Values (for the application method): immediate | pending-reboot

    You can use the immediate value with dynamic parameters only. You can use the pending-reboot value for both dynamic and static parameters.

    When the application method is immediate, changes to dynamic parameters are applied immediately to the DB clusters associated with the parameter group. When the application method is pending-reboot, changes to dynamic and static parameters are applied after a reboot without failover to the DB clusters associated with the parameter group.

Returns:



62
# File 'sig/db_cluster_parameter_group.rbs', line 62

def modify: (

#nameString Also known as: db_cluster_parameter_group_name

Returns:

  • (String)


18
# File 'sig/db_cluster_parameter_group.rbs', line 18

def name: () -> String

#reset(options = {}) ⇒ DBClusterParameterGroup

Examples:

Request syntax with placeholder values


dbclusterparametergroup = db_cluster_parameter_group.reset({
  reset_all_parameters: false,
  parameters: [
    {
      parameter_name: "String",
      parameter_value: "PotentiallySensitiveParameterValue",
      description: "String",
      source: "String",
      apply_type: "String",
      data_type: "String",
      allowed_values: "String",
      is_modifiable: false,
      minimum_engine_version: "String",
      apply_method: "immediate", # accepts immediate, pending-reboot
      supported_engine_modes: ["String"],
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :reset_all_parameters (Boolean)

    Specifies whether to reset all parameters in the DB cluster parameter group to their default values. You can't use this parameter if there is a list of parameter names specified for the Parameters parameter.

  • :parameters (Array<Types::Parameter>)

    A list of parameter names in the DB cluster parameter group to reset to the default values. You can't use this parameter if the ResetAllParameters parameter is enabled.

Returns:



82
# File 'sig/db_cluster_parameter_group.rbs', line 82

def reset: (

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/aws-sdk-rds/db_cluster_parameter_group.rb', line 175

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end