Class: Aws::RDS::DBClusterSnapshot

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/db_cluster_snapshot.rbs,
lib/aws-sdk-rds/db_cluster_snapshot.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(cluster_id, snapshot_id, options = {}) ⇒ DBClusterSnapshot #initialize(options = {}) ⇒ DBClusterSnapshot

Returns a new instance of DBClusterSnapshot.

Overloads:

  • #initialize(cluster_id, snapshot_id, options = {}) ⇒ DBClusterSnapshot

    Parameters:

    • cluster_id (String)
    • snapshot_id (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ DBClusterSnapshot

    Options Hash (options):

    • :cluster_id (required, String)
    • :snapshot_id (required, String)
    • :client (Client)


13
14
15
# File 'sig/db_cluster_snapshot.rbs', line 13

def initialize: (String cluster_id, String snapshot_id, Hash[Symbol, untyped] options) -> void
| (cluster_id: String, snapshot_id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#allocated_storageInteger

The allocated storage size of the DB cluster snapshot in gibibytes (GiB).

Returns:

  • (Integer)


38
# File 'sig/db_cluster_snapshot.rbs', line 38

def allocated_storage: () -> ::Integer

#availability_zonesArray<String>

The list of Availability Zones (AZs) where instances in the DB cluster snapshot can be restored.

Returns:

  • (Array<String>)


26
# File 'sig/db_cluster_snapshot.rbs', line 26

def availability_zones: () -> ::Array[::String]

#backup_retention_periodInteger

The number of days for which automatic DB snapshots are retained.

Returns:

  • (Integer)


74
# File 'sig/db_cluster_snapshot.rbs', line 74

def backup_retention_period: () -> ::Integer

#clientClient

Returns:



258
# File 'lib/aws-sdk-rds/db_cluster_snapshot.rb', line 258

def client: () -> Client

#clusterDBCluster

Returns:



226
# File 'sig/db_cluster_snapshot.rbs', line 226

def cluster: () -> DBCluster

#cluster_create_timeTime

The time when the DB cluster was created, in Universal Coordinated Time (UTC).

Returns:

  • (Time)


50
# File 'sig/db_cluster_snapshot.rbs', line 50

def cluster_create_time: () -> ::Time

#cluster_idString Also known as: db_cluster_identifier

Returns:

  • (String)


18
# File 'sig/db_cluster_snapshot.rbs', line 18

def cluster_id: () -> String

#copy(options = {}) ⇒ DBClusterSnapshot

Examples:

Request syntax with placeholder values


dbclustersnapshot = db_cluster_snapshot.copy({
  target_db_cluster_snapshot_identifier: "String", # required
  kms_key_id: "String",
  pre_signed_url: "SensitiveString",
  copy_tags: false,
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
  source_region: "String",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :target_db_cluster_snapshot_identifier (required, String)

    The identifier of the new DB cluster snapshot to create from the source DB cluster snapshot. This parameter isn't case-sensitive.

    Constraints:

    • Must contain from 1 to 63 letters, numbers, or hyphens.

    • First character must be a letter.

    • Can't end with a hyphen or contain two consecutive hyphens.

    Example: my-cluster-snapshot2

  • :kms_key_id (String)

    The Amazon Web Services KMS key identifier for an encrypted DB cluster snapshot. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the Amazon Web Services KMS key.

    If you copy an encrypted DB cluster snapshot from your Amazon Web Services account, you can specify a value for KmsKeyId to encrypt the copy with a new KMS key. If you don't specify a value for KmsKeyId, then the copy of the DB cluster snapshot is encrypted with the same KMS key as the source DB cluster snapshot.

    If you copy an encrypted DB cluster snapshot that is shared from another Amazon Web Services account, then you must specify a value for KmsKeyId.

    To copy an encrypted DB cluster snapshot to another Amazon Web Services Region, you must set KmsKeyId to the Amazon Web Services KMS key identifier you want to use to encrypt the copy of the DB cluster snapshot in the destination Amazon Web Services Region. KMS keys are specific to the Amazon Web Services Region that they are created in, and you can't use KMS keys from one Amazon Web Services Region in another Amazon Web Services Region.

    If you copy an unencrypted DB cluster snapshot and specify a value for the KmsKeyId parameter, an error is returned.

  • :pre_signed_url (String)

    When you are copying a DB cluster snapshot from one Amazon Web Services GovCloud (US) Region to another, the URL that contains a Signature Version 4 signed request for the CopyDBClusterSnapshot API operation in the Amazon Web Services Region that contains the source DB cluster snapshot to copy. Use the PreSignedUrl parameter when copying an encrypted DB cluster snapshot from another Amazon Web Services Region. Don't specify PreSignedUrl when copying an encrypted DB cluster snapshot in the same Amazon Web Services Region.

    This setting applies only to Amazon Web Services GovCloud (US) Regions. It's ignored in other Amazon Web Services Regions.

    The presigned URL must be a valid request for the CopyDBClusterSnapshot API operation that can run in the source Amazon Web Services Region that contains the encrypted DB cluster snapshot to copy. The presigned URL request must contain the following parameter values:

    • KmsKeyId - The KMS key identifier for the KMS key to use to encrypt the copy of the DB cluster snapshot in the destination Amazon Web Services Region. This is the same identifier for both the CopyDBClusterSnapshot operation that is called in the destination Amazon Web Services Region, and the operation contained in the presigned URL.

    • DestinationRegion - The name of the Amazon Web Services Region that the DB cluster snapshot is to be created in.

    • SourceDBClusterSnapshotIdentifier - The DB cluster snapshot identifier for the encrypted DB cluster snapshot to be copied. This identifier must be in the Amazon Resource Name (ARN) format for the source Amazon Web Services Region. For example, if you are copying an encrypted DB cluster snapshot from the us-west-2 Amazon Web Services Region, then your SourceDBClusterSnapshotIdentifier looks like the following example: arn:aws:rds:us-west-2:123456789012:cluster-snapshot:aurora-cluster1-snapshot-20161115.

    To learn how to generate a Signature Version 4 signed request, see Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) and Signature Version 4 Signing Process.

    If you are using an Amazon Web Services SDK tool or the CLI, you can specify SourceRegion (or --source-region for the CLI) instead of specifying PreSignedUrl manually. Specifying SourceRegion autogenerates a presigned URL that is a valid request for the operation that can run in the source Amazon Web Services Region.

  • :copy_tags (Boolean)

    Specifies whether to copy all tags from the source DB cluster snapshot to the target DB cluster snapshot. By default, tags are not copied.

  • :tags (Array<Types::Tag>)

    A list of tags.

    For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.

  • :source_region (String)

    The source region of the snapshot. This is only needed when the shapshot is encrypted and in a different region.

Returns:



131
# File 'sig/db_cluster_snapshot.rbs', line 131

def copy: (

#create(options = {}) ⇒ DBClusterSnapshot

Examples:

Request syntax with placeholder values


dbclustersnapshot = db_cluster_snapshot.create({
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :tags (Array<Types::Tag>)

    The tags to be assigned to the DB cluster snapshot.

Returns:



120
# File 'sig/db_cluster_snapshot.rbs', line 120

def create: (

#dataTypes::DBClusterSnapshot



113
# File 'sig/db_cluster_snapshot.rbs', line 113

def data: () -> Types::DBClusterSnapshot

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



116
# File 'sig/db_cluster_snapshot.rbs', line 116

def data_loaded?: () -> bool

#db_cluster_resource_idString

The resource ID of the DB cluster that this DB cluster snapshot was created from.

Returns:

  • (String)


101
# File 'sig/db_cluster_snapshot.rbs', line 101

def db_cluster_resource_id: () -> ::String

#db_cluster_snapshot_arnString

The Amazon Resource Name (ARN) for the DB cluster snapshot.

Returns:

  • (String)


83
# File 'sig/db_cluster_snapshot.rbs', line 83

def db_cluster_snapshot_arn: () -> ::String

#db_system_idString

Reserved for future use.

Returns:

  • (String)


104
# File 'sig/db_cluster_snapshot.rbs', line 104

def db_system_id: () -> ::String

#delete(options = {}) ⇒ DBClusterSnapshot

Examples:

Request syntax with placeholder values


db_cluster_snapshot.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



147
# File 'sig/db_cluster_snapshot.rbs', line 147

def delete: (

#engineString

The name of the database engine for this DB cluster snapshot.

Returns:

  • (String)


32
# File 'sig/db_cluster_snapshot.rbs', line 32

def engine: () -> ::String

#engine_modeString

The engine mode of the database engine for this DB cluster snapshot.

Returns:

  • (String)


35
# File 'sig/db_cluster_snapshot.rbs', line 35

def engine_mode: () -> ::String

#engine_versionString

The version of the database engine for this DB cluster snapshot.

Returns:

  • (String)


56
# File 'sig/db_cluster_snapshot.rbs', line 56

def engine_version: () -> ::String

#events(options = {}) ⇒ Event::Collection

Examples:

Request syntax with placeholder values


events = db_cluster_snapshot.events({
  start_time: Time.now,
  end_time: Time.now,
  duration: 1,
  event_categories: ["String"],
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :start_time (Time, DateTime, Date, Integer, String)

    The beginning of the time interval to retrieve events for, specified in ISO 8601 format. For more information about ISO 8601, go to the ISO8601 Wikipedia page.

    Example: 2009-07-08T18:00Z

  • :end_time (Time, DateTime, Date, Integer, String)

    The end of the time interval for which to retrieve events, specified in ISO 8601 format. For more information about ISO 8601, go to the ISO8601 Wikipedia page.

    Example: 2009-07-08T18:00Z

  • :duration (Integer)

    The number of minutes to retrieve events for.

    Default: 60

  • :event_categories (Array<String>)

    A list of event categories that trigger notifications for a event notification subscription.

  • :filters (Array<Types::Filter>)

    This parameter isn't currently supported.

Returns:



229
# File 'sig/db_cluster_snapshot.rbs', line 229

def events: (

#iam_database_authentication_enabledBoolean

Indicates whether mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.

Returns:

  • (Boolean)


89
# File 'sig/db_cluster_snapshot.rbs', line 89

def iam_database_authentication_enabled: () -> bool

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


1284
1285
1286
1287
1288
1289
# File 'lib/aws-sdk-rds/db_cluster_snapshot.rb', line 1284

def identifiers
  {
    cluster_id: @cluster_id,
    snapshot_id: @snapshot_id
  }
end

#kms_key_idString

If StorageEncrypted is true, the Amazon Web Services KMS key identifier for the encrypted DB cluster snapshot.

The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.

Returns:

  • (String)


80
# File 'sig/db_cluster_snapshot.rbs', line 80

def kms_key_id: () -> ::String

#license_modelString

The license model information for this DB cluster snapshot.

Returns:

  • (String)


59
# File 'sig/db_cluster_snapshot.rbs', line 59

def license_model: () -> ::String

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::RDS::DBClusterSnapshot. Returns self making it possible to chain methods.

db_cluster_snapshot.reload.data

Returns:

  • (self)


109
# File 'sig/db_cluster_snapshot.rbs', line 109

def load: () -> self

#master_usernameString

The master username for this DB cluster snapshot.

Returns:

  • (String)


53
# File 'sig/db_cluster_snapshot.rbs', line 53

def master_username: () -> ::String

#percent_progressInteger

The percentage of the estimated data that has been transferred.

Returns:

  • (Integer)


65
# File 'sig/db_cluster_snapshot.rbs', line 65

def percent_progress: () -> ::Integer

#portInteger

The port that the DB cluster was listening on at the time of the snapshot.

Returns:

  • (Integer)


44
# File 'sig/db_cluster_snapshot.rbs', line 44

def port: () -> ::Integer

#preferred_backup_windowString

The daily time range during which automated backups are created if automated backups are enabled, as determined by the BackupRetentionPeriod.

Returns:

  • (String)


77
# File 'sig/db_cluster_snapshot.rbs', line 77

def preferred_backup_window: () -> ::String

#restore(options = {}) ⇒ DBCluster

Examples:

Request syntax with placeholder values


dbcluster = db_cluster_snapshot.restore({
  availability_zones: ["String"],
  db_cluster_identifier: "String", # required
  engine: "String", # required
  engine_version: "String",
  port: 1,
  db_subnet_group_name: "String",
  database_name: "String",
  option_group_name: "String",
  vpc_security_group_ids: ["String"],
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
  kms_key_id: "String",
  enable_iam_database_authentication: false,
  backtrack_window: 1,
  enable_cloudwatch_logs_exports: ["String"],
  engine_mode: "String",
  scaling_configuration: {
    min_capacity: 1,
    max_capacity: 1,
    auto_pause: false,
    seconds_until_auto_pause: 1,
    timeout_action: "String",
    seconds_before_timeout: 1,
  },
  db_cluster_parameter_group_name: "String",
  deletion_protection: false,
  copy_tags_to_snapshot: false,
  domain: "String",
  domain_iam_role_name: "String",
  db_cluster_instance_class: "String",
  storage_type: "String",
  iops: 1,
  publicly_accessible: false,
  network_type: "String",
  serverless_v2_scaling_configuration: {
    min_capacity: 1.0,
    max_capacity: 1.0,
    seconds_until_auto_pause: 1,
  },
  rds_custom_cluster_configuration: {
    interconnect_subnet_id: "String",
    transit_gateway_multicast_domain_id: "String",
    replica_mode: "open-read-only", # accepts open-read-only, mounted
  },
  monitoring_interval: 1,
  monitoring_role_arn: "String",
  enable_performance_insights: false,
  performance_insights_kms_key_id: "String",
  performance_insights_retention_period: 1,
  backup_retention_period: 1,
  preferred_backup_window: "String",
  engine_lifecycle_support: "String",
  tag_specifications: [
    {
      resource_type: "String",
      tags: [
        {
          key: "String",
          value: "String",
        },
      ],
    },
  ],
  enable_vpc_networking: false,
  enable_internet_access_gateway: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :availability_zones (Array<String>)

    Provides the list of Availability Zones (AZs) where instances in the restored DB cluster can be created.

    Valid for: Aurora DB clusters only

  • :db_cluster_identifier (required, String)

    The name of the DB cluster to create from the DB snapshot or DB cluster snapshot. This parameter isn't case-sensitive.

    Constraints:

    • Must contain from 1 to 63 letters, numbers, or hyphens

    • First character must be a letter

    • Can't end with a hyphen or contain two consecutive hyphens

    Example: my-snapshot-id

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :engine (required, String)

    The database engine to use for the new DB cluster.

    Default: The same as source

    Constraint: Must be compatible with the engine of the source

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :engine_version (String)

    The version of the database engine to use for the new DB cluster. If you don't specify an engine version, the default version for the database engine in the Amazon Web Services Region is used.

    To list all of the available engine versions for Aurora MySQL, use the following command:

    aws rds describe-db-engine-versions --engine aurora-mysql --query "DBEngineVersions[].EngineVersion"

    To list all of the available engine versions for Aurora PostgreSQL, use the following command:

    aws rds describe-db-engine-versions --engine aurora-postgresql --query "DBEngineVersions[].EngineVersion"

    To list all of the available engine versions for RDS for MySQL, use the following command:

    aws rds describe-db-engine-versions --engine mysql --query "DBEngineVersions[].EngineVersion"

    To list all of the available engine versions for RDS for PostgreSQL, use the following command:

    aws rds describe-db-engine-versions --engine postgres --query "DBEngineVersions[].EngineVersion"

    Aurora MySQL

    See Database engine updates for Amazon Aurora MySQL in the Amazon Aurora User Guide.

    Aurora PostgreSQL

    See Amazon Aurora PostgreSQL releases and engine versions in the Amazon Aurora User Guide.

    MySQL

    See Amazon RDS for MySQL in the Amazon RDS User Guide.

    PostgreSQL

    See Amazon RDS for PostgreSQL versions and extensions in the Amazon RDS User Guide.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :port (Integer)

    The port number on which the new DB cluster accepts connections.

    Constraints: This value must be 1150-65535

    Default: The same port as the original DB cluster.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :db_subnet_group_name (String)

    The name of the DB subnet group to use for the new DB cluster.

    Constraints: If supplied, must match the name of an existing DB subnet group.

    Example: mydbsubnetgroup

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :database_name (String)

    The database name for the restored DB cluster.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :option_group_name (String)

    The name of the option group to use for the restored DB cluster.

    DB clusters are associated with a default option group that can't be modified.

  • :vpc_security_group_ids (Array<String>)

    A list of VPC security groups that the new DB cluster will belong to.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :tags (Array<Types::Tag>)

    The tags to be assigned to the restored DB cluster.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :kms_key_id (String)

    The Amazon Web Services KMS key identifier to use when restoring an encrypted DB cluster from a DB snapshot or DB cluster snapshot.

    The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. To use a KMS key in a different Amazon Web Services account, specify the key ARN or alias ARN.

    When you don't specify a value for the KmsKeyId parameter, then the following occurs:

    • If the DB snapshot or DB cluster snapshot in SnapshotIdentifier is encrypted, then the restored DB cluster is encrypted using the KMS key that was used to encrypt the DB snapshot or DB cluster snapshot.

    • If the DB snapshot or DB cluster snapshot in SnapshotIdentifier isn't encrypted, then the restored DB cluster isn't encrypted.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :enable_iam_database_authentication (Boolean)

    Specifies whether to enable mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts. By default, mapping isn't enabled.

    For more information, see IAM Database Authentication in the Amazon Aurora User Guide or IAM database authentication for MariaDB, MySQL, and PostgreSQL in the Amazon RDS User Guide.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :backtrack_window (Integer)

    The target backtrack window, in seconds. To disable backtracking, set this value to 0.

    Currently, Backtrack is only supported for Aurora MySQL DB clusters.

    Default: 0

    Constraints:

    • If specified, this value must be set to a number from 0 to 259,200 (72 hours).

    ^

    Valid for: Aurora DB clusters only

  • :enable_cloudwatch_logs_exports (Array<String>)

    The list of logs that the restored DB cluster is to export to Amazon CloudWatch Logs. The values in the list depend on the DB engine being used.

    RDS for MySQL

    Possible values are error, general, slowquery, and iam-db-auth-error.

    RDS for PostgreSQL

    Possible values are postgresql, upgrade, and iam-db-auth-error.

    Aurora MySQL

    Possible values are audit, error, general, instance, slowquery, and iam-db-auth-error.

    Aurora PostgreSQL

    Possible value are instance, postgresql, and iam-db-auth-error.

    For more information about exporting CloudWatch Logs for Amazon RDS, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon RDS User Guide.

    For more information about exporting CloudWatch Logs for Amazon Aurora, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon Aurora User Guide.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :engine_mode (String)

    The DB engine mode of the DB cluster, either provisioned or serverless.

    For more information, see CreateDBCluster.

    Valid for: Aurora DB clusters only

  • :scaling_configuration (Types::ScalingConfiguration)

    For DB clusters in serverless DB engine mode, the scaling properties of the DB cluster.

    Valid for: Aurora DB clusters only

  • :db_cluster_parameter_group_name (String)

    The name of the DB cluster parameter group to associate with this DB cluster. If this argument is omitted, the default DB cluster parameter group for the specified engine is used.

    Constraints:

    • If supplied, must match the name of an existing default DB cluster parameter group.

    • Must be 1 to 255 letters, numbers, or hyphens.

    • First character must be a letter.

    • Can't end with a hyphen or contain two consecutive hyphens.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :deletion_protection (Boolean)

    Specifies whether to enable deletion protection for the DB cluster. The database can't be deleted when deletion protection is enabled. By default, deletion protection isn't enabled.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :copy_tags_to_snapshot (Boolean)

    Specifies whether to copy all tags from the restored DB cluster to snapshots of the restored DB cluster. The default is not to copy them.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :domain (String)

    The Active Directory directory ID to restore the DB cluster in. The domain must be created prior to this operation. Currently, only MySQL, Microsoft SQL Server, Oracle, and PostgreSQL DB instances can be created in an Active Directory Domain.

    For more information, see Kerberos Authentication in the Amazon RDS User Guide.

    Valid for: Aurora DB clusters only

  • :domain_iam_role_name (String)

    The name of the IAM role to be used when making API calls to the Directory Service.

    Valid for: Aurora DB clusters only

  • :db_cluster_instance_class (String)

    The compute and memory capacity of the each DB instance in the Multi-AZ DB cluster, for example db.m6gd.xlarge. Not all DB instance classes are available in all Amazon Web Services Regions, or for all database engines.

    For the full list of DB instance classes, and availability for your engine, see DB Instance Class in the Amazon RDS User Guide.

    Valid for: Multi-AZ DB clusters only

  • :storage_type (String)

    Specifies the storage type to be associated with the DB cluster.

    When specified for a Multi-AZ DB cluster, a value for the Iops parameter is required.

    Valid Values: aurora, aurora-iopt1 (Aurora DB clusters); io1 (Multi-AZ DB clusters)

    Default: aurora (Aurora DB clusters); io1 (Multi-AZ DB clusters)

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :iops (Integer)

    The amount of Provisioned IOPS (input/output operations per second) to be initially allocated for each DB instance in the Multi-AZ DB cluster.

    For information about valid IOPS values, see Amazon RDS Provisioned IOPS storage in the Amazon RDS User Guide.

    Constraints: Must be a multiple between .5 and 50 of the storage amount for the DB instance.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :publicly_accessible (Boolean)

    Specifies whether the DB cluster is publicly accessible.

    When the DB cluster is publicly accessible, its Domain Name System (DNS) endpoint resolves to the private IP address from within the DB cluster's virtual private cloud (VPC). It resolves to the public IP address from outside of the DB cluster's VPC. Access to the DB cluster is ultimately controlled by the security group it uses. That public access is not permitted if the security group assigned to the DB cluster doesn't permit it.

    When the DB cluster isn't publicly accessible, it is an internal DB cluster with a DNS name that resolves to a private IP address.

    Default: The default behavior varies depending on whether DBSubnetGroupName is specified.

    If DBSubnetGroupName isn't specified, and PubliclyAccessible isn't specified, the following applies:

    • If the default VPC in the target Region doesn’t have an internet gateway attached to it, the DB cluster is private.

    • If the default VPC in the target Region has an internet gateway attached to it, the DB cluster is public.

    If DBSubnetGroupName is specified, and PubliclyAccessible isn't specified, the following applies:

    • If the subnets are part of a VPC that doesn’t have an internet gateway attached to it, the DB cluster is private.

    • If the subnets are part of a VPC that has an internet gateway attached to it, the DB cluster is public.

    Valid for: Aurora DB clusters and Multi-AZ DB clusters

  • :network_type (String)

    The network type of the DB cluster.

    Valid Values:

    • IPV4

    • DUAL

    The network type is determined by the DBSubnetGroup specified for the DB cluster. A DBSubnetGroup can support only the IPv4 protocol or the IPv4 and the IPv6 protocols (DUAL).

    For more information, see Working with a DB instance in a VPC in the Amazon Aurora User Guide.

    Valid for: Aurora DB clusters only

  • :serverless_v2_scaling_configuration (Types::ServerlessV2ScalingConfiguration)

    Contains the scaling configuration of an Aurora Serverless v2 DB cluster.

    For more information, see Using Amazon Aurora Serverless v2 in the Amazon Aurora User Guide.

  • :rds_custom_cluster_configuration (Types::RdsCustomClusterConfiguration)

    Reserved for future use.

  • :monitoring_interval (Integer)

    The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the DB cluster. To turn off collecting Enhanced Monitoring metrics, specify 0.

    If MonitoringRoleArn is specified, also set MonitoringInterval to a value other than 0.

    Valid Values: 0 | 1 | 5 | 10 | 15 | 30 | 60

    Default: 0

  • :monitoring_role_arn (String)

    The Amazon Resource Name (ARN) for the IAM role that permits RDS to send Enhanced Monitoring metrics to Amazon CloudWatch Logs. An example is arn:aws:iam:123456789012:role/emaccess.

    If MonitoringInterval is set to a value other than 0, supply a MonitoringRoleArn value.

  • :enable_performance_insights (Boolean)

    Specifies whether to turn on Performance Insights for the DB cluster.

  • :performance_insights_kms_key_id (String)

    The Amazon Web Services KMS key identifier for encryption of Performance Insights data.

    The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.

    If you don't specify a value for PerformanceInsightsKMSKeyId, then Amazon RDS uses your default KMS key. There is a default KMS key for your Amazon Web Services account. Your Amazon Web Services account has a different default KMS key for each Amazon Web Services Region.

  • :performance_insights_retention_period (Integer)

    The number of days to retain Performance Insights data.

    Valid Values:

    • 7

    • month * 31, where month is a number of months from 1-23. Examples: 93 (3 months * 31), 341 (11 months * 31), 589 (19 months * 31)

    • 731

    Default: 7 days

    If you specify a retention period that isn't valid, such as 94, Amazon RDS issues an error.

  • :backup_retention_period (Integer)

    The number of days for which automated backups are retained. Specify a minimum value of 1.

    Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters

    Default: Uses existing setting

    Constraints:

    • Must be a value from 1 to 35.

    ^

  • :preferred_backup_window (String)

    The daily time range during which automated backups are created if automated backups are enabled, using the BackupRetentionPeriod parameter.

    The default is a 30-minute window selected at random from an 8-hour block of time for each Amazon Web Services Region. To view the time blocks available, see Backup window in the Amazon Aurora User Guide.

    Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters

    Constraints:

    • Must be in the format hh24:mi-hh24:mi.

    • Must be in Universal Coordinated Time (UTC).

    • Must not conflict with the preferred maintenance window.

    • Must be at least 30 minutes.

  • :engine_lifecycle_support (String)

    The life cycle type for this DB cluster.

    By default, this value is set to open-source-rds-extended-support, which enrolls your DB cluster into Amazon RDS Extended Support. At the end of standard support, you can avoid charges for Extended Support by setting the value to open-source-rds-extended-support-disabled. In this case, RDS automatically upgrades your restored DB cluster to a higher engine version, if the major engine version is past its end of standard support date.

    You can use this setting to enroll your DB cluster into Amazon RDS Extended Support. With RDS Extended Support, you can run the selected major engine version on your DB cluster past the end of standard support for that engine version. For more information, see the following sections:

    Valid for Cluster Type: Aurora DB clusters and Multi-AZ DB clusters

    Valid Values: open-source-rds-extended-support | open-source-rds-extended-support-disabled

    Default: open-source-rds-extended-support

  • :tag_specifications (Array<Types::TagSpecification>)

    Tags to assign to resources associated with the DB cluster.

    Valid Values:

    • cluster-auto-backup - The DB cluster's automated backup.

    ^

  • :enable_vpc_networking (Boolean)

    Specifies whether to enable VPC networking for the restored DB cluster. Set this parameter to false to create a cluster without the VPC network interface (ENI).

    This parameter must be used together with EnableInternetAccessGateway. When both parameters are specified, IAM database authentication is required. You must also specify EnableIAMDatabaseAuthentication.

    Valid for Cluster Type: Aurora PostgreSQL clusters

  • :enable_internet_access_gateway (Boolean)

    Specifies that the restored DB cluster should use internet-based connectivity through an internet access gateway. This allows clients to connect to the cluster over the internet without requiring a VPC.

    This parameter must be used together with EnableVPCNetworking set to false. When both parameters are specified, IAM database authentication is required. You must also specify EnableIAMDatabaseAuthentication.

    Valid for Cluster Type: Aurora PostgreSQL clusters

Returns:



152
# File 'sig/db_cluster_snapshot.rbs', line 152

def restore: (

#snapshot_create_timeTime

The time when the snapshot was taken, in Universal Coordinated Time (UTC).

Returns:

  • (Time)


29
# File 'sig/db_cluster_snapshot.rbs', line 29

def snapshot_create_time: () -> ::Time

#snapshot_idString Also known as: db_cluster_snapshot_identifier

Returns:

  • (String)


22
# File 'sig/db_cluster_snapshot.rbs', line 22

def snapshot_id: () -> String

#snapshot_typeString

The type of the DB cluster snapshot.

Returns:

  • (String)


62
# File 'sig/db_cluster_snapshot.rbs', line 62

def snapshot_type: () -> ::String

#source_db_cluster_snapshot_arnString

If the DB cluster snapshot was copied from a source DB cluster snapshot, the Amazon Resource Name (ARN) for the source DB cluster snapshot, otherwise, a null value.

Returns:

  • (String)


86
# File 'sig/db_cluster_snapshot.rbs', line 86

def source_db_cluster_snapshot_arn: () -> ::String

#statusString

The status of this DB cluster snapshot. Valid statuses are the following:

  • available

  • copying

  • creating

Returns:

  • (String)


41
# File 'sig/db_cluster_snapshot.rbs', line 41

def status: () -> ::String

#storage_encryptedBoolean

Indicates whether the DB cluster snapshot is encrypted.

Returns:

  • (Boolean)


68
# File 'sig/db_cluster_snapshot.rbs', line 68

def storage_encrypted: () -> bool

#storage_encryption_typeString

The type of encryption used to protect data at rest in the DB cluster snapshot. Possible values:

  • none - The DB cluster snapshot is not encrypted.

  • sse-rds - The DB cluster snapshot is encrypted using an Amazon Web Services owned KMS key.

  • sse-kms - The DB cluster snapshot is encrypted using a customer managed KMS key or Amazon Web Services managed KMS key.

Returns:

  • (String)


71
# File 'sig/db_cluster_snapshot.rbs', line 71

def storage_encryption_type: () -> ("none" | "sse-kms" | "sse-rds")

#storage_throughputInteger

The storage throughput for the DB cluster snapshot. The throughput is automatically set based on the IOPS that you provision, and is not configurable.

This setting is only for non-Aurora Multi-AZ DB clusters.

Returns:

  • (Integer)


98
# File 'sig/db_cluster_snapshot.rbs', line 98

def storage_throughput: () -> ::Integer

#storage_typeString

The storage type associated with the DB cluster snapshot.

This setting is only for Aurora DB clusters.

Returns:

  • (String)


95
# File 'sig/db_cluster_snapshot.rbs', line 95

def storage_type: () -> ::String

#tag_listArray<Types::Tag>

A list of tags.

For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.

Returns:



92
# File 'sig/db_cluster_snapshot.rbs', line 92

def tag_list: () -> ::Array[Types::Tag]

#vpc_idString

The VPC ID associated with the DB cluster snapshot.

Returns:

  • (String)


47
# File 'sig/db_cluster_snapshot.rbs', line 47

def vpc_id: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
# File 'lib/aws-sdk-rds/db_cluster_snapshot.rb', line 372

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end