Class: Aws::RDS::DBEngine

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/db_engine.rbs,
lib/aws-sdk-rds/db_engine.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ DBEngine #initialize(options = {}) ⇒ DBEngine

Returns a new instance of DBEngine.

Overloads:

  • #initialize(name, options = {}) ⇒ DBEngine

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ DBEngine

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/db_engine.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



40
# File 'lib/aws-sdk-rds/db_engine.rb', line 40

def client: () -> Client

#dataEmptyStructure

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (EmptyStructure)


24
# File 'sig/db_engine.rbs', line 24

def data: () -> EmptyStructure

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



27
# File 'sig/db_engine.rbs', line 27

def data_loaded?: () -> bool

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


376
377
378
# File 'lib/aws-sdk-rds/db_engine.rb', line 376

def identifiers
  { name: @name }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


46
47
48
49
# File 'lib/aws-sdk-rds/db_engine.rb', line 46

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#nameString

Returns:

  • (String)


18
# File 'sig/db_engine.rbs', line 18

def name: () -> String

#option_group_options(options = {}) ⇒ OptionGroupOption::Collection

Examples:

Request syntax with placeholder values


option_group_options = db_engine.option_group_options({
  major_engine_version: "String",
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :major_engine_version (String)

    If specified, filters the results to include only options for the specified major engine version.

  • :filters (Array<Types::Filter>)

    This parameter isn't currently supported.

Returns:



31
# File 'sig/db_engine.rbs', line 31

def option_group_options: (

#option_groups(options = {}) ⇒ OptionGroup::Collection

Examples:

Request syntax with placeholder values


option_groups = db_engine.option_groups({
  option_group_name: "String",
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
  major_engine_version: "String",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :option_group_name (String)

    The name of the option group to describe. Can't be supplied together with EngineName or MajorEngineVersion.

  • :filters (Array<Types::Filter>)

    This parameter isn't currently supported.

  • :major_engine_version (String)

    Filters the list of option groups to only include groups associated with a specific database engine version. If specified, then EngineName must also be specified.

Returns:



43
# File 'sig/db_engine.rbs', line 43

def option_groups: (

#version(version) ⇒ DBEngineVersion

Parameters:

  • version (String)

Returns:



56
# File 'sig/db_engine.rbs', line 56

def version: (String version) -> DBEngineVersion

#versions(options = {}) ⇒ DBEngineVersion::Collection

Examples:

Request syntax with placeholder values


versions = db_engine.versions({
  engine_version: "String",
  db_parameter_group_family: "String",
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
  default_only: false,
  list_supported_character_sets: false,
  list_supported_timezones: false,
  include_all: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :engine_version (String)

    A specific database engine version to return details for.

    Example: 5.1.49

  • :db_parameter_group_family (String)

    The name of a specific DB parameter group family to return details for.

    Constraints:

    • If supplied, must match an existing DB parameter group family.

    ^

  • :filters (Array<Types::Filter>)

    A filter that specifies one or more DB engine versions to describe.

    Supported filters:

    • db-parameter-group-family - Accepts parameter groups family names. The results list only includes information about the DB engine versions for these parameter group families.

    • engine - Accepts engine names. The results list only includes information about the DB engine versions for these engines.

    • engine-mode - Accepts DB engine modes. The results list only includes information about the DB engine versions for these engine modes. Valid DB engine modes are the following:

    • global

    • multimaster

    • parallelquery

    • provisioned

    • serverless

    • engine-version - Accepts engine versions. The results list only includes information about the DB engine versions for these engine versions.

    • status - Accepts engine version statuses. The results list only includes information about the DB engine versions for these statuses. Valid statuses are the following:

    • available

    • deprecated

  • :default_only (Boolean)

    Specifies whether to return only the default version of the specified engine or the engine and major version combination.

  • :list_supported_character_sets (Boolean)

    Specifies whether to list the supported character sets for each engine version.

    If this parameter is enabled and the requested engine supports the CharacterSetName parameter for CreateDBInstance, the response includes a list of supported character sets for each engine version.

    For RDS Custom, the default is not to list supported character sets. If you enable this parameter, RDS Custom returns no results.

  • :list_supported_timezones (Boolean)

    Specifies whether to list the supported time zones for each engine version.

    If this parameter is enabled and the requested engine supports the TimeZone parameter for CreateDBInstance, the response includes a list of supported time zones for each engine version.

    For RDS Custom, the default is not to list supported time zones. If you enable this parameter, RDS Custom returns no results.

  • :include_all (Boolean)

    Specifies whether to also list the engine versions that aren't available. The default is to list only available engine versions.

Returns:



59
# File 'sig/db_engine.rbs', line 59

def versions: (

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/aws-sdk-rds/db_engine.rb', line 145

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end