Class: Aws::RDS::DBParameterGroup
- Inherits:
-
Object
- Object
- Aws::RDS::DBParameterGroup
- Extended by:
- Deprecations
- Defined in:
- sig/db_parameter_group.rbs,
lib/aws-sdk-rds/db_parameter_group.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#db_parameter_group_arn ⇒ String
The Amazon Resource Name (ARN) for the DB parameter group.
-
#db_parameter_group_family ⇒ String
The name of the DB parameter group family that this DB parameter group is compatible with.
-
#description ⇒ String
Provides the customer-specified description for this DB parameter group.
- #name ⇒ String (also: #db_parameter_group_name)
Actions collapse
- #copy(options = {}) ⇒ DBParameterGroup
- #create(options = {}) ⇒ DBParameterGroup
- #delete(options = {}) ⇒ EmptyStructure
- #modify(options = {}) ⇒ DBParameterGroup
- #reset(options = {}) ⇒ DBParameterGroup
- #subscribe_to(options = {}) ⇒ EventSubscription
- #unsubscribe_from(options = {}) ⇒ EventSubscription
Associations collapse
- #events(options = {}) ⇒ Event::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
- #parameters(options = {}) ⇒ Parameter::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::DBParameterGroup
Returns the data for this DBParameterGroup.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ DBParameterGroup
constructor
A new instance of DBParameterGroup.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current DBParameterGroup.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ DBParameterGroup #initialize(options = {}) ⇒ DBParameterGroup
Returns a new instance of DBParameterGroup.
13 14 15 |
# File 'sig/db_parameter_group.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#client ⇒ Client
61 |
# File 'lib/aws-sdk-rds/db_parameter_group.rb', line 61
def client: () -> Client
|
#create(options = {}) ⇒ DBParameterGroup
44 |
# File 'sig/db_parameter_group.rbs', line 44
def create: (
|
#data ⇒ Types::DBParameterGroup
Returns the data for this Aws::RDS::DBParameterGroup. Calls
Client#describe_db_parameter_groups if #data_loaded? is false.
37 |
# File 'sig/db_parameter_group.rbs', line 37
def data: () -> Types::DBParameterGroup
|
#data_loaded? ⇒ Boolean
40 |
# File 'sig/db_parameter_group.rbs', line 40
def data_loaded?: () -> bool
|
#db_parameter_group_arn ⇒ String
The Amazon Resource Name (ARN) for the DB parameter group.
28 |
# File 'sig/db_parameter_group.rbs', line 28
def db_parameter_group_arn: () -> ::String
|
#db_parameter_group_family ⇒ String
The name of the DB parameter group family that this DB parameter group is compatible with.
22 |
# File 'sig/db_parameter_group.rbs', line 22
def db_parameter_group_family: () -> ::String
|
#delete(options = {}) ⇒ EmptyStructure
70 |
# File 'sig/db_parameter_group.rbs', line 70
def delete: (
|
#description ⇒ String
Provides the customer-specified description for this DB parameter group.
25 |
# File 'sig/db_parameter_group.rbs', line 25
def description: () -> ::String
|
#events(options = {}) ⇒ Event::Collection
128 |
# File 'sig/db_parameter_group.rbs', line 128
def events: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
635 636 637 |
# File 'lib/aws-sdk-rds/db_parameter_group.rb', line 635 def identifiers { name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::RDS::DBParameterGroup.
Returns self making it possible to chain methods.
db_parameter_group.reload.data
33 |
# File 'sig/db_parameter_group.rbs', line 33
def load: () -> self
|
#modify(options = {}) ⇒ DBParameterGroup
75 |
# File 'sig/db_parameter_group.rbs', line 75
def modify: (
|
#name ⇒ String Also known as: db_parameter_group_name
18 |
# File 'sig/db_parameter_group.rbs', line 18
def name: () -> String
|
#parameters(options = {}) ⇒ Parameter::Collection
143 |
# File 'sig/db_parameter_group.rbs', line 143
def parameters: (
|
#reset(options = {}) ⇒ DBParameterGroup
95 |
# File 'sig/db_parameter_group.rbs', line 95
def reset: (
|
#subscribe_to(options = {}) ⇒ EventSubscription
116 |
# File 'sig/db_parameter_group.rbs', line 116
def subscribe_to: (
|
#unsubscribe_from(options = {}) ⇒ EventSubscription
122 |
# File 'sig/db_parameter_group.rbs', line 122
def unsubscribe_from: (
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/aws-sdk-rds/db_parameter_group.rb', line 175 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |