Class: Aws::RDS::DBParameterGroupFamily

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/db_parameter_group_family.rbs,
lib/aws-sdk-rds/db_parameter_group_family.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ DBParameterGroupFamily #initialize(options = {}) ⇒ DBParameterGroupFamily

Returns a new instance of DBParameterGroupFamily.

Overloads:



13
14
15
# File 'sig/db_parameter_group_family.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



40
# File 'lib/aws-sdk-rds/db_parameter_group_family.rb', line 40

def client: () -> Client

#dataEmptyStructure

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (EmptyStructure)


24
# File 'sig/db_parameter_group_family.rbs', line 24

def data: () -> EmptyStructure

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



27
# File 'sig/db_parameter_group_family.rbs', line 27

def data_loaded?: () -> bool

#engine_default_cluster_parameters(options = {}) ⇒ Parameter::Collection

Examples:

Request syntax with placeholder values


engine_default_cluster_parameters = db_parameter_group_family.engine_default_cluster_parameters({
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :filters (Array<Types::Filter>)

    This parameter isn't currently supported.

Returns:



31
# File 'sig/db_parameter_group_family.rbs', line 31

def engine_default_cluster_parameters: (

#engine_default_parameters(options = {}) ⇒ Parameter::Collection

Examples:

Request syntax with placeholder values


engine_default_parameters = db_parameter_group_family.engine_default_parameters({
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :filters (Array<Types::Filter>)

    A filter that specifies one or more parameters to describe.

    The only supported filter is parameter-name. The results list only includes information about the parameters with these names.

Returns:



42
# File 'sig/db_parameter_group_family.rbs', line 42

def engine_default_parameters: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


241
242
243
# File 'lib/aws-sdk-rds/db_parameter_group_family.rb', line 241

def identifiers
  { name: @name }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


46
47
48
49
# File 'lib/aws-sdk-rds/db_parameter_group_family.rb', line 46

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#nameString

Returns:

  • (String)


18
# File 'sig/db_parameter_group_family.rbs', line 18

def name: () -> String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/aws-sdk-rds/db_parameter_group_family.rb', line 145

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end