Class: Aws::RDS::DBSecurityGroup

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/db_security_group.rbs,
lib/aws-sdk-rds/db_security_group.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ DBSecurityGroup #initialize(options = {}) ⇒ DBSecurityGroup

Returns a new instance of DBSecurityGroup.

Overloads:

  • #initialize(name, options = {}) ⇒ DBSecurityGroup

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ DBSecurityGroup

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/db_security_group.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#authorize_ingress(options = {}) ⇒ DBSecurityGroup

Examples:

Request syntax with placeholder values


dbsecuritygroup = db_security_group.authorize_ingress({
  cidrip: "String",
  ec2_security_group_name: "String",
  ec2_security_group_id: "String",
  ec2_security_group_owner_id: "String",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :cidrip (String)

    The IP range to authorize.

  • :ec2_security_group_name (String)

    Name of the EC2 security group to authorize. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.

  • :ec2_security_group_id (String)

    Id of the EC2 security group to authorize. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.

  • :ec2_security_group_owner_id (String)

    Amazon Web Services account number of the owner of the EC2 security group specified in the EC2SecurityGroupName parameter. The Amazon Web Services access key ID isn't an acceptable value. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.

Returns:



53
# File 'sig/db_security_group.rbs', line 53

def authorize_ingress: (

#clientClient

Returns:



78
# File 'lib/aws-sdk-rds/db_security_group.rb', line 78

def client: () -> Client

#create(options = {}) ⇒ DBSecurityGroup

Examples:

Request syntax with placeholder values


dbsecuritygroup = db_security_group.create({
  db_security_group_description: "String", # required
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :db_security_group_description (required, String)

    The description for the DB security group.

  • :tags (Array<Types::Tag>)

    Tags to assign to the DB security group.

Returns:



62
# File 'sig/db_security_group.rbs', line 62

def create: (

#dataTypes::DBSecurityGroup

Returns the data for this Aws::RDS::DBSecurityGroup. Calls Client#describe_db_security_groups if #data_loaded? is false.

Returns:



46
# File 'sig/db_security_group.rbs', line 46

def data: () -> Types::DBSecurityGroup

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



49
# File 'sig/db_security_group.rbs', line 49

def data_loaded?: () -> bool

#db_security_group_arnString

The Amazon Resource Name (ARN) for the DB security group.

Returns:

  • (String)


37
# File 'sig/db_security_group.rbs', line 37

def db_security_group_arn: () -> ::String

#db_security_group_descriptionString

Provides the description of the DB security group.

Returns:

  • (String)


25
# File 'sig/db_security_group.rbs', line 25

def db_security_group_description: () -> ::String

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


db_security_group.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


74
# File 'sig/db_security_group.rbs', line 74

def delete: (

#ec2_security_groupsArray<Types::EC2SecurityGroup>

Contains a list of EC2SecurityGroup elements.

Returns:



31
# File 'sig/db_security_group.rbs', line 31

def ec2_security_groups: () -> ::Array[Types::EC2SecurityGroup]

#events(options = {}) ⇒ Event::Collection

Examples:

Request syntax with placeholder values


events = db_security_group.events({
  start_time: Time.now,
  end_time: Time.now,
  duration: 1,
  event_categories: ["String"],
  filters: [
    {
      name: "String", # required
      values: ["String"], # required
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :start_time (Time, DateTime, Date, Integer, String)

    The beginning of the time interval to retrieve events for, specified in ISO 8601 format. For more information about ISO 8601, go to the ISO8601 Wikipedia page.

    Example: 2009-07-08T18:00Z

  • :end_time (Time, DateTime, Date, Integer, String)

    The end of the time interval for which to retrieve events, specified in ISO 8601 format. For more information about ISO 8601, go to the ISO8601 Wikipedia page.

    Example: 2009-07-08T18:00Z

  • :duration (Integer)

    The number of minutes to retrieve events for.

    Default: 60

  • :event_categories (Array<String>)

    A list of event categories that trigger notifications for a event notification subscription.

  • :filters (Array<Types::Filter>)

    This parameter isn't currently supported.

Returns:



100
# File 'sig/db_security_group.rbs', line 100

def events: (

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


457
458
459
# File 'lib/aws-sdk-rds/db_security_group.rb', line 457

def identifiers
  { name: @name }
end

#ip_rangesArray<Types::IPRange>

Contains a list of IPRange elements.

Returns:



34
# File 'sig/db_security_group.rbs', line 34

def ip_ranges: () -> ::Array[Types::IPRange]

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::RDS::DBSecurityGroup. Returns self making it possible to chain methods.

db_security_group.reload.data

Returns:

  • (self)


42
# File 'sig/db_security_group.rbs', line 42

def load: () -> self

#nameString Also known as: db_security_group_name

Returns:

  • (String)


18
# File 'sig/db_security_group.rbs', line 18

def name: () -> String

#owner_idString

Provides the Amazon Web Services ID of the owner of a specific DB security group.

Returns:

  • (String)


22
# File 'sig/db_security_group.rbs', line 22

def owner_id: () -> ::String

#revoke_ingress(options = {}) ⇒ DBSecurityGroup

Examples:

Request syntax with placeholder values


dbsecuritygroup = db_security_group.revoke_ingress({
  cidrip: "String",
  ec2_security_group_name: "String",
  ec2_security_group_id: "String",
  ec2_security_group_owner_id: "String",
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :cidrip (String)

    The IP range to revoke access from. Must be a valid CIDR range. If CIDRIP is specified, EC2SecurityGroupName, EC2SecurityGroupId and EC2SecurityGroupOwnerId can't be provided.

  • :ec2_security_group_name (String)

    The name of the EC2 security group to revoke access from. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.

  • :ec2_security_group_id (String)

    The id of the EC2 security group to revoke access from. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.

  • :ec2_security_group_owner_id (String)

    The Amazon Web Services account number of the owner of the EC2 security group specified in the EC2SecurityGroupName parameter. The Amazon Web Services access key ID isn't an acceptable value. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.

Returns:



79
# File 'sig/db_security_group.rbs', line 79

def revoke_ingress: (

#subscribe_to(options = {}) ⇒ EventSubscription

Examples:

Request syntax with placeholder values


eventsubscription = db_security_group.subscribe_to({
  subscription_name: "String", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :subscription_name (required, String)

    The name of the RDS event notification subscription you want to add a source identifier to.

Returns:



88
# File 'sig/db_security_group.rbs', line 88

def subscribe_to: (

#unsubscribe_from(options = {}) ⇒ EventSubscription

Examples:

Request syntax with placeholder values


eventsubscription = db_security_group.unsubscribe_from({
  subscription_name: "String", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :subscription_name (required, String)

    The name of the RDS event notification subscription you want to remove a source identifier from.

Returns:



94
# File 'sig/db_security_group.rbs', line 94

def unsubscribe_from: (

#vpc_idString

Provides the VpcId of the DB security group.

Returns:

  • (String)


28
# File 'sig/db_security_group.rbs', line 28

def vpc_id: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/aws-sdk-rds/db_security_group.rb', line 192

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end