Class: Aws::RDS::DBSubnetGroup
- Inherits:
-
Object
- Object
- Aws::RDS::DBSubnetGroup
- Extended by:
- Deprecations
- Defined in:
- sig/db_subnet_group.rbs,
lib/aws-sdk-rds/db_subnet_group.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#db_subnet_group_arn ⇒ String
The Amazon Resource Name (ARN) for the DB subnet group.
-
#db_subnet_group_description ⇒ String
Provides the description of the DB subnet group.
- #name ⇒ String (also: #db_subnet_group_name)
-
#subnet_group_status ⇒ String
Provides the status of the DB subnet group.
-
#subnets ⇒ Array<Types::Subnet>
Contains a list of
Subnetelements. -
#supported_network_types ⇒ Array<String>
The network type of the DB subnet group.
-
#vpc_id ⇒ String
Provides the VpcId of the DB subnet group.
Actions collapse
- #create(options = {}) ⇒ DBSubnetGroup
- #delete(options = {}) ⇒ EmptyStructure
- #identifiers ⇒ Object deprecated private Deprecated.
- #modify(options = {}) ⇒ DBSubnetGroup
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::DBSubnetGroup
Returns the data for this DBSubnetGroup.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ DBSubnetGroup
constructor
A new instance of DBSubnetGroup.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current DBSubnetGroup.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ DBSubnetGroup #initialize(options = {}) ⇒ DBSubnetGroup
Returns a new instance of DBSubnetGroup.
13 14 15 |
# File 'sig/db_subnet_group.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#data ⇒ Types::DBSubnetGroup
Returns the data for this Aws::RDS::DBSubnetGroup. Calls
Client#describe_db_subnet_groups if #data_loaded? is false.
46 |
# File 'sig/db_subnet_group.rbs', line 46
def data: () -> Types::DBSubnetGroup
|
#data_loaded? ⇒ Boolean
49 |
# File 'sig/db_subnet_group.rbs', line 49
def data_loaded?: () -> bool
|
#db_subnet_group_arn ⇒ String
The Amazon Resource Name (ARN) for the DB subnet group.
34 |
# File 'sig/db_subnet_group.rbs', line 34
def db_subnet_group_arn: () -> ::String
|
#db_subnet_group_description ⇒ String
Provides the description of the DB subnet group.
22 |
# File 'sig/db_subnet_group.rbs', line 22
def db_subnet_group_description: () -> ::String
|
#delete(options = {}) ⇒ EmptyStructure
66 |
# File 'sig/db_subnet_group.rbs', line 66
def delete: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
302 303 304 |
# File 'lib/aws-sdk-rds/db_subnet_group.rb', line 302 def identifiers { name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::RDS::DBSubnetGroup.
Returns self making it possible to chain methods.
db_subnet_group.reload.data
42 |
# File 'sig/db_subnet_group.rbs', line 42
def load: () -> self
|
#name ⇒ String Also known as: db_subnet_group_name
18 |
# File 'sig/db_subnet_group.rbs', line 18
def name: () -> String
|
#subnet_group_status ⇒ String
Provides the status of the DB subnet group.
28 |
# File 'sig/db_subnet_group.rbs', line 28
def subnet_group_status: () -> ::String
|
#subnets ⇒ Array<Types::Subnet>
Contains a list of Subnet elements. The list of subnets shown here
might not reflect the current state of your VPC. For the most
up-to-date information, we recommend checking your VPC configuration
directly.
31 |
# File 'sig/db_subnet_group.rbs', line 31
def subnets: () -> ::Array[Types::Subnet]
|
#supported_network_types ⇒ Array<String>
The network type of the DB subnet group.
Valid values:
-
IPV4 -
DUAL
A DBSubnetGroup can support only the IPv4 protocol or the IPv4 and
the IPv6 protocols (DUAL).
For more information, see Working with a DB instance in a VPC in the Amazon RDS User Guide.
37 |
# File 'sig/db_subnet_group.rbs', line 37
def supported_network_types: () -> ::Array[::String]
|
#vpc_id ⇒ String
Provides the VpcId of the DB subnet group.
25 |
# File 'sig/db_subnet_group.rbs', line 25
def vpc_id: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-rds/db_subnet_group.rb', line 210 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |