Class: Aws::RDS::Event

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/event.rbs,
lib/aws-sdk-rds/event.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Instance Method Summary collapse

Constructor Details

#initialize(source_id, date, options = {}) ⇒ Event #initialize(options = {}) ⇒ Event

Returns a new instance of Event.

Overloads:

  • #initialize(source_id, date, options = {}) ⇒ Event

    Parameters:

    • source_id (String)
    • date (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Event

    Options Hash (options):

    • :source_id (required, String)
    • :date (required, String)
    • :client (Client)


13
14
15
# File 'sig/event.rbs', line 13

def initialize: (String source_id, String date, Hash[Symbol, untyped] options) -> void
| (source_id: String, date: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



73
# File 'lib/aws-sdk-rds/event.rb', line 73

def client: () -> Client

#dataTypes::Event

Returns the data for this Aws::RDS::Event.

Returns:

Raises:



40
# File 'sig/event.rbs', line 40

def data: () -> Types::Event

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



43
# File 'sig/event.rbs', line 43

def data_loaded?: () -> bool

#dateString

Returns:

  • (String)


22
# File 'sig/event.rbs', line 22

def date: () -> String

#event_categoriesArray<String>

Specifies the category for the event.

Returns:

  • (Array<String>)


31
# File 'sig/event.rbs', line 31

def event_categories: () -> ::Array[::String]

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


201
202
203
204
205
206
# File 'lib/aws-sdk-rds/event.rb', line 201

def identifiers
  {
    source_id: @source_id,
    date: @date
  }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


79
80
81
82
# File 'lib/aws-sdk-rds/event.rb', line 79

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#messageString

Provides the text of this event.

Returns:

  • (String)


28
# File 'sig/event.rbs', line 28

def message: () -> ::String

#source_arnString

The Amazon Resource Name (ARN) for the event.

Returns:

  • (String)


34
# File 'sig/event.rbs', line 34

def source_arn: () -> ::String

#source_idString Also known as: source_identifier

Returns:

  • (String)


18
# File 'sig/event.rbs', line 18

def source_id: () -> String

#source_typeString

Specifies the source type for this event.

Returns:

  • (String)


25
# File 'sig/event.rbs', line 25

def source_type: () -> ("db-instance" | "db-parameter-group" | "db-security-group" | "db-snapshot" | "db-cluster" | "db-cluster-snapshot" | "custom-engine-version" | "db-proxy" | "blue-green-deployment" | "db-shard-group" | "zero-etl")

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/aws-sdk-rds/event.rb', line 180

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end