Class: Aws::RDS::OptionGroup

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/option_group.rbs,
lib/aws-sdk-rds/option_group.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ OptionGroup #initialize(options = {}) ⇒ OptionGroup

Returns a new instance of OptionGroup.

Overloads:

  • #initialize(name, options = {}) ⇒ OptionGroup

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ OptionGroup

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/option_group.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#allows_vpc_and_non_vpc_instance_membershipsBoolean

Indicates whether this option group can be applied to both VPC and non-VPC instances. The value true indicates the option group can be applied to both VPC and non-VPC instances.

Returns:

  • (Boolean)


34
# File 'sig/option_group.rbs', line 34

def allows_vpc_and_non_vpc_instance_memberships: () -> bool

#clientClient

Returns:



111
# File 'lib/aws-sdk-rds/option_group.rb', line 111

def client: () -> Client

#copy(options = {}) ⇒ OptionGroup

Examples:

Request syntax with placeholder values


optiongroup = option_group.copy({
  target_option_group_identifier: "String", # required
  target_option_group_description: "String", # required
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :target_option_group_identifier (required, String)

    The identifier for the copied option group.

    Constraints:

    • Can't be null, empty, or blank

    • Must contain from 1 to 255 letters, numbers, or hyphens

    • First character must be a letter

    • Can't end with a hyphen or contain two consecutive hyphens

    Example: my-option-group

  • :target_option_group_description (required, String)

    The description for the copied option group.

  • :tags (Array<Types::Tag>)

    A list of tags.

    For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.

Returns:



79
# File 'sig/option_group.rbs', line 79

def copy: (

#copy_timestampTime

Indicates when the option group was copied.

Returns:

  • (Time)


49
# File 'sig/option_group.rbs', line 49

def copy_timestamp: () -> ::Time

#create(options = {}) ⇒ OptionGroup

Examples:

Request syntax with placeholder values


optiongroup = option_group.create({
  engine_name: "String", # required
  major_engine_version: "String", # required
  option_group_description: "String", # required
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :engine_name (required, String)

    The name of the engine to associate this option group with.

    Valid Values:

    • db2-ae

    • db2-ce

    • db2-se

    • mariadb

    • mysql

    • oracle-ee

    • oracle-ee-cdb

    • oracle-se2

    • oracle-se2-cdb

    • postgres

    • sqlserver-ee

    • sqlserver-se

    • sqlserver-ex

    • sqlserver-web

  • :major_engine_version (required, String)

    Specifies the major version of the engine that this option group should be associated with.

  • :option_group_description (required, String)

    The description of the option group.

  • :tags (Array<Types::Tag>)

    Tags to assign to the option group.

Returns:



65
# File 'sig/option_group.rbs', line 65

def create: (

#dataTypes::OptionGroup

Returns the data for this Aws::RDS::OptionGroup. Calls Client#describe_option_groups if #data_loaded? is false.

Returns:



58
# File 'sig/option_group.rbs', line 58

def data: () -> Types::OptionGroup

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



61
# File 'sig/option_group.rbs', line 61

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EmptyStructure

Examples:

Request syntax with placeholder values


option_group.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:

  • (EmptyStructure)


92
# File 'sig/option_group.rbs', line 92

def delete: (

#engine_nameString

Indicates the name of the engine that this option group can be applied to.

Returns:

  • (String)


25
# File 'sig/option_group.rbs', line 25

def engine_name: () -> ::String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


431
432
433
# File 'lib/aws-sdk-rds/option_group.rb', line 431

def identifiers
  { name: @name }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::RDS::OptionGroup. Returns self making it possible to chain methods.

option_group.reload.data

Returns:

  • (self)


54
# File 'sig/option_group.rbs', line 54

def load: () -> self

#major_engine_versionString

Indicates the major engine version associated with this option group.

Returns:

  • (String)


28
# File 'sig/option_group.rbs', line 28

def major_engine_version: () -> ::String

#modify(options = {}) ⇒ OptionGroup

Examples:

Request syntax with placeholder values


optiongroup = option_group.modify({
  options_to_include: [
    {
      option_name: "String", # required
      port: 1,
      option_version: "String",
      db_security_group_memberships: ["String"],
      vpc_security_group_memberships: ["String"],
      option_settings: [
        {
          name: "String",
          value: "PotentiallySensitiveOptionSettingValue",
          default_value: "String",
          description: "String",
          apply_type: "String",
          data_type: "String",
          allowed_values: "String",
          is_modifiable: false,
          is_collection: false,
        },
      ],
    },
  ],
  options_to_remove: ["String"],
  apply_immediately: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :options_to_include (Array<Types::OptionConfiguration>)

    Options in this list are added to the option group or, if already present, the specified configuration is used to update the existing configuration.

  • :options_to_remove (Array<String>)

    Options in this list are removed from the option group.

  • :apply_immediately (Boolean)

    Specifies whether to apply the change immediately or during the next maintenance window for each instance associated with the option group.

Returns:



97
# File 'sig/option_group.rbs', line 97

def modify: (

#nameString Also known as: option_group_name

Returns:

  • (String)


18
# File 'sig/option_group.rbs', line 18

def name: () -> String

#option_group_arnString

Specifies the Amazon Resource Name (ARN) for the option group.

Returns:

  • (String)


40
# File 'sig/option_group.rbs', line 40

def option_group_arn: () -> ::String

#option_group_descriptionString

Provides a description of the option group.

Returns:

  • (String)


22
# File 'sig/option_group.rbs', line 22

def option_group_description: () -> ::String

#optionsArray<Types::Option>

Indicates what options are available in the option group.

Returns:



31
# File 'sig/option_group.rbs', line 31

def options: () -> ::Array[Types::Option]

#source_account_idString

Specifies the Amazon Web Services account ID for the option group from which this option group is copied.

Returns:

  • (String)


46
# File 'sig/option_group.rbs', line 46

def source_account_id: () -> ::String

#source_option_groupString

Specifies the name of the option group from which this option group is copied.

Returns:

  • (String)


43
# File 'sig/option_group.rbs', line 43

def source_option_group: () -> ::String

#vpc_idString

If AllowsVpcAndNonVpcInstanceMemberships is false, this field is blank. If AllowsVpcAndNonVpcInstanceMemberships is true and this field is blank, then this option group can be applied to both VPC and non-VPC instances. If this field contains a value, then this option group can only be applied to instances that are in the VPC indicated by this field.

Returns:

  • (String)


37
# File 'sig/option_group.rbs', line 37

def vpc_id: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/aws-sdk-rds/option_group.rb', line 225

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end