Class: Aws::RDS::OptionGroupOption

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/option_group_option.rbs,
lib/aws-sdk-rds/option_group_option.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ OptionGroupOption #initialize(options = {}) ⇒ OptionGroupOption

Returns a new instance of OptionGroupOption.

Overloads:

  • #initialize(name, options = {}) ⇒ OptionGroupOption

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ OptionGroupOption

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/option_group_option.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



150
# File 'lib/aws-sdk-rds/option_group_option.rb', line 150

def client: () -> Client

#copyable_cross_accountBoolean

Indicates whether the option can be copied across Amazon Web Services accounts.

Returns:

  • (Boolean)


66
# File 'sig/option_group_option.rbs', line 66

def copyable_cross_account: () -> bool

#dataTypes::OptionGroupOption

Returns the data for this Aws::RDS::OptionGroupOption.

Returns:

Raises:



72
# File 'sig/option_group_option.rbs', line 72

def data: () -> Types::OptionGroupOption

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



75
# File 'sig/option_group_option.rbs', line 75

def data_loaded?: () -> bool

#default_portInteger

If the option requires a port, specifies the default port for the option.

Returns:

  • (Integer)


36
# File 'sig/option_group_option.rbs', line 36

def default_port: () -> ::Integer

#descriptionString

The description of the option.

Returns:

  • (String)


21
# File 'sig/option_group_option.rbs', line 21

def description: () -> ::String

#engine_nameString

The name of the engine that this option can be applied to.

Returns:

  • (String)


24
# File 'sig/option_group_option.rbs', line 24

def engine_name: () -> ::String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


278
279
280
# File 'lib/aws-sdk-rds/option_group_option.rb', line 278

def identifiers
  { name: @name }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


156
157
158
159
# File 'lib/aws-sdk-rds/option_group_option.rb', line 156

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#major_engine_versionString

Indicates the major engine version that the option is available for.

Returns:

  • (String)


27
# File 'sig/option_group_option.rbs', line 27

def major_engine_version: () -> ::String

#minimum_required_minor_engine_versionString

The minimum required engine version for the option to be applied.

Returns:

  • (String)


30
# File 'sig/option_group_option.rbs', line 30

def minimum_required_minor_engine_version: () -> ::String

#nameString

Returns:

  • (String)


18
# File 'sig/option_group_option.rbs', line 18

def name: () -> String

#option_group_option_settingsArray<Types::OptionGroupOptionSetting>

The option settings that are available (and the default value) for each option in an option group.



60
# File 'sig/option_group_option.rbs', line 60

def option_group_option_settings: () -> ::Array[Types::OptionGroupOptionSetting]

#option_group_option_versionsArray<Types::OptionVersion>

The versions that are available for the option.

Returns:



63
# File 'sig/option_group_option.rbs', line 63

def option_group_option_versions: () -> ::Array[Types::OptionVersion]

#options_conflicts_withArray<String>

The options that conflict with this option.

Returns:

  • (Array<String>)


42
# File 'sig/option_group_option.rbs', line 42

def options_conflicts_with: () -> ::Array[::String]

#options_depended_onArray<String>

The options that are prerequisites for this option.

Returns:

  • (Array<String>)


39
# File 'sig/option_group_option.rbs', line 39

def options_depended_on: () -> ::Array[::String]

#permanentBoolean

Permanent options can never be removed from an option group. An option group containing a permanent option can't be removed from a DB instance.

Returns:

  • (Boolean)


48
# File 'sig/option_group_option.rbs', line 48

def permanent: () -> bool

#persistentBoolean

Persistent options can't be removed from an option group while DB instances are associated with the option group. If you disassociate all DB instances from the option group, your can remove the persistent option from the option group.

Returns:

  • (Boolean)


45
# File 'sig/option_group_option.rbs', line 45

def persistent: () -> bool

#port_requiredBoolean

Indicates whether the option requires a port.

Returns:

  • (Boolean)


33
# File 'sig/option_group_option.rbs', line 33

def port_required: () -> bool

#requires_auto_minor_engine_version_upgradeBoolean

If true, you must enable the Auto Minor Version Upgrade setting for your DB instance before you can use this option. You can enable Auto Minor Version Upgrade when you first create your DB instance, or by modifying your DB instance later.

Returns:

  • (Boolean)


51
# File 'sig/option_group_option.rbs', line 51

def requires_auto_minor_engine_version_upgrade: () -> bool

#supports_option_version_downgradeBoolean

If true, you can change the option to an earlier version of the option. This only applies to options that have different versions available.

Returns:

  • (Boolean)


57
# File 'sig/option_group_option.rbs', line 57

def supports_option_version_downgrade: () -> bool

#vpc_onlyBoolean

If true, you can only use this option with a DB instance that is in a VPC.

Returns:

  • (Boolean)


54
# File 'sig/option_group_option.rbs', line 54

def vpc_only: () -> bool

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/aws-sdk-rds/option_group_option.rb', line 257

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end