Class: Aws::RDS::Parameter

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/parameter.rbs,
lib/aws-sdk-rds/parameter.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ Parameter #initialize(options = {}) ⇒ Parameter

Returns a new instance of Parameter.

Overloads:

  • #initialize(name, options = {}) ⇒ Parameter

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ Parameter

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/parameter.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#allowed_valuesString

Specifies the valid range of values for the parameter.

Returns:

  • (String)


37
# File 'sig/parameter.rbs', line 37

def allowed_values: () -> ::String

#apply_methodString

Indicates when to apply parameter updates.

Returns:

  • (String)


46
# File 'sig/parameter.rbs', line 46

def apply_method: () -> ("immediate" | "pending-reboot")

#apply_typeString

Specifies the engine specific parameters type.

Returns:

  • (String)


31
# File 'sig/parameter.rbs', line 31

def apply_type: () -> ::String

#clientClient

Returns:



103
# File 'lib/aws-sdk-rds/parameter.rb', line 103

def client: () -> Client

#dataTypes::Parameter

Returns the data for this Aws::RDS::Parameter.

Returns:

Raises:



55
# File 'sig/parameter.rbs', line 55

def data: () -> Types::Parameter

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



58
# File 'sig/parameter.rbs', line 58

def data_loaded?: () -> bool

#data_typeString

Specifies the valid data type for the parameter.

Returns:

  • (String)


34
# File 'sig/parameter.rbs', line 34

def data_type: () -> ::String

#descriptionString

Provides a description of the parameter.

Returns:

  • (String)


25
# File 'sig/parameter.rbs', line 25

def description: () -> ::String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


231
232
233
# File 'lib/aws-sdk-rds/parameter.rb', line 231

def identifiers
  { name: @name }
end

#is_modifiableBoolean

Indicates whether (true) or not (false) the parameter can be modified. Some parameters have security or operational implications that prevent them from being changed.

Returns:

  • (Boolean)


40
# File 'sig/parameter.rbs', line 40

def is_modifiable: () -> bool

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


109
110
111
112
# File 'lib/aws-sdk-rds/parameter.rb', line 109

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#minimum_engine_versionString

The earliest engine version to which the parameter can apply.

Returns:

  • (String)


43
# File 'sig/parameter.rbs', line 43

def minimum_engine_version: () -> ::String

#nameString Also known as: parameter_name

Returns:

  • (String)


18
# File 'sig/parameter.rbs', line 18

def name: () -> String

#parameter_valueString

The value of the parameter.

Returns:

  • (String)


22
# File 'sig/parameter.rbs', line 22

def parameter_value: () -> ::String

#sourceString

The source of the parameter value.

Returns:

  • (String)


28
# File 'sig/parameter.rbs', line 28

def source: () -> ::String

#supported_engine_modesArray<String>

The valid DB engine modes.

Returns:

  • (Array<String>)


49
# File 'sig/parameter.rbs', line 49

def supported_engine_modes: () -> ::Array[::String]

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/aws-sdk-rds/parameter.rb', line 210

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end