Class: Aws::RDS::PendingMaintenanceAction

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/pending_maintenance_action.rbs,
lib/aws-sdk-rds/pending_maintenance_action.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(target_arn, name, options = {}) ⇒ PendingMaintenanceAction #initialize(options = {}) ⇒ PendingMaintenanceAction

Returns a new instance of PendingMaintenanceAction.

Overloads:

  • #initialize(target_arn, name, options = {}) ⇒ PendingMaintenanceAction

    Parameters:

    • target_arn (String)
    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ PendingMaintenanceAction

    Options Hash (options):

    • :target_arn (required, String)
    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/pending_maintenance_action.rbs', line 13

def initialize: (String target_arn, String name, Hash[Symbol, untyped] options) -> void
| (target_arn: String, name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#apply_immediately(options = {}) ⇒ ResourcePendingMaintenanceActionList

Examples:

Request syntax with placeholder values


pending_maintenance_action.apply_immediately()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



50
# File 'sig/pending_maintenance_action.rbs', line 50

def apply_immediately: (

#apply_on_next_maintenance(options = {}) ⇒ ResourcePendingMaintenanceActionList

Examples:

Request syntax with placeholder values


pending_maintenance_action.apply_on_next_maintenance()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



60
# File 'sig/pending_maintenance_action.rbs', line 60

def apply_on_next_maintenance: (

#auto_applied_after_dateTime

The date of the maintenance window when the action is applied. The maintenance action is applied to the resource during its first maintenance window after this date.

Returns:

  • (Time)


25
# File 'sig/pending_maintenance_action.rbs', line 25

def auto_applied_after_date: () -> ::Time

#clientClient

Returns:



92
# File 'lib/aws-sdk-rds/pending_maintenance_action.rb', line 92

def client: () -> Client

#current_apply_dateTime

The effective date when the pending maintenance action is applied to the resource. This date takes into account opt-in requests received from the ApplyPendingMaintenanceAction API, the AutoAppliedAfterDate, and the ForcedApplyDate. This value is blank if an opt-in request has not been received and nothing has been specified as AutoAppliedAfterDate or ForcedApplyDate.

Returns:

  • (Time)


34
# File 'sig/pending_maintenance_action.rbs', line 34

def current_apply_date: () -> ::Time

#dataTypes::PendingMaintenanceAction

Returns the data for this Aws::RDS::PendingMaintenanceAction.

Returns:

Raises:



43
# File 'sig/pending_maintenance_action.rbs', line 43

def data: () -> Types::PendingMaintenanceAction

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



46
# File 'sig/pending_maintenance_action.rbs', line 46

def data_loaded?: () -> bool

#descriptionString

A description providing more detail about the maintenance action.

Returns:

  • (String)


37
# File 'sig/pending_maintenance_action.rbs', line 37

def description: () -> ::String

#forced_apply_dateTime

The date when the maintenance action is automatically applied.

On this date, the maintenance action is applied to the resource as soon as possible, regardless of the maintenance window for the resource. There might be a delay of one or more days from this date before the maintenance action is applied.

Returns:

  • (Time)


28
# File 'sig/pending_maintenance_action.rbs', line 28

def forced_apply_date: () -> ::Time

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


285
286
287
288
289
290
# File 'lib/aws-sdk-rds/pending_maintenance_action.rb', line 285

def identifiers
  {
    target_arn: @target_arn,
    name: @name
  }
end

#loadObject Also known as: reload

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Raises:

  • (NotImplementedError)


98
99
100
101
# File 'lib/aws-sdk-rds/pending_maintenance_action.rb', line 98

def load
  msg = "#load is not implemented, data only available via enumeration"
  raise NotImplementedError, msg
end

#nameString Also known as: action

Returns:

  • (String)


21
# File 'sig/pending_maintenance_action.rbs', line 21

def name: () -> String

#opt_in_statusString

Indicates the type of opt-in request that has been received for the resource.

Returns:

  • (String)


31
# File 'sig/pending_maintenance_action.rbs', line 31

def opt_in_status: () -> ::String

#target_arnString

Returns:

  • (String)


18
# File 'sig/pending_maintenance_action.rbs', line 18

def target_arn: () -> String

#undo_opt_in(options = {}) ⇒ ResourcePendingMaintenanceActionList

Examples:

Request syntax with placeholder values


pending_maintenance_action.undo_opt_in()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



55
# File 'sig/pending_maintenance_action.rbs', line 55

def undo_opt_in: (

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/aws-sdk-rds/pending_maintenance_action.rb', line 199

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end