Class: Aws::RDS::ReservedDBInstance

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/reserved_db_instance.rbs,
lib/aws-sdk-rds/reserved_db_instance.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Associations collapse

Instance Method Summary collapse

Constructor Details

#initialize(id, options = {}) ⇒ ReservedDBInstance #initialize(options = {}) ⇒ ReservedDBInstance

Returns a new instance of ReservedDBInstance.

Overloads:



13
14
15
# File 'sig/reserved_db_instance.rbs', line 13

def initialize: (String id, Hash[Symbol, untyped] options) -> void
| (id: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#clientClient

Returns:



137
# File 'lib/aws-sdk-rds/reserved_db_instance.rb', line 137

def client: () -> Client

#currency_codeString

The currency code for the reserved DB instance.

Returns:

  • (String)


40
# File 'sig/reserved_db_instance.rbs', line 40

def currency_code: () -> ::String

#dataTypes::ReservedDBInstance



73
# File 'sig/reserved_db_instance.rbs', line 73

def data: () -> Types::ReservedDBInstance

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



76
# File 'sig/reserved_db_instance.rbs', line 76

def data_loaded?: () -> bool

#db_instance_classString

The DB instance class for the reserved DB instance.

Returns:

  • (String)


25
# File 'sig/reserved_db_instance.rbs', line 25

def db_instance_class: () -> ::String

#db_instance_countInteger

The number of reserved DB instances.

Returns:

  • (Integer)


43
# File 'sig/reserved_db_instance.rbs', line 43

def db_instance_count: () -> ::Integer

#durationInteger

The duration of the reservation in seconds.

Returns:

  • (Integer)


31
# File 'sig/reserved_db_instance.rbs', line 31

def duration: () -> ::Integer

#fixed_priceFloat

The fixed price charged for this reserved DB instance.

Returns:

  • (Float)


34
# File 'sig/reserved_db_instance.rbs', line 34

def fixed_price: () -> ::Float

#idString Also known as: reserved_db_instance_id

Returns:

  • (String)


18
# File 'sig/reserved_db_instance.rbs', line 18

def id: () -> String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


286
287
288
# File 'lib/aws-sdk-rds/reserved_db_instance.rb', line 286

def identifiers
  { id: @id }
end

#lease_idString

The unique identifier for the lease associated with the reserved DB instance.

Amazon Web Services Support might request the lease ID for an issue related to a reserved DB instance.

Returns:

  • (String)


64
# File 'sig/reserved_db_instance.rbs', line 64

def lease_id: () -> ::String

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::RDS::ReservedDBInstance. Returns self making it possible to chain methods.

reserved_db_instance.reload.data

Returns:

  • (self)


69
# File 'sig/reserved_db_instance.rbs', line 69

def load: () -> self

#multi_azBoolean

Indicates whether the reservation applies to Multi-AZ deployments.

Returns:

  • (Boolean)


52
# File 'sig/reserved_db_instance.rbs', line 52

def multi_az: () -> bool

#offeringReservedDBInstancesOffering?

Returns:



80
# File 'sig/reserved_db_instance.rbs', line 80

def offering: () -> ReservedDBInstancesOffering?

#offering_typeString

The offering type of this reserved DB instance.

Returns:

  • (String)


49
# File 'sig/reserved_db_instance.rbs', line 49

def offering_type: () -> ::String

#product_descriptionString

The description of the reserved DB instance.

Returns:

  • (String)


46
# File 'sig/reserved_db_instance.rbs', line 46

def product_description: () -> ::String

#recurring_chargesArray<Types::RecurringCharge>

The recurring price charged to run this reserved DB instance.

Returns:



58
# File 'sig/reserved_db_instance.rbs', line 58

def recurring_charges: () -> ::Array[Types::RecurringCharge]

#reserved_db_instance_arnString

The Amazon Resource Name (ARN) for the reserved DB instance.

Returns:

  • (String)


61
# File 'sig/reserved_db_instance.rbs', line 61

def reserved_db_instance_arn: () -> ::String

#reserved_db_instances_offering_idString

The offering identifier.

Returns:

  • (String)


22
# File 'sig/reserved_db_instance.rbs', line 22

def reserved_db_instances_offering_id: () -> ::String

#start_timeTime

The time the reservation started.

Returns:

  • (Time)


28
# File 'sig/reserved_db_instance.rbs', line 28

def start_time: () -> ::Time

#stateString

The state of the reserved DB instance.

Returns:

  • (String)


55
# File 'sig/reserved_db_instance.rbs', line 55

def state: () -> ::String

#usage_priceFloat

The hourly price charged for this reserved DB instance.

Returns:

  • (Float)


37
# File 'sig/reserved_db_instance.rbs', line 37

def usage_price: () -> ::Float

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/aws-sdk-rds/reserved_db_instance.rb', line 251

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end