Class: Aws::RDS::Resource
- Inherits:
-
Object
- Object
- Aws::RDS::Resource
- Defined in:
- lib/aws-sdk-rds/resource.rb
Overview
This class provides a resource oriented interface for RDS. To create a resource object:
resource = Aws::RDS::Resource.new(region: 'us-west-2')
You can supply a client object with custom configuration that will be used for all resource operations. If you do not pass ‘:client`, a default client will be constructed.
client = Aws::RDS::Client.new(region: 'us-west-2')
resource = Aws::RDS::Resource.new(client: client)
Actions collapse
- #create_db_cluster(options = {}) ⇒ DBCluster
- #create_db_cluster_parameter_group(options = {}) ⇒ DBClusterParameterGroup
- #create_db_instance(options = {}) ⇒ DBInstance
- #create_db_parameter_group(options = {}) ⇒ DBParameterGroup
- #create_db_security_group(options = {}) ⇒ DBSecurityGroup
- #create_db_subnet_group(options = {}) ⇒ DBSubnetGroup
- #create_event_subscription(options = {}) ⇒ EventSubscription
- #create_option_group(options = {}) ⇒ OptionGroup
Associations collapse
- #account_quotas(options = {}) ⇒ AccountQuota::Collection
- #certificate(id) ⇒ Certificate
- #certificates(options = {}) ⇒ Certificate::Collection
- #db_cluster(id) ⇒ DBCluster
- #db_cluster_parameter_group(name) ⇒ DBClusterParameterGroup
- #db_cluster_parameter_groups(options = {}) ⇒ DBClusterParameterGroup::Collection
- #db_clusters(options = {}) ⇒ DBCluster::Collection
- #db_engine(name) ⇒ DBEngine
- #db_engine_version(engine_name, version) ⇒ DBEngineVersion
- #db_engine_versions(options = {}) ⇒ DBEngineVersion::Collection
- #db_instance(id) ⇒ DBInstance
- #db_instances(options = {}) ⇒ DBInstance::Collection
- #db_parameter_group(name) ⇒ DBParameterGroup
- #db_parameter_group_family(name) ⇒ DBParameterGroupFamily
- #db_parameter_groups(options = {}) ⇒ DBParameterGroup::Collection
- #db_security_group(name) ⇒ DBSecurityGroup
- #db_security_groups(options = {}) ⇒ DBSecurityGroup::Collection
- #db_snapshots(options = {}) ⇒ DBSnapshot::Collection
- #db_subnet_group(name) ⇒ DBSubnetGroup
- #db_subnet_groups(options = {}) ⇒ DBSubnetGroup::Collection
- #event_category_map(source_type) ⇒ EventCategoryMap
- #event_category_maps(options = {}) ⇒ EventCategoryMap::Collection
- #event_subscription(name) ⇒ EventSubscription
- #event_subscriptions(options = {}) ⇒ EventSubscription::Collection
- #events(options = {}) ⇒ Event::Collection
- #option_group(name) ⇒ OptionGroup
- #option_groups(options = {}) ⇒ OptionGroup::Collection
- #pending_maintenance_action(target_arn, name) ⇒ PendingMaintenanceAction
- #reserved_db_instance(id) ⇒ ReservedDBInstance
- #reserved_db_instances(options = {}) ⇒ ReservedDBInstance::Collection
- #reserved_db_instances_offering(id) ⇒ ReservedDBInstancesOffering
- #reserved_db_instances_offerings(options = {}) ⇒ ReservedDBInstancesOffering::Collection
- #resource_with_pending_maintenance_actions(arn) ⇒ ResourcePendingMaintenanceActionList
- #resources_with_pending_maintenance_actions(options = {}) ⇒ ResourcePendingMaintenanceActionList::Collection
Instance Method Summary collapse
- #client ⇒ Client
-
#initialize(options = {}) ⇒ Resource
constructor
A new instance of Resource.
Constructor Details
Instance Method Details
#account_quotas(options = {}) ⇒ AccountQuota::Collection
2904 2905 2906 2907 2908 2909 2910 2911 2912 2913 2914 2915 2916 2917 2918 2919 2920 |
# File 'lib/aws-sdk-rds/resource.rb', line 2904 def account_quotas( = {}) batches = Enumerator.new do |y| batch = [] resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_account_attributes() end resp.data.account_quotas.each do |a| batch << AccountQuota.new( name: a.account_quota_name, data: a, client: @client ) end y.yield(batch) end AccountQuota::Collection.new(batches) end |
#certificate(id) ⇒ Certificate
2924 2925 2926 2927 2928 2929 |
# File 'lib/aws-sdk-rds/resource.rb', line 2924 def certificate(id) Certificate.new( id: id, client: @client ) end |
#certificates(options = {}) ⇒ Certificate::Collection
2956 2957 2958 2959 2960 2961 2962 2963 2964 2965 2966 2967 2968 2969 2970 2971 2972 2973 2974 |
# File 'lib/aws-sdk-rds/resource.rb', line 2956 def certificates( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_certificates() end resp.each_page do |page| batch = [] page.data.certificates.each do |c| batch << Certificate.new( id: c.certificate_identifier, data: c, client: @client ) end y.yield(batch) end end Certificate::Collection.new(batches) end |
#create_db_cluster(options = {}) ⇒ DBCluster
1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 |
# File 'lib/aws-sdk-rds/resource.rb', line 1031 def create_db_cluster( = {}) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_db_cluster() end DBCluster.new( id: resp.data.db_cluster.db_cluster_identifier, data: resp.data.db_cluster, client: @client ) end |
#create_db_cluster_parameter_group(options = {}) ⇒ DBClusterParameterGroup
1122 1123 1124 1125 1126 1127 1128 1129 1130 1131 |
# File 'lib/aws-sdk-rds/resource.rb', line 1122 def create_db_cluster_parameter_group( = {}) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_db_cluster_parameter_group() end DBClusterParameterGroup.new( name: resp.data.db_cluster_parameter_group.db_cluster_parameter_group_name, data: resp.data.db_cluster_parameter_group, client: @client ) end |
#create_db_instance(options = {}) ⇒ DBInstance
2507 2508 2509 2510 2511 2512 2513 2514 2515 2516 |
# File 'lib/aws-sdk-rds/resource.rb', line 2507 def create_db_instance( = {}) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_db_instance() end DBInstance.new( id: resp.data.db_instance.db_instance_identifier, data: resp.data.db_instance, client: @client ) end |
#create_db_parameter_group(options = {}) ⇒ DBParameterGroup
2604 2605 2606 2607 2608 2609 2610 2611 2612 2613 |
# File 'lib/aws-sdk-rds/resource.rb', line 2604 def create_db_parameter_group( = {}) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_db_parameter_group() end DBParameterGroup.new( name: resp.data.db_parameter_group.db_parameter_group_name, data: resp.data.db_parameter_group, client: @client ) end |
#create_db_security_group(options = {}) ⇒ DBSecurityGroup
2648 2649 2650 2651 2652 2653 2654 2655 2656 2657 |
# File 'lib/aws-sdk-rds/resource.rb', line 2648 def create_db_security_group( = {}) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_db_security_group() end DBSecurityGroup.new( name: resp.data.db_security_group.db_security_group_name, data: resp.data.db_security_group, client: @client ) end |
#create_db_subnet_group(options = {}) ⇒ DBSubnetGroup
2694 2695 2696 2697 2698 2699 2700 2701 2702 2703 |
# File 'lib/aws-sdk-rds/resource.rb', line 2694 def create_db_subnet_group( = {}) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_db_subnet_group() end DBSubnetGroup.new( name: resp.data.db_subnet_group.db_subnet_group_name, data: resp.data.db_subnet_group, client: @client ) end |
#create_event_subscription(options = {}) ⇒ EventSubscription
2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 |
# File 'lib/aws-sdk-rds/resource.rb', line 2808 def create_event_subscription( = {}) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_event_subscription() end EventSubscription.new( name: resp.data.event_subscription.cust_subscription_id, data: resp.data.event_subscription, client: @client ) end |
#create_option_group(options = {}) ⇒ OptionGroup
2886 2887 2888 2889 2890 2891 2892 2893 2894 2895 |
# File 'lib/aws-sdk-rds/resource.rb', line 2886 def create_option_group( = {}) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.create_option_group() end OptionGroup.new( name: resp.data.option_group.option_group_name, data: resp.data.option_group, client: @client ) end |
#db_cluster(id) ⇒ DBCluster
2978 2979 2980 2981 2982 2983 |
# File 'lib/aws-sdk-rds/resource.rb', line 2978 def db_cluster(id) DBCluster.new( id: id, client: @client ) end |
#db_cluster_parameter_group(name) ⇒ DBClusterParameterGroup
2987 2988 2989 2990 2991 2992 |
# File 'lib/aws-sdk-rds/resource.rb', line 2987 def db_cluster_parameter_group(name) DBClusterParameterGroup.new( name: name, client: @client ) end |
#db_cluster_parameter_groups(options = {}) ⇒ DBClusterParameterGroup::Collection
3019 3020 3021 3022 3023 3024 3025 3026 3027 3028 3029 3030 3031 3032 3033 3034 3035 3036 3037 |
# File 'lib/aws-sdk-rds/resource.rb', line 3019 def db_cluster_parameter_groups( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_cluster_parameter_groups() end resp.each_page do |page| batch = [] page.data.db_cluster_parameter_groups.each do |d| batch << DBClusterParameterGroup.new( name: d.db_cluster_parameter_group_name, data: d, client: @client ) end y.yield(batch) end end DBClusterParameterGroup::Collection.new(batches) end |
#db_clusters(options = {}) ⇒ DBCluster::Collection
3090 3091 3092 3093 3094 3095 3096 3097 3098 3099 3100 3101 3102 3103 3104 3105 3106 3107 3108 |
# File 'lib/aws-sdk-rds/resource.rb', line 3090 def db_clusters( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_clusters() end resp.each_page do |page| batch = [] page.data.db_clusters.each do |d| batch << DBCluster.new( id: d.db_cluster_identifier, data: d, client: @client ) end y.yield(batch) end end DBCluster::Collection.new(batches) end |
#db_engine(name) ⇒ DBEngine
3112 3113 3114 3115 3116 3117 |
# File 'lib/aws-sdk-rds/resource.rb', line 3112 def db_engine(name) DBEngine.new( name: name, client: @client ) end |
#db_engine_version(engine_name, version) ⇒ DBEngineVersion
3122 3123 3124 3125 3126 3127 3128 |
# File 'lib/aws-sdk-rds/resource.rb', line 3122 def db_engine_version(engine_name, version) DBEngineVersion.new( engine_name: engine_name, version: version, client: @client ) end |
#db_engine_versions(options = {}) ⇒ DBEngineVersion::Collection
3270 3271 3272 3273 3274 3275 3276 3277 3278 3279 3280 3281 3282 3283 3284 3285 3286 3287 3288 3289 |
# File 'lib/aws-sdk-rds/resource.rb', line 3270 def db_engine_versions( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_engine_versions() end resp.each_page do |page| batch = [] page.data.db_engine_versions.each do |d| batch << DBEngineVersion.new( engine_name: d.engine, version: d.engine_version, data: d, client: @client ) end y.yield(batch) end end DBEngineVersion::Collection.new(batches) end |
#db_instance(id) ⇒ DBInstance
3293 3294 3295 3296 3297 3298 |
# File 'lib/aws-sdk-rds/resource.rb', line 3293 def db_instance(id) DBInstance.new( id: id, client: @client ) end |
#db_instances(options = {}) ⇒ DBInstance::Collection
3348 3349 3350 3351 3352 3353 3354 3355 3356 3357 3358 3359 3360 3361 3362 3363 3364 3365 3366 |
# File 'lib/aws-sdk-rds/resource.rb', line 3348 def db_instances( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_instances() end resp.each_page do |page| batch = [] page.data.db_instances.each do |d| batch << DBInstance.new( id: d.db_instance_identifier, data: d, client: @client ) end y.yield(batch) end end DBInstance::Collection.new(batches) end |
#db_parameter_group(name) ⇒ DBParameterGroup
3370 3371 3372 3373 3374 3375 |
# File 'lib/aws-sdk-rds/resource.rb', line 3370 def db_parameter_group(name) DBParameterGroup.new( name: name, client: @client ) end |
#db_parameter_group_family(name) ⇒ DBParameterGroupFamily
3379 3380 3381 3382 3383 3384 |
# File 'lib/aws-sdk-rds/resource.rb', line 3379 def db_parameter_group_family(name) DBParameterGroupFamily.new( name: name, client: @client ) end |
#db_parameter_groups(options = {}) ⇒ DBParameterGroup::Collection
3410 3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 3424 3425 3426 3427 3428 |
# File 'lib/aws-sdk-rds/resource.rb', line 3410 def db_parameter_groups( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_parameter_groups() end resp.each_page do |page| batch = [] page.data.db_parameter_groups.each do |d| batch << DBParameterGroup.new( name: d.db_parameter_group_name, data: d, client: @client ) end y.yield(batch) end end DBParameterGroup::Collection.new(batches) end |
#db_security_group(name) ⇒ DBSecurityGroup
3432 3433 3434 3435 3436 3437 |
# File 'lib/aws-sdk-rds/resource.rb', line 3432 def db_security_group(name) DBSecurityGroup.new( name: name, client: @client ) end |
#db_security_groups(options = {}) ⇒ DBSecurityGroup::Collection
3456 3457 3458 3459 3460 3461 3462 3463 3464 3465 3466 3467 3468 3469 3470 3471 3472 3473 3474 |
# File 'lib/aws-sdk-rds/resource.rb', line 3456 def db_security_groups( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_security_groups() end resp.each_page do |page| batch = [] page.data.db_security_groups.each do |d| batch << DBSecurityGroup.new( name: d.db_security_group_name, data: d, client: @client ) end y.yield(batch) end end DBSecurityGroup::Collection.new(batches) end |
#db_snapshots(options = {}) ⇒ DBSnapshot::Collection
3589 3590 3591 3592 3593 3594 3595 3596 3597 3598 3599 3600 3601 3602 3603 3604 3605 3606 3607 3608 |
# File 'lib/aws-sdk-rds/resource.rb', line 3589 def db_snapshots( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_snapshots() end resp.each_page do |page| batch = [] page.data.db_snapshots.each do |d| batch << DBSnapshot.new( instance_id: d.db_instance_identifier, snapshot_id: d.db_snapshot_identifier, data: d, client: @client ) end y.yield(batch) end end DBSnapshot::Collection.new(batches) end |
#db_subnet_group(name) ⇒ DBSubnetGroup
3612 3613 3614 3615 3616 3617 |
# File 'lib/aws-sdk-rds/resource.rb', line 3612 def db_subnet_group(name) DBSubnetGroup.new( name: name, client: @client ) end |
#db_subnet_groups(options = {}) ⇒ DBSubnetGroup::Collection
3636 3637 3638 3639 3640 3641 3642 3643 3644 3645 3646 3647 3648 3649 3650 3651 3652 3653 3654 |
# File 'lib/aws-sdk-rds/resource.rb', line 3636 def db_subnet_groups( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_subnet_groups() end resp.each_page do |page| batch = [] page.data.db_subnet_groups.each do |d| batch << DBSubnetGroup.new( name: d.db_subnet_group_name, data: d, client: @client ) end y.yield(batch) end end DBSubnetGroup::Collection.new(batches) end |
#event_category_map(source_type) ⇒ EventCategoryMap
3658 3659 3660 3661 3662 3663 |
# File 'lib/aws-sdk-rds/resource.rb', line 3658 def event_category_map(source_type) EventCategoryMap.new( source_type: source_type, client: @client ) end |
#event_category_maps(options = {}) ⇒ EventCategoryMap::Collection
3687 3688 3689 3690 3691 3692 3693 3694 3695 3696 3697 3698 3699 3700 3701 3702 3703 |
# File 'lib/aws-sdk-rds/resource.rb', line 3687 def event_category_maps( = {}) batches = Enumerator.new do |y| batch = [] resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_event_categories() end resp.data.event_categories_map_list.each do |e| batch << EventCategoryMap.new( source_type: e.source_type, data: e, client: @client ) end y.yield(batch) end EventCategoryMap::Collection.new(batches) end |
#event_subscription(name) ⇒ EventSubscription
3707 3708 3709 3710 3711 3712 |
# File 'lib/aws-sdk-rds/resource.rb', line 3707 def event_subscription(name) EventSubscription.new( name: name, client: @client ) end |
#event_subscriptions(options = {}) ⇒ EventSubscription::Collection
3732 3733 3734 3735 3736 3737 3738 3739 3740 3741 3742 3743 3744 3745 3746 3747 3748 3749 3750 |
# File 'lib/aws-sdk-rds/resource.rb', line 3732 def event_subscriptions( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_event_subscriptions() end resp.each_page do |page| batch = [] page.data.event_subscriptions_list.each do |e| batch << EventSubscription.new( name: e.cust_subscription_id, data: e, client: @client ) end y.yield(batch) end end EventSubscription::Collection.new(batches) end |
#events(options = {}) ⇒ Event::Collection
3833 3834 3835 3836 3837 3838 3839 3840 3841 3842 3843 3844 3845 3846 3847 3848 3849 3850 3851 3852 |
# File 'lib/aws-sdk-rds/resource.rb', line 3833 def events( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_events() end resp.each_page do |page| batch = [] page.data.events.each do |e| batch << Event.new( source_id: e.source_identifier, date: e.date, data: e, client: @client ) end y.yield(batch) end end Event::Collection.new(batches) end |
#option_group(name) ⇒ OptionGroup
3856 3857 3858 3859 3860 3861 |
# File 'lib/aws-sdk-rds/resource.rb', line 3856 def option_group(name) OptionGroup.new( name: name, client: @client ) end |
#option_groups(options = {}) ⇒ OptionGroup::Collection
3920 3921 3922 3923 3924 3925 3926 3927 3928 3929 3930 3931 3932 3933 3934 3935 3936 3937 3938 |
# File 'lib/aws-sdk-rds/resource.rb', line 3920 def option_groups( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_option_groups() end resp.each_page do |page| batch = [] page.data.option_groups_list.each do |o| batch << OptionGroup.new( name: o.option_group_name, data: o, client: @client ) end y.yield(batch) end end OptionGroup::Collection.new(batches) end |
#pending_maintenance_action(target_arn, name) ⇒ PendingMaintenanceAction
3943 3944 3945 3946 3947 3948 3949 |
# File 'lib/aws-sdk-rds/resource.rb', line 3943 def pending_maintenance_action(target_arn, name) PendingMaintenanceAction.new( target_arn: target_arn, name: name, client: @client ) end |
#reserved_db_instance(id) ⇒ ReservedDBInstance
3953 3954 3955 3956 3957 3958 |
# File 'lib/aws-sdk-rds/resource.rb', line 3953 def reserved_db_instance(id) ReservedDBInstance.new( id: id, client: @client ) end |
#reserved_db_instances(options = {}) ⇒ ReservedDBInstance::Collection
4017 4018 4019 4020 4021 4022 4023 4024 4025 4026 4027 4028 4029 4030 4031 4032 4033 4034 4035 |
# File 'lib/aws-sdk-rds/resource.rb', line 4017 def reserved_db_instances( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_reserved_db_instances() end resp.each_page do |page| batch = [] page.data.reserved_db_instances.each do |r| batch << ReservedDBInstance.new( id: r.reserved_db_instance_id, data: r, client: @client ) end y.yield(batch) end end ReservedDBInstance::Collection.new(batches) end |
#reserved_db_instances_offering(id) ⇒ ReservedDBInstancesOffering
4039 4040 4041 4042 4043 4044 |
# File 'lib/aws-sdk-rds/resource.rb', line 4039 def reserved_db_instances_offering(id) ReservedDBInstancesOffering.new( id: id, client: @client ) end |
#reserved_db_instances_offerings(options = {}) ⇒ ReservedDBInstancesOffering::Collection
4096 4097 4098 4099 4100 4101 4102 4103 4104 4105 4106 4107 4108 4109 4110 4111 4112 4113 4114 |
# File 'lib/aws-sdk-rds/resource.rb', line 4096 def reserved_db_instances_offerings( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_reserved_db_instances_offerings() end resp.each_page do |page| batch = [] page.data.reserved_db_instances_offerings.each do |r| batch << ReservedDBInstancesOffering.new( id: r.reserved_db_instances_offering_id, data: r, client: @client ) end y.yield(batch) end end ReservedDBInstancesOffering::Collection.new(batches) end |
#resource_with_pending_maintenance_actions(arn) ⇒ ResourcePendingMaintenanceActionList
4118 4119 4120 4121 4122 4123 |
# File 'lib/aws-sdk-rds/resource.rb', line 4118 def resource_with_pending_maintenance_actions(arn) ResourcePendingMaintenanceActionList.new( arn: arn, client: @client ) end |
#resources_with_pending_maintenance_actions(options = {}) ⇒ ResourcePendingMaintenanceActionList::Collection
4153 4154 4155 4156 4157 4158 4159 4160 4161 4162 4163 4164 4165 4166 4167 4168 4169 4170 4171 |
# File 'lib/aws-sdk-rds/resource.rb', line 4153 def resources_with_pending_maintenance_actions( = {}) batches = Enumerator.new do |y| resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_pending_maintenance_actions() end resp.each_page do |page| batch = [] page.data.pending_maintenance_actions.each do |p| batch << ResourcePendingMaintenanceActionList.new( arn: p.resource_identifier, data: p, client: @client ) end y.yield(batch) end end ResourcePendingMaintenanceActionList::Collection.new(batches) end |