Class: Aws::RDS::Types::AdditionalStorageVolume

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains details about an additional storage volume for a DB instance. RDS support additional storage volumes for RDS for Oracle and RDS for SQL Server.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The amount of storage allocated for the additional storage volume, in gibibytes (GiB). The minimum is 20 GiB. The maximum is 65,536 GiB (64 TiB).



315
316
317
318
319
320
321
322
323
324
# File 'lib/aws-sdk-rds/types.rb', line 315

class AdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

The number of I/O operations per second (IOPS) provisioned for the additional storage volume.



315
316
317
318
319
320
321
322
323
324
# File 'lib/aws-sdk-rds/types.rb', line 315

class AdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#max_allocated_storageInteger

The upper limit in gibibytes (GiB) to which RDS can automatically scale the storage of the additional storage volume.



315
316
317
318
319
320
321
322
323
324
# File 'lib/aws-sdk-rds/types.rb', line 315

class AdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_throughputInteger

The storage throughput value for the additional storage volume, in mebibytes per second (MiBps). This setting applies only to the General Purpose SSD (gp3) storage type.



315
316
317
318
319
320
321
322
323
324
# File 'lib/aws-sdk-rds/types.rb', line 315

class AdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The storage type for the additional storage volume.

Valid Values: ‘GP3 | IO2`



315
316
317
318
319
320
321
322
323
324
# File 'lib/aws-sdk-rds/types.rb', line 315

class AdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#volume_nameString

The name of the additional storage volume.

Valid Values: ‘RDSDBDATA2 | RDSDBDATA3 | RDSDBDATA4`



315
316
317
318
319
320
321
322
323
324
# File 'lib/aws-sdk-rds/types.rb', line 315

class AdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end