Class: Aws::RDS::Types::AdditionalStorageVolumeOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains information about an additional storage volume for a DB instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The amount of storage allocated for the additional storage volume, in gibibytes (GiB). The minimum is 20 GiB. The maximum is 65,536 GiB (64 TiB).



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

The number of I/O operations per second (IOPS) provisioned for the additional storage volume.



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#max_allocated_storageInteger

The upper limit in gibibytes (GiB) to which RDS can automatically scale the storage of the additional storage volume.



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_operation_percent_progressInteger

The percentage of the in-progress storage operation on the additional storage volume that has completed, from 0 to 100. This field appears only while a storage operation is in progress. It isn't present when no storage operation is active.



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_operation_statusString

The status of an in-progress storage operation on the additional storage volume. This field appears only while a storage operation is in progress. It isn't present when no storage operation is active. Possible values:

  • Initializing - The volume is initializing from a snapshot, such as during a snapshot restore, point-in-time restore, read replica creation, or blue/green deployment. Performance can be lower than provisioned until initialization completes.

  • Optimizing - The volume is optimizing following a storage scaling or modification operation.



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_throughputInteger

The storage throughput value for the additional storage volume, in mebibytes per second (MiBps).



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The storage type for the additional storage volume.

Valid Values: GP3 | IO2



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_volume_statusString

The status of the additional storage volume.

Valid Values: ACTIVE | CREATING | DELETING | MODIFYING | NOT-IN-USE | STORAGE-OPTIMIZATION | VOLUME-FULL



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#volume_nameString

The name of the additional storage volume.



391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/aws-sdk-rds/types.rb', line 391

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :storage_operation_status,
  :storage_operation_percent_progress,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end