Class: Aws::RDS::Types::AuthorizeDBSecurityGroupIngressMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::AuthorizeDBSecurityGroupIngressMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidrip ⇒ String
The IP range to authorize.
-
#db_security_group_name ⇒ String
The name of the DB security group to add authorization to.
-
#ec2_security_group_id ⇒ String
Id of the EC2 security group to authorize.
-
#ec2_security_group_name ⇒ String
Name of the EC2 security group to authorize.
-
#ec2_security_group_owner_id ⇒ String
Amazon Web Services account number of the owner of the EC2 security group specified in the
EC2SecurityGroupNameparameter.
Instance Attribute Details
#cidrip ⇒ String
The IP range to authorize.
509 510 511 512 513 514 515 516 517 |
# File 'lib/aws-sdk-rds/types.rb', line 509 class AuthorizeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#db_security_group_name ⇒ String
The name of the DB security group to add authorization to.
509 510 511 512 513 514 515 516 517 |
# File 'lib/aws-sdk-rds/types.rb', line 509 class AuthorizeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#ec2_security_group_id ⇒ String
Id of the EC2 security group to authorize. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.
509 510 511 512 513 514 515 516 517 |
# File 'lib/aws-sdk-rds/types.rb', line 509 class AuthorizeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#ec2_security_group_name ⇒ String
Name of the EC2 security group to authorize. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.
509 510 511 512 513 514 515 516 517 |
# File 'lib/aws-sdk-rds/types.rb', line 509 class AuthorizeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#ec2_security_group_owner_id ⇒ String
Amazon Web Services account number of the owner of the EC2 security group specified in the EC2SecurityGroupName parameter. The Amazon Web Services access key ID isn’t an acceptable value. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.
509 510 511 512 513 514 515 516 517 |
# File 'lib/aws-sdk-rds/types.rb', line 509 class AuthorizeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |