Class: Aws::RDS::Types::AvailableAdditionalStorageVolumesOption

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains the available options for additional storage volumes for a DB instance class.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_iopsInteger

The maximum number of I/O operations per second (IOPS) that the additional storage volume supports.



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#max_iops_per_gibFloat

The maximum ratio of I/O operations per second (IOPS) to gibibytes (GiB) of storage for the additional storage volume.



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#max_storage_sizeInteger

The maximum amount of storage that you can allocate for the additional storage volume, in gibibytes (GiB).



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#max_storage_throughputInteger

The maximum storage throughput that the additional storage volume supports, in mebibytes per second (MiBps).



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#min_iopsInteger

The minimum number of I/O operations per second (IOPS) that the additional storage volume supports.



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#min_iops_per_gibFloat

The minimum ratio of I/O operations per second (IOPS) to gibibytes (GiB) of storage for the additional storage volume.



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#min_storage_sizeInteger

The minimum amount of storage that you can allocate for the additional storage volume, in gibibytes (GiB).



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#min_storage_throughputInteger

The minimum storage throughput that the additional storage volume supports, in mebibytes per second (MiBps).



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The storage type for the additional storage volume.

Valid Values: GP3 | IO2



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#supports_iopsBoolean

Indicates whether the additional storage volume supports provisioned IOPS.



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#supports_storage_autoscalingBoolean

Indicates whether the additional storage volume supports storage autoscaling.



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end

#supports_storage_throughputBoolean

Indicates whether the additional storage volume supports configurable storage throughput.



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
# File 'lib/aws-sdk-rds/types.rb', line 641

class AvailableAdditionalStorageVolumesOption < Struct.new(
  :supports_storage_autoscaling,
  :supports_storage_throughput,
  :supports_iops,
  :storage_type,
  :min_storage_size,
  :max_storage_size,
  :min_iops,
  :max_iops,
  :min_iops_per_gib,
  :max_iops_per_gib,
  :min_storage_throughput,
  :max_storage_throughput)
  SENSITIVE = []
  include Aws::Structure
end