Class: Aws::RDS::Types::CertificateMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Data returned by the DescribeCertificates action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#certificatesArray<Types::Certificate>

The list of Certificate objects for the Amazon Web Services account.

Returns:



1054
1055
1056
1057
1058
1059
1060
# File 'lib/aws-sdk-rds/types.rb', line 1054

class CertificateMessage < Struct.new(
  :default_certificate_for_new_launches,
  :certificates,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#default_certificate_for_new_launchesString

The default root CA for new databases created by your Amazon Web Services account. This is either the root CA override set on your Amazon Web Services account or the system default CA for the Region if no override exists. To override the default CA, use the ModifyCertificates operation.

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
# File 'lib/aws-sdk-rds/types.rb', line 1054

class CertificateMessage < Struct.new(
  :default_certificate_for_new_launches,
  :certificates,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeCertificates request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords .

Returns:

  • (String)


1054
1055
1056
1057
1058
1059
1060
# File 'lib/aws-sdk-rds/types.rb', line 1054

class CertificateMessage < Struct.new(
  :default_certificate_for_new_launches,
  :certificates,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end