Class: Aws::RDS::Types::CloudwatchLogsExportConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::CloudwatchLogsExportConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
The configuration setting for the log types to be enabled for export to CloudWatch Logs for a specific DB instance or DB cluster.
The EnableLogTypes and DisableLogTypes arrays determine which logs will be exported (or not exported) to CloudWatch Logs. The values within these arrays depend on the DB engine being used.
For more information about exporting CloudWatch Logs for Amazon RDS DB instances, see [Publishing Database Logs to Amazon CloudWatch Logs ][1] in the *Amazon RDS User Guide*.
For more information about exporting CloudWatch Logs for Amazon Aurora DB clusters, see [Publishing Database Logs to Amazon CloudWatch Logs] in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_LogAccess.html#USER_LogAccess.Procedural.UploadtoCloudWatch [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_LogAccess.html#USER_LogAccess.Procedural.UploadtoCloudWatch
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#disable_log_types ⇒ Array<String>
The list of log types to disable.
-
#enable_log_types ⇒ Array<String>
The list of log types to enable.
Instance Attribute Details
#disable_log_types ⇒ Array<String>
The list of log types to disable.
The following values are valid for each DB engine:
-
Aurora MySQL - ‘audit | error | general | slowquery`
-
Aurora PostgreSQL -
postgresql -
RDS for MySQL - ‘error | general | slowquery`
-
RDS for PostgreSQL - ‘postgresql | upgrade`
1118 1119 1120 1121 1122 1123 |
# File 'lib/aws-sdk-rds/types.rb', line 1118 class CloudwatchLogsExportConfiguration < Struct.new( :enable_log_types, :disable_log_types) SENSITIVE = [] include Aws::Structure end |
#enable_log_types ⇒ Array<String>
The list of log types to enable.
The following values are valid for each DB engine:
-
Aurora MySQL - ‘audit | error | general | slowquery`
-
Aurora PostgreSQL -
postgresql -
RDS for MySQL - ‘error | general | slowquery`
-
RDS for PostgreSQL - ‘postgresql | upgrade`
1118 1119 1120 1121 1122 1123 |
# File 'lib/aws-sdk-rds/types.rb', line 1118 class CloudwatchLogsExportConfiguration < Struct.new( :enable_log_types, :disable_log_types) SENSITIVE = [] include Aws::Structure end |