Class: Aws::RDS::Types::CopyDBClusterParameterGroupMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#source_db_cluster_parameter_group_identifierString

The identifier or Amazon Resource Name (ARN) for the source DB cluster parameter group. For information about creating an ARN, see Constructing an ARN for Amazon RDS in the Amazon Aurora User Guide.

Constraints:

  • Must specify a valid DB cluster parameter group.

^

Returns:

  • (String)


1472
1473
1474
1475
1476
1477
1478
1479
# File 'lib/aws-sdk-rds/types.rb', line 1472

class CopyDBClusterParameterGroupMessage < Struct.new(
  :source_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags.

For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.

Returns:



1472
1473
1474
1475
1476
1477
1478
1479
# File 'lib/aws-sdk-rds/types.rb', line 1472

class CopyDBClusterParameterGroupMessage < Struct.new(
  :source_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_db_cluster_parameter_group_descriptionString

A description for the copied DB cluster parameter group.

Returns:

  • (String)


1472
1473
1474
1475
1476
1477
1478
1479
# File 'lib/aws-sdk-rds/types.rb', line 1472

class CopyDBClusterParameterGroupMessage < Struct.new(
  :source_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#target_db_cluster_parameter_group_identifierString

The identifier for the copied DB cluster parameter group.

Constraints:

  • Can't be null, empty, or blank

  • Must contain from 1 to 255 letters, numbers, or hyphens

  • First character must be a letter

  • Can't end with a hyphen or contain two consecutive hyphens

Example: my-cluster-param-group1

Returns:

  • (String)


1472
1473
1474
1475
1476
1477
1478
1479
# File 'lib/aws-sdk-rds/types.rb', line 1472

class CopyDBClusterParameterGroupMessage < Struct.new(
  :source_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_identifier,
  :target_db_cluster_parameter_group_description,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end