Class: Aws::RDS::Types::CopyDBParameterGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::CopyDBParameterGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_db_parameter_group_identifier ⇒ String
The identifier or ARN for the source DB parameter group.
-
#tags ⇒ Array<Types::Tag>
A list of tags.
-
#target_db_parameter_group_description ⇒ String
A description for the copied DB parameter group.
-
#target_db_parameter_group_identifier ⇒ String
The identifier for the copied DB parameter group.
Instance Attribute Details
#source_db_parameter_group_identifier ⇒ String
The identifier or ARN for the source DB parameter group. For information about creating an ARN, see Constructing an ARN for Amazon RDS in the Amazon RDS User Guide.
Constraints:
- Must specify a valid DB parameter group.
^
1726 1727 1728 1729 1730 1731 1732 1733 |
# File 'lib/aws-sdk-rds/types.rb', line 1726 class CopyDBParameterGroupMessage < Struct.new( :source_db_parameter_group_identifier, :target_db_parameter_group_identifier, :target_db_parameter_group_description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.
1726 1727 1728 1729 1730 1731 1732 1733 |
# File 'lib/aws-sdk-rds/types.rb', line 1726 class CopyDBParameterGroupMessage < Struct.new( :source_db_parameter_group_identifier, :target_db_parameter_group_identifier, :target_db_parameter_group_description, :tags) SENSITIVE = [] include Aws::Structure end |
#target_db_parameter_group_description ⇒ String
A description for the copied DB parameter group.
1726 1727 1728 1729 1730 1731 1732 1733 |
# File 'lib/aws-sdk-rds/types.rb', line 1726 class CopyDBParameterGroupMessage < Struct.new( :source_db_parameter_group_identifier, :target_db_parameter_group_identifier, :target_db_parameter_group_description, :tags) SENSITIVE = [] include Aws::Structure end |
#target_db_parameter_group_identifier ⇒ String
The identifier for the copied DB parameter group.
Constraints:
-
Can't be null, empty, or blank
-
Must contain from 1 to 255 letters, numbers, or hyphens
-
First character must be a letter
-
Can't end with a hyphen or contain two consecutive hyphens
Example: my-db-parameter-group
1726 1727 1728 1729 1730 1731 1732 1733 |
# File 'lib/aws-sdk-rds/types.rb', line 1726 class CopyDBParameterGroupMessage < Struct.new( :source_db_parameter_group_identifier, :target_db_parameter_group_identifier, :target_db_parameter_group_description, :tags) SENSITIVE = [] include Aws::Structure end |