Class: Aws::RDS::Types::CreateDBClusterParameterGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::CreateDBClusterParameterGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group.
-
#db_parameter_group_family ⇒ String
The DB cluster parameter group family name.
-
#description ⇒ String
The description for the DB cluster parameter group.
-
#tags ⇒ Array<Types::Tag>
Tags to assign to the DB cluster parameter group.
Instance Attribute Details
#db_cluster_parameter_group_name ⇒ String
The name of the DB cluster parameter group.
Constraints:
-
Must not match the name of an existing DB cluster parameter group.
^
<note markdown=“1”> This value is stored as a lowercase string.
</note>
3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-rds/types.rb', line 3572 class CreateDBClusterParameterGroupMessage < Struct.new( :db_cluster_parameter_group_name, :db_parameter_group_family, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_family ⇒ String
The DB cluster parameter group family name. A DB cluster parameter group can be associated with one and only one DB cluster parameter group family, and can be applied only to a DB cluster running a database engine and engine version compatible with that DB cluster parameter group family.
**Aurora MySQL**
Example: aurora-mysql5.7, aurora-mysql8.0
**Aurora PostgreSQL**
Example: aurora-postgresql14
**RDS for MySQL**
Example: mysql8.0
**RDS for PostgreSQL**
Example: postgres13
To list all of the available parameter group families for a DB engine, use the following command:
‘aws rds describe-db-engine-versions –query “DBEngineVersions[].DBParameterGroupFamily” –engine <engine>`
For example, to list all of the available parameter group families for the Aurora PostgreSQL DB engine, use the following command:
‘aws rds describe-db-engine-versions –query “DBEngineVersions[].DBParameterGroupFamily” –engine aurora-postgresql`
<note markdown=“1”> The output contains duplicates.
</note>
The following are the valid DB engine values:
-
aurora-mysql -
aurora-postgresql -
mysql -
postgres
3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-rds/types.rb', line 3572 class CreateDBClusterParameterGroupMessage < Struct.new( :db_cluster_parameter_group_name, :db_parameter_group_family, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description for the DB cluster parameter group.
3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-rds/types.rb', line 3572 class CreateDBClusterParameterGroupMessage < Struct.new( :db_cluster_parameter_group_name, :db_parameter_group_family, :description, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
Tags to assign to the DB cluster parameter group.
3572 3573 3574 3575 3576 3577 3578 3579 |
# File 'lib/aws-sdk-rds/types.rb', line 3572 class CreateDBClusterParameterGroupMessage < Struct.new( :db_cluster_parameter_group_name, :db_parameter_group_family, :description, :tags) SENSITIVE = [] include Aws::Structure end |