Class: Aws::RDS::Types::CreateDBSnapshotMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::CreateDBSnapshotMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_instance_identifier ⇒ String
The identifier of the DB instance that you want to create the snapshot of.
-
#db_snapshot_identifier ⇒ String
The identifier for the DB snapshot.
-
#tags ⇒ Array<Types::Tag>
A list of tags.
Instance Attribute Details
#db_instance_identifier ⇒ String
The identifier of the DB instance that you want to create the snapshot of.
Constraints:
- Must match the identifier of an existing DBInstance.
^
6685 6686 6687 6688 6689 6690 6691 |
# File 'lib/aws-sdk-rds/types.rb', line 6685 class CreateDBSnapshotMessage < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#db_snapshot_identifier ⇒ String
The identifier for the DB snapshot.
Constraints:
-
Can't be null, empty, or blank
-
Must contain from 1 to 255 letters, numbers, or hyphens
-
First character must be a letter
-
Can't end with a hyphen or contain two consecutive hyphens
Example: my-snapshot-id
6685 6686 6687 6688 6689 6690 6691 |
# File 'lib/aws-sdk-rds/types.rb', line 6685 class CreateDBSnapshotMessage < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.
6685 6686 6687 6688 6689 6690 6691 |
# File 'lib/aws-sdk-rds/types.rb', line 6685 class CreateDBSnapshotMessage < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :tags) SENSITIVE = [] include Aws::Structure end |