Class: Aws::RDS::Types::CreateIntegrationMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_encryption_contextHash<String,String>

An optional set of non-secret key–value pairs that contains additional contextual information about the data. For more information, see [Encryption context] in the *Amazon Web Services Key Management Service Developer Guide*.

You can only include this parameter if you specify the KMSKeyId parameter.

[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context

Returns:

  • (Hash<String,String>)


7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
# File 'lib/aws-sdk-rds/types.rb', line 7040

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :additional_encryption_context,
  :tags,
  :data_filter,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#data_filterString

Data filtering options for the integration. For more information, see [Data filtering for Aurora zero-ETL integrations with Amazon Redshift] or [Data filtering for Amazon RDS zero-ETL integrations with Amazon Redshift].

[1]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/zero-etl.filtering.html [2]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/zero-etl.filtering.html

Returns:

  • (String)


7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
# File 'lib/aws-sdk-rds/types.rb', line 7040

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :additional_encryption_context,
  :tags,
  :data_filter,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the integration.

Returns:

  • (String)


7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
# File 'lib/aws-sdk-rds/types.rb', line 7040

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :additional_encryption_context,
  :tags,
  :data_filter,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#integration_nameString

The name of the integration.

Returns:

  • (String)


7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
# File 'lib/aws-sdk-rds/types.rb', line 7040

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :additional_encryption_context,
  :tags,
  :data_filter,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Web Services Key Management System (Amazon Web Services KMS) key identifier for the key to use to encrypt the integration. If you don’t specify an encryption key, RDS uses a default Amazon Web Services owned key.

Returns:

  • (String)


7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
# File 'lib/aws-sdk-rds/types.rb', line 7040

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :additional_encryption_context,
  :tags,
  :data_filter,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) of the database to use as the source for replication.

Returns:

  • (String)


7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
# File 'lib/aws-sdk-rds/types.rb', line 7040

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :additional_encryption_context,
  :tags,
  :data_filter,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags.

For more information, see [Tagging Amazon RDS resources] in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources] in the *Amazon Aurora User Guide*.

[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html

Returns:



7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
# File 'lib/aws-sdk-rds/types.rb', line 7040

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :additional_encryption_context,
  :tags,
  :data_filter,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#target_arnString

The ARN of the Redshift data warehouse to use as the target for replication.

Returns:

  • (String)


7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
# File 'lib/aws-sdk-rds/types.rb', line 7040

class CreateIntegrationMessage < Struct.new(
  :source_arn,
  :target_arn,
  :integration_name,
  :kms_key_id,
  :additional_encryption_context,
  :tags,
  :data_filter,
  :description)
  SENSITIVE = []
  include Aws::Structure
end