Class: Aws::RDS::Types::DBClusterAssociatedRole

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains information about an Amazon Web Services Identity and Access Management (IAM) role to associate with a DB cluster. You can specify this structure in the AssociatedRoles parameter of CreateDBCluster, RestoreDBClusterFromS3, RestoreDBClusterFromSnapshot, and RestoreDBClusterToPointInTime.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#feature_nameString

The name of the feature associated with the IAM role. For information about supported feature names, see DBEngineVersion.

Returns:

  • (String)


8132
8133
8134
8135
8136
8137
# File 'lib/aws-sdk-rds/types.rb', line 8132

class DBClusterAssociatedRole < Struct.new(
  :role_arn,
  :feature_name)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role to associate with the DB cluster.

Returns:

  • (String)


8132
8133
8134
8135
8136
8137
# File 'lib/aws-sdk-rds/types.rb', line 8132

class DBClusterAssociatedRole < Struct.new(
  :role_arn,
  :feature_name)
  SENSITIVE = []
  include Aws::Structure
end