Class: Aws::RDS::Types::DBClusterEndpoint
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBClusterEndpoint
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type represents the information you need to connect to an Amazon Aurora DB cluster. This data type is used as a response element in the following actions:
-
CreateDBClusterEndpoint -
DescribeDBClusterEndpoints -
ModifyDBClusterEndpoint -
DeleteDBClusterEndpoint
For the data structure that represents Amazon RDS DB instance endpoints, see Endpoint.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_endpoint_type ⇒ String
The type associated with a custom endpoint.
-
#db_cluster_endpoint_arn ⇒ String
The Amazon Resource Name (ARN) for the endpoint.
-
#db_cluster_endpoint_identifier ⇒ String
The identifier associated with the endpoint.
-
#db_cluster_endpoint_resource_identifier ⇒ String
A unique system-generated identifier for an endpoint.
-
#db_cluster_identifier ⇒ String
The DB cluster identifier of the DB cluster associated with the endpoint.
-
#endpoint ⇒ String
The DNS address of the endpoint.
-
#endpoint_type ⇒ String
The type of the endpoint.
-
#excluded_members ⇒ Array<String>
List of DB instance identifiers that aren’t part of the custom endpoint group.
-
#static_members ⇒ Array<String>
List of DB instance identifiers that are part of the custom endpoint group.
-
#status ⇒ String
The current status of the endpoint.
Instance Attribute Details
#custom_endpoint_type ⇒ String
The type associated with a custom endpoint. One of: READER, WRITER, ANY.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#db_cluster_endpoint_arn ⇒ String
The Amazon Resource Name (ARN) for the endpoint.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#db_cluster_endpoint_identifier ⇒ String
The identifier associated with the endpoint. This parameter is stored as a lowercase string.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#db_cluster_endpoint_resource_identifier ⇒ String
A unique system-generated identifier for an endpoint. It remains the same for the whole life of the endpoint.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The DB cluster identifier of the DB cluster associated with the endpoint. This parameter is stored as a lowercase string.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The DNS address of the endpoint.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#endpoint_type ⇒ String
The type of the endpoint. One of: READER, WRITER, CUSTOM.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#excluded_members ⇒ Array<String>
List of DB instance identifiers that aren’t part of the custom endpoint group. All other eligible instances are reachable through the custom endpoint. Only relevant if the list of static members is empty.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#static_members ⇒ Array<String>
List of DB instance identifiers that are part of the custom endpoint group.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the endpoint. One of: creating, available, deleting, inactive, modifying. The inactive state applies to an endpoint that can’t be used for a certain kind of cluster, such as a writer endpoint for a read-only secondary cluster in a global database.
8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 |
# File 'lib/aws-sdk-rds/types.rb', line 8505 class DBClusterEndpoint < Struct.new( :db_cluster_endpoint_identifier, :db_cluster_identifier, :db_cluster_endpoint_resource_identifier, :endpoint, :status, :endpoint_type, :custom_endpoint_type, :static_members, :excluded_members, :db_cluster_endpoint_arn) SENSITIVE = [] include Aws::Structure end |