Class: Aws::RDS::Types::DBClusterMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBClusterMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the result of a successful invocation of the
DescribeDBClusters action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_clusters ⇒ Array<Types::DBCluster>
Contains a list of DB clusters for the user.
-
#marker ⇒ String
A pagination token that can be used in a later
DescribeDBClustersrequest.
Instance Attribute Details
#db_clusters ⇒ Array<Types::DBCluster>
Contains a list of DB clusters for the user.
8694 8695 8696 8697 8698 8699 |
# File 'lib/aws-sdk-rds/types.rb', line 8694 class DBClusterMessage < Struct.new( :marker, :db_clusters) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
A pagination token that can be used in a later DescribeDBClusters
request.
8694 8695 8696 8697 8698 8699 |
# File 'lib/aws-sdk-rds/types.rb', line 8694 class DBClusterMessage < Struct.new( :marker, :db_clusters) SENSITIVE = [] include Aws::Structure end |