Class: Aws::RDS::Types::DBClusterSnapshot

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains the details for an Amazon RDS DB cluster snapshot

This data type is used as a response element in the DescribeDBClusterSnapshots action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The allocated storage size of the DB cluster snapshot in gibibytes (GiB).

Returns:

  • (Integer)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zonesArray<String>

The list of Availability Zones (AZs) where instances in the DB cluster snapshot can be restored.

Returns:

  • (Array<String>)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#backup_retention_periodInteger

The number of days for which automatic DB snapshots are retained.

Returns:

  • (Integer)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#cluster_create_timeTime

The time when the DB cluster was created, in Universal Coordinated Time (UTC).

Returns:

  • (Time)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_identifierString

The DB cluster identifier of the DB cluster that this DB cluster snapshot was created from.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_resource_idString

The resource ID of the DB cluster that this DB cluster snapshot was created from.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_snapshot_arnString

The Amazon Resource Name (ARN) for the DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_cluster_snapshot_identifierString

The identifier for the DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#db_system_idString

Reserved for future use.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The name of the database engine for this DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#engine_modeString

The engine mode of the database engine for this DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The version of the database engine for this DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#iam_database_authentication_enabledBoolean

Indicates whether mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.

Returns:

  • (Boolean)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

If StorageEncrypted is true, the Amazon Web Services KMS key identifier for the encrypted DB cluster snapshot.

The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#license_modelString

The license model information for this DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#master_usernameString

The master username for this DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#percent_progressInteger

The percentage of the estimated data that has been transferred.

Returns:

  • (Integer)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port that the DB cluster was listening on at the time of the snapshot.

Returns:

  • (Integer)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#preferred_backup_windowString

The daily time range during which automated backups are created if automated backups are enabled, as determined by the BackupRetentionPeriod.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_create_timeTime

The time when the snapshot was taken, in Universal Coordinated Time (UTC).

Returns:

  • (Time)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_typeString

The type of the DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#source_db_cluster_snapshot_arnString

If the DB cluster snapshot was copied from a source DB cluster snapshot, the Amazon Resource Name (ARN) for the source DB cluster snapshot, otherwise, a null value.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of this DB cluster snapshot. Valid statuses are the following:

  • available

  • copying

  • creating

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#storage_encryptedBoolean

Indicates whether the DB cluster snapshot is encrypted.

Returns:

  • (Boolean)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#storage_encryption_typeString

The type of encryption used to protect data at rest in the DB cluster snapshot. Possible values:

  • none - The DB cluster snapshot is not encrypted.

  • sse-rds - The DB cluster snapshot is encrypted using an Amazon Web Services owned KMS key.

  • sse-kms - The DB cluster snapshot is encrypted using a customer managed KMS key or Amazon Web Services managed KMS key.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#storage_throughputInteger

The storage throughput for the DB cluster snapshot. The throughput is automatically set based on the IOPS that you provision, and is not configurable.

This setting is only for non-Aurora Multi-AZ DB clusters.

Returns:

  • (Integer)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The storage type associated with the DB cluster snapshot.

This setting is only for Aurora DB clusters.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#tag_listArray<Types::Tag>

A list of tags.

For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.

Returns:



9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The VPC ID associated with the DB cluster snapshot.

Returns:

  • (String)


9047
9048
9049
9050
9051
9052
9053
9054
9055
9056
9057
9058
9059
9060
9061
9062
9063
9064
9065
9066
9067
9068
9069
9070
9071
9072
9073
9074
9075
9076
9077
9078
9079
# File 'lib/aws-sdk-rds/types.rb', line 9047

class DBClusterSnapshot < Struct.new(
  :availability_zones,
  :db_cluster_snapshot_identifier,
  :db_cluster_identifier,
  :snapshot_create_time,
  :engine,
  :engine_mode,
  :allocated_storage,
  :status,
  :port,
  :vpc_id,
  :cluster_create_time,
  :master_username,
  :engine_version,
  :license_model,
  :snapshot_type,
  :percent_progress,
  :storage_encrypted,
  :storage_encryption_type,
  :backup_retention_period,
  :preferred_backup_window,
  :kms_key_id,
  :db_cluster_snapshot_arn,
  :source_db_cluster_snapshot_arn,
  :iam_database_authentication_enabled,
  :tag_list,
  :storage_type,
  :storage_throughput,
  :db_cluster_resource_id,
  :db_system_id)
  SENSITIVE = []
  include Aws::Structure
end