Class: Aws::RDS::Types::DBClusterSnapshotAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBClusterSnapshotAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the name and values of a manual DB cluster snapshot attribute.
Manual DB cluster snapshot attributes are used to authorize other Amazon Web Services accounts to restore a manual DB cluster snapshot. For more information, see the ModifyDBClusterSnapshotAttribute API action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
The name of the manual DB cluster snapshot attribute.
-
#attribute_values ⇒ Array<String>
The value(s) for the manual DB cluster snapshot attribute.
Instance Attribute Details
#attribute_name ⇒ String
The name of the manual DB cluster snapshot attribute.
The attribute named restore refers to the list of Amazon Web Services accounts that have permission to copy or restore the manual DB cluster snapshot. For more information, see the ModifyDBClusterSnapshotAttribute API action.
9059 9060 9061 9062 9063 9064 |
# File 'lib/aws-sdk-rds/types.rb', line 9059 class DBClusterSnapshotAttribute < Struct.new( :attribute_name, :attribute_values) SENSITIVE = [] include Aws::Structure end |
#attribute_values ⇒ Array<String>
The value(s) for the manual DB cluster snapshot attribute.
If the AttributeName field is set to restore, then this element returns a list of IDs of the Amazon Web Services accounts that are authorized to copy or restore the manual DB cluster snapshot. If a value of all is in the list, then the manual DB cluster snapshot is public and available for any Amazon Web Services account to copy or restore.
9059 9060 9061 9062 9063 9064 |
# File 'lib/aws-sdk-rds/types.rb', line 9059 class DBClusterSnapshotAttribute < Struct.new( :attribute_name, :attribute_values) SENSITIVE = [] include Aws::Structure end |