Class: Aws::RDS::Types::DBEngineVersion
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBEngineVersion
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type is used as a response element in the action
DescribeDBEngineVersions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#create_time ⇒ Time
The creation time of the DB engine version.
-
#custom_db_engine_version_manifest ⇒ String
JSON string that lists the installation files and parameters that RDS Custom uses to create a custom engine version (CEV).
-
#database_installation_files ⇒ Array<String>
The database installation files (ISO and EXE) that were uploaded to Amazon S3 and used to import the database engine version to Amazon RDS.
-
#database_installation_files_s3_bucket_name ⇒ String
The name of the Amazon S3 bucket that contains your database installation files.
-
#database_installation_files_s3_prefix ⇒ String
The Amazon S3 directory that contains the database installation files.
-
#db_engine_description ⇒ String
The description of the database engine.
-
#db_engine_media_type ⇒ String
The source of the installation media for this engine version.
-
#db_engine_version_arn ⇒ String
The ARN of the custom engine version.
-
#db_engine_version_description ⇒ String
The description of the database engine version.
-
#db_parameter_group_family ⇒ String
The name of the DB parameter group family for the database engine.
-
#default_character_set ⇒ Types::CharacterSet
The default character set for new instances of this engine version, if the
CharacterSetNameparameter of the CreateDBInstance API isn't specified. -
#engine ⇒ String
The name of the database engine.
-
#engine_version ⇒ String
The version number of the database engine.
-
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to CloudWatch Logs.
-
#failure_reason ⇒ String
The reason that the custom engine version creation failed with an
incompatible-installation-mediastatus. -
#image ⇒ Types::CustomDBEngineVersionAMI
The EC2 image.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for an encrypted CEV.
-
#major_engine_version ⇒ String
The major engine version of the CEV.
-
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Aurora Serverless v2 properties or limits that differ between Aurora engine versions.
-
#status ⇒ String
The status of the DB engine version, either
availableordeprecated. -
#supported_ca_certificate_identifiers ⇒ Array<String>
A list of the supported CA certificate identifiers.
-
#supported_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by this engine for the
CharacterSetNameparameter of theCreateDBInstanceoperation. -
#supported_engine_modes ⇒ Array<String>
A list of the supported DB engine modes.
-
#supported_feature_names ⇒ Array<String>
A list of features supported by the DB engine.
-
#supported_nchar_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by the Oracle DB engine for the
NcharCharacterSetNameparameter of theCreateDBInstanceoperation. -
#supported_timezones ⇒ Array<Types::Timezone>
A list of the time zones supported by this engine for the
Timezoneparameter of theCreateDBInstanceaction. -
#supports_babelfish ⇒ Boolean
Indicates whether the engine version supports Babelfish for Aurora PostgreSQL.
-
#supports_certificate_rotation_without_restart ⇒ Boolean
Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.
-
#supports_global_databases ⇒ Boolean
Indicates whether you can use Aurora global databases with a specific DB engine version.
-
#supports_integrations ⇒ Boolean
Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.
-
#supports_limitless_database ⇒ Boolean
Indicates whether the DB engine version supports Aurora Limitless Database.
-
#supports_local_write_forwarding ⇒ Boolean
Indicates whether the DB engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster.
-
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
Indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.
-
#supports_parallel_query ⇒ Boolean
Indicates whether you can use Aurora parallel query with a specific DB engine version.
-
#supports_read_replica ⇒ Boolean
Indicates whether the database engine version supports read replicas.
-
#tag_list ⇒ Array<Types::Tag>
A list of tags.
-
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
Instance Attribute Details
#create_time ⇒ Time
The creation time of the DB engine version.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#custom_db_engine_version_manifest ⇒ String
JSON string that lists the installation files and parameters that RDS Custom uses to create a custom engine version (CEV). RDS Custom applies the patches in the order in which they're listed in the manifest. You can set the Oracle home, Oracle base, and UNIX/Linux user and group using the installation parameters. For more information, see JSON fields in the CEV manifest in the Amazon RDS User Guide.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#database_installation_files ⇒ Array<String>
The database installation files (ISO and EXE) that were uploaded to
Amazon S3 and used to import the database engine version to Amazon
RDS. Returned for RDS for SQL Server engine versions
(sqlserver-ee, sqlserver-se, and sqlserver-dev-ee) created
from customer-supplied installation media.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#database_installation_files_s3_bucket_name ⇒ String
The name of the Amazon S3 bucket that contains your database installation files.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#database_installation_files_s3_prefix ⇒ String
The Amazon S3 directory that contains the database installation files. If not specified, then no prefix is assumed.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#db_engine_description ⇒ String
The description of the database engine.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#db_engine_media_type ⇒ String
The source of the installation media for this engine version. A
value of Customer Provided indicates that the engine version was
created from customer-supplied installation media using
CreateCustomDBEngineVersion. Applicable to RDS Custom for SQL
Server and to RDS for SQL Server engine versions (sqlserver-ee and
sqlserver-se with the bring-your-own-media license model, and
sqlserver-dev-ee).
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#db_engine_version_arn ⇒ String
The ARN of the custom engine version.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#db_engine_version_description ⇒ String
The description of the database engine version.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#db_parameter_group_family ⇒ String
The name of the DB parameter group family for the database engine.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#default_character_set ⇒ Types::CharacterSet
The default character set for new instances of this engine version,
if the CharacterSetName parameter of the CreateDBInstance API
isn't specified.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the database engine.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version number of the database engine.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to CloudWatch Logs.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#failure_reason ⇒ String
The reason that the custom engine version creation failed with an
incompatible-installation-media status. Applicable to RDS for SQL
Server engine versions (sqlserver-ee, sqlserver-se, and
sqlserver-dev-ee).
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#image ⇒ Types::CustomDBEngineVersionAMI
The EC2 image
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for an encrypted CEV. This parameter is required for RDS Custom, but optional for Amazon RDS.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#major_engine_version ⇒ String
The major engine version of the CEV.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Aurora Serverless v2 properties or limits that differ between Aurora engine versions. You can test the values of this attribute when deciding which Aurora version to use in a new or upgraded DB cluster. You can also retrieve the version of an existing DB cluster and check whether that version supports certain Aurora Serverless v2 features before you attempt to use those features.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the DB engine version, either available or
deprecated.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supported_ca_certificate_identifiers ⇒ Array<String>
A list of the supported CA certificate identifiers.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supported_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by this engine for the
CharacterSetName parameter of the CreateDBInstance operation.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supported_engine_modes ⇒ Array<String>
A list of the supported DB engine modes.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supported_feature_names ⇒ Array<String>
A list of features supported by the DB engine.
The supported features vary by DB engine and DB engine version.
To determine the supported features for a specific DB engine and DB engine version using the CLI, use the following command:
aws rds describe-db-engine-versions --engine <engine_name> --engine-version <engine_version>
For example, to determine the supported features for RDS for PostgreSQL version 13.3 using the CLI, use the following command:
aws rds describe-db-engine-versions --engine postgres --engine-version 13.3
The supported features are listed under SupportedFeatureNames in
the output.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supported_nchar_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by the Oracle DB engine for
the NcharCharacterSetName parameter of the CreateDBInstance
operation.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supported_timezones ⇒ Array<Types::Timezone>
A list of the time zones supported by this engine for the Timezone
parameter of the CreateDBInstance action.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_babelfish ⇒ Boolean
Indicates whether the engine version supports Babelfish for Aurora PostgreSQL.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_certificate_rotation_without_restart ⇒ Boolean
Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_global_databases ⇒ Boolean
Indicates whether you can use Aurora global databases with a specific DB engine version.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_integrations ⇒ Boolean
Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_limitless_database ⇒ Boolean
Indicates whether the DB engine version supports Aurora Limitless Database.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_local_write_forwarding ⇒ Boolean
Indicates whether the DB engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster. By default, write operations aren't allowed on reader DB instances.
Valid for: Aurora DB clusters only
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
Indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_parallel_query ⇒ Boolean
Indicates whether you can use Aurora parallel query with a specific DB engine version.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#supports_read_replica ⇒ Boolean
Indicates whether the database engine version supports read replicas.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#tag_list ⇒ Array<Types::Tag>
A list of tags.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
9454 9455 9456 9457 9458 9459 9460 9461 9462 9463 9464 9465 9466 9467 9468 9469 9470 9471 9472 9473 9474 9475 9476 9477 9478 9479 9480 9481 9482 9483 9484 9485 9486 9487 9488 9489 9490 9491 9492 9493 9494 |
# File 'lib/aws-sdk-rds/types.rb', line 9454 class DBEngineVersion < Struct.new( :engine, :major_engine_version, :engine_version, :database_installation_files_s3_bucket_name, :database_installation_files_s3_prefix, :database_installation_files, :custom_db_engine_version_manifest, :db_parameter_group_family, :db_engine_description, :db_engine_version_arn, :db_engine_version_description, :default_character_set, :failure_reason, :image, :db_engine_media_type, :kms_key_id, :create_time, :supported_character_sets, :supported_nchar_character_sets, :valid_upgrade_target, :supported_timezones, :exportable_log_types, :supports_log_exports_to_cloudwatch_logs, :supports_read_replica, :supported_engine_modes, :supported_feature_names, :status, :supports_parallel_query, :supports_global_databases, :tag_list, :supports_babelfish, :supports_limitless_database, :supports_certificate_rotation_without_restart, :supported_ca_certificate_identifiers, :supports_local_write_forwarding, :supports_integrations, :serverless_v2_features_support) SENSITIVE = [] include Aws::Structure end |