Class: Aws::RDS::Types::DBInstanceStatusInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Provides a list of status information for a DB instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

Details of the error if there is an error for the instance. If the instance isn’t in an error state, this value is blank.



10640
10641
10642
10643
10644
10645
10646
10647
# File 'lib/aws-sdk-rds/types.rb', line 10640

class DBInstanceStatusInfo < Struct.new(
  :status_type,
  :normal,
  :status,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#normalBoolean

Indicates whether the instance is operating normally (TRUE) or is in an error state (FALSE).



10640
10641
10642
10643
10644
10645
10646
10647
# File 'lib/aws-sdk-rds/types.rb', line 10640

class DBInstanceStatusInfo < Struct.new(
  :status_type,
  :normal,
  :status,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the DB instance. For a StatusType of read replica, the values can be replicating, replication stop point set, replication stop point reached, error, stopped, or terminated.



10640
10641
10642
10643
10644
10645
10646
10647
# File 'lib/aws-sdk-rds/types.rb', line 10640

class DBInstanceStatusInfo < Struct.new(
  :status_type,
  :normal,
  :status,
  :message)
  SENSITIVE = []
  include Aws::Structure
end

#status_typeString

This value is currently “read replication.”



10640
10641
10642
10643
10644
10645
10646
10647
# File 'lib/aws-sdk-rds/types.rb', line 10640

class DBInstanceStatusInfo < Struct.new(
  :status_type,
  :normal,
  :status,
  :message)
  SENSITIVE = []
  include Aws::Structure
end