Class: Aws::RDS::Types::DBProxyTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBProxyTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the details for an RDS Proxy target. It represents an RDS DB instance or Aurora DB cluster that the proxy can connect to. One or more targets are associated with an RDS Proxy target group.
This data type is used as a response element in the
DescribeDBProxyTargets action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#endpoint ⇒ String
The writer endpoint for the RDS DB instance or Aurora DB cluster.
-
#port ⇒ Integer
The port that the RDS Proxy uses to connect to the target RDS DB instance or Aurora DB cluster.
-
#rds_resource_id ⇒ String
The identifier representing the target.
-
#role ⇒ String
A value that indicates whether the target of the proxy can be used for read/write or read-only operations.
-
#target_arn ⇒ String
The Amazon Resource Name (ARN) for the RDS DB instance or Aurora DB cluster.
-
#target_health ⇒ Types::TargetHealth
Information about the connection health of the RDS Proxy target.
-
#tracked_cluster_id ⇒ String
The DB cluster identifier when the target represents an Aurora DB cluster.
-
#type ⇒ String
Specifies the kind of database, such as an RDS DB instance or an Aurora DB cluster, that the target represents.
Instance Attribute Details
#endpoint ⇒ String
The writer endpoint for the RDS DB instance or Aurora DB cluster.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 |
# File 'lib/aws-sdk-rds/types.rb', line 11248 class DBProxyTarget < Struct.new( :target_arn, :endpoint, :tracked_cluster_id, :rds_resource_id, :port, :type, :role, :target_health) SENSITIVE = [] include Aws::Structure end |
#port ⇒ Integer
The port that the RDS Proxy uses to connect to the target RDS DB instance or Aurora DB cluster.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 |
# File 'lib/aws-sdk-rds/types.rb', line 11248 class DBProxyTarget < Struct.new( :target_arn, :endpoint, :tracked_cluster_id, :rds_resource_id, :port, :type, :role, :target_health) SENSITIVE = [] include Aws::Structure end |
#rds_resource_id ⇒ String
The identifier representing the target. It can be the instance identifier for an RDS DB instance, or the cluster identifier for an Aurora DB cluster.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 |
# File 'lib/aws-sdk-rds/types.rb', line 11248 class DBProxyTarget < Struct.new( :target_arn, :endpoint, :tracked_cluster_id, :rds_resource_id, :port, :type, :role, :target_health) SENSITIVE = [] include Aws::Structure end |
#role ⇒ String
A value that indicates whether the target of the proxy can be used for read/write or read-only operations.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 |
# File 'lib/aws-sdk-rds/types.rb', line 11248 class DBProxyTarget < Struct.new( :target_arn, :endpoint, :tracked_cluster_id, :rds_resource_id, :port, :type, :role, :target_health) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The Amazon Resource Name (ARN) for the RDS DB instance or Aurora DB cluster.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 |
# File 'lib/aws-sdk-rds/types.rb', line 11248 class DBProxyTarget < Struct.new( :target_arn, :endpoint, :tracked_cluster_id, :rds_resource_id, :port, :type, :role, :target_health) SENSITIVE = [] include Aws::Structure end |
#target_health ⇒ Types::TargetHealth
Information about the connection health of the RDS Proxy target.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 |
# File 'lib/aws-sdk-rds/types.rb', line 11248 class DBProxyTarget < Struct.new( :target_arn, :endpoint, :tracked_cluster_id, :rds_resource_id, :port, :type, :role, :target_health) SENSITIVE = [] include Aws::Structure end |
#tracked_cluster_id ⇒ String
The DB cluster identifier when the target represents an Aurora DB cluster. This field is blank when the target represents an RDS DB instance.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 |
# File 'lib/aws-sdk-rds/types.rb', line 11248 class DBProxyTarget < Struct.new( :target_arn, :endpoint, :tracked_cluster_id, :rds_resource_id, :port, :type, :role, :target_health) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Specifies the kind of database, such as an RDS DB instance or an Aurora DB cluster, that the target represents.
11248 11249 11250 11251 11252 11253 11254 11255 11256 11257 11258 11259 |
# File 'lib/aws-sdk-rds/types.rb', line 11248 class DBProxyTarget < Struct.new( :target_arn, :endpoint, :tracked_cluster_id, :rds_resource_id, :port, :type, :role, :target_health) SENSITIVE = [] include Aws::Structure end |