Class: Aws::RDS::Types::DBProxyTargetGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Represents a set of RDS DB instances, Aurora DB clusters, or both that a proxy can connect to. Currently, each target group is associated with exactly one RDS DB instance or Aurora DB cluster.

This data type is used as a response element in the DescribeDBProxyTargetGroups action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connection_pool_configTypes::ConnectionPoolConfigurationInfo

The settings that determine the size and behavior of the connection pool for the target group.



11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
# File 'lib/aws-sdk-rds/types.rb', line 11229

class DBProxyTargetGroup < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :target_group_arn,
  :is_default,
  :status,
  :connection_pool_config,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#created_dateTime

The date and time when the target group was first created.

Returns:

  • (Time)


11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
# File 'lib/aws-sdk-rds/types.rb', line 11229

class DBProxyTargetGroup < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :target_group_arn,
  :is_default,
  :status,
  :connection_pool_config,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#db_proxy_nameString

The identifier for the RDS proxy associated with this target group.

Returns:

  • (String)


11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
# File 'lib/aws-sdk-rds/types.rb', line 11229

class DBProxyTargetGroup < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :target_group_arn,
  :is_default,
  :status,
  :connection_pool_config,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#is_defaultBoolean

Indicates whether this target group is the first one used for connection requests by the associated proxy. Because each proxy is currently associated with a single target group, currently this setting is always true.

Returns:

  • (Boolean)


11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
# File 'lib/aws-sdk-rds/types.rb', line 11229

class DBProxyTargetGroup < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :target_group_arn,
  :is_default,
  :status,
  :connection_pool_config,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of this target group. A status of available means the target group is correctly associated with a database. Other values indicate that you must wait for the target group to be ready, or take some action to resolve an issue.

Returns:

  • (String)


11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
# File 'lib/aws-sdk-rds/types.rb', line 11229

class DBProxyTargetGroup < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :target_group_arn,
  :is_default,
  :status,
  :connection_pool_config,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#target_group_arnString

The Amazon Resource Name (ARN) representing the target group.

Returns:

  • (String)


11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
# File 'lib/aws-sdk-rds/types.rb', line 11229

class DBProxyTargetGroup < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :target_group_arn,
  :is_default,
  :status,
  :connection_pool_config,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#target_group_nameString

The identifier for the target group. This name must be unique for all target groups owned by your Amazon Web Services account in the specified Amazon Web Services Region.

Returns:

  • (String)


11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
# File 'lib/aws-sdk-rds/types.rb', line 11229

class DBProxyTargetGroup < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :target_group_arn,
  :is_default,
  :status,
  :connection_pool_config,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end

#updated_dateTime

The date and time when the target group was last updated.

Returns:

  • (Time)


11229
11230
11231
11232
11233
11234
11235
11236
11237
11238
11239
11240
# File 'lib/aws-sdk-rds/types.rb', line 11229

class DBProxyTargetGroup < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :target_group_arn,
  :is_default,
  :status,
  :connection_pool_config,
  :created_date,
  :updated_date)
  SENSITIVE = []
  include Aws::Structure
end