Class: Aws::RDS::Types::DBRecommendationsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_recommendationsArray<Types::DBRecommendation>

A list of recommendations which is returned from DescribeDBRecommendations API request.

Returns:



11443
11444
11445
11446
11447
11448
# File 'lib/aws-sdk-rds/types.rb', line 11443

class DBRecommendationsMessage < Struct.new(
  :db_recommendations,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DBRecommendationsMessage request. This token can be used later in a DescribeDBRecomendations request.

Returns:

  • (String)


11443
11444
11445
11446
11447
11448
# File 'lib/aws-sdk-rds/types.rb', line 11443

class DBRecommendationsMessage < Struct.new(
  :db_recommendations,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end