Class: Aws::RDS::Types::DBSnapshotAttribute
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBSnapshotAttribute
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the name and values of a manual DB snapshot attribute
Manual DB snapshot attributes are used to authorize other Amazon Web Services accounts to restore a manual DB snapshot. For more information, see the ModifyDBSnapshotAttribute API.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#attribute_name ⇒ String
The name of the manual DB snapshot attribute.
-
#attribute_values ⇒ Array<String>
The value or values for the manual DB snapshot attribute.
Instance Attribute Details
#attribute_name ⇒ String
The name of the manual DB snapshot attribute.
The attribute named restore refers to the list of Amazon Web Services accounts that have permission to copy or restore the manual DB cluster snapshot. For more information, see the ModifyDBSnapshotAttribute API action.
11877 11878 11879 11880 11881 11882 |
# File 'lib/aws-sdk-rds/types.rb', line 11877 class DBSnapshotAttribute < Struct.new( :attribute_name, :attribute_values) SENSITIVE = [] include Aws::Structure end |
#attribute_values ⇒ Array<String>
The value or values for the manual DB snapshot attribute.
If the AttributeName field is set to restore, then this element returns a list of IDs of the Amazon Web Services accounts that are authorized to copy or restore the manual DB snapshot. If a value of all is in the list, then the manual DB snapshot is public and available for any Amazon Web Services account to copy or restore.
11877 11878 11879 11880 11881 11882 |
# File 'lib/aws-sdk-rds/types.rb', line 11877 class DBSnapshotAttribute < Struct.new( :attribute_name, :attribute_values) SENSITIVE = [] include Aws::Structure end |