Class: Aws::RDS::Types::DBSnapshotMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBSnapshotMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the result of a successful invocation of the ‘DescribeDBSnapshots` action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_snapshots ⇒ Array<Types::DBSnapshot>
A list of ‘DBSnapshot` instances.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
Instance Attribute Details
#db_snapshots ⇒ Array<Types::DBSnapshot>
A list of ‘DBSnapshot` instances.
12046 12047 12048 12049 12050 12051 |
# File 'lib/aws-sdk-rds/types.rb', line 12046 class DBSnapshotMessage < Struct.new( :marker, :db_snapshots) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.
12046 12047 12048 12049 12050 12051 |
# File 'lib/aws-sdk-rds/types.rb', line 12046 class DBSnapshotMessage < Struct.new( :marker, :db_snapshots) SENSITIVE = [] include Aws::Structure end |