Class: Aws::RDS::Types::DBSnapshotTenantDatabase

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains the details of a tenant database in a snapshot of a DB instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#character_set_nameString

The name of the character set of a tenant database.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_identifierString

The ID for the DB instance that contains the tenant databases.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#db_snapshot_identifierString

The identifier for the snapshot of the DB instance.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#db_snapshot_tenant_database_arnString

The Amazon Resource Name (ARN) for the snapshot tenant database.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#dbi_resource_idString

The resource identifier of the source CDB instance. This identifier can't be changed and is unique to an Amazon Web Services Region.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#engine_nameString

The name of the database engine.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#master_usernameString

The master username of the tenant database.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#nchar_character_set_nameString

The NCHAR character set name of the tenant database.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_typeString

The type of DB snapshot.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#tag_listArray<Types::Tag>

A list of tags.

For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.

Returns:



12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_database_create_timeTime

The time the DB snapshot was taken, specified in Coordinated Universal Time (UTC). If you copy the snapshot, the creation time changes.

Returns:

  • (Time)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_database_resource_idString

The resource ID of the tenant database.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_db_nameString

The name of the tenant database.

Returns:

  • (String)


12273
12274
12275
12276
12277
12278
12279
12280
12281
12282
12283
12284
12285
12286
12287
12288
12289
# File 'lib/aws-sdk-rds/types.rb', line 12273

class DBSnapshotTenantDatabase < Struct.new(
  :db_snapshot_identifier,
  :db_instance_identifier,
  :dbi_resource_id,
  :engine_name,
  :snapshot_type,
  :tenant_database_create_time,
  :tenant_db_name,
  :master_username,
  :tenant_database_resource_id,
  :character_set_name,
  :db_snapshot_tenant_database_arn,
  :nchar_character_set_name,
  :tag_list)
  SENSITIVE = []
  include Aws::Structure
end