Class: Aws::RDS::Types::DeleteTenantDatabaseMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_instance_identifierString

The user-supplied identifier for the DB instance that contains the tenant database that you want to delete.



13144
13145
13146
13147
13148
13149
13150
13151
# File 'lib/aws-sdk-rds/types.rb', line 13144

class DeleteTenantDatabaseMessage < Struct.new(
  :db_instance_identifier,
  :tenant_db_name,
  :skip_final_snapshot,
  :final_db_snapshot_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#final_db_snapshot_identifierString

The DBSnapshotIdentifier of the new DBSnapshot created when the SkipFinalSnapshot parameter is disabled.

If you enable this parameter and also enable SkipFinalShapshot, the command results in an error.



13144
13145
13146
13147
13148
13149
13150
13151
# File 'lib/aws-sdk-rds/types.rb', line 13144

class DeleteTenantDatabaseMessage < Struct.new(
  :db_instance_identifier,
  :tenant_db_name,
  :skip_final_snapshot,
  :final_db_snapshot_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#skip_final_snapshotBoolean

Specifies whether to skip the creation of a final DB snapshot before removing the tenant database from your DB instance. If you enable this parameter, RDS doesn't create a DB snapshot. If you don't enable this parameter, RDS creates a DB snapshot before it deletes the tenant database. By default, RDS doesn't skip the final snapshot. If you don't enable this parameter, you must specify the FinalDBSnapshotIdentifier parameter.



13144
13145
13146
13147
13148
13149
13150
13151
# File 'lib/aws-sdk-rds/types.rb', line 13144

class DeleteTenantDatabaseMessage < Struct.new(
  :db_instance_identifier,
  :tenant_db_name,
  :skip_final_snapshot,
  :final_db_snapshot_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#tenant_db_nameString

The user-supplied name of the tenant database that you want to remove from your DB instance. Amazon RDS deletes the tenant database with this name. This parameter isn’t case-sensitive.



13144
13145
13146
13147
13148
13149
13150
13151
# File 'lib/aws-sdk-rds/types.rb', line 13144

class DeleteTenantDatabaseMessage < Struct.new(
  :db_instance_identifier,
  :tenant_db_name,
  :skip_final_snapshot,
  :final_db_snapshot_identifier)
  SENSITIVE = []
  include Aws::Structure
end