Class: Aws::RDS::Types::DescribeBlueGreenDeploymentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeBlueGreenDeploymentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#blue_green_deployment_identifier ⇒ String
The blue/green deployment identifier.
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more blue/green deployments to describe.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeBlueGreenDeploymentsrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#blue_green_deployment_identifier ⇒ String
The blue/green deployment identifier. If you specify this parameter, the response only includes information about the specific blue/green deployment. This parameter isn't case-sensitive.
Constraints:
- Must match an existing blue/green deployment identifier.
^
13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-rds/types.rb', line 13255 class DescribeBlueGreenDeploymentsRequest < Struct.new( :blue_green_deployment_identifier, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more blue/green deployments to describe.
Valid Values:
-
blue-green-deployment-identifier- Accepts system-generated identifiers for blue/green deployments. The results list only includes information about the blue/green deployments with the specified identifiers. -
blue-green-deployment-name- Accepts user-supplied names for blue/green deployments. The results list only includes information about the blue/green deployments with the specified names. -
source- Accepts source databases for a blue/green deployment. The results list only includes information about the blue/green deployments with the specified source databases. -
target- Accepts target databases for a blue/green deployment. The results list only includes information about the blue/green deployments with the specified target databases.
13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-rds/types.rb', line 13255 class DescribeBlueGreenDeploymentsRequest < Struct.new( :blue_green_deployment_identifier, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeBlueGreenDeployments request. If you specify this
parameter, the response only includes records beyond the marker, up
to the value specified by MaxRecords.
13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-rds/types.rb', line 13255 class DescribeBlueGreenDeploymentsRequest < Struct.new( :blue_green_deployment_identifier, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so you can
retrieve the remaining results.
Default: 100
Constraints:
-
Must be a minimum of 20.
-
Can't exceed 100.
13255 13256 13257 13258 13259 13260 13261 13262 |
# File 'lib/aws-sdk-rds/types.rb', line 13255 class DescribeBlueGreenDeploymentsRequest < Struct.new( :blue_green_deployment_identifier, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |