Class: Aws::RDS::Types::DescribeDBEngineVersionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBEngineVersionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_parameter_group_family ⇒ String
The name of a specific DB parameter group family to return details for.
-
#default_only ⇒ Boolean
Specifies whether to return only the default version of the specified engine or the engine and major version combination.
-
#engine ⇒ String
The database engine to return version details for.
-
#engine_version ⇒ String
A specific database engine version to return details for.
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB engine versions to describe.
-
#include_all ⇒ Boolean
Specifies whether to also list the engine versions that aren’t available.
-
#list_supported_character_sets ⇒ Boolean
Specifies whether to list the supported character sets for each engine version.
-
#list_supported_timezones ⇒ Boolean
Specifies whether to list the supported time zones for each engine version.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_parameter_group_family ⇒ String
The name of a specific DB parameter group family to return details for.
Constraints:
-
If supplied, must match an existing DB parameter group family.
^
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#default_only ⇒ Boolean
Specifies whether to return only the default version of the specified engine or the engine and major version combination.
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The database engine to return version details for.
Valid Values:
-
aurora-mysql -
aurora-postgresql -
custom-oracle-ee -
custom-oracle-ee-cdb -
custom-oracle-se2 -
custom-oracle-se2-cdb -
db2-ae -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
A specific database engine version to return details for.
Example: 5.1.49
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB engine versions to describe.
Supported filters:
-
db-parameter-group-family- Accepts parameter groups family names. The results list only includes information about the DB engine versions for these parameter group families. -
engine- Accepts engine names. The results list only includes information about the DB engine versions for these engines. -
engine-mode- Accepts DB engine modes. The results list only includes information about the DB engine versions for these engine modes. Valid DB engine modes are the following:-
global -
multimaster -
parallelquery -
provisioned -
serverless
-
-
engine-version- Accepts engine versions. The results list only includes information about the DB engine versions for these engine versions. -
status- Accepts engine version statuses. The results list only includes information about the DB engine versions for these statuses. Valid statuses are the following:-
available -
deprecated
-
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#include_all ⇒ Boolean
Specifies whether to also list the engine versions that aren’t available. The default is to list only available engine versions.
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#list_supported_character_sets ⇒ Boolean
Specifies whether to list the supported character sets for each engine version.
If this parameter is enabled and the requested engine supports the CharacterSetName parameter for CreateDBInstance, the response includes a list of supported character sets for each engine version.
For RDS Custom, the default is not to list supported character sets. If you enable this parameter, RDS Custom returns no results.
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#list_supported_timezones ⇒ Boolean
Specifies whether to list the supported time zones for each engine version.
If this parameter is enabled and the requested engine supports the TimeZone parameter for CreateDBInstance, the response includes a list of supported time zones for each engine version.
For RDS Custom, the default is not to list supported time zones. If you enable this parameter, RDS Custom returns no results.
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so you can retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
13892 13893 13894 13895 13896 13897 13898 13899 13900 13901 13902 13903 13904 13905 |
# File 'lib/aws-sdk-rds/types.rb', line 13892 class DescribeDBEngineVersionsMessage < Struct.new( :engine, :engine_version, :db_parameter_group_family, :filters, :max_records, :marker, :default_only, :list_supported_character_sets, :list_supported_timezones, :include_all) SENSITIVE = [] include Aws::Structure end |