Class: Aws::RDS::Types::DescribeDBMajorEngineVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#engineString

The database engine to return major version details for.

Valid Values:

  • aurora-mysql

  • aurora-postgresql

  • custom-sqlserver-ee

  • custom-sqlserver-se

  • custom-sqlserver-web

  • db2-ae

  • db2-se

  • mariadb

  • mysql

  • oracle-ee

  • oracle-ee-cdb

  • oracle-se2

  • oracle-se2-cdb

  • postgres

  • sqlserver-ee

  • sqlserver-se

  • sqlserver-ex

  • sqlserver-web

Returns:

  • (String)


14215
14216
14217
14218
14219
14220
14221
14222
# File 'lib/aws-sdk-rds/types.rb', line 14215

class DescribeDBMajorEngineVersionsRequest < Struct.new(
  :engine,
  :major_engine_version,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#major_engine_versionString

A specific database major engine version to return details for.

Example: 8.4

Returns:

  • (String)


14215
14216
14217
14218
14219
14220
14221
14222
# File 'lib/aws-sdk-rds/types.rb', line 14215

class DescribeDBMajorEngineVersionsRequest < Struct.new(
  :engine,
  :major_engine_version,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


14215
14216
14217
14218
14219
14220
14221
14222
# File 'lib/aws-sdk-rds/types.rb', line 14215

class DescribeDBMajorEngineVersionsRequest < Struct.new(
  :engine,
  :major_engine_version,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so you can retrieve the remaining results.

Default: 100

Returns:

  • (Integer)


14215
14216
14217
14218
14219
14220
14221
14222
# File 'lib/aws-sdk-rds/types.rb', line 14215

class DescribeDBMajorEngineVersionsRequest < Struct.new(
  :engine,
  :major_engine_version,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end