Class: Aws::RDS::Types::DescribeDBMajorEngineVersionsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_major_engine_versionsArray<Types::DBMajorEngineVersion>

A list of DBMajorEngineVersion elements.



14236
14237
14238
14239
14240
14241
# File 'lib/aws-sdk-rds/types.rb', line 14236

class DescribeDBMajorEngineVersionsResponse < Struct.new(
  :db_major_engine_versions,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



14236
14237
14238
14239
14240
14241
# File 'lib/aws-sdk-rds/types.rb', line 14236

class DescribeDBMajorEngineVersionsResponse < Struct.new(
  :db_major_engine_versions,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end