Class: Aws::RDS::Types::DescribeDBProxiesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBProxiesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_proxy_name ⇒ String
The name of the DB proxy.
-
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_proxy_name ⇒ String
The name of the DB proxy. If you omit this parameter, the output includes information about all DB proxies owned by your Amazon Web Services account ID.
14476 14477 14478 14479 14480 14481 14482 14483 |
# File 'lib/aws-sdk-rds/types.rb', line 14476 class DescribeDBProxiesRequest < Struct.new( :db_proxy_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
14476 14477 14478 14479 14480 14481 14482 14483 |
# File 'lib/aws-sdk-rds/types.rb', line 14476 class DescribeDBProxiesRequest < Struct.new( :db_proxy_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond
the marker, up to the value specified by MaxRecords.
14476 14477 14478 14479 14480 14481 14482 14483 |
# File 'lib/aws-sdk-rds/types.rb', line 14476 class DescribeDBProxiesRequest < Struct.new( :db_proxy_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that the
remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
14476 14477 14478 14479 14480 14481 14482 14483 |
# File 'lib/aws-sdk-rds/types.rb', line 14476 class DescribeDBProxiesRequest < Struct.new( :db_proxy_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |