Class: Aws::RDS::Types::DescribeDBProxiesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_proxiesArray<Types::DBProxy>

A return value representing an arbitrary number of DBProxy data structures.

Returns:



14275
14276
14277
14278
14279
14280
# File 'lib/aws-sdk-rds/types.rb', line 14275

class DescribeDBProxiesResponse < Struct.new(
  :db_proxies,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

Returns:

  • (String)


14275
14276
14277
14278
14279
14280
# File 'lib/aws-sdk-rds/types.rb', line 14275

class DescribeDBProxiesResponse < Struct.new(
  :db_proxies,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end