Class: Aws::RDS::Types::DescribeDBProxyTargetsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_proxy_nameString

The identifier of the DBProxyTarget to describe.



14583
14584
14585
14586
14587
14588
14589
14590
14591
# File 'lib/aws-sdk-rds/types.rb', line 14583

class DescribeDBProxyTargetsRequest < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter is not currently supported.



14583
14584
14585
14586
14587
14588
14589
14590
14591
# File 'lib/aws-sdk-rds/types.rb', line 14583

class DescribeDBProxyTargetsRequest < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



14583
14584
14585
14586
14587
14588
14589
14590
14591
# File 'lib/aws-sdk-rds/types.rb', line 14583

class DescribeDBProxyTargetsRequest < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.

Default: 100

Constraints: Minimum 20, maximum 100.



14583
14584
14585
14586
14587
14588
14589
14590
14591
# File 'lib/aws-sdk-rds/types.rb', line 14583

class DescribeDBProxyTargetsRequest < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end

#target_group_nameString

The identifier of the DBProxyTargetGroup to describe.



14583
14584
14585
14586
14587
14588
14589
14590
14591
# File 'lib/aws-sdk-rds/types.rb', line 14583

class DescribeDBProxyTargetsRequest < Struct.new(
  :db_proxy_name,
  :target_group_name,
  :filters,
  :marker,
  :max_records)
  SENSITIVE = []
  include Aws::Structure
end