Class: Aws::RDS::Types::DescribeDBSecurityGroupsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_security_group_nameString

The name of the DB security group to return details for.



14766
14767
14768
14769
14770
14771
14772
14773
# File 'lib/aws-sdk-rds/types.rb', line 14766

class DescribeDBSecurityGroupsMessage < Struct.new(
  :db_security_group_name,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter isn’t currently supported.



14766
14767
14768
14769
14770
14771
14772
14773
# File 'lib/aws-sdk-rds/types.rb', line 14766

class DescribeDBSecurityGroupsMessage < Struct.new(
  :db_security_group_name,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeDBSecurityGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



14766
14767
14768
14769
14770
14771
14772
14773
# File 'lib/aws-sdk-rds/types.rb', line 14766

class DescribeDBSecurityGroupsMessage < Struct.new(
  :db_security_group_name,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 100.



14766
14767
14768
14769
14770
14771
14772
14773
# File 'lib/aws-sdk-rds/types.rb', line 14766

class DescribeDBSecurityGroupsMessage < Struct.new(
  :db_security_group_name,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end