Class: Aws::RDS::Types::DescribeDBSnapshotTenantDatabasesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBSnapshotTenantDatabasesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_instance_identifier ⇒ String
The ID of the DB instance used to create the DB snapshots.
-
#db_snapshot_identifier ⇒ String
The ID of a DB snapshot that contains the tenant databases to describe.
-
#dbi_resource_id ⇒ String
A specific DB resource identifier to describe.
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more tenant databases to describe.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBSnapshotTenantDatabasesrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#snapshot_type ⇒ String
The type of DB snapshots to be returned.
Instance Attribute Details
#db_instance_identifier ⇒ String
The ID of the DB instance used to create the DB snapshots. This parameter isn't case-sensitive.
Constraints:
- If supplied, must match the identifier of an existing
DBInstance.
^
15035 15036 15037 15038 15039 15040 15041 15042 15043 15044 15045 |
# File 'lib/aws-sdk-rds/types.rb', line 15035 class DescribeDBSnapshotTenantDatabasesMessage < Struct.new( :db_instance_identifier, :db_snapshot_identifier, :snapshot_type, :filters, :max_records, :marker, :dbi_resource_id) SENSITIVE = [] include Aws::Structure end |
#db_snapshot_identifier ⇒ String
The ID of a DB snapshot that contains the tenant databases to describe. This value is stored as a lowercase string.
Constraints:
-
If you specify this parameter, the value must match the ID of an existing DB snapshot.
-
If you specify an automatic snapshot, you must also specify
SnapshotType.
15035 15036 15037 15038 15039 15040 15041 15042 15043 15044 15045 |
# File 'lib/aws-sdk-rds/types.rb', line 15035 class DescribeDBSnapshotTenantDatabasesMessage < Struct.new( :db_instance_identifier, :db_snapshot_identifier, :snapshot_type, :filters, :max_records, :marker, :dbi_resource_id) SENSITIVE = [] include Aws::Structure end |
#dbi_resource_id ⇒ String
A specific DB resource identifier to describe.
15035 15036 15037 15038 15039 15040 15041 15042 15043 15044 15045 |
# File 'lib/aws-sdk-rds/types.rb', line 15035 class DescribeDBSnapshotTenantDatabasesMessage < Struct.new( :db_instance_identifier, :db_snapshot_identifier, :snapshot_type, :filters, :max_records, :marker, :dbi_resource_id) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more tenant databases to describe.
Supported filters:
-
tenant-db-name- Tenant database names. The results list only includes information about the tenant databases that match these tenant DB names. -
tenant-database-resource-id- Tenant database resource identifiers. The results list only includes information about the tenant databases contained within the DB snapshots. -
dbi-resource-id- DB instance resource identifiers. The results list only includes information about snapshots containing tenant databases contained within the DB instances identified by these resource identifiers. -
db-instance-id- Accepts DB instance identifiers and DB instance Amazon Resource Names (ARNs). -
db-snapshot-id- Accepts DB snapshot identifiers. -
snapshot-type- Accepts types of DB snapshots.
15035 15036 15037 15038 15039 15040 15041 15042 15043 15044 15045 |
# File 'lib/aws-sdk-rds/types.rb', line 15035 class DescribeDBSnapshotTenantDatabasesMessage < Struct.new( :db_instance_identifier, :db_snapshot_identifier, :snapshot_type, :filters, :max_records, :marker, :dbi_resource_id) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBSnapshotTenantDatabases request. If this parameter is
specified, the response includes only records beyond the marker, up
to the value specified by MaxRecords.
15035 15036 15037 15038 15039 15040 15041 15042 15043 15044 15045 |
# File 'lib/aws-sdk-rds/types.rb', line 15035 class DescribeDBSnapshotTenantDatabasesMessage < Struct.new( :db_instance_identifier, :db_snapshot_identifier, :snapshot_type, :filters, :max_records, :marker, :dbi_resource_id) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that you can
retrieve the remaining results.
15035 15036 15037 15038 15039 15040 15041 15042 15043 15044 15045 |
# File 'lib/aws-sdk-rds/types.rb', line 15035 class DescribeDBSnapshotTenantDatabasesMessage < Struct.new( :db_instance_identifier, :db_snapshot_identifier, :snapshot_type, :filters, :max_records, :marker, :dbi_resource_id) SENSITIVE = [] include Aws::Structure end |
#snapshot_type ⇒ String
The type of DB snapshots to be returned. You can specify one of the following values:
-
automated– All DB snapshots that have been automatically taken by Amazon RDS for my Amazon Web Services account. -
manual– All DB snapshots that have been taken by my Amazon Web Services account. -
shared– All manual DB snapshots that have been shared to my Amazon Web Services account. -
public– All DB snapshots that have been marked as public. -
awsbackup– All DB snapshots managed by the Amazon Web Services Backup service.
15035 15036 15037 15038 15039 15040 15041 15042 15043 15044 15045 |
# File 'lib/aws-sdk-rds/types.rb', line 15035 class DescribeDBSnapshotTenantDatabasesMessage < Struct.new( :db_instance_identifier, :db_snapshot_identifier, :snapshot_type, :filters, :max_records, :marker, :dbi_resource_id) SENSITIVE = [] include Aws::Structure end |