Class: Aws::RDS::Types::DescribeDBSubnetGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBSubnetGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_subnet_group_name ⇒ String
The name of the DB subnet group to return details for.
-
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous DescribeDBSubnetGroups request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_subnet_group_name ⇒ String
The name of the DB subnet group to return details for.
15266 15267 15268 15269 15270 15271 15272 15273 |
# File 'lib/aws-sdk-rds/types.rb', line 15266 class DescribeDBSubnetGroupsMessage < Struct.new( :db_subnet_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
15266 15267 15268 15269 15270 15271 15272 15273 |
# File 'lib/aws-sdk-rds/types.rb', line 15266 class DescribeDBSubnetGroupsMessage < Struct.new( :db_subnet_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBSubnetGroups request. If this parameter is specified, the
response includes only records beyond the marker, up to the value
specified by MaxRecords.
15266 15267 15268 15269 15270 15271 15272 15273 |
# File 'lib/aws-sdk-rds/types.rb', line 15266 class DescribeDBSubnetGroupsMessage < Struct.new( :db_subnet_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that you can
retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
15266 15267 15268 15269 15270 15271 15272 15273 |
# File 'lib/aws-sdk-rds/types.rb', line 15266 class DescribeDBSubnetGroupsMessage < Struct.new( :db_subnet_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |