Class: Aws::RDS::Types::DescribeGlobalClustersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeGlobalClustersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more global database clusters to describe.
-
#global_cluster_identifier ⇒ String
The user-supplied DB cluster identifier.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeGlobalClustersrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more global database clusters to describe. This parameter is case-sensitive.
Currently, the only supported filter is region.
If used, the request returns information about any global cluster with at least one member (primary or secondary) in the specified Amazon Web Services Regions.
15772 15773 15774 15775 15776 15777 15778 15779 |
# File 'lib/aws-sdk-rds/types.rb', line 15772 class DescribeGlobalClustersMessage < Struct.new( :global_cluster_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#global_cluster_identifier ⇒ String
The user-supplied DB cluster identifier. If this parameter is specified, information from only the specific DB cluster is returned. This parameter isn't case-sensitive.
Constraints:
- If supplied, must match an existing DBClusterIdentifier.
^
15772 15773 15774 15775 15776 15777 15778 15779 |
# File 'lib/aws-sdk-rds/types.rb', line 15772 class DescribeGlobalClustersMessage < Struct.new( :global_cluster_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeGlobalClusters request. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
15772 15773 15774 15775 15776 15777 15778 15779 |
# File 'lib/aws-sdk-rds/types.rb', line 15772 class DescribeGlobalClustersMessage < Struct.new( :global_cluster_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that you can
retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
15772 15773 15774 15775 15776 15777 15778 15779 |
# File 'lib/aws-sdk-rds/types.rb', line 15772 class DescribeGlobalClustersMessage < Struct.new( :global_cluster_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |