Class: Aws::RDS::Types::DescribeIntegrationsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filtersArray<Types::Filter>

A filter that specifies one or more resources to return.



15682
15683
15684
15685
15686
15687
15688
15689
# File 'lib/aws-sdk-rds/types.rb', line 15682

class DescribeIntegrationsMessage < Struct.new(
  :integration_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#integration_identifierString

The unique identifier of the integration.



15682
15683
15684
15685
15686
15687
15688
15689
# File 'lib/aws-sdk-rds/types.rb', line 15682

class DescribeIntegrationsMessage < Struct.new(
  :integration_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous DescribeIntegrations request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



15682
15683
15684
15685
15686
15687
15688
15689
# File 'lib/aws-sdk-rds/types.rb', line 15682

class DescribeIntegrationsMessage < Struct.new(
  :integration_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 100.



15682
15683
15684
15685
15686
15687
15688
15689
# File 'lib/aws-sdk-rds/types.rb', line 15682

class DescribeIntegrationsMessage < Struct.new(
  :integration_identifier,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end