Class: Aws::RDS::Types::DescribeOptionGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeOptionGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine_name ⇒ String
A filter to only include option groups associated with this database engine.
-
#filters ⇒ Array<Types::Filter>
This parameter isn’t currently supported.
-
#major_engine_version ⇒ String
Filters the list of option groups to only include groups associated with a specific database engine version.
-
#marker ⇒ String
An optional pagination token provided by a previous DescribeOptionGroups request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#option_group_name ⇒ String
The name of the option group to describe.
Instance Attribute Details
#engine_name ⇒ String
A filter to only include option groups associated with this database engine.
Valid Values:
-
db2-ae -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
15847 15848 15849 15850 15851 15852 15853 15854 15855 15856 |
# File 'lib/aws-sdk-rds/types.rb', line 15847 class DescribeOptionGroupsMessage < Struct.new( :option_group_name, :filters, :marker, :max_records, :engine_name, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter isn’t currently supported.
15847 15848 15849 15850 15851 15852 15853 15854 15855 15856 |
# File 'lib/aws-sdk-rds/types.rb', line 15847 class DescribeOptionGroupsMessage < Struct.new( :option_group_name, :filters, :marker, :max_records, :engine_name, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#major_engine_version ⇒ String
Filters the list of option groups to only include groups associated with a specific database engine version. If specified, then EngineName must also be specified.
15847 15848 15849 15850 15851 15852 15853 15854 15855 15856 |
# File 'lib/aws-sdk-rds/types.rb', line 15847 class DescribeOptionGroupsMessage < Struct.new( :option_group_name, :filters, :marker, :max_records, :engine_name, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeOptionGroups request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
15847 15848 15849 15850 15851 15852 15853 15854 15855 15856 |
# File 'lib/aws-sdk-rds/types.rb', line 15847 class DescribeOptionGroupsMessage < Struct.new( :option_group_name, :filters, :marker, :max_records, :engine_name, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
15847 15848 15849 15850 15851 15852 15853 15854 15855 15856 |
# File 'lib/aws-sdk-rds/types.rb', line 15847 class DescribeOptionGroupsMessage < Struct.new( :option_group_name, :filters, :marker, :max_records, :engine_name, :major_engine_version) SENSITIVE = [] include Aws::Structure end |
#option_group_name ⇒ String
The name of the option group to describe. Can’t be supplied together with EngineName or MajorEngineVersion.
15847 15848 15849 15850 15851 15852 15853 15854 15855 15856 |
# File 'lib/aws-sdk-rds/types.rb', line 15847 class DescribeOptionGroupsMessage < Struct.new( :option_group_name, :filters, :marker, :max_records, :engine_name, :major_engine_version) SENSITIVE = [] include Aws::Structure end |