Class: Aws::RDS::Types::DescribeOrderableDBInstanceOptionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeOrderableDBInstanceOptionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#availability_zone_group ⇒ String
The Availability Zone group associated with a Local Zone.
-
#db_instance_class ⇒ String
A filter to include only the available options for the specified DB instance class.
-
#engine ⇒ String
The name of the database engine to describe DB instance options for.
-
#engine_version ⇒ String
A filter to include only the available options for the specified engine version.
-
#filters ⇒ Array<Types::Filter>
This parameter isn’t currently supported.
-
#license_model ⇒ String
A filter to include only the available options for the specified license model.
-
#marker ⇒ String
An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#vpc ⇒ Boolean
Specifies whether to show only VPC or non-VPC offerings.
Instance Attribute Details
#availability_zone_group ⇒ String
The Availability Zone group associated with a Local Zone. Specify this parameter to retrieve available options for the Local Zones in the group.
Omit this parameter to show the available options in the specified Amazon Web Services Region.
This setting doesn’t apply to RDS Custom DB instances.
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#db_instance_class ⇒ String
A filter to include only the available options for the specified DB instance class.
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the database engine to describe DB instance options for.
Valid Values:
-
aurora-mysql -
aurora-postgresql -
custom-oracle-ee -
custom-oracle-ee-cdb -
custom-oracle-se2 -
custom-oracle-se2-cdb -
db2-ae -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
A filter to include only the available options for the specified engine version.
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter isn’t currently supported.
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#license_model ⇒ String
A filter to include only the available options for the specified license model.
RDS Custom supports only the BYOL licensing model.
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeOrderableDBInstanceOptions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 1000.
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#vpc ⇒ Boolean
Specifies whether to show only VPC or non-VPC offerings. RDS Custom supports only VPC offerings.
RDS Custom supports only VPC offerings. If you describe non-VPC offerings for RDS Custom, the output shows VPC offerings.
15939 15940 15941 15942 15943 15944 15945 15946 15947 15948 15949 15950 15951 |
# File 'lib/aws-sdk-rds/types.rb', line 15939 class DescribeOrderableDBInstanceOptionsMessage < Struct.new( :engine, :engine_version, :db_instance_class, :license_model, :availability_zone_group, :vpc, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |