Class: Aws::RDS::Types::DescribeServerlessV2PlatformVersionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeServerlessV2PlatformVersionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#default_only ⇒ Boolean
Specifies whether to return only the default platform versions for each engine.
-
#engine ⇒ String
The database engine to return platform version details for.
-
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
-
#include_all ⇒ Boolean
Specifies whether to also include platform versions which are no longer in use.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#serverless_v2_platform_version ⇒ String
A specific platform version to return details for.
Instance Attribute Details
#default_only ⇒ Boolean
Specifies whether to return only the default platform versions for each engine. The default platform version is the version used for new DB clusters.
16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 |
# File 'lib/aws-sdk-rds/types.rb', line 16331 class DescribeServerlessV2PlatformVersionsMessage < Struct.new( :serverless_v2_platform_version, :engine, :filters, :default_only, :include_all, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The database engine to return platform version details for.
Valid Values:
-
aurora-mysql -
aurora-postgresql
16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 |
# File 'lib/aws-sdk-rds/types.rb', line 16331 class DescribeServerlessV2PlatformVersionsMessage < Struct.new( :serverless_v2_platform_version, :engine, :filters, :default_only, :include_all, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 |
# File 'lib/aws-sdk-rds/types.rb', line 16331 class DescribeServerlessV2PlatformVersionsMessage < Struct.new( :serverless_v2_platform_version, :engine, :filters, :default_only, :include_all, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#include_all ⇒ Boolean
Specifies whether to also include platform versions which are no longer in use.
16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 |
# File 'lib/aws-sdk-rds/types.rb', line 16331 class DescribeServerlessV2PlatformVersionsMessage < Struct.new( :serverless_v2_platform_version, :engine, :filters, :default_only, :include_all, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond
the marker, up to the value specified by MaxRecords.
16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 |
# File 'lib/aws-sdk-rds/types.rb', line 16331 class DescribeServerlessV2PlatformVersionsMessage < Struct.new( :serverless_v2_platform_version, :engine, :filters, :default_only, :include_all, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
than the MaxRecords value is available, a pagination token called
a marker is included in the response so you can retrieve the
remaining results.
Default: 20
Constraints: Minimum 1, maximum 200.
16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 |
# File 'lib/aws-sdk-rds/types.rb', line 16331 class DescribeServerlessV2PlatformVersionsMessage < Struct.new( :serverless_v2_platform_version, :engine, :filters, :default_only, :include_all, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_platform_version ⇒ String
A specific platform version to return details for.
Example: 3
16331 16332 16333 16334 16335 16336 16337 16338 16339 16340 16341 |
# File 'lib/aws-sdk-rds/types.rb', line 16331 class DescribeServerlessV2PlatformVersionsMessage < Struct.new( :serverless_v2_platform_version, :engine, :filters, :default_only, :include_all, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |