Class: Aws::RDS::Types::DescribeSourceRegionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeSourceRegionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
This parameter isn’t currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeSourceRegionsrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#region_name ⇒ String
The source Amazon Web Services Region name.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
This parameter isn’t currently supported.
16207 16208 16209 16210 16211 16212 16213 16214 |
# File 'lib/aws-sdk-rds/types.rb', line 16207 class DescribeSourceRegionsMessage < Struct.new( :region_name, :max_records, :marker, :filters) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeSourceRegions request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
16207 16208 16209 16210 16211 16212 16213 16214 |
# File 'lib/aws-sdk-rds/types.rb', line 16207 class DescribeSourceRegionsMessage < Struct.new( :region_name, :max_records, :marker, :filters) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
16207 16208 16209 16210 16211 16212 16213 16214 |
# File 'lib/aws-sdk-rds/types.rb', line 16207 class DescribeSourceRegionsMessage < Struct.new( :region_name, :max_records, :marker, :filters) SENSITIVE = [] include Aws::Structure end |
#region_name ⇒ String
The source Amazon Web Services Region name. For example, us-east-1.
Constraints:
-
Must specify a valid Amazon Web Services Region name.
^
16207 16208 16209 16210 16211 16212 16213 16214 |
# File 'lib/aws-sdk-rds/types.rb', line 16207 class DescribeSourceRegionsMessage < Struct.new( :region_name, :max_records, :marker, :filters) SENSITIVE = [] include Aws::Structure end |