Class: Aws::RDS::Types::DescribeTenantDatabasesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeTenantDatabasesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_instance_identifier ⇒ String
The user-supplied DB instance identifier, which must match the identifier of an existing instance owned by the Amazon Web Services account.
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more database tenants to describe.
-
#marker ⇒ String
An optional pagination token provided by a previous ‘DescribeTenantDatabases` request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#tenant_db_name ⇒ String
The user-supplied tenant database name, which must match the name of an existing tenant database on the specified DB instance owned by your Amazon Web Services account.
Instance Attribute Details
#db_instance_identifier ⇒ String
The user-supplied DB instance identifier, which must match the identifier of an existing instance owned by the Amazon Web Services account. This parameter isn’t case-sensitive.
16347 16348 16349 16350 16351 16352 16353 16354 16355 |
# File 'lib/aws-sdk-rds/types.rb', line 16347 class DescribeTenantDatabasesMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more database tenants to describe.
Supported filters:
-
‘tenant-db-name` - Tenant database names. The results list only includes information about the tenant databases that match these tenant DB names.
-
‘tenant-database-resource-id` - Tenant database resource identifiers.
-
‘dbi-resource-id` - DB instance resource identifiers. The results list only includes information about the tenants contained within the DB instances identified by these resource identifiers.
16347 16348 16349 16350 16351 16352 16353 16354 16355 |
# File 'lib/aws-sdk-rds/types.rb', line 16347 class DescribeTenantDatabasesMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous ‘DescribeTenantDatabases` request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by `MaxRecords`.
16347 16348 16349 16350 16351 16352 16353 16354 16355 |
# File 'lib/aws-sdk-rds/types.rb', line 16347 class DescribeTenantDatabasesMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified ‘MaxRecords` value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.
16347 16348 16349 16350 16351 16352 16353 16354 16355 |
# File 'lib/aws-sdk-rds/types.rb', line 16347 class DescribeTenantDatabasesMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#tenant_db_name ⇒ String
The user-supplied tenant database name, which must match the name of an existing tenant database on the specified DB instance owned by your Amazon Web Services account. This parameter isn’t case-sensitive.
16347 16348 16349 16350 16351 16352 16353 16354 16355 |
# File 'lib/aws-sdk-rds/types.rb', line 16347 class DescribeTenantDatabasesMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |