Class: Aws::RDS::Types::EventsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::EventsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the result of a successful invocation of the DescribeEvents
action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#events ⇒ Array<Types::Event>
A list of
Eventinstances. -
#marker ⇒ String
An optional pagination token provided by a previous Events request.
Instance Attribute Details
#events ⇒ Array<Types::Event>
A list of Event instances.
17019 17020 17021 17022 17023 17024 |
# File 'lib/aws-sdk-rds/types.rb', line 17019 class EventsMessage < Struct.new( :marker, :events) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous Events request.
If this parameter is specified, the response includes only records
beyond the marker, up to the value specified by MaxRecords.
17019 17020 17021 17022 17023 17024 |
# File 'lib/aws-sdk-rds/types.rb', line 17019 class EventsMessage < Struct.new( :marker, :events) SENSITIVE = [] include Aws::Structure end |