Class: Aws::RDS::Types::ExportTask

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains the details of a snapshot or cluster export to Amazon S3.

This data type is used as a response element in the DescribeExportTasks operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#export_onlyArray<String>

The data exported from the snapshot or cluster.

Valid Values:

  • database - Export all the data from a specified database.

  • database.table table-name - Export a table of the snapshot or cluster. This format is valid only for RDS for MySQL, RDS for MariaDB, and Aurora MySQL.

  • database.schema schema-name - Export a database schema of the snapshot or cluster. This format is valid only for RDS for PostgreSQL and Aurora PostgreSQL.

  • database.schema.table table-name - Export a table of the database schema. This format is valid only for RDS for PostgreSQL and Aurora PostgreSQL.

Returns:

  • (Array<String>)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#export_task_identifierString

A unique identifier for the snapshot or cluster export task. This ID isn’t an identifier for the Amazon S3 bucket where the data is exported.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#failure_causeString

The reason the export failed, if it failed.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#iam_role_arnString

The name of the IAM role that is used to write to Amazon S3 when exporting a snapshot or cluster.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The key identifier of the Amazon Web Services KMS key that is used to encrypt the data when it’s exported to Amazon S3. The KMS key identifier is its key ARN, key ID, alias ARN, or alias name. The IAM role used for the export must have encryption and decryption permissions to use this KMS key.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#percent_progressInteger

The progress of the snapshot or cluster export task as a percentage.

Returns:

  • (Integer)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#s3_bucketString

The Amazon S3 bucket where the snapshot or cluster is exported to.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#s3_prefixString

The Amazon S3 bucket prefix that is the file name and path of the exported data.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#snapshot_timeTime

The time when the snapshot was created.

Returns:

  • (Time)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_arnString

The Amazon Resource Name (ARN) of the snapshot or cluster exported to Amazon S3.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#source_typeString

The type of source for the export.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The progress status of the export task. The status can be one of the following:

  • CANCELED

  • CANCELING

  • COMPLETE

  • FAILED

  • IN_PROGRESS

  • STARTING

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#task_end_timeTime

The time when the snapshot or cluster export task ended.

Returns:

  • (Time)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#task_start_timeTime

The time when the snapshot or cluster export task started.

Returns:

  • (Time)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#total_extracted_data_in_gbInteger

The total amount of data exported, in gigabytes.

Returns:

  • (Integer)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end

#warning_messageString

A warning about the snapshot or cluster export task.

Returns:

  • (String)


16987
16988
16989
16990
16991
16992
16993
16994
16995
16996
16997
16998
16999
17000
17001
17002
17003
17004
17005
17006
# File 'lib/aws-sdk-rds/types.rb', line 16987

class ExportTask < Struct.new(
  :export_task_identifier,
  :source_arn,
  :export_only,
  :snapshot_time,
  :task_start_time,
  :task_end_time,
  :s3_bucket,
  :s3_prefix,
  :iam_role_arn,
  :kms_key_id,
  :status,
  :percent_progress,
  :total_extracted_data_in_gb,
  :failure_cause,
  :warning_message,
  :source_type)
  SENSITIVE = []
  include Aws::Structure
end