Class: Aws::RDS::Types::GlobalClustersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::GlobalClustersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#global_clusters ⇒ Array<Types::GlobalCluster>
The list of global clusters returned by this request.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeGlobalClustersrequest.
Instance Attribute Details
#global_clusters ⇒ Array<Types::GlobalCluster>
The list of global clusters returned by this request.
17473 17474 17475 17476 17477 17478 |
# File 'lib/aws-sdk-rds/types.rb', line 17473 class GlobalClustersMessage < Struct.new( :marker, :global_clusters) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeGlobalClusters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
17473 17474 17475 17476 17477 17478 |
# File 'lib/aws-sdk-rds/types.rb', line 17473 class GlobalClustersMessage < Struct.new( :marker, :global_clusters) SENSITIVE = [] include Aws::Structure end |