Class: Aws::RDS::Types::ModifyAdditionalStorageVolume
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ModifyAdditionalStorageVolume
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains details about the modification of an additional storage volume.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allocated_storage ⇒ Integer
The amount of storage allocated for the additional storage volume, in gibibytes (GiB).
-
#iops ⇒ Integer
The number of I/O operations per second (IOPS) provisioned for the additional storage volume.
-
#max_allocated_storage ⇒ Integer
The upper limit in gibibytes (GiB) to which RDS can automatically scale the storage of the additional storage volume.
-
#set_for_delete ⇒ Boolean
Indicates whether to delete the additional storage volume.
-
#storage_throughput ⇒ Integer
The storage throughput value for the additional storage volume, in mebibytes per second (MiBps).
-
#storage_type ⇒ String
The new storage type for the additional storage volume.
-
#volume_name ⇒ String
The name of the additional storage volume that you want to modify.
Instance Attribute Details
#allocated_storage ⇒ Integer
The amount of storage allocated for the additional storage volume, in gibibytes (GiB). The minimum is 20 GiB. The maximum is 65,536 GiB (64 TiB).
18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 |
# File 'lib/aws-sdk-rds/types.rb', line 18212 class ModifyAdditionalStorageVolume < Struct.new( :volume_name, :allocated_storage, :iops, :max_allocated_storage, :storage_throughput, :storage_type, :set_for_delete) SENSITIVE = [] include Aws::Structure end |
#iops ⇒ Integer
The number of I/O operations per second (IOPS) provisioned for the additional storage volume. This setting is only supported for Provisioned IOPS SSD (io1 and io2) storage types.
18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 |
# File 'lib/aws-sdk-rds/types.rb', line 18212 class ModifyAdditionalStorageVolume < Struct.new( :volume_name, :allocated_storage, :iops, :max_allocated_storage, :storage_throughput, :storage_type, :set_for_delete) SENSITIVE = [] include Aws::Structure end |
#max_allocated_storage ⇒ Integer
The upper limit in gibibytes (GiB) to which RDS can automatically scale the storage of the additional storage volume. You must provide a value greater than or equal to AllocatedStorage.
18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 |
# File 'lib/aws-sdk-rds/types.rb', line 18212 class ModifyAdditionalStorageVolume < Struct.new( :volume_name, :allocated_storage, :iops, :max_allocated_storage, :storage_throughput, :storage_type, :set_for_delete) SENSITIVE = [] include Aws::Structure end |
#set_for_delete ⇒ Boolean
Indicates whether to delete the additional storage volume. The value true schedules the volume for deletion. You can delete an additional storage volume only when it doesn’t contain database files or other data.
18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 |
# File 'lib/aws-sdk-rds/types.rb', line 18212 class ModifyAdditionalStorageVolume < Struct.new( :volume_name, :allocated_storage, :iops, :max_allocated_storage, :storage_throughput, :storage_type, :set_for_delete) SENSITIVE = [] include Aws::Structure end |
#storage_throughput ⇒ Integer
The storage throughput value for the additional storage volume, in mebibytes per second (MiBps). This setting applies only to the General Purpose SSD (gp3) storage type.
18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 |
# File 'lib/aws-sdk-rds/types.rb', line 18212 class ModifyAdditionalStorageVolume < Struct.new( :volume_name, :allocated_storage, :iops, :max_allocated_storage, :storage_throughput, :storage_type, :set_for_delete) SENSITIVE = [] include Aws::Structure end |
#storage_type ⇒ String
The new storage type for the additional storage volume.
Valid Values: ‘GP3 | IO2`
18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 |
# File 'lib/aws-sdk-rds/types.rb', line 18212 class ModifyAdditionalStorageVolume < Struct.new( :volume_name, :allocated_storage, :iops, :max_allocated_storage, :storage_throughput, :storage_type, :set_for_delete) SENSITIVE = [] include Aws::Structure end |
#volume_name ⇒ String
The name of the additional storage volume that you want to modify.
Valid Values: ‘RDSDBDATA2 | RDSDBDATA3 | RDSDBDATA4`
18212 18213 18214 18215 18216 18217 18218 18219 18220 18221 18222 |
# File 'lib/aws-sdk-rds/types.rb', line 18212 class ModifyAdditionalStorageVolume < Struct.new( :volume_name, :allocated_storage, :iops, :max_allocated_storage, :storage_throughput, :storage_type, :set_for_delete) SENSITIVE = [] include Aws::Structure end |