Class: Aws::RDS::Types::ModifyDBProxyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ModifyDBProxyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth ⇒ Array<Types::UserAuthConfig>
The new authentication settings for the
DBProxy. -
#db_proxy_name ⇒ String
The identifier for the
DBProxyto modify. -
#debug_logging ⇒ Boolean
Specifies whether the proxy logs detailed connection and query information.
-
#default_auth_scheme ⇒ String
The default authentication scheme that the proxy uses for client connections to the proxy and connections from the proxy to the underlying database.
-
#idle_client_timeout ⇒ Integer
The number of seconds that a connection to the proxy can be inactive before the proxy disconnects it.
-
#new_db_proxy_name ⇒ String
The new identifier for the
DBProxy. -
#require_tls ⇒ Boolean
Whether Transport Layer Security (TLS) encryption is required for connections to the proxy.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that the proxy uses to access secrets in Amazon Web Services Secrets Manager.
-
#security_groups ⇒ Array<String>
The new list of security groups for the
DBProxy.
Instance Attribute Details
#auth ⇒ Array<Types::UserAuthConfig>
The new authentication settings for the DBProxy.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |
#db_proxy_name ⇒ String
The identifier for the DBProxy to modify.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |
#debug_logging ⇒ Boolean
Specifies whether the proxy logs detailed connection and query information. When you enable DebugLogging, the proxy captures connection details and connection pool behavior from your queries. Debug logging increases CloudWatch costs and can impact proxy performance. Enable this option only when you need to troubleshoot connection or performance issues.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |
#default_auth_scheme ⇒ String
The default authentication scheme that the proxy uses for client connections to the proxy and connections from the proxy to the underlying database. Valid values are NONE and IAM_AUTH. When set to IAM_AUTH, the proxy uses end-to-end IAM authentication to connect to the database.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |
#idle_client_timeout ⇒ Integer
The number of seconds that a connection to the proxy can be inactive before the proxy disconnects it. You can set this value higher or lower than the connection timeout limit for the associated database.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |
#new_db_proxy_name ⇒ String
The new identifier for the DBProxy. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can’t end with a hyphen or contain two consecutive hyphens.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |
#require_tls ⇒ Boolean
Whether Transport Layer Security (TLS) encryption is required for connections to the proxy. By enabling this setting, you can enforce encrypted TLS connections to the proxy, even if the associated database doesn’t use TLS.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role that the proxy uses to access secrets in Amazon Web Services Secrets Manager.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |
#security_groups ⇒ Array<String>
The new list of security groups for the DBProxy.
20925 20926 20927 20928 20929 20930 20931 20932 20933 20934 20935 20936 20937 |
# File 'lib/aws-sdk-rds/types.rb', line 20925 class ModifyDBProxyRequest < Struct.new( :db_proxy_name, :new_db_proxy_name, :default_auth_scheme, :auth, :require_tls, :idle_client_timeout, :debug_logging, :role_arn, :security_groups) SENSITIVE = [] include Aws::Structure end |