Class: Aws::RDS::Types::ModifyDBSnapshotAttributeResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ModifyDBSnapshotAttributeResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_snapshot_attributes_result ⇒ Types::DBSnapshotAttributesResult
Contains the results of a successful call to the
DescribeDBSnapshotAttributesAPI action.
Instance Attribute Details
#db_snapshot_attributes_result ⇒ Types::DBSnapshotAttributesResult
Contains the results of a successful call to the
DescribeDBSnapshotAttributes API action.
Manual DB snapshot attributes are used to authorize other Amazon Web
Services accounts to copy or restore a manual DB snapshot. For more
information, see the ModifyDBSnapshotAttribute API action.
21340 21341 21342 21343 21344 |
# File 'lib/aws-sdk-rds/types.rb', line 21340 class ModifyDBSnapshotAttributeResult < Struct.new( :db_snapshot_attributes_result) SENSITIVE = [] include Aws::Structure end |