Class: Aws::RDS::Types::OptionGroup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allows_vpc_and_non_vpc_instance_membershipsBoolean

Indicates whether this option group can be applied to both VPC and non-VPC instances. The value true indicates the option group can be applied to both VPC and non-VPC instances.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#copy_timestampTime

Indicates when the option group was copied.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#engine_nameString

Indicates the name of the engine that this option group can be applied to.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#major_engine_versionString

Indicates the major engine version associated with this option group.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#option_group_arnString

Specifies the Amazon Resource Name (ARN) for the option group.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#option_group_descriptionString

Provides a description of the option group.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#option_group_nameString

Specifies the name of the option group.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#optionsArray<Types::Option>

Indicates what options are available in the option group.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#source_account_idString

Specifies the Amazon Web Services account ID for the option group from which this option group is copied.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#source_option_groupString

Specifies the name of the option group from which this option group is copied.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

If AllowsVpcAndNonVpcInstanceMemberships is false, this field is blank. If AllowsVpcAndNonVpcInstanceMemberships is true and this field is blank, then this option group can be applied to both VPC and non-VPC instances. If this field contains a value, then this option group can only be applied to instances that are in the VPC indicated by this field.



22117
22118
22119
22120
22121
22122
22123
22124
22125
22126
22127
22128
22129
22130
22131
# File 'lib/aws-sdk-rds/types.rb', line 22117

class OptionGroup < Struct.new(
  :option_group_name,
  :option_group_description,
  :engine_name,
  :major_engine_version,
  :options,
  :allows_vpc_and_non_vpc_instance_memberships,
  :vpc_id,
  :option_group_arn,
  :source_option_group,
  :source_account_id,
  :copy_timestamp)
  SENSITIVE = []
  include Aws::Structure
end