Class: Aws::RDS::Types::Parameter

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

This data type is used as a request parameter in the ModifyDBParameterGroup and ResetDBParameterGroup actions.

This data type is used as a response element in the DescribeEngineDefaultParameters and DescribeDBParameters actions.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_valuesString

Specifies the valid range of values for the parameter.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#apply_methodString

Indicates when to apply parameter updates.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#apply_typeString

Specifies the engine specific parameters type.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#data_typeString

Specifies the valid data type for the parameter.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

Provides a description of the parameter.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#is_modifiableBoolean

Indicates whether (true) or not (false) the parameter can be modified. Some parameters have security or operational implications that prevent them from being changed.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_engine_versionString

The earliest engine version to which the parameter can apply.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_nameString

The name of the parameter.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#parameter_valueString

The value of the parameter.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source of the parameter value.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end

#supported_engine_modesArray<String>

The valid DB engine modes.



22537
22538
22539
22540
22541
22542
22543
22544
22545
22546
22547
22548
22549
22550
22551
# File 'lib/aws-sdk-rds/types.rb', line 22537

class Parameter < Struct.new(
  :parameter_name,
  :parameter_value,
  :description,
  :source,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :minimum_engine_version,
  :apply_method,
  :supported_engine_modes)
  SENSITIVE = []
  include Aws::Structure
end