Class: Aws::RDS::Types::PendingModifiedValues

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

This data type is used as a response element in the ModifyDBInstance operation and contains changes that will be applied during the next maintenance window.

Constant Summary collapse

SENSITIVE =
[:master_user_password]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_storage_volumesArray<Types::AdditionalStorageVolume>

The additional storage volume modifications that are pending for the DB instance.

Returns:



23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#allocated_storageInteger

The allocated storage size for the DB instance specified in gibibytes (GiB).

Returns:

  • (Integer)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#automation_modeString

The automation mode of the RDS Custom DB instance: full or all-paused. If full, the DB instance automates monitoring and instance recovery. If all-paused, the instance pauses automation for the duration set by --resume-full-automation-mode-minutes.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#backup_retention_periodInteger

The number of days for which automated backups are retained.

Returns:

  • (Integer)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#ca_certificate_identifierString

The identifier of the CA certificate for the DB instance.

For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#db_instance_classString

The name of the compute and memory capacity class for the DB instance.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#db_instance_identifierString

The database identifier for the DB instance.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#db_subnet_group_nameString

The DB subnet group for the DB instance.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#dedicated_log_volumeBoolean

Indicates whether the DB instance has a dedicated log volume (DLV) enabled.>

Returns:

  • (Boolean)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#engineString

The database engine of the DB instance.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#engine_versionString

The database engine version.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#iam_database_authentication_enabledBoolean

Indicates whether mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.

Returns:

  • (Boolean)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#iopsInteger

The Provisioned IOPS value for the DB instance.

Returns:

  • (Integer)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#license_modelString

The license model for the DB instance.

Valid values: license-included | bring-your-own-license | general-public-license | bring-your-own-media

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#master_user_passwordString

The master credentials for the DB instance.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#multi_azBoolean

Indicates whether the Single-AZ DB instance will change to a Multi-AZ deployment.

Returns:

  • (Boolean)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#multi_tenantBoolean

Indicates whether the DB instance will change to the multi-tenant configuration (TRUE) or the single-tenant configuration (FALSE).

Returns:

  • (Boolean)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#pending_cloudwatch_logs_exportsTypes::PendingCloudwatchLogsExports

A list of the log types whose configuration is still pending. In other words, these log types are in the process of being activated or deactivated.



23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#portInteger

The port for the DB instance.

Returns:

  • (Integer)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#processor_featuresArray<Types::ProcessorFeature>

The number of CPU cores and the number of threads per core for the DB instance class of the DB instance.

Returns:



23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#resume_full_automation_mode_timeTime

The number of minutes to pause the automation. When the time period ends, RDS Custom resumes full automation. The minimum value is 60 (default). The maximum value is 1,440.

Returns:

  • (Time)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#storage_throughputInteger

The storage throughput of the DB instance.

Returns:

  • (Integer)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end

#storage_typeString

The storage type of the DB instance.

Returns:

  • (String)


23060
23061
23062
23063
23064
23065
23066
23067
23068
23069
23070
23071
23072
23073
23074
23075
23076
23077
23078
23079
23080
23081
23082
23083
23084
23085
23086
# File 'lib/aws-sdk-rds/types.rb', line 23060

class PendingModifiedValues < Struct.new(
  :db_instance_class,
  :allocated_storage,
  :master_user_password,
  :port,
  :backup_retention_period,
  :multi_az,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :db_instance_identifier,
  :storage_type,
  :ca_certificate_identifier,
  :db_subnet_group_name,
  :pending_cloudwatch_logs_exports,
  :processor_features,
  :automation_mode,
  :resume_full_automation_mode_time,
  :multi_tenant,
  :iam_database_authentication_enabled,
  :dedicated_log_volume,
  :engine,
  :additional_storage_volumes)
  SENSITIVE = [:master_user_password]
  include Aws::Structure
end