Class: Aws::RDS::Types::RecommendedActionParameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::RecommendedActionParameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
A single parameter to use with the RecommendedAction API operation to apply the action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
The key of the parameter to use with the
RecommendedActionAPI operation. -
#value ⇒ String
The value of the parameter to use with the
RecommendedActionAPI operation.
Instance Attribute Details
#key ⇒ String
The key of the parameter to use with the RecommendedAction API operation.
23400 23401 23402 23403 23404 23405 |
# File 'lib/aws-sdk-rds/types.rb', line 23400 class RecommendedActionParameter < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
The value of the parameter to use with the RecommendedAction API operation.
23400 23401 23402 23403 23404 23405 |
# File 'lib/aws-sdk-rds/types.rb', line 23400 class RecommendedActionParameter < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |