Class: Aws::RDS::Types::ReservedDBInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ReservedDBInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type is used as a response element in the
DescribeReservedDBInstances and
PurchaseReservedDBInstancesOffering actions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency code for the reserved DB instance.
-
#db_instance_class ⇒ String
The DB instance class for the reserved DB instance.
-
#db_instance_count ⇒ Integer
The number of reserved DB instances.
-
#duration ⇒ Integer
The duration of the reservation in seconds.
-
#fixed_price ⇒ Float
The fixed price charged for this reserved DB instance.
-
#lease_id ⇒ String
The unique identifier for the lease associated with the reserved DB instance.
-
#multi_az ⇒ Boolean
Indicates whether the reservation applies to Multi-AZ deployments.
-
#offering_type ⇒ String
The offering type of this reserved DB instance.
-
#product_description ⇒ String
The description of the reserved DB instance.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring price charged to run this reserved DB instance.
-
#reserved_db_instance_arn ⇒ String
The Amazon Resource Name (ARN) for the reserved DB instance.
-
#reserved_db_instance_id ⇒ String
The unique identifier for the reservation.
-
#reserved_db_instances_offering_id ⇒ String
The offering identifier.
-
#start_time ⇒ Time
The time the reservation started.
-
#state ⇒ String
The state of the reserved DB instance.
-
#usage_price ⇒ Float
The hourly price charged for this reserved DB instance.
Instance Attribute Details
#currency_code ⇒ String
The currency code for the reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#db_instance_class ⇒ String
The DB instance class for the reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#db_instance_count ⇒ Integer
The number of reserved DB instances.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration of the reservation in seconds.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The fixed price charged for this reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#lease_id ⇒ String
The unique identifier for the lease associated with the reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#multi_az ⇒ Boolean
Indicates whether the reservation applies to Multi-AZ deployments.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#offering_type ⇒ String
The offering type of this reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#product_description ⇒ String
The description of the reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring price charged to run this reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#reserved_db_instance_arn ⇒ String
The Amazon Resource Name (ARN) for the reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#reserved_db_instance_id ⇒ String
The unique identifier for the reservation.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#reserved_db_instances_offering_id ⇒ String
The offering identifier.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time the reservation started.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The hourly price charged for this reserved DB instance.
24101 24102 24103 24104 24105 24106 24107 24108 24109 24110 24111 24112 24113 24114 24115 24116 24117 24118 24119 24120 |
# File 'lib/aws-sdk-rds/types.rb', line 24101 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |