Class: Aws::RDS::Types::RestoreDBClusterToPointInTimeResult
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::RestoreDBClusterToPointInTimeResult
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster ⇒ Types::DBCluster
Contains the details of an Amazon Aurora DB cluster or Multi-AZ DB cluster.
Instance Attribute Details
#db_cluster ⇒ Types::DBCluster
Contains the details of an Amazon Aurora DB cluster or Multi-AZ DB cluster.
For an Amazon Aurora DB cluster, this data type is used as a
response element in the operations CreateDBCluster,
DeleteDBCluster, DescribeDBClusters, FailoverDBCluster,
ModifyDBCluster, PromoteReadReplicaDBCluster,
RestoreDBClusterFromS3, RestoreDBClusterFromSnapshot,
RestoreDBClusterToPointInTime, StartDBCluster, and
StopDBCluster.
For a Multi-AZ DB cluster, this data type is used as a response
element in the operations CreateDBCluster, DeleteDBCluster,
DescribeDBClusters, FailoverDBCluster, ModifyDBCluster,
RebootDBCluster, RestoreDBClusterFromSnapshot, and
RestoreDBClusterToPointInTime.
For more information on Amazon Aurora DB clusters, see What is Amazon Aurora? in the Amazon Aurora User Guide.
For more information on Multi-AZ DB clusters, see Multi-AZ deployments with two readable standby DB instances in the Amazon RDS User Guide.
26192 26193 26194 26195 26196 |
# File 'lib/aws-sdk-rds/types.rb', line 26192 class RestoreDBClusterToPointInTimeResult < Struct.new( :db_cluster) SENSITIVE = [] include Aws::Structure end |