Class: Aws::RDS::Types::ScalingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ScalingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the scaling configuration of an Aurora Serverless v1 DB cluster.
For more information, see [Using Amazon Aurora Serverless v1] in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_pause ⇒ Boolean
Indicates whether to allow or disallow automatic pause for an Aurora DB cluster in
serverlessDB engine mode. -
#max_capacity ⇒ Integer
The maximum capacity for an Aurora DB cluster in
serverlessDB engine mode. -
#min_capacity ⇒ Integer
The minimum capacity for an Aurora DB cluster in
serverlessDB engine mode. -
#seconds_before_timeout ⇒ Integer
The amount of time, in seconds, that Aurora Serverless v1 tries to find a scaling point to perform seamless scaling before enforcing the timeout action.
-
#seconds_until_auto_pause ⇒ Integer
The time, in seconds, before an Aurora DB cluster in
serverlessmode is paused. -
#timeout_action ⇒ String
The action to take when the timeout is reached, either
ForceApplyCapacityChangeorRollbackCapacityChange.
Instance Attribute Details
#auto_pause ⇒ Boolean
Indicates whether to allow or disallow automatic pause for an Aurora DB cluster in serverless DB engine mode. A DB cluster can be paused only when it’s idle (it has no connections).
<note markdown=“1”> If a DB cluster is paused for more than seven days, the DB cluster might be backed up with a snapshot. In this case, the DB cluster is restored when there is a request to connect to it.
</note>
28611 28612 28613 28614 28615 28616 28617 28618 28619 28620 |
# File 'lib/aws-sdk-rds/types.rb', line 28611 class ScalingConfiguration < Struct.new( :min_capacity, :max_capacity, :auto_pause, :seconds_until_auto_pause, :timeout_action, :seconds_before_timeout) SENSITIVE = [] include Aws::Structure end |
#max_capacity ⇒ Integer
The maximum capacity for an Aurora DB cluster in serverless DB engine mode.
For Aurora MySQL, valid capacity values are 1, 2, 4, 8, 16, 32, 64, 128, and 256.
For Aurora PostgreSQL, valid capacity values are 2, 4, 8, 16, 32, 64, 192, and 384.
The maximum capacity must be greater than or equal to the minimum capacity.
28611 28612 28613 28614 28615 28616 28617 28618 28619 28620 |
# File 'lib/aws-sdk-rds/types.rb', line 28611 class ScalingConfiguration < Struct.new( :min_capacity, :max_capacity, :auto_pause, :seconds_until_auto_pause, :timeout_action, :seconds_before_timeout) SENSITIVE = [] include Aws::Structure end |
#min_capacity ⇒ Integer
The minimum capacity for an Aurora DB cluster in serverless DB engine mode.
For Aurora MySQL, valid capacity values are 1, 2, 4, 8, 16, 32, 64, 128, and 256.
For Aurora PostgreSQL, valid capacity values are 2, 4, 8, 16, 32, 64, 192, and 384.
The minimum capacity must be less than or equal to the maximum capacity.
28611 28612 28613 28614 28615 28616 28617 28618 28619 28620 |
# File 'lib/aws-sdk-rds/types.rb', line 28611 class ScalingConfiguration < Struct.new( :min_capacity, :max_capacity, :auto_pause, :seconds_until_auto_pause, :timeout_action, :seconds_before_timeout) SENSITIVE = [] include Aws::Structure end |
#seconds_before_timeout ⇒ Integer
The amount of time, in seconds, that Aurora Serverless v1 tries to find a scaling point to perform seamless scaling before enforcing the timeout action. The default is 300.
Specify a value between 60 and 600 seconds.
28611 28612 28613 28614 28615 28616 28617 28618 28619 28620 |
# File 'lib/aws-sdk-rds/types.rb', line 28611 class ScalingConfiguration < Struct.new( :min_capacity, :max_capacity, :auto_pause, :seconds_until_auto_pause, :timeout_action, :seconds_before_timeout) SENSITIVE = [] include Aws::Structure end |
#seconds_until_auto_pause ⇒ Integer
The time, in seconds, before an Aurora DB cluster in serverless mode is paused.
Specify a value between 300 and 86,400 seconds.
28611 28612 28613 28614 28615 28616 28617 28618 28619 28620 |
# File 'lib/aws-sdk-rds/types.rb', line 28611 class ScalingConfiguration < Struct.new( :min_capacity, :max_capacity, :auto_pause, :seconds_until_auto_pause, :timeout_action, :seconds_before_timeout) SENSITIVE = [] include Aws::Structure end |
#timeout_action ⇒ String
The action to take when the timeout is reached, either ForceApplyCapacityChange or RollbackCapacityChange.
ForceApplyCapacityChange sets the capacity to the specified value as soon as possible.
RollbackCapacityChange, the default, ignores the capacity change if a scaling point isn’t found in the timeout period.
If you specify ForceApplyCapacityChange, connections that prevent Aurora Serverless v1 from finding a scaling point might be dropped.
For more information, see [ Autoscaling for Aurora Serverless v1] in the *Amazon Aurora User Guide*.
28611 28612 28613 28614 28615 28616 28617 28618 28619 28620 |
# File 'lib/aws-sdk-rds/types.rb', line 28611 class ScalingConfiguration < Struct.new( :min_capacity, :max_capacity, :auto_pause, :seconds_until_auto_pause, :timeout_action, :seconds_before_timeout) SENSITIVE = [] include Aws::Structure end |