Class: Aws::RDS::Types::ScalingConfigurationInfo

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

The scaling configuration for an Aurora DB cluster in serverless DB engine mode.

For more information, see [Using Amazon Aurora Serverless v1] in the *Amazon Aurora User Guide*.

[1]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/aurora-serverless.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auto_pauseBoolean

Indicates whether automatic pause is allowed for the Aurora DB cluster in serverless DB engine mode.

When the value is set to false for an Aurora Serverless v1 DB cluster, the DB cluster automatically resumes.

Returns:

  • (Boolean)


28336
28337
28338
28339
28340
28341
28342
28343
28344
28345
# File 'lib/aws-sdk-rds/types.rb', line 28336

class ScalingConfigurationInfo < Struct.new(
  :min_capacity,
  :max_capacity,
  :auto_pause,
  :seconds_until_auto_pause,
  :timeout_action,
  :seconds_before_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#max_capacityInteger

The maximum capacity for an Aurora DB cluster in serverless DB engine mode.

Returns:

  • (Integer)


28336
28337
28338
28339
28340
28341
28342
28343
28344
28345
# File 'lib/aws-sdk-rds/types.rb', line 28336

class ScalingConfigurationInfo < Struct.new(
  :min_capacity,
  :max_capacity,
  :auto_pause,
  :seconds_until_auto_pause,
  :timeout_action,
  :seconds_before_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#min_capacityInteger

The minimum capacity for an Aurora DB cluster in serverless DB engine mode.

Returns:

  • (Integer)


28336
28337
28338
28339
28340
28341
28342
28343
28344
28345
# File 'lib/aws-sdk-rds/types.rb', line 28336

class ScalingConfigurationInfo < Struct.new(
  :min_capacity,
  :max_capacity,
  :auto_pause,
  :seconds_until_auto_pause,
  :timeout_action,
  :seconds_before_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#seconds_before_timeoutInteger

The number of seconds before scaling times out. What happens when an attempted scaling action times out is determined by the TimeoutAction setting.

Returns:

  • (Integer)


28336
28337
28338
28339
28340
28341
28342
28343
28344
28345
# File 'lib/aws-sdk-rds/types.rb', line 28336

class ScalingConfigurationInfo < Struct.new(
  :min_capacity,
  :max_capacity,
  :auto_pause,
  :seconds_until_auto_pause,
  :timeout_action,
  :seconds_before_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#seconds_until_auto_pauseInteger

The remaining amount of time, in seconds, before the Aurora DB cluster in serverless mode is paused. A DB cluster can be paused only when it’s idle (it has no connections).

Returns:

  • (Integer)


28336
28337
28338
28339
28340
28341
28342
28343
28344
28345
# File 'lib/aws-sdk-rds/types.rb', line 28336

class ScalingConfigurationInfo < Struct.new(
  :min_capacity,
  :max_capacity,
  :auto_pause,
  :seconds_until_auto_pause,
  :timeout_action,
  :seconds_before_timeout)
  SENSITIVE = []
  include Aws::Structure
end

#timeout_actionString

The action that occurs when Aurora times out while attempting to change the capacity of an Aurora Serverless v1 cluster. The value is either ForceApplyCapacityChange or RollbackCapacityChange.

ForceApplyCapacityChange, the default, sets the capacity to the specified value as soon as possible.

RollbackCapacityChange ignores the capacity change if a scaling point isn’t found in the timeout period.

Returns:

  • (String)


28336
28337
28338
28339
28340
28341
28342
28343
28344
28345
# File 'lib/aws-sdk-rds/types.rb', line 28336

class ScalingConfigurationInfo < Struct.new(
  :min_capacity,
  :max_capacity,
  :auto_pause,
  :seconds_until_auto_pause,
  :timeout_action,
  :seconds_before_timeout)
  SENSITIVE = []
  include Aws::Structure
end