Class: Aws::RDS::Types::StartActivityStreamRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::StartActivityStreamRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
Specifies whether or not the database activity stream is to start as soon as possible, regardless of the maintenance window for the database.
-
#engine_native_audit_fields_included ⇒ Boolean
Specifies whether the database activity stream includes engine-native audit fields.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for encrypting messages in the database activity stream.
-
#mode ⇒ String
Specifies the mode of the database activity stream.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the DB cluster, for example,
arn:aws:rds:us-east-1:12345667890:cluster:das-cluster.
Instance Attribute Details
#apply_immediately ⇒ Boolean
Specifies whether or not the database activity stream is to start as soon as possible, regardless of the maintenance window for the database.
29018 29019 29020 29021 29022 29023 29024 29025 29026 |
# File 'lib/aws-sdk-rds/types.rb', line 29018 class StartActivityStreamRequest < Struct.new( :resource_arn, :mode, :kms_key_id, :apply_immediately, :engine_native_audit_fields_included) SENSITIVE = [] include Aws::Structure end |
#engine_native_audit_fields_included ⇒ Boolean
Specifies whether the database activity stream includes engine-native audit fields. This option applies to an Oracle or Microsoft SQL Server DB instance. By default, no engine-native audit fields are included.
29018 29019 29020 29021 29022 29023 29024 29025 29026 |
# File 'lib/aws-sdk-rds/types.rb', line 29018 class StartActivityStreamRequest < Struct.new( :resource_arn, :mode, :kms_key_id, :apply_immediately, :engine_native_audit_fields_included) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for encrypting messages in the database activity stream. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
29018 29019 29020 29021 29022 29023 29024 29025 29026 |
# File 'lib/aws-sdk-rds/types.rb', line 29018 class StartActivityStreamRequest < Struct.new( :resource_arn, :mode, :kms_key_id, :apply_immediately, :engine_native_audit_fields_included) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
Specifies the mode of the database activity stream. Database events such as a change or access generate an activity stream event. The database session can handle these events either synchronously or asynchronously.
29018 29019 29020 29021 29022 29023 29024 29025 29026 |
# File 'lib/aws-sdk-rds/types.rb', line 29018 class StartActivityStreamRequest < Struct.new( :resource_arn, :mode, :kms_key_id, :apply_immediately, :engine_native_audit_fields_included) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the DB cluster, for example, arn:aws:rds:us-east-1:12345667890:cluster:das-cluster.
29018 29019 29020 29021 29022 29023 29024 29025 29026 |
# File 'lib/aws-sdk-rds/types.rb', line 29018 class StartActivityStreamRequest < Struct.new( :resource_arn, :mode, :kms_key_id, :apply_immediately, :engine_native_audit_fields_included) SENSITIVE = [] include Aws::Structure end |