Class: Aws::RDS::Types::StartDBInstanceAutomatedBackupsReplicationMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::StartDBInstanceAutomatedBackupsReplicationMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:pre_signed_url]
Instance Attribute Summary collapse
-
#backup_retention_period ⇒ Integer
The retention period for the replicated automated backups.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for encryption of the replicated automated backups.
-
#pre_signed_url ⇒ String
In an Amazon Web Services GovCloud (US) Region, an URL that contains a Signature Version 4 signed request for the
StartDBInstanceAutomatedBackupsReplicationoperation to call in the Amazon Web Services Region of the source DB instance. -
#source_db_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the source DB instance for the replicated automated backups, for example,
arn:aws:rds:us-west-2:123456789012:db:mydatabase. -
#source_region ⇒ String
The source region of the snapshot.
-
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the replicated automated backups.
Instance Attribute Details
#backup_retention_period ⇒ Integer
The retention period for the replicated automated backups.
29104 29105 29106 29107 29108 29109 29110 29111 29112 29113 |
# File 'lib/aws-sdk-rds/types.rb', line 29104 class StartDBInstanceAutomatedBackupsReplicationMessage < Struct.new( :source_db_instance_arn, :backup_retention_period, :kms_key_id, :pre_signed_url, :tags, :source_region) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for encryption of the replicated automated backups. The KMS key ID is the Amazon Resource Name (ARN) for the KMS encryption key in the destination Amazon Web Services Region, for example, arn:aws:kms:us-east-1:123456789012:key/AKIAIOSFODNN7EXAMPLE.
29104 29105 29106 29107 29108 29109 29110 29111 29112 29113 |
# File 'lib/aws-sdk-rds/types.rb', line 29104 class StartDBInstanceAutomatedBackupsReplicationMessage < Struct.new( :source_db_instance_arn, :backup_retention_period, :kms_key_id, :pre_signed_url, :tags, :source_region) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#pre_signed_url ⇒ String
In an Amazon Web Services GovCloud (US) Region, an URL that contains a Signature Version 4 signed request for the StartDBInstanceAutomatedBackupsReplication operation to call in the Amazon Web Services Region of the source DB instance. The presigned URL must be a valid request for the StartDBInstanceAutomatedBackupsReplication API operation that can run in the Amazon Web Services Region that contains the source DB instance.
This setting applies only to Amazon Web Services GovCloud (US) Regions. It’s ignored in other Amazon Web Services Regions.
To learn how to generate a Signature Version 4 signed request, see [ Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4)] and [ Signature Version 4 Signing Process].
<note markdown=“1”> If you are using an Amazon Web Services SDK tool or the CLI, you can specify SourceRegion (or --source-region for the CLI) instead of specifying PreSignedUrl manually. Specifying SourceRegion autogenerates a presigned URL that is a valid request for the operation that can run in the source Amazon Web Services Region.
</note>
[1]: docs.aws.amazon.com/AmazonS3/latest/API/sigv4-query-string-auth.html [2]: docs.aws.amazon.com/general/latest/gr/signature-version-4.html
29104 29105 29106 29107 29108 29109 29110 29111 29112 29113 |
# File 'lib/aws-sdk-rds/types.rb', line 29104 class StartDBInstanceAutomatedBackupsReplicationMessage < Struct.new( :source_db_instance_arn, :backup_retention_period, :kms_key_id, :pre_signed_url, :tags, :source_region) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#source_db_instance_arn ⇒ String
The Amazon Resource Name (ARN) of the source DB instance for the replicated automated backups, for example, arn:aws:rds:us-west-2:123456789012:db:mydatabase.
29104 29105 29106 29107 29108 29109 29110 29111 29112 29113 |
# File 'lib/aws-sdk-rds/types.rb', line 29104 class StartDBInstanceAutomatedBackupsReplicationMessage < Struct.new( :source_db_instance_arn, :backup_retention_period, :kms_key_id, :pre_signed_url, :tags, :source_region) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#source_region ⇒ String
The source region of the snapshot. This is only needed when the shapshot is encrypted and in a different region.
29104 29105 29106 29107 29108 29109 29110 29111 29112 29113 |
# File 'lib/aws-sdk-rds/types.rb', line 29104 class StartDBInstanceAutomatedBackupsReplicationMessage < Struct.new( :source_db_instance_arn, :backup_retention_period, :kms_key_id, :pre_signed_url, :tags, :source_region) SENSITIVE = [:pre_signed_url] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags to associate with the replicated automated backups.
29104 29105 29106 29107 29108 29109 29110 29111 29112 29113 |
# File 'lib/aws-sdk-rds/types.rb', line 29104 class StartDBInstanceAutomatedBackupsReplicationMessage < Struct.new( :source_db_instance_arn, :backup_retention_period, :kms_key_id, :pre_signed_url, :tags, :source_region) SENSITIVE = [:pre_signed_url] include Aws::Structure end |