Class: Aws::RDS::Types::StopActivityStreamResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kinesis_stream_nameString

The name of the Amazon Kinesis data stream used for the database activity stream.

Returns:

  • (String)


29297
29298
29299
29300
29301
29302
29303
# File 'lib/aws-sdk-rds/types.rb', line 29297

class StopActivityStreamResponse < Struct.new(
  :kms_key_id,
  :kinesis_stream_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Web Services KMS key identifier used for encrypting messages in the database activity stream.

The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.

Returns:

  • (String)


29297
29298
29299
29300
29301
29302
29303
# File 'lib/aws-sdk-rds/types.rb', line 29297

class StopActivityStreamResponse < Struct.new(
  :kms_key_id,
  :kinesis_stream_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the database activity stream.

Returns:

  • (String)


29297
29298
29299
29300
29301
29302
29303
# File 'lib/aws-sdk-rds/types.rb', line 29297

class StopActivityStreamResponse < Struct.new(
  :kms_key_id,
  :kinesis_stream_name,
  :status)
  SENSITIVE = []
  include Aws::Structure
end