Class: Aws::RDS::Types::Subnet

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

This data type is used as a response element for the DescribeDBSubnetGroups operation.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#subnet_availability_zoneTypes::AvailabilityZone

Contains Availability Zone information.

This data type is used as an element in the OrderableDBInstanceOption data type.



29933
29934
29935
29936
29937
29938
29939
29940
# File 'lib/aws-sdk-rds/types.rb', line 29933

class Subnet < Struct.new(
  :subnet_identifier,
  :subnet_availability_zone,
  :subnet_outpost,
  :subnet_status)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_identifierString

The identifier of the subnet.

Returns:

  • (String)


29933
29934
29935
29936
29937
29938
29939
29940
# File 'lib/aws-sdk-rds/types.rb', line 29933

class Subnet < Struct.new(
  :subnet_identifier,
  :subnet_availability_zone,
  :subnet_outpost,
  :subnet_status)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_outpostTypes::Outpost

If the subnet is associated with an Outpost, this value specifies the Outpost.

For more information about RDS on Outposts, see Amazon RDS on Amazon Web Services Outposts in the Amazon RDS User Guide.

Returns:



29933
29934
29935
29936
29937
29938
29939
29940
# File 'lib/aws-sdk-rds/types.rb', line 29933

class Subnet < Struct.new(
  :subnet_identifier,
  :subnet_availability_zone,
  :subnet_outpost,
  :subnet_status)
  SENSITIVE = []
  include Aws::Structure
end

#subnet_statusString

The status of the subnet.

Returns:

  • (String)


29933
29934
29935
29936
29937
29938
29939
29940
# File 'lib/aws-sdk-rds/types.rb', line 29933

class Subnet < Struct.new(
  :subnet_identifier,
  :subnet_availability_zone,
  :subnet_outpost,
  :subnet_status)
  SENSITIVE = []
  include Aws::Structure
end