Class: Aws::RDS::Types::SupportedEngineLifecycle
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::SupportedEngineLifecycle
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type is used as a response element in the operation DescribeDBMajorEngineVersions.
You can use the information that this data type returns to plan for upgrades.
This data type only returns information for the open source engines Amazon RDS for MariaDB, Amazon RDS for MySQL, Amazon RDS for PostgreSQL, Aurora MySQL, and Aurora PostgreSQL.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lifecycle_support_end_date ⇒ Time
The end date for the type of support returned by
LifecycleSupportName. -
#lifecycle_support_name ⇒ String
The type of lifecycle support that the engine version is in.
-
#lifecycle_support_start_date ⇒ Time
The start date for the type of support returned by
LifecycleSupportName.
Instance Attribute Details
#lifecycle_support_end_date ⇒ Time
The end date for the type of support returned by LifecycleSupportName.
29560 29561 29562 29563 29564 29565 29566 |
# File 'lib/aws-sdk-rds/types.rb', line 29560 class SupportedEngineLifecycle < Struct.new( :lifecycle_support_name, :lifecycle_support_start_date, :lifecycle_support_end_date) SENSITIVE = [] include Aws::Structure end |
#lifecycle_support_name ⇒ String
The type of lifecycle support that the engine version is in.
This parameter returns the following values:
-
open-source-rds-standard-support- Indicates RDS standard support or Aurora standard support. -
open-source-rds-extended-support- Indicates Amazon RDS Extended Support.
For Amazon RDS for MySQL, Amazon RDS for PostgreSQL, Aurora MySQL, and Aurora PostgreSQL, this parameter returns both open-source-rds-standard-support and open-source-rds-extended-support.
For Amazon RDS for MariaDB, this parameter only returns the value open-source-rds-standard-support.
For information about Amazon RDS Extended Support, see [Amazon RDS Extended Support with Amazon RDS] in the *Amazon RDS User Guide* and [Amazon RDS Extended Support with Amazon Aurora] in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/extended-support.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/extended-support.html
29560 29561 29562 29563 29564 29565 29566 |
# File 'lib/aws-sdk-rds/types.rb', line 29560 class SupportedEngineLifecycle < Struct.new( :lifecycle_support_name, :lifecycle_support_start_date, :lifecycle_support_end_date) SENSITIVE = [] include Aws::Structure end |
#lifecycle_support_start_date ⇒ Time
The start date for the type of support returned by LifecycleSupportName.
29560 29561 29562 29563 29564 29565 29566 |
# File 'lib/aws-sdk-rds/types.rb', line 29560 class SupportedEngineLifecycle < Struct.new( :lifecycle_support_name, :lifecycle_support_start_date, :lifecycle_support_end_date) SENSITIVE = [] include Aws::Structure end |