Class: Aws::RDS::Types::Tag
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::Tag
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Metadata assigned to an Amazon RDS resource consisting of a key-value pair.
For more information, see [Tagging Amazon RDS resources] in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources] in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#key ⇒ String
A key is the required name of the tag.
-
#value ⇒ String
A value is the optional value of the tag.
Instance Attribute Details
#key ⇒ String
A key is the required name of the tag. The string value can be from 1 to 128 Unicode characters in length and can’t be prefixed with aws: or rds:. The string can only contain only the set of Unicode letters, digits, white-space, ‘_’, ‘.’, ‘:’, ‘/’, ‘=’, ‘+’, ‘-’, ‘@’ (Java regex: “^([\\pL\\pZ\\pN_.:/=+\\-@]*)$”).
29444 29445 29446 29447 29448 29449 |
# File 'lib/aws-sdk-rds/types.rb', line 29444 class Tag < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |
#value ⇒ String
A value is the optional value of the tag. The string value can be from 1 to 256 Unicode characters in length and can’t be prefixed with aws: or rds:. The string can only contain only the set of Unicode letters, digits, white-space, ‘_’, ‘.’, ‘:’, ‘/’, ‘=’, ‘+’, ‘-’, ‘@’ (Java regex: “^([\\pL\\pZ\\pN_.:/=+\\-@]*)$”).
29444 29445 29446 29447 29448 29449 |
# File 'lib/aws-sdk-rds/types.rb', line 29444 class Tag < Struct.new( :key, :value) SENSITIVE = [] include Aws::Structure end |