Class: Aws::RDS::Types::TagSpecification

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

The tags to apply to resources when creating or modifying a DB instance or DB cluster. When you specify a tag, you must specify the resource type to tag, otherwise the request will fail.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#resource_typeString

The type of resource to tag on creation.

Valid Values:

  • ‘auto-backup` - The DB instance’s automated backup.

  • ‘cluster-auto-backup` - The DB cluster’s automated backup.

Returns:

  • (String)


29476
29477
29478
29479
29480
29481
# File 'lib/aws-sdk-rds/types.rb', line 29476

class TagSpecification < Struct.new(
  :resource_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsArray<Types::Tag>

A list of tags.

For more information, see [Tagging Amazon RDS resources] in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources] in the *Amazon Aurora User Guide*.

[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html

Returns:



29476
29477
29478
29479
29480
29481
# File 'lib/aws-sdk-rds/types.rb', line 29476

class TagSpecification < Struct.new(
  :resource_type,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end