Class: Aws::RDS::Types::TenantDatabase
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::TenantDatabase
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
A tenant database in the DB instance. This data type is an element in
the response to the DescribeTenantDatabases action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#character_set_name ⇒ String
The character set of the tenant database.
-
#db_instance_identifier ⇒ String
The ID of the DB instance that contains the tenant database.
-
#dbi_resource_id ⇒ String
The Amazon Web Services Region-unique, immutable identifier for the DB instance.
-
#deletion_protection ⇒ Boolean
Specifies whether deletion protection is enabled for the DB instance.
-
#master_user_secret ⇒ Types::MasterUserSecret
Contains the secret managed by RDS in Amazon Web Services Secrets Manager for the master user password.
-
#master_username ⇒ String
The master username of the tenant database.
-
#nchar_character_set_name ⇒ String
The
NCHARcharacter set name of the tenant database. -
#pending_modified_values ⇒ Types::TenantDatabasePendingModifiedValues
Information about pending changes for a tenant database.
-
#status ⇒ String
The status of the tenant database.
-
#tag_list ⇒ Array<Types::Tag>
A list of tags.
-
#tenant_database_arn ⇒ String
The Amazon Resource Name (ARN) for the tenant database.
-
#tenant_database_create_time ⇒ Time
The creation time of the tenant database.
-
#tenant_database_resource_id ⇒ String
The Amazon Web Services Region-unique, immutable identifier for the tenant database.
-
#tenant_db_name ⇒ String
The database name of the tenant database.
Instance Attribute Details
#character_set_name ⇒ String
The character set of the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#db_instance_identifier ⇒ String
The ID of the DB instance that contains the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#dbi_resource_id ⇒ String
The Amazon Web Services Region-unique, immutable identifier for the DB instance.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#deletion_protection ⇒ Boolean
Specifies whether deletion protection is enabled for the DB instance.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#master_user_secret ⇒ Types::MasterUserSecret
Contains the secret managed by RDS in Amazon Web Services Secrets Manager for the master user password.
For more information, see Password management with Amazon Web Services Secrets Manager in the Amazon RDS User Guide and Password management with Amazon Web Services Secrets Manager in the Amazon Aurora User Guide.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#master_username ⇒ String
The master username of the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#nchar_character_set_name ⇒ String
The NCHAR character set name of the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#pending_modified_values ⇒ Types::TenantDatabasePendingModifiedValues
Information about pending changes for a tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tag_list ⇒ Array<Types::Tag>
A list of tags.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tenant_database_arn ⇒ String
The Amazon Resource Name (ARN) for the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tenant_database_create_time ⇒ Time
The creation time of the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tenant_database_resource_id ⇒ String
The Amazon Web Services Region-unique, immutable identifier for the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tenant_db_name ⇒ String
The database name of the tenant database.
30402 30403 30404 30405 30406 30407 30408 30409 30410 30411 30412 30413 30414 30415 30416 30417 30418 30419 |
# File 'lib/aws-sdk-rds/types.rb', line 30402 class TenantDatabase < Struct.new( :tenant_database_create_time, :db_instance_identifier, :tenant_db_name, :status, :master_username, :dbi_resource_id, :tenant_database_resource_id, :tenant_database_arn, :character_set_name, :nchar_character_set_name, :deletion_protection, :pending_modified_values, :master_user_secret, :tag_list) SENSITIVE = [] include Aws::Structure end |