Class: Aws::RDS::Waiters::DBClusterDeleted

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-rds/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ DBClusterDeleted

Returns a new instance of DBClusterDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


161
162
# File 'lib/aws-sdk-rds/waiters.rb', line 161

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



216
217
218
# File 'lib/aws-sdk-rds/waiters.rb', line 216

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::DBClusterMessage

Returns a response object which responds to the following methods:

Options Hash (params):

  • :db_cluster_identifier (String)

    The user-supplied DB cluster identifier or the Amazon Resource Name (ARN) of the DB cluster. If this parameter is specified, information for only the specific DB cluster is returned. This parameter isn't case-sensitive.

    Constraints:

    • If supplied, must match an existing DB cluster identifier.

    ^

  • :filters (Array<Types::Filter>)

    A filter that specifies one or more DB clusters to describe.

    Supported Filters:

    • clone-group-id - Accepts clone group identifiers. The results list only includes information about the DB clusters associated with these clone groups.

    • db-cluster-id - Accepts DB cluster identifiers and DB cluster Amazon Resource Names (ARNs). The results list only includes information about the DB clusters identified by these ARNs.

    • db-cluster-resource-id - Accepts DB cluster resource identifiers. The results list will only include information about the DB clusters identified by these DB cluster resource identifiers.

    • domain - Accepts Active Directory directory IDs. The results list only includes information about the DB clusters associated with these domains.

    • engine - Accepts engine names. The results list only includes information about the DB clusters for these engines.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.

    Default: 100

    Constraints: Minimum 20, maximum 100

  • :marker (String)

    An optional pagination token provided by a previous DescribeDBClusters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  • :include_shared (Boolean)

    Specifies whether the output includes information about clusters shared from other Amazon Web Services accounts.

Returns:



211
# File 'lib/aws-sdk-rds/waiters.rb', line 211

def wait: (