Class: Aws::RDS::Waiters::DBClusterSnapshotAvailable
- Inherits:
-
Object
- Object
- Aws::RDS::Waiters::DBClusterSnapshotAvailable
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-rds/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ DBClusterSnapshotAvailable
constructor
A new instance of DBClusterSnapshotAvailable.
-
#wait(params = {}) ⇒ Types::DBClusterSnapshotMessage
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ DBClusterSnapshotAvailable
Returns a new instance of DBClusterSnapshotAvailable.
228 229 |
# File 'lib/aws-sdk-rds/waiters.rb', line 228
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
284 285 286 |
# File 'lib/aws-sdk-rds/waiters.rb', line 284 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::DBClusterSnapshotMessage
Returns a response object which responds to the following methods:
- #marker => String
- #db_cluster_snapshots => Array<Types::DBClusterSnapshot>
279 |
# File 'lib/aws-sdk-rds/waiters.rb', line 279
def wait: (
|