Class: Aws::RDS::Waiters::TenantDatabaseAvailable
- Inherits:
-
Object
- Object
- Aws::RDS::Waiters::TenantDatabaseAvailable
- Defined in:
- sig/waiters.rbs,
lib/aws-sdk-rds/waiters.rb
Instance Attribute Summary collapse
- #waiter ⇒ Object readonly private
Instance Method Summary collapse
-
#initialize(options) ⇒ TenantDatabaseAvailable
constructor
A new instance of TenantDatabaseAvailable.
-
#wait(params = {}) ⇒ Types::TenantDatabasesMessage
Returns a response object which responds to the following methods:.
Constructor Details
#initialize(options) ⇒ TenantDatabaseAvailable
Returns a new instance of TenantDatabaseAvailable.
633 634 |
# File 'lib/aws-sdk-rds/waiters.rb', line 633
def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void
|
Instance Attribute Details
#waiter ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
677 678 679 |
# File 'lib/aws-sdk-rds/waiters.rb', line 677 def waiter @waiter end |
Instance Method Details
#wait(params = {}) ⇒ Types::TenantDatabasesMessage
Returns a response object which responds to the following methods:
- #marker => String
- #tenant_databases => Array<Types::TenantDatabase>
672 |
# File 'lib/aws-sdk-rds/waiters.rb', line 672
def wait: (
|