Class: Aws::RDS::Waiters::TenantDatabaseDeleted

Inherits:
Object
  • Object
show all
Defined in:
sig/waiters.rbs,
lib/aws-sdk-rds/waiters.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(options) ⇒ TenantDatabaseDeleted

Returns a new instance of TenantDatabaseDeleted.

Parameters:

  • options (Hash)

Options Hash (options):

  • :client (required, Client)
  • :max_attempts (Integer) — default: 60
  • :delay (Integer) — default: 30
  • :before_attempt (Proc)
  • :before_wait (Proc)


689
690
# File 'lib/aws-sdk-rds/waiters.rb', line 689

def initialize: (?client: Client, ?max_attempts: Integer, ?delay: Integer, ?before_attempt: Proc, ?before_wait: Proc) -> void
| (?Hash[Symbol, untyped]) -> void

Instance Attribute Details

#waiterObject (readonly)

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.



720
721
722
# File 'lib/aws-sdk-rds/waiters.rb', line 720

def waiter
  @waiter
end

Instance Method Details

#wait(params = {}) ⇒ Types::TenantDatabasesMessage

Returns a response object which responds to the following methods:

Options Hash (params):

  • :db_instance_identifier (String)

    The user-supplied DB instance identifier, which must match the identifier of an existing instance owned by the Amazon Web Services account. This parameter isn't case-sensitive.

  • :tenant_db_name (String)

    The user-supplied tenant database name, which must match the name of an existing tenant database on the specified DB instance owned by your Amazon Web Services account. This parameter isn’t case-sensitive.

  • :filters (Array<Types::Filter>)

    A filter that specifies one or more database tenants to describe.

    Supported filters:

    • tenant-db-name - Tenant database names. The results list only includes information about the tenant databases that match these tenant DB names.

    • tenant-database-resource-id - Tenant database resource identifiers.

    • dbi-resource-id - DB instance resource identifiers. The results list only includes information about the tenants contained within the DB instances identified by these resource identifiers.

  • :marker (String)

    An optional pagination token provided by a previous DescribeTenantDatabases request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

  • :max_records (Integer)

    The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.

Returns:



715
# File 'lib/aws-sdk-rds/waiters.rb', line 715

def wait: (