Class: Aws::RDS::DBEngineVersion
- Inherits:
-
Object
- Object
- Aws::RDS::DBEngineVersion
- Extended by:
- Deprecations
- Defined in:
- sig/db_engine_version.rbs,
lib/aws-sdk-rds/db_engine_version.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#create_time ⇒ Time
The creation time of the DB engine version.
-
#custom_db_engine_version_manifest ⇒ String
JSON string that lists the installation files and parameters that RDS Custom uses to create a custom engine version (CEV).
-
#database_installation_files ⇒ Array<String>
The database installation files (ISO and EXE) that were uploaded to Amazon S3 and used to import the database engine version to Amazon RDS.
-
#database_installation_files_s3_bucket_name ⇒ String
The name of the Amazon S3 bucket that contains your database installation files.
-
#database_installation_files_s3_prefix ⇒ String
The Amazon S3 directory that contains the database installation files.
-
#db_engine_description ⇒ String
The description of the database engine.
-
#db_engine_media_type ⇒ String
The source of the installation media for this engine version.
-
#db_engine_version_arn ⇒ String
The ARN of the custom engine version.
-
#db_engine_version_description ⇒ String
The description of the database engine version.
-
#db_parameter_group_family ⇒ String
The name of the DB parameter group family for the database engine.
-
#default_character_set ⇒ Types::CharacterSet
The default character set for new instances of this engine version, if the
CharacterSetNameparameter of the CreateDBInstance API isn't specified. - #engine_name ⇒ String (also: #engine)
-
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to CloudWatch Logs.
-
#failure_reason ⇒ String
The reason that the custom engine version creation failed with an
incompatible-installation-mediastatus. -
#image ⇒ Types::CustomDBEngineVersionAMI
The EC2 image.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for an encrypted CEV.
-
#major_engine_version ⇒ String
The major engine version of the CEV.
-
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Aurora Serverless v2 properties or limits that differ between Aurora engine versions.
-
#status ⇒ String
The status of the DB engine version, either
availableordeprecated. -
#supported_ca_certificate_identifiers ⇒ Array<String>
A list of the supported CA certificate identifiers.
-
#supported_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by this engine for the
CharacterSetNameparameter of theCreateDBInstanceoperation. -
#supported_engine_modes ⇒ Array<String>
A list of the supported DB engine modes.
-
#supported_feature_names ⇒ Array<String>
A list of features supported by the DB engine.
-
#supported_nchar_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by the Oracle DB engine for the
NcharCharacterSetNameparameter of theCreateDBInstanceoperation. -
#supported_timezones ⇒ Array<Types::Timezone>
A list of the time zones supported by this engine for the
Timezoneparameter of theCreateDBInstanceaction. -
#supports_babelfish ⇒ Boolean
Indicates whether the engine version supports Babelfish for Aurora PostgreSQL.
-
#supports_certificate_rotation_without_restart ⇒ Boolean
Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.
-
#supports_global_databases ⇒ Boolean
Indicates whether you can use Aurora global databases with a specific DB engine version.
-
#supports_integrations ⇒ Boolean
Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.
-
#supports_limitless_database ⇒ Boolean
Indicates whether the DB engine version supports Aurora Limitless Database.
-
#supports_local_write_forwarding ⇒ Boolean
Indicates whether the DB engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster.
-
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
Indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.
-
#supports_parallel_query ⇒ Boolean
Indicates whether you can use Aurora parallel query with a specific DB engine version.
-
#supports_read_replica ⇒ Boolean
Indicates whether the database engine version supports read replicas.
-
#tag_list ⇒ Array<Types::Tag>
A list of tags.
-
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
- #version ⇒ String (also: #engine_version)
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #option_group_options(options = {}) ⇒ OptionGroupOption::Collection
- #option_groups(options = {}) ⇒ OptionGroup::Collection
- #parameter_group_family ⇒ DBParameterGroupFamily?
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::DBEngineVersion
Returns the data for this DBEngineVersion.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ DBEngineVersion
constructor
A new instance of DBEngineVersion.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current DBEngineVersion.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(engine_name, version, options = {}) ⇒ DBEngineVersion #initialize(options = {}) ⇒ DBEngineVersion
Returns a new instance of DBEngineVersion.
13 14 15 |
# File 'sig/db_engine_version.rbs', line 13
def initialize: (String engine_name, String version, Hash[Symbol, untyped] options) -> void
| (engine_name: String, version: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#client ⇒ Client
347 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 347
def client: () -> Client
|
#create_time ⇒ Time
The creation time of the DB engine version.
67 |
# File 'sig/db_engine_version.rbs', line 67
def create_time: () -> ::Time
|
#custom_db_engine_version_manifest ⇒ String
JSON string that lists the installation files and parameters that RDS Custom uses to create a custom engine version (CEV). RDS Custom applies the patches in the order in which they're listed in the manifest. You can set the Oracle home, Oracle base, and UNIX/Linux user and group using the installation parameters. For more information, see JSON fields in the CEV manifest in the Amazon RDS User Guide.
37 |
# File 'sig/db_engine_version.rbs', line 37
def custom_db_engine_version_manifest: () -> ::String
|
#data ⇒ Types::DBEngineVersion
Returns the data for this Aws::RDS::DBEngineVersion. Calls
Client#describe_db_engine_versions if #data_loaded? is false.
136 |
# File 'sig/db_engine_version.rbs', line 136
def data: () -> Types::DBEngineVersion
|
#data_loaded? ⇒ Boolean
139 |
# File 'sig/db_engine_version.rbs', line 139
def data_loaded?: () -> bool
|
#database_installation_files ⇒ Array<String>
The database installation files (ISO and EXE) that were uploaded to
Amazon S3 and used to import the database engine version to Amazon
RDS. Returned for RDS for SQL Server engine versions (sqlserver-ee,
sqlserver-se, and sqlserver-dev-ee) created from customer-supplied
installation media.
34 |
# File 'sig/db_engine_version.rbs', line 34
def database_installation_files: () -> ::Array[::String]
|
#database_installation_files_s3_bucket_name ⇒ String
The name of the Amazon S3 bucket that contains your database installation files.
28 |
# File 'sig/db_engine_version.rbs', line 28
def database_installation_files_s3_bucket_name: () -> ::String
|
#database_installation_files_s3_prefix ⇒ String
The Amazon S3 directory that contains the database installation files. If not specified, then no prefix is assumed.
31 |
# File 'sig/db_engine_version.rbs', line 31
def database_installation_files_s3_prefix: () -> ::String
|
#db_engine_description ⇒ String
The description of the database engine.
43 |
# File 'sig/db_engine_version.rbs', line 43
def db_engine_description: () -> ::String
|
#db_engine_media_type ⇒ String
The source of the installation media for this engine version. A value
of Customer Provided indicates that the engine version was created
from customer-supplied installation media using
CreateCustomDBEngineVersion. Applicable to RDS Custom for SQL Server
and to RDS for SQL Server engine versions (sqlserver-ee and
sqlserver-se with the bring-your-own-media license model, and
sqlserver-dev-ee).
61 |
# File 'sig/db_engine_version.rbs', line 61
def db_engine_media_type: () -> ::String
|
#db_engine_version_arn ⇒ String
The ARN of the custom engine version.
46 |
# File 'sig/db_engine_version.rbs', line 46
def db_engine_version_arn: () -> ::String
|
#db_engine_version_description ⇒ String
The description of the database engine version.
49 |
# File 'sig/db_engine_version.rbs', line 49
def db_engine_version_description: () -> ::String
|
#db_parameter_group_family ⇒ String
The name of the DB parameter group family for the database engine.
40 |
# File 'sig/db_engine_version.rbs', line 40
def db_parameter_group_family: () -> ::String
|
#default_character_set ⇒ Types::CharacterSet
The default character set for new instances of this engine version, if
the CharacterSetName parameter of the CreateDBInstance API isn't
specified.
52 |
# File 'sig/db_engine_version.rbs', line 52
def default_character_set: () -> Types::CharacterSet
|
#engine_name ⇒ String Also known as: engine
18 |
# File 'sig/db_engine_version.rbs', line 18
def engine_name: () -> String
|
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to CloudWatch Logs.
82 |
# File 'sig/db_engine_version.rbs', line 82
def exportable_log_types: () -> ::Array[::String]
|
#failure_reason ⇒ String
The reason that the custom engine version creation failed with an
incompatible-installation-media status. Applicable to RDS for SQL
Server engine versions (sqlserver-ee, sqlserver-se, and
sqlserver-dev-ee).
55 |
# File 'sig/db_engine_version.rbs', line 55
def failure_reason: () -> ::String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
587 588 589 590 591 592 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 587 def identifiers { engine_name: @engine_name, version: @version } end |
#image ⇒ Types::CustomDBEngineVersionAMI
The EC2 image
58 |
# File 'sig/db_engine_version.rbs', line 58
def image: () -> Types::CustomDBEngineVersionAMI
|
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for an encrypted CEV. This parameter is required for RDS Custom, but optional for Amazon RDS.
64 |
# File 'sig/db_engine_version.rbs', line 64
def kms_key_id: () -> ::String
|
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::RDS::DBEngineVersion.
Returns self making it possible to chain methods.
db_engine_version.reload.data
132 |
# File 'sig/db_engine_version.rbs', line 132
def load: () -> self
|
#major_engine_version ⇒ String
The major engine version of the CEV.
25 |
# File 'sig/db_engine_version.rbs', line 25
def major_engine_version: () -> ::String
|
#option_group_options(options = {}) ⇒ OptionGroupOption::Collection
146 |
# File 'sig/db_engine_version.rbs', line 146
def option_group_options: (
|
#option_groups(options = {}) ⇒ OptionGroup::Collection
157 |
# File 'sig/db_engine_version.rbs', line 157
def option_groups: (
|
#parameter_group_family ⇒ DBParameterGroupFamily?
169 |
# File 'sig/db_engine_version.rbs', line 169
def parameter_group_family: () -> DBParameterGroupFamily?
|
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Aurora Serverless v2 properties or limits that differ between Aurora engine versions. You can test the values of this attribute when deciding which Aurora version to use in a new or upgraded DB cluster. You can also retrieve the version of an existing DB cluster and check whether that version supports certain Aurora Serverless v2 features before you attempt to use those features.
127 |
# File 'sig/db_engine_version.rbs', line 127
def serverless_v2_features_support: () -> Types::ServerlessV2FeaturesSupport
|
#status ⇒ String
The status of the DB engine version, either available or
deprecated.
97 |
# File 'sig/db_engine_version.rbs', line 97
def status: () -> ::String
|
#supported_ca_certificate_identifiers ⇒ Array<String>
A list of the supported CA certificate identifiers.
For more information, see Using SSL/TLS to encrypt a connection to a DB instance in the Amazon RDS User Guide and Using SSL/TLS to encrypt a connection to a DB cluster in the Amazon Aurora User Guide.
118 |
# File 'sig/db_engine_version.rbs', line 118
def supported_ca_certificate_identifiers: () -> ::Array[::String]
|
#supported_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by this engine for the
CharacterSetName parameter of the CreateDBInstance operation.
70 |
# File 'sig/db_engine_version.rbs', line 70
def supported_character_sets: () -> ::Array[Types::CharacterSet]
|
#supported_engine_modes ⇒ Array<String>
A list of the supported DB engine modes.
91 |
# File 'sig/db_engine_version.rbs', line 91
def supported_engine_modes: () -> ::Array[::String]
|
#supported_feature_names ⇒ Array<String>
A list of features supported by the DB engine.
The supported features vary by DB engine and DB engine version.
To determine the supported features for a specific DB engine and DB engine version using the CLI, use the following command:
aws rds describe-db-engine-versions --engine <engine_name> --engine-version <engine_version>
For example, to determine the supported features for RDS for PostgreSQL version 13.3 using the CLI, use the following command:
aws rds describe-db-engine-versions --engine postgres --engine-version 13.3
The supported features are listed under SupportedFeatureNames in the
output.
94 |
# File 'sig/db_engine_version.rbs', line 94
def supported_feature_names: () -> ::Array[::String]
|
#supported_nchar_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by the Oracle DB engine for the
NcharCharacterSetName parameter of the CreateDBInstance operation.
73 |
# File 'sig/db_engine_version.rbs', line 73
def supported_nchar_character_sets: () -> ::Array[Types::CharacterSet]
|
#supported_timezones ⇒ Array<Types::Timezone>
A list of the time zones supported by this engine for the Timezone
parameter of the CreateDBInstance action.
79 |
# File 'sig/db_engine_version.rbs', line 79
def supported_timezones: () -> ::Array[Types::Timezone]
|
#supports_babelfish ⇒ Boolean
Indicates whether the engine version supports Babelfish for Aurora PostgreSQL.
109 |
# File 'sig/db_engine_version.rbs', line 109
def supports_babelfish: () -> bool
|
#supports_certificate_rotation_without_restart ⇒ Boolean
Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.
115 |
# File 'sig/db_engine_version.rbs', line 115
def supports_certificate_rotation_without_restart: () -> bool
|
#supports_global_databases ⇒ Boolean
Indicates whether you can use Aurora global databases with a specific DB engine version.
103 |
# File 'sig/db_engine_version.rbs', line 103
def supports_global_databases: () -> bool
|
#supports_integrations ⇒ Boolean
Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.
124 |
# File 'sig/db_engine_version.rbs', line 124
def supports_integrations: () -> bool
|
#supports_limitless_database ⇒ Boolean
Indicates whether the DB engine version supports Aurora Limitless Database.
112 |
# File 'sig/db_engine_version.rbs', line 112
def supports_limitless_database: () -> bool
|
#supports_local_write_forwarding ⇒ Boolean
Indicates whether the DB engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster. By default, write operations aren't allowed on reader DB instances.
Valid for: Aurora DB clusters only
121 |
# File 'sig/db_engine_version.rbs', line 121
def supports_local_write_forwarding: () -> bool
|
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
Indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.
85 |
# File 'sig/db_engine_version.rbs', line 85
def supports_log_exports_to_cloudwatch_logs: () -> bool
|
#supports_parallel_query ⇒ Boolean
Indicates whether you can use Aurora parallel query with a specific DB engine version.
100 |
# File 'sig/db_engine_version.rbs', line 100
def supports_parallel_query: () -> bool
|
#supports_read_replica ⇒ Boolean
Indicates whether the database engine version supports read replicas.
88 |
# File 'sig/db_engine_version.rbs', line 88
def supports_read_replica: () -> bool
|
#tag_list ⇒ Array<Types::Tag>
A list of tags.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.
106 |
# File 'sig/db_engine_version.rbs', line 106
def tag_list: () -> ::Array[Types::Tag]
|
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
76 |
# File 'sig/db_engine_version.rbs', line 76
def valid_upgrade_target: () -> ::Array[Types::UpgradeTarget]
|
#version ⇒ String Also known as: engine_version
21 |
# File 'sig/db_engine_version.rbs', line 21
def version: () -> String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 464 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |