Class: Aws::RDS::DBEngineVersion
- Inherits:
-
Object
- Object
- Aws::RDS::DBEngineVersion
- Extended by:
- Deprecations
- Defined in:
- lib/aws-sdk-rds/db_engine_version.rb
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#create_time ⇒ Time
The creation time of the DB engine version.
-
#custom_db_engine_version_manifest ⇒ String
JSON string that lists the installation files and parameters that RDS Custom uses to create a custom engine version (CEV).
-
#database_installation_files ⇒ Array<String>
The database installation files (ISO and EXE) that were uploaded to Amazon S3 and used to import the database engine version to Amazon RDS.
-
#database_installation_files_s3_bucket_name ⇒ String
The name of the Amazon S3 bucket that contains your database installation files.
-
#database_installation_files_s3_prefix ⇒ String
The Amazon S3 directory that contains the database installation files.
-
#db_engine_description ⇒ String
The description of the database engine.
-
#db_engine_media_type ⇒ String
The source of the installation media for this engine version.
-
#db_engine_version_arn ⇒ String
The ARN of the custom engine version.
-
#db_engine_version_description ⇒ String
The description of the database engine version.
-
#db_parameter_group_family ⇒ String
The name of the DB parameter group family for the database engine.
-
#default_character_set ⇒ Types::CharacterSet
The default character set for new instances of this engine version, if the ‘CharacterSetName` parameter of the CreateDBInstance API isn’t specified.
- #engine_name ⇒ String (also: #engine)
-
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to CloudWatch Logs.
-
#failure_reason ⇒ String
The reason that the custom engine version creation failed with an ‘incompatible-installation-media` status.
-
#image ⇒ Types::CustomDBEngineVersionAMI
The EC2 image.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for an encrypted CEV.
-
#major_engine_version ⇒ String
The major engine version of the CEV.
-
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Aurora Serverless v2 properties or limits that differ between Aurora engine versions.
-
#status ⇒ String
The status of the DB engine version, either ‘available` or `deprecated`.
-
#supported_ca_certificate_identifiers ⇒ Array<String>
A list of the supported CA certificate identifiers.
-
#supported_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by this engine for the ‘CharacterSetName` parameter of the `CreateDBInstance` operation.
-
#supported_engine_modes ⇒ Array<String>
A list of the supported DB engine modes.
-
#supported_feature_names ⇒ Array<String>
A list of features supported by the DB engine.
-
#supported_nchar_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by the Oracle DB engine for the ‘NcharCharacterSetName` parameter of the `CreateDBInstance` operation.
-
#supported_timezones ⇒ Array<Types::Timezone>
A list of the time zones supported by this engine for the ‘Timezone` parameter of the `CreateDBInstance` action.
-
#supports_babelfish ⇒ Boolean
Indicates whether the engine version supports Babelfish for Aurora PostgreSQL.
-
#supports_certificate_rotation_without_restart ⇒ Boolean
Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.
-
#supports_global_databases ⇒ Boolean
Indicates whether you can use Aurora global databases with a specific DB engine version.
-
#supports_integrations ⇒ Boolean
Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.
-
#supports_limitless_database ⇒ Boolean
Indicates whether the DB engine version supports Aurora Limitless Database.
-
#supports_local_write_forwarding ⇒ Boolean
Indicates whether the DB engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster.
-
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
Indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.
-
#supports_parallel_query ⇒ Boolean
Indicates whether you can use Aurora parallel query with a specific DB engine version.
-
#supports_read_replica ⇒ Boolean
Indicates whether the database engine version supports read replicas.
-
#tag_list ⇒ Array<Types::Tag>
A list of tags.
-
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
- #version ⇒ String (also: #engine_version)
Associations collapse
- #identifiers ⇒ Object deprecated private Deprecated.
- #option_group_options(options = {}) ⇒ OptionGroupOption::Collection
- #option_groups(options = {}) ⇒ OptionGroup::Collection
- #parameter_group_family ⇒ DBParameterGroupFamily?
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::DBEngineVersion
Returns the data for this DBEngineVersion.
-
#data_loaded? ⇒ Boolean
Returns ‘true` if this resource is loaded.
-
#initialize(*args) ⇒ DBEngineVersion
constructor
A new instance of DBEngineVersion.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current DBEngineVersion.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(engine_name, version, options = {}) ⇒ DBEngineVersion #initialize(options = {}) ⇒ DBEngineVersion
Returns a new instance of DBEngineVersion.
24 25 26 27 28 29 30 31 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 24 def initialize(*args) = Hash === args.last ? args.pop.dup : {} @engine_name = extract_engine_name(args, ) @version = extract_version(args, ) @data = .delete(:data) @client = .delete(:client) || Client.new() @waiter_block_warned = false end |
Instance Method Details
#client ⇒ Client
347 348 349 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 347 def client @client end |
#create_time ⇒ Time
The creation time of the DB engine version.
161 162 163 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 161 def create_time data[:create_time] end |
#custom_db_engine_version_manifest ⇒ String
JSON string that lists the installation files and parameters that RDS Custom uses to create a custom engine version (CEV). RDS Custom applies the patches in the order in which they’re listed in the manifest. You can set the Oracle home, Oracle base, and UNIX/Linux user and group using the installation parameters. For more information, see [JSON fields in the CEV manifest] in the *Amazon RDS User Guide*.
89 90 91 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 89 def custom_db_engine_version_manifest data[:custom_db_engine_version_manifest] end |
#data ⇒ Types::DBEngineVersion
Returns the data for this Aws::RDS::DBEngineVersion. Calls Client#describe_db_engine_versions if #data_loaded? is ‘false`.
372 373 374 375 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 372 def data load unless @data @data end |
#data_loaded? ⇒ Boolean
380 381 382 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 380 def data_loaded? !!@data end |
#database_installation_files ⇒ Array<String>
The database installation files (ISO and EXE) that were uploaded to Amazon S3 and used to import the database engine version to Amazon RDS. Returned for RDS for SQL Server engine versions (‘sqlserver-ee`, `sqlserver-se`, and `sqlserver-dev-ee`) created from customer-supplied installation media.
73 74 75 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 73 def database_installation_files data[:database_installation_files] end |
#database_installation_files_s3_bucket_name ⇒ String
The name of the Amazon S3 bucket that contains your database installation files.
56 57 58 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 56 def database_installation_files_s3_bucket_name data[:database_installation_files_s3_bucket_name] end |
#database_installation_files_s3_prefix ⇒ String
The Amazon S3 directory that contains the database installation files. If not specified, then no prefix is assumed.
63 64 65 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 63 def database_installation_files_s3_prefix data[:database_installation_files_s3_prefix] end |
#db_engine_description ⇒ String
The description of the database engine.
101 102 103 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 101 def db_engine_description data[:db_engine_description] end |
#db_engine_media_type ⇒ String
The source of the installation media for this engine version. A value of ‘Customer Provided` indicates that the engine version was created from customer-supplied installation media using `CreateCustomDBEngineVersion`. Applicable to RDS Custom for SQL Server and to RDS for SQL Server engine versions (`sqlserver-ee` and `sqlserver-se` with the `bring-your-own-media` license model, and `sqlserver-dev-ee`).
148 149 150 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 148 def db_engine_media_type data[:db_engine_media_type] end |
#db_engine_version_arn ⇒ String
The ARN of the custom engine version.
107 108 109 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 107 def db_engine_version_arn data[:db_engine_version_arn] end |
#db_engine_version_description ⇒ String
The description of the database engine version.
113 114 115 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 113 def db_engine_version_description data[:db_engine_version_description] end |
#db_parameter_group_family ⇒ String
The name of the DB parameter group family for the database engine.
95 96 97 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 95 def db_parameter_group_family data[:db_parameter_group_family] end |
#default_character_set ⇒ Types::CharacterSet
The default character set for new instances of this engine version, if the ‘CharacterSetName` parameter of the CreateDBInstance API isn’t specified.
121 122 123 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 121 def default_character_set data[:default_character_set] end |
#engine_name ⇒ String Also known as: engine
36 37 38 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 36 def engine_name @engine_name end |
#exportable_log_types ⇒ Array<String>
The types of logs that the database engine has available for export to CloudWatch Logs.
196 197 198 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 196 def exportable_log_types data[:exportable_log_types] end |
#failure_reason ⇒ String
The reason that the custom engine version creation failed with an ‘incompatible-installation-media` status. Applicable to RDS for SQL Server engine versions (`sqlserver-ee`, `sqlserver-se`, and `sqlserver-dev-ee`).
130 131 132 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 130 def failure_reason data[:failure_reason] end |
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
587 588 589 590 591 592 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 587 def identifiers { engine_name: @engine_name, version: @version } end |
#image ⇒ Types::CustomDBEngineVersionAMI
The EC2 image
136 137 138 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 136 def image data[:image] end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for an encrypted CEV. This parameter is required for RDS Custom, but optional for Amazon RDS.
155 156 157 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 155 def kms_key_id data[:kms_key_id] end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::RDS::DBEngineVersion. Returns ‘self` making it possible to chain methods.
db_engine_version.reload.data
357 358 359 360 361 362 363 364 365 366 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 357 def load resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_db_engine_versions( engine: @engine_name, engine_version: @version ) end @data = resp.db_engine_versions[0] self end |
#major_engine_version ⇒ String
The major engine version of the CEV.
49 50 51 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 49 def major_engine_version data[:major_engine_version] end |
#option_group_options(options = {}) ⇒ OptionGroupOption::Collection
507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 507 def ( = {}) batches = Enumerator.new do |y| = .merge( engine_name: @engine, major_engine_version: @version ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.() end resp.each_page do |page| batch = [] page.data..each do |o| batch << OptionGroupOption.new( name: o.name, data: o, client: @client ) end y.yield(batch) end end OptionGroupOption::Collection.new(batches) end |
#option_groups(options = {}) ⇒ OptionGroup::Collection
549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 549 def option_groups( = {}) batches = Enumerator.new do |y| = .merge( engine_name: @engine, major_engine_version: @version ) resp = Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do @client.describe_option_groups() end resp.each_page do |page| batch = [] page.data.option_groups_list.each do |o| batch << OptionGroup.new( name: o.option_group_name, data: o, client: @client ) end y.yield(batch) end end OptionGroup::Collection.new(batches) end |
#parameter_group_family ⇒ DBParameterGroupFamily?
574 575 576 577 578 579 580 581 582 583 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 574 def parameter_group_family if data[:db_parameter_group_family] DBParameterGroupFamily.new( name: data[:db_parameter_group_family], client: @client ) else nil end end |
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Aurora Serverless v2 properties or limits that differ between Aurora engine versions. You can test the values of this attribute when deciding which Aurora version to use in a new or upgraded DB cluster. You can also retrieve the version of an existing DB cluster and check whether that version supports certain Aurora Serverless v2 features before you attempt to use those features.
340 341 342 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 340 def serverless_v2_features_support data[:serverless_v2_features_support] end |
#status ⇒ String
The status of the DB engine version, either ‘available` or `deprecated`.
245 246 247 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 245 def status data[:status] end |
#supported_ca_certificate_identifiers ⇒ Array<String>
A list of the supported CA certificate identifiers.
For more information, see [Using SSL/TLS to encrypt a connection to a DB instance] in the *Amazon RDS User Guide* and [ Using SSL/TLS to encrypt a connection to a DB cluster] in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/UsingWithRDS.SSL.html
311 312 313 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 311 def supported_ca_certificate_identifiers data[:supported_ca_certificate_identifiers] end |
#supported_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by this engine for the ‘CharacterSetName` parameter of the `CreateDBInstance` operation.
168 169 170 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 168 def supported_character_sets data[:supported_character_sets] end |
#supported_engine_modes ⇒ Array<String>
A list of the supported DB engine modes.
215 216 217 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 215 def supported_engine_modes data[:supported_engine_modes] end |
#supported_feature_names ⇒ Array<String>
A list of features supported by the DB engine.
The supported features vary by DB engine and DB engine version.
To determine the supported features for a specific DB engine and DB engine version using the CLI, use the following command:
‘aws rds describe-db-engine-versions –engine <engine_name> –engine-version <engine_version>`
For example, to determine the supported features for RDS for PostgreSQL version 13.3 using the CLI, use the following command:
‘aws rds describe-db-engine-versions –engine postgres –engine-version 13.3`
The supported features are listed under ‘SupportedFeatureNames` in the output.
238 239 240 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 238 def supported_feature_names data[:supported_feature_names] end |
#supported_nchar_character_sets ⇒ Array<Types::CharacterSet>
A list of the character sets supported by the Oracle DB engine for the ‘NcharCharacterSetName` parameter of the `CreateDBInstance` operation.
175 176 177 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 175 def supported_nchar_character_sets data[:supported_nchar_character_sets] end |
#supported_timezones ⇒ Array<Types::Timezone>
A list of the time zones supported by this engine for the ‘Timezone` parameter of the `CreateDBInstance` action.
189 190 191 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 189 def supported_timezones data[:supported_timezones] end |
#supports_babelfish ⇒ Boolean
Indicates whether the engine version supports Babelfish for Aurora PostgreSQL.
281 282 283 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 281 def supports_babelfish data[:supports_babelfish] end |
#supports_certificate_rotation_without_restart ⇒ Boolean
Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.
295 296 297 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 295 def supports_certificate_rotation_without_restart data[:supports_certificate_rotation_without_restart] end |
#supports_global_databases ⇒ Boolean
Indicates whether you can use Aurora global databases with a specific DB engine version.
259 260 261 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 259 def supports_global_databases data[:supports_global_databases] end |
#supports_integrations ⇒ Boolean
Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.
329 330 331 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 329 def supports_integrations data[:supports_integrations] end |
#supports_limitless_database ⇒ Boolean
Indicates whether the DB engine version supports Aurora Limitless Database.
288 289 290 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 288 def supports_limitless_database data[:supports_limitless_database] end |
#supports_local_write_forwarding ⇒ Boolean
Indicates whether the DB engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster. By default, write operations aren’t allowed on reader DB instances.
Valid for: Aurora DB clusters only
322 323 324 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 322 def supports_local_write_forwarding data[:supports_local_write_forwarding] end |
#supports_log_exports_to_cloudwatch_logs ⇒ Boolean
Indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.
203 204 205 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 203 def supports_log_exports_to_cloudwatch_logs data[:supports_log_exports_to_cloudwatch_logs] end |
#supports_parallel_query ⇒ Boolean
Indicates whether you can use Aurora parallel query with a specific DB engine version.
252 253 254 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 252 def supports_parallel_query data[:supports_parallel_query] end |
#supports_read_replica ⇒ Boolean
Indicates whether the database engine version supports read replicas.
209 210 211 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 209 def supports_read_replica data[:supports_read_replica] end |
#tag_list ⇒ Array<Types::Tag>
A list of tags.
For more information, see [Tagging Amazon RDS resources] in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources] in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html
274 275 276 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 274 def tag_list data[:tag_list] end |
#valid_upgrade_target ⇒ Array<Types::UpgradeTarget>
A list of engine versions that this database engine version can be upgraded to.
182 183 184 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 182 def valid_upgrade_target data[:valid_upgrade_target] end |
#version ⇒ String Also known as: engine_version
42 43 44 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 42 def version @version end |
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
## Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
## Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
## Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
## Callbacks
You can be notified before each polling attempt and before each delay. If you throw ‘:success` or `:failure` from these callbacks, it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
## Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 |
# File 'lib/aws-sdk-rds/db_engine_version.rb', line 464 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |