Class: Aws::RDS::DBSecurityGroup
- Inherits:
-
Object
- Object
- Aws::RDS::DBSecurityGroup
- Extended by:
- Deprecations
- Defined in:
- sig/db_security_group.rbs,
lib/aws-sdk-rds/db_security_group.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#db_security_group_arn ⇒ String
The Amazon Resource Name (ARN) for the DB security group.
-
#db_security_group_description ⇒ String
Provides the description of the DB security group.
-
#ec2_security_groups ⇒ Array<Types::EC2SecurityGroup>
Contains a list of
EC2SecurityGroupelements. -
#ip_ranges ⇒ Array<Types::IPRange>
Contains a list of
IPRangeelements. - #name ⇒ String (also: #db_security_group_name)
-
#owner_id ⇒ String
Provides the Amazon Web Services ID of the owner of a specific DB security group.
-
#vpc_id ⇒ String
Provides the VpcId of the DB security group.
Actions collapse
- #authorize_ingress(options = {}) ⇒ DBSecurityGroup
- #create(options = {}) ⇒ DBSecurityGroup
- #delete(options = {}) ⇒ EmptyStructure
- #revoke_ingress(options = {}) ⇒ DBSecurityGroup
- #subscribe_to(options = {}) ⇒ EventSubscription
- #unsubscribe_from(options = {}) ⇒ EventSubscription
Associations collapse
- #events(options = {}) ⇒ Event::Collection
- #identifiers ⇒ Object deprecated private Deprecated.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::DBSecurityGroup
Returns the data for this DBSecurityGroup.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ DBSecurityGroup
constructor
A new instance of DBSecurityGroup.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current DBSecurityGroup.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ DBSecurityGroup #initialize(options = {}) ⇒ DBSecurityGroup
Returns a new instance of DBSecurityGroup.
13 14 15 |
# File 'sig/db_security_group.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#authorize_ingress(options = {}) ⇒ DBSecurityGroup
53 |
# File 'sig/db_security_group.rbs', line 53
def authorize_ingress: (
|
#create(options = {}) ⇒ DBSecurityGroup
62 |
# File 'sig/db_security_group.rbs', line 62
def create: (
|
#data ⇒ Types::DBSecurityGroup
Returns the data for this Aws::RDS::DBSecurityGroup. Calls
Client#describe_db_security_groups if #data_loaded? is false.
46 |
# File 'sig/db_security_group.rbs', line 46
def data: () -> Types::DBSecurityGroup
|
#data_loaded? ⇒ Boolean
49 |
# File 'sig/db_security_group.rbs', line 49
def data_loaded?: () -> bool
|
#db_security_group_arn ⇒ String
The Amazon Resource Name (ARN) for the DB security group.
37 |
# File 'sig/db_security_group.rbs', line 37
def db_security_group_arn: () -> ::String
|
#db_security_group_description ⇒ String
Provides the description of the DB security group.
25 |
# File 'sig/db_security_group.rbs', line 25
def db_security_group_description: () -> ::String
|
#delete(options = {}) ⇒ EmptyStructure
74 |
# File 'sig/db_security_group.rbs', line 74
def delete: (
|
#ec2_security_groups ⇒ Array<Types::EC2SecurityGroup>
Contains a list of EC2SecurityGroup elements.
31 |
# File 'sig/db_security_group.rbs', line 31
def ec2_security_groups: () -> ::Array[Types::EC2SecurityGroup]
|
#events(options = {}) ⇒ Event::Collection
100 |
# File 'sig/db_security_group.rbs', line 100
def events: (
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
457 458 459 |
# File 'lib/aws-sdk-rds/db_security_group.rb', line 457 def identifiers { name: @name } end |
#ip_ranges ⇒ Array<Types::IPRange>
Contains a list of IPRange elements.
34 |
# File 'sig/db_security_group.rbs', line 34
def ip_ranges: () -> ::Array[Types::IPRange]
|
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::RDS::DBSecurityGroup.
Returns self making it possible to chain methods.
db_security_group.reload.data
42 |
# File 'sig/db_security_group.rbs', line 42
def load: () -> self
|
#name ⇒ String Also known as: db_security_group_name
18 |
# File 'sig/db_security_group.rbs', line 18
def name: () -> String
|
#owner_id ⇒ String
Provides the Amazon Web Services ID of the owner of a specific DB security group.
22 |
# File 'sig/db_security_group.rbs', line 22
def owner_id: () -> ::String
|
#revoke_ingress(options = {}) ⇒ DBSecurityGroup
79 |
# File 'sig/db_security_group.rbs', line 79
def revoke_ingress: (
|
#subscribe_to(options = {}) ⇒ EventSubscription
88 |
# File 'sig/db_security_group.rbs', line 88
def subscribe_to: (
|
#unsubscribe_from(options = {}) ⇒ EventSubscription
94 |
# File 'sig/db_security_group.rbs', line 94
def unsubscribe_from: (
|
#vpc_id ⇒ String
Provides the VpcId of the DB security group.
28 |
# File 'sig/db_security_group.rbs', line 28
def vpc_id: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/aws-sdk-rds/db_security_group.rb', line 192 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |