Class: Aws::RDS::EventSubscription

Inherits:
Object
  • Object
show all
Extended by:
Deprecations
Defined in:
sig/event_subscription.rbs,
lib/aws-sdk-rds/event_subscription.rb

Overview

Defined Under Namespace

Classes: Collection

Read-Only Attributes collapse

Actions collapse

Instance Method Summary collapse

Constructor Details

#initialize(name, options = {}) ⇒ EventSubscription #initialize(options = {}) ⇒ EventSubscription

Returns a new instance of EventSubscription.

Overloads:

  • #initialize(name, options = {}) ⇒ EventSubscription

    Parameters:

    • name (String)

    Options Hash (options):

  • #initialize(options = {}) ⇒ EventSubscription

    Options Hash (options):

    • :name (required, String)
    • :client (Client)


13
14
15
# File 'sig/event_subscription.rbs', line 13

def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void

Instance Method Details

#add_subscriber(options = {}) ⇒ EventSubscription

Examples:

Request syntax with placeholder values


eventsubscription = event_subscription.add_subscriber({
  source_identifier: "String", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :source_identifier (required, String)

    The identifier of the event source to be added.

    Constraints:

    • If the source type is a DB instance, a DBInstanceIdentifier value must be supplied.

    • If the source type is a DB cluster, a DBClusterIdentifier value must be supplied.

    • If the source type is a DB parameter group, a DBParameterGroupName value must be supplied.

    • If the source type is a DB security group, a DBSecurityGroupName value must be supplied.

    • If the source type is a DB snapshot, a DBSnapshotIdentifier value must be supplied.

    • If the source type is a DB cluster snapshot, a DBClusterSnapshotIdentifier value must be supplied.

    • If the source type is an RDS Proxy, a DBProxyName value must be supplied.

Returns:



62
# File 'sig/event_subscription.rbs', line 62

def add_subscriber: (

#clientClient

Returns:



108
# File 'lib/aws-sdk-rds/event_subscription.rb', line 108

def client: () -> Client

#create(options = {}) ⇒ EventSubscription

Examples:

Request syntax with placeholder values


eventsubscription = event_subscription.create({
  sns_topic_arn: "String", # required
  source_type: "String",
  event_categories: ["String"],
  source_ids: ["String"],
  enabled: false,
  tags: [
    {
      key: "String",
      value: "String",
    },
  ],
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :sns_topic_arn (required, String)

    The Amazon Resource Name (ARN) of the SNS topic created for event notification. SNS automatically creates the ARN when you create a topic and subscribe to it.

    RDS doesn't support FIFO (first in, first out) topics. For more information, see Message ordering and deduplication (FIFO topics) in the Amazon Simple Notification Service Developer Guide.

  • :source_type (String)

    The type of source that is generating the events. For example, if you want to be notified of events generated by a DB instance, you set this parameter to db-instance. For RDS Proxy events, specify db-proxy. If this value isn't specified, all events are returned.

    Valid Values:db-instance | db-cluster | db-parameter-group | db-security-group | db-snapshot | db-cluster-snapshot | db-proxy | zero-etl | custom-engine-version | blue-green-deployment

  • :event_categories (Array<String>)

    A list of event categories for a particular source type (SourceType) that you want to subscribe to. You can see a list of the categories for a given source type in the "Amazon RDS event categories and event messages" section of the Amazon RDS User Guide or the Amazon Aurora User Guide . You can also see this list by using the DescribeEventCategories operation.

  • :source_ids (Array<String>)

    The list of identifiers of the event sources for which events are returned. If not specified, then all sources are included in the response. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens. It can't end with a hyphen or contain two consecutive hyphens.

    Constraints:

    • If SourceIds are supplied, SourceType must also be provided.

    • If the source type is a DB instance, a DBInstanceIdentifier value must be supplied.

    • If the source type is a DB cluster, a DBClusterIdentifier value must be supplied.

    • If the source type is a DB parameter group, a DBParameterGroupName value must be supplied.

    • If the source type is a DB security group, a DBSecurityGroupName value must be supplied.

    • If the source type is a DB snapshot, a DBSnapshotIdentifier value must be supplied.

    • If the source type is a DB cluster snapshot, a DBClusterSnapshotIdentifier value must be supplied.

    • If the source type is an RDS Proxy, a DBProxyName value must be supplied.

  • :enabled (Boolean)

    Specifies whether to activate the subscription. If the event notification subscription isn't activated, the subscription is created but not active.

  • :tags (Array<Types::Tag>)

    A list of tags.

    For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.

Returns:



68
# File 'sig/event_subscription.rbs', line 68

def create: (

#customer_aws_idString

The Amazon Web Services customer account associated with the RDS event notification subscription.

Returns:

  • (String)


22
# File 'sig/event_subscription.rbs', line 22

def customer_aws_id: () -> ::String

#dataTypes::EventSubscription

Returns the data for this Aws::RDS::EventSubscription. Calls Client#describe_event_subscriptions if #data_loaded? is false.

Returns:



55
# File 'sig/event_subscription.rbs', line 55

def data: () -> Types::EventSubscription

#data_loaded?Boolean

Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.

Returns:

  • (Boolean)

    Returns true if this resource is loaded. Accessing attributes or #data on an unloaded resource will trigger a call to #load.



58
# File 'sig/event_subscription.rbs', line 58

def data_loaded?: () -> bool

#delete(options = {}) ⇒ EventSubscription

Examples:

Request syntax with placeholder values


event_subscription.delete()

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Returns:



84
# File 'sig/event_subscription.rbs', line 84

def delete: (

#enabledBoolean

Specifies whether the subscription is enabled. True indicates the subscription is enabled.

Returns:

  • (Boolean)


43
# File 'sig/event_subscription.rbs', line 43

def enabled: () -> bool

#event_categories_listArray<String>

A list of event categories for the RDS event notification subscription.

Returns:

  • (Array<String>)


40
# File 'sig/event_subscription.rbs', line 40

def event_categories_list: () -> ::Array[::String]

#event_subscription_arnString

The Amazon Resource Name (ARN) for the event subscription.

Returns:

  • (String)


46
# File 'sig/event_subscription.rbs', line 46

def event_subscription_arn: () -> ::String

#identifiersObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Deprecated.


485
486
487
# File 'lib/aws-sdk-rds/event_subscription.rb', line 485

def identifiers
  { name: @name }
end

#loadself Also known as: reload

Loads, or reloads #data for the current Aws::RDS::EventSubscription. Returns self making it possible to chain methods.

event_subscription.reload.data

Returns:

  • (self)


51
# File 'sig/event_subscription.rbs', line 51

def load: () -> self

#modify(options = {}) ⇒ EventSubscription

Examples:

Request syntax with placeholder values


eventsubscription = event_subscription.modify({
  sns_topic_arn: "String",
  source_type: "String",
  event_categories: ["String"],
  enabled: false,
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :sns_topic_arn (String)

    The Amazon Resource Name (ARN) of the SNS topic created for event notification. The ARN is created by Amazon SNS when you create a topic and subscribe to it.

  • :source_type (String)

    The type of source that is generating the events. For example, if you want to be notified of events generated by a DB instance, you would set this parameter to db-instance. For RDS Proxy events, specify db-proxy. If this value isn't specified, all events are returned.

    Valid Values:db-instance | db-cluster | db-parameter-group | db-security-group | db-snapshot | db-cluster-snapshot | db-proxy | zero-etl | custom-engine-version | blue-green-deployment

  • :event_categories (Array<String>)

    A list of event categories for a source type (SourceType) that you want to subscribe to. You can see a list of the categories for a given source type in Events in the Amazon RDS User Guide or by using the DescribeEventCategories operation.

  • :enabled (Boolean)

    Specifies whether to activate the subscription.

Returns:



89
# File 'sig/event_subscription.rbs', line 89

def modify: (

#nameString Also known as: cust_subscription_id

Returns:

  • (String)


18
# File 'sig/event_subscription.rbs', line 18

def name: () -> String

#remove_subscriber(options = {}) ⇒ EventSubscription

Examples:

Request syntax with placeholder values


eventsubscription = event_subscription.remove_subscriber({
  source_identifier: "String", # required
})

Parameters:

  • options (Hash) (defaults to: {})

    ({})

Options Hash (options):

  • :source_identifier (required, String)

    The source identifier to be removed from the subscription, such as the DB instance identifier for a DB instance or the name of a security group.

Returns:



98
# File 'sig/event_subscription.rbs', line 98

def remove_subscriber: (

#sns_topic_arnString

The topic ARN of the RDS event notification subscription.

Returns:

  • (String)


25
# File 'sig/event_subscription.rbs', line 25

def sns_topic_arn: () -> ::String

#source_ids_listArray<String>

A list of source IDs for the RDS event notification subscription.

Returns:

  • (Array<String>)


37
# File 'sig/event_subscription.rbs', line 37

def source_ids_list: () -> ::Array[::String]

#source_typeString

The source type for the RDS event notification subscription.

Returns:

  • (String)


34
# File 'sig/event_subscription.rbs', line 34

def source_type: () -> ::String

#statusString

The status of the RDS event notification subscription.

Constraints:

Can be one of the following: creating | modifying | deleting | active | no-permission | topic-not-exist

The status "no-permission" indicates that RDS no longer has permission to post to the SNS topic. The status "topic-not-exist" indicates that the topic was deleted after the subscription was created.

Returns:

  • (String)


28
# File 'sig/event_subscription.rbs', line 28

def status: () -> ::String

#subscription_creation_timeString

The time the RDS event notification subscription was created.

Returns:

  • (String)


31
# File 'sig/event_subscription.rbs', line 31

def subscription_creation_time: () -> ::String

#wait_until(options = {}) {|resource| ... } ⇒ Resource

Deprecated.

Use [Aws::RDS::Client] #wait_until instead

Note:

The waiting operation is performed on a copy. The original resource remains unchanged.

Waiter polls an API operation until a resource enters a desired state.

Basic Usage

Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.

# polls in a loop until condition is true
resource.wait_until(options) {|resource| condition}

Example

instance.wait_until(max_attempts:10, delay:5) do |instance|
  instance.state.name == 'running'
end

Configuration

You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:

# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}

Callbacks

You can be notified before each polling attempt and before each delay. If you throw :success or :failure from these callbacks, it will terminate the waiter.

started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
  throw :failure if Time.now - started_at > 3600
end

  # disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}

Handling Errors

When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.

begin
  resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
  # resource did not enter the desired state in time
end

attempts attempt in seconds invoked before each attempt invoked before each wait

Parameters:

  • options (Hash) (defaults to: {})

    a customizable set of options

Options Hash (options):

  • :max_attempts (Integer) — default: 10

    Maximum number of

  • :delay (Integer) — default: 10

    Delay between each

  • :before_attempt (Proc) — default: nil

    Callback

  • :before_wait (Proc) — default: nil

    Callback

Yield Parameters:

  • resource (Resource)

    to be used in the waiting condition.

Returns:

  • (Resource)

    if the waiter was successful

Raises:

  • (Aws::Waiters::Errors::FailureStateError)

    Raised when the waiter terminates because the waiter has entered a state that it will not transition out of, preventing success.

    yet successful.

  • (Aws::Waiters::Errors::UnexpectedError)

    Raised when an error is encountered while polling for a resource that is not expected.

  • (NotImplementedError)

    Raised when the resource does not



222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/aws-sdk-rds/event_subscription.rb', line 222

def wait_until(options = {}, &block)
  self_copy = self.dup
  attempts = 0
  options[:max_attempts] = 10 unless options.key?(:max_attempts)
  options[:delay] ||= 10
  options[:poller] = Proc.new do
    attempts += 1
    if block.call(self_copy)
      [:success, self_copy]
    else
      self_copy.reload unless attempts == options[:max_attempts]
      :retry
    end
  end
  Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do
    Aws::Waiters::Waiter.new(options).wait({})
  end
end