Class: Aws::RDS::EventSubscription
- Inherits:
-
Object
- Object
- Aws::RDS::EventSubscription
- Extended by:
- Deprecations
- Defined in:
- sig/event_subscription.rbs,
lib/aws-sdk-rds/event_subscription.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#customer_aws_id ⇒ String
The Amazon Web Services customer account associated with the RDS event notification subscription.
-
#enabled ⇒ Boolean
Specifies whether the subscription is enabled.
-
#event_categories_list ⇒ Array<String>
A list of event categories for the RDS event notification subscription.
-
#event_subscription_arn ⇒ String
The Amazon Resource Name (ARN) for the event subscription.
- #name ⇒ String (also: #cust_subscription_id)
-
#sns_topic_arn ⇒ String
The topic ARN of the RDS event notification subscription.
-
#source_ids_list ⇒ Array<String>
A list of source IDs for the RDS event notification subscription.
-
#source_type ⇒ String
The source type for the RDS event notification subscription.
-
#status ⇒ String
The status of the RDS event notification subscription.
-
#subscription_creation_time ⇒ String
The time the RDS event notification subscription was created.
Actions collapse
- #add_subscriber(options = {}) ⇒ EventSubscription
- #create(options = {}) ⇒ EventSubscription
- #delete(options = {}) ⇒ EventSubscription
- #identifiers ⇒ Object deprecated private Deprecated.
- #modify(options = {}) ⇒ EventSubscription
- #remove_subscriber(options = {}) ⇒ EventSubscription
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::EventSubscription
Returns the data for this EventSubscription.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ EventSubscription
constructor
A new instance of EventSubscription.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current EventSubscription.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ EventSubscription #initialize(options = {}) ⇒ EventSubscription
Returns a new instance of EventSubscription.
13 14 15 |
# File 'sig/event_subscription.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#add_subscriber(options = {}) ⇒ EventSubscription
62 |
# File 'sig/event_subscription.rbs', line 62
def add_subscriber: (
|
#client ⇒ Client
108 |
# File 'lib/aws-sdk-rds/event_subscription.rb', line 108
def client: () -> Client
|
#create(options = {}) ⇒ EventSubscription
68 |
# File 'sig/event_subscription.rbs', line 68
def create: (
|
#customer_aws_id ⇒ String
The Amazon Web Services customer account associated with the RDS event notification subscription.
22 |
# File 'sig/event_subscription.rbs', line 22
def customer_aws_id: () -> ::String
|
#data ⇒ Types::EventSubscription
Returns the data for this Aws::RDS::EventSubscription. Calls
Client#describe_event_subscriptions if #data_loaded? is false.
55 |
# File 'sig/event_subscription.rbs', line 55
def data: () -> Types::EventSubscription
|
#data_loaded? ⇒ Boolean
58 |
# File 'sig/event_subscription.rbs', line 58
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EventSubscription
84 |
# File 'sig/event_subscription.rbs', line 84
def delete: (
|
#enabled ⇒ Boolean
Specifies whether the subscription is enabled. True indicates the subscription is enabled.
43 |
# File 'sig/event_subscription.rbs', line 43
def enabled: () -> bool
|
#event_categories_list ⇒ Array<String>
A list of event categories for the RDS event notification subscription.
40 |
# File 'sig/event_subscription.rbs', line 40
def event_categories_list: () -> ::Array[::String]
|
#event_subscription_arn ⇒ String
The Amazon Resource Name (ARN) for the event subscription.
46 |
# File 'sig/event_subscription.rbs', line 46
def event_subscription_arn: () -> ::String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
485 486 487 |
# File 'lib/aws-sdk-rds/event_subscription.rb', line 485 def identifiers { name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::RDS::EventSubscription.
Returns self making it possible to chain methods.
event_subscription.reload.data
51 |
# File 'sig/event_subscription.rbs', line 51
def load: () -> self
|
#modify(options = {}) ⇒ EventSubscription
89 |
# File 'sig/event_subscription.rbs', line 89
def modify: (
|
#name ⇒ String Also known as: cust_subscription_id
18 |
# File 'sig/event_subscription.rbs', line 18
def name: () -> String
|
#remove_subscriber(options = {}) ⇒ EventSubscription
98 |
# File 'sig/event_subscription.rbs', line 98
def remove_subscriber: (
|
#sns_topic_arn ⇒ String
The topic ARN of the RDS event notification subscription.
25 |
# File 'sig/event_subscription.rbs', line 25
def sns_topic_arn: () -> ::String
|
#source_ids_list ⇒ Array<String>
A list of source IDs for the RDS event notification subscription.
37 |
# File 'sig/event_subscription.rbs', line 37
def source_ids_list: () -> ::Array[::String]
|
#source_type ⇒ String
The source type for the RDS event notification subscription.
34 |
# File 'sig/event_subscription.rbs', line 34
def source_type: () -> ::String
|
#status ⇒ String
The status of the RDS event notification subscription.
Constraints:
Can be one of the following: creating | modifying | deleting | active | no-permission | topic-not-exist
The status "no-permission" indicates that RDS no longer has permission to post to the SNS topic. The status "topic-not-exist" indicates that the topic was deleted after the subscription was created.
28 |
# File 'sig/event_subscription.rbs', line 28
def status: () -> ::String
|
#subscription_creation_time ⇒ String
The time the RDS event notification subscription was created.
31 |
# File 'sig/event_subscription.rbs', line 31
def subscription_creation_time: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/aws-sdk-rds/event_subscription.rb', line 222 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |