Class: Aws::RDS::OptionGroup
- Inherits:
-
Object
- Object
- Aws::RDS::OptionGroup
- Extended by:
- Deprecations
- Defined in:
- sig/option_group.rbs,
lib/aws-sdk-rds/option_group.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#allows_vpc_and_non_vpc_instance_memberships ⇒ Boolean
Indicates whether this option group can be applied to both VPC and non-VPC instances.
-
#copy_timestamp ⇒ Time
Indicates when the option group was copied.
-
#engine_name ⇒ String
Indicates the name of the engine that this option group can be applied to.
-
#major_engine_version ⇒ String
Indicates the major engine version associated with this option group.
- #name ⇒ String (also: #option_group_name)
-
#option_group_arn ⇒ String
Specifies the Amazon Resource Name (ARN) for the option group.
-
#option_group_description ⇒ String
Provides a description of the option group.
-
#options ⇒ Array<Types::Option>
Indicates what options are available in the option group.
-
#source_account_id ⇒ String
Specifies the Amazon Web Services account ID for the option group from which this option group is copied.
-
#source_option_group ⇒ String
Specifies the name of the option group from which this option group is copied.
-
#vpc_id ⇒ String
If AllowsVpcAndNonVpcInstanceMemberships is
false, this field is blank.
Actions collapse
- #copy(options = {}) ⇒ OptionGroup
- #create(options = {}) ⇒ OptionGroup
- #delete(options = {}) ⇒ EmptyStructure
- #identifiers ⇒ Object deprecated private Deprecated.
- #modify(options = {}) ⇒ OptionGroup
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::OptionGroup
Returns the data for this OptionGroup.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ OptionGroup
constructor
A new instance of OptionGroup.
-
#load ⇒ self
(also: #reload)
Loads, or reloads #data for the current OptionGroup.
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ OptionGroup #initialize(options = {}) ⇒ OptionGroup
Returns a new instance of OptionGroup.
13 14 15 |
# File 'sig/option_group.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#allows_vpc_and_non_vpc_instance_memberships ⇒ Boolean
Indicates whether this option group can be applied to both VPC and
non-VPC instances. The value true indicates the option group can be
applied to both VPC and non-VPC instances.
34 |
# File 'sig/option_group.rbs', line 34
def allows_vpc_and_non_vpc_instance_memberships: () -> bool
|
#copy_timestamp ⇒ Time
Indicates when the option group was copied.
49 |
# File 'sig/option_group.rbs', line 49
def copy_timestamp: () -> ::Time
|
#data ⇒ Types::OptionGroup
Returns the data for this Aws::RDS::OptionGroup. Calls
Client#describe_option_groups if #data_loaded? is false.
58 |
# File 'sig/option_group.rbs', line 58
def data: () -> Types::OptionGroup
|
#data_loaded? ⇒ Boolean
61 |
# File 'sig/option_group.rbs', line 61
def data_loaded?: () -> bool
|
#delete(options = {}) ⇒ EmptyStructure
92 |
# File 'sig/option_group.rbs', line 92
def delete: (
|
#engine_name ⇒ String
Indicates the name of the engine that this option group can be applied to.
25 |
# File 'sig/option_group.rbs', line 25
def engine_name: () -> ::String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
431 432 433 |
# File 'lib/aws-sdk-rds/option_group.rb', line 431 def identifiers { name: @name } end |
#load ⇒ self Also known as: reload
Loads, or reloads #data for the current Aws::RDS::OptionGroup.
Returns self making it possible to chain methods.
option_group.reload.data
54 |
# File 'sig/option_group.rbs', line 54
def load: () -> self
|
#major_engine_version ⇒ String
Indicates the major engine version associated with this option group.
28 |
# File 'sig/option_group.rbs', line 28
def major_engine_version: () -> ::String
|
#name ⇒ String Also known as: option_group_name
18 |
# File 'sig/option_group.rbs', line 18
def name: () -> String
|
#option_group_arn ⇒ String
Specifies the Amazon Resource Name (ARN) for the option group.
40 |
# File 'sig/option_group.rbs', line 40
def option_group_arn: () -> ::String
|
#option_group_description ⇒ String
Provides a description of the option group.
22 |
# File 'sig/option_group.rbs', line 22
def option_group_description: () -> ::String
|
#options ⇒ Array<Types::Option>
Indicates what options are available in the option group.
31 |
# File 'sig/option_group.rbs', line 31
def options: () -> ::Array[Types::Option]
|
#source_account_id ⇒ String
Specifies the Amazon Web Services account ID for the option group from which this option group is copied.
46 |
# File 'sig/option_group.rbs', line 46
def source_account_id: () -> ::String
|
#source_option_group ⇒ String
Specifies the name of the option group from which this option group is copied.
43 |
# File 'sig/option_group.rbs', line 43
def source_option_group: () -> ::String
|
#vpc_id ⇒ String
If AllowsVpcAndNonVpcInstanceMemberships is false, this field is
blank. If AllowsVpcAndNonVpcInstanceMemberships is true and this
field is blank, then this option group can be applied to both VPC and
non-VPC instances. If this field contains a value, then this option
group can only be applied to instances that are in the VPC indicated
by this field.
37 |
# File 'sig/option_group.rbs', line 37
def vpc_id: () -> ::String
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/aws-sdk-rds/option_group.rb', line 225 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |