Class: Aws::RDS::Parameter
- Inherits:
-
Object
- Object
- Aws::RDS::Parameter
- Extended by:
- Deprecations
- Defined in:
- sig/parameter.rbs,
lib/aws-sdk-rds/parameter.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#allowed_values ⇒ String
Specifies the valid range of values for the parameter.
-
#apply_method ⇒ String
Indicates when to apply parameter updates.
-
#apply_type ⇒ String
Specifies the engine specific parameters type.
-
#data_type ⇒ String
Specifies the valid data type for the parameter.
-
#description ⇒ String
Provides a description of the parameter.
-
#is_modifiable ⇒ Boolean
Indicates whether (
true) or not (false) the parameter can be modified. -
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
- #name ⇒ String (also: #parameter_name)
-
#parameter_value ⇒ String
The value of the parameter.
-
#source ⇒ String
The source of the parameter value.
-
#supported_engine_modes ⇒ Array<String>
The valid DB engine modes.
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::Parameter
Returns the data for this Parameter.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. - #identifiers ⇒ Object deprecated private Deprecated.
-
#initialize(*args) ⇒ Parameter
constructor
A new instance of Parameter.
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(name, options = {}) ⇒ Parameter #initialize(options = {}) ⇒ Parameter
Returns a new instance of Parameter.
13 14 15 |
# File 'sig/parameter.rbs', line 13
def initialize: (String name, Hash[Symbol, untyped] options) -> void
| (name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#allowed_values ⇒ String
Specifies the valid range of values for the parameter.
37 |
# File 'sig/parameter.rbs', line 37
def allowed_values: () -> ::String
|
#apply_method ⇒ String
Indicates when to apply parameter updates.
46 |
# File 'sig/parameter.rbs', line 46
def apply_method: () -> ("immediate" | "pending-reboot")
|
#apply_type ⇒ String
Specifies the engine specific parameters type.
31 |
# File 'sig/parameter.rbs', line 31
def apply_type: () -> ::String
|
#data ⇒ Types::Parameter
Returns the data for this Aws::RDS::Parameter.
55 |
# File 'sig/parameter.rbs', line 55
def data: () -> Types::Parameter
|
#data_loaded? ⇒ Boolean
58 |
# File 'sig/parameter.rbs', line 58
def data_loaded?: () -> bool
|
#data_type ⇒ String
Specifies the valid data type for the parameter.
34 |
# File 'sig/parameter.rbs', line 34
def data_type: () -> ::String
|
#description ⇒ String
Provides a description of the parameter.
25 |
# File 'sig/parameter.rbs', line 25
def description: () -> ::String
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
231 232 233 |
# File 'lib/aws-sdk-rds/parameter.rb', line 231 def identifiers { name: @name } end |
#is_modifiable ⇒ Boolean
Indicates whether (true) or not (false) the parameter can be
modified. Some parameters have security or operational implications
that prevent them from being changed.
40 |
# File 'sig/parameter.rbs', line 40
def is_modifiable: () -> bool
|
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
109 110 111 112 |
# File 'lib/aws-sdk-rds/parameter.rb', line 109 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
43 |
# File 'sig/parameter.rbs', line 43
def minimum_engine_version: () -> ::String
|
#name ⇒ String Also known as: parameter_name
18 |
# File 'sig/parameter.rbs', line 18
def name: () -> String
|
#parameter_value ⇒ String
The value of the parameter.
22 |
# File 'sig/parameter.rbs', line 22
def parameter_value: () -> ::String
|
#source ⇒ String
The source of the parameter value.
28 |
# File 'sig/parameter.rbs', line 28
def source: () -> ::String
|
#supported_engine_modes ⇒ Array<String>
The valid DB engine modes.
49 |
# File 'sig/parameter.rbs', line 49
def supported_engine_modes: () -> ::Array[::String]
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/aws-sdk-rds/parameter.rb', line 210 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |