Class: Aws::RDS::PendingMaintenanceAction
- Inherits:
-
Object
- Object
- Aws::RDS::PendingMaintenanceAction
- Extended by:
- Deprecations
- Defined in:
- sig/pending_maintenance_action.rbs,
lib/aws-sdk-rds/pending_maintenance_action.rb
Overview
Defined Under Namespace
Classes: Collection
Read-Only Attributes collapse
-
#auto_applied_after_date ⇒ Time
The date of the maintenance window when the action is applied.
-
#current_apply_date ⇒ Time
The effective date when the pending maintenance action is applied to the resource.
-
#description ⇒ String
A description providing more detail about the maintenance action.
-
#forced_apply_date ⇒ Time
The date when the maintenance action is automatically applied.
- #name ⇒ String (also: #action)
-
#opt_in_status ⇒ String
Indicates the type of opt-in request that has been received for the resource.
- #target_arn ⇒ String
Actions collapse
- #apply_immediately(options = {}) ⇒ ResourcePendingMaintenanceActionList
- #apply_on_next_maintenance(options = {}) ⇒ ResourcePendingMaintenanceActionList
- #identifiers ⇒ Object deprecated private Deprecated.
- #undo_opt_in(options = {}) ⇒ ResourcePendingMaintenanceActionList
Instance Method Summary collapse
- #client ⇒ Client
-
#data ⇒ Types::PendingMaintenanceAction
Returns the data for this PendingMaintenanceAction.
-
#data_loaded? ⇒ Boolean
Returns
trueif this resource is loaded. -
#initialize(*args) ⇒ PendingMaintenanceAction
constructor
A new instance of PendingMaintenanceAction.
- #load ⇒ Object (also: #reload) private
-
#wait_until(options = {}) {|resource| ... } ⇒ Resource
deprecated
Deprecated.
Use [Aws::RDS::Client] #wait_until instead
Constructor Details
#initialize(target_arn, name, options = {}) ⇒ PendingMaintenanceAction #initialize(options = {}) ⇒ PendingMaintenanceAction
Returns a new instance of PendingMaintenanceAction.
13 14 15 |
# File 'sig/pending_maintenance_action.rbs', line 13
def initialize: (String target_arn, String name, Hash[Symbol, untyped] options) -> void
| (target_arn: String, name: String, ?client: Client) -> void
| (Hash[Symbol, untyped] args) -> void
|
Instance Method Details
#apply_immediately(options = {}) ⇒ ResourcePendingMaintenanceActionList
50 |
# File 'sig/pending_maintenance_action.rbs', line 50
def apply_immediately: (
|
#apply_on_next_maintenance(options = {}) ⇒ ResourcePendingMaintenanceActionList
60 |
# File 'sig/pending_maintenance_action.rbs', line 60
def apply_on_next_maintenance: (
|
#auto_applied_after_date ⇒ Time
The date of the maintenance window when the action is applied. The maintenance action is applied to the resource during its first maintenance window after this date.
25 |
# File 'sig/pending_maintenance_action.rbs', line 25
def auto_applied_after_date: () -> ::Time
|
#client ⇒ Client
92 |
# File 'lib/aws-sdk-rds/pending_maintenance_action.rb', line 92
def client: () -> Client
|
#current_apply_date ⇒ Time
The effective date when the pending maintenance action is applied to
the resource. This date takes into account opt-in requests received
from the ApplyPendingMaintenanceAction API, the
AutoAppliedAfterDate, and the ForcedApplyDate. This value is blank
if an opt-in request has not been received and nothing has been
specified as AutoAppliedAfterDate or ForcedApplyDate.
34 |
# File 'sig/pending_maintenance_action.rbs', line 34
def current_apply_date: () -> ::Time
|
#data ⇒ Types::PendingMaintenanceAction
Returns the data for this Aws::RDS::PendingMaintenanceAction.
43 |
# File 'sig/pending_maintenance_action.rbs', line 43
def data: () -> Types::PendingMaintenanceAction
|
#data_loaded? ⇒ Boolean
46 |
# File 'sig/pending_maintenance_action.rbs', line 46
def data_loaded?: () -> bool
|
#description ⇒ String
A description providing more detail about the maintenance action.
37 |
# File 'sig/pending_maintenance_action.rbs', line 37
def description: () -> ::String
|
#forced_apply_date ⇒ Time
The date when the maintenance action is automatically applied.
On this date, the maintenance action is applied to the resource as soon as possible, regardless of the maintenance window for the resource. There might be a delay of one or more days from this date before the maintenance action is applied.
28 |
# File 'sig/pending_maintenance_action.rbs', line 28
def forced_apply_date: () -> ::Time
|
#identifiers ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
285 286 287 288 289 290 |
# File 'lib/aws-sdk-rds/pending_maintenance_action.rb', line 285 def identifiers { target_arn: @target_arn, name: @name } end |
#load ⇒ Object Also known as: reload
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
98 99 100 101 |
# File 'lib/aws-sdk-rds/pending_maintenance_action.rb', line 98 def load msg = "#load is not implemented, data only available via enumeration" raise NotImplementedError, msg end |
#name ⇒ String Also known as: action
21 |
# File 'sig/pending_maintenance_action.rbs', line 21
def name: () -> String
|
#opt_in_status ⇒ String
Indicates the type of opt-in request that has been received for the resource.
31 |
# File 'sig/pending_maintenance_action.rbs', line 31
def opt_in_status: () -> ::String
|
#target_arn ⇒ String
18 |
# File 'sig/pending_maintenance_action.rbs', line 18
def target_arn: () -> String
|
#undo_opt_in(options = {}) ⇒ ResourcePendingMaintenanceActionList
55 |
# File 'sig/pending_maintenance_action.rbs', line 55
def undo_opt_in: (
|
#wait_until(options = {}) {|resource| ... } ⇒ Resource
Use [Aws::RDS::Client] #wait_until instead
The waiting operation is performed on a copy. The original resource remains unchanged.
Waiter polls an API operation until a resource enters a desired state.
Basic Usage
Waiter will polls until it is successful, it fails by entering a terminal state, or until a maximum number of attempts are made.
# polls in a loop until condition is true
resource.wait_until() {|resource| condition}
Example
instance.wait_until(max_attempts:10, delay:5) do |instance|
instance.state.name == 'running'
end
Configuration
You can configure the maximum number of polling attempts, and the delay (in seconds) between each polling attempt. The waiting condition is set by passing a block to #wait_until:
# poll for ~25 seconds
resource.wait_until(max_attempts:5,delay:5) {|resource|...}
Callbacks
You can be notified before each polling attempt and before each
delay. If you throw :success or :failure from these callbacks,
it will terminate the waiter.
started_at = Time.now
# poll for 1 hour, instead of a number of attempts
proc = Proc.new do |attempts, response|
throw :failure if Time.now - started_at > 3600
end
# disable max attempts
instance.wait_until(before_wait:proc, max_attempts:nil) {...}
Handling Errors
When a waiter is successful, it returns the Resource. When a waiter fails, it raises an error.
begin
resource.wait_until(...)
rescue Aws::Waiters::Errors::WaiterFailed
# resource did not enter the desired state in time
end
attempts attempt in seconds invoked before each attempt invoked before each wait
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/aws-sdk-rds/pending_maintenance_action.rb', line 199 def wait_until( = {}, &block) self_copy = self.dup attempts = 0 [:max_attempts] = 10 unless .key?(:max_attempts) [:delay] ||= 10 [:poller] = Proc.new do attempts += 1 if block.call(self_copy) [:success, self_copy] else self_copy.reload unless attempts == [:max_attempts] :retry end end Aws::Plugins::UserAgent.metric('RESOURCE_MODEL') do Aws::Waiters::Waiter.new().wait({}) end end |