Class: Aws::RDS::Types::AdditionalStorageVolumeOutput

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains information about an additional storage volume for a DB instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The amount of storage allocated for the additional storage volume, in gibibytes (GiB). The minimum is 20 GiB. The maximum is 65,536 GiB (64 TiB).



369
370
371
372
373
374
375
376
377
378
379
# File 'lib/aws-sdk-rds/types.rb', line 369

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

The number of I/O operations per second (IOPS) provisioned for the additional storage volume.



369
370
371
372
373
374
375
376
377
378
379
# File 'lib/aws-sdk-rds/types.rb', line 369

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#max_allocated_storageInteger

The upper limit in gibibytes (GiB) to which RDS can automatically scale the storage of the additional storage volume.



369
370
371
372
373
374
375
376
377
378
379
# File 'lib/aws-sdk-rds/types.rb', line 369

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_throughputInteger

The storage throughput value for the additional storage volume, in mebibytes per second (MiBps).



369
370
371
372
373
374
375
376
377
378
379
# File 'lib/aws-sdk-rds/types.rb', line 369

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The storage type for the additional storage volume.

Valid Values: ‘GP3 | IO2`



369
370
371
372
373
374
375
376
377
378
379
# File 'lib/aws-sdk-rds/types.rb', line 369

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#storage_volume_statusString

The status of the additional storage volume.

Valid Values: ‘ACTIVE | CREATING | DELETING | MODIFYING | NOT-IN-USE | STORAGE-OPTIMIZATION | VOLUME-FULL`



369
370
371
372
373
374
375
376
377
378
379
# File 'lib/aws-sdk-rds/types.rb', line 369

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end

#volume_nameString

The name of the additional storage volume.



369
370
371
372
373
374
375
376
377
378
379
# File 'lib/aws-sdk-rds/types.rb', line 369

class AdditionalStorageVolumeOutput < Struct.new(
  :volume_name,
  :storage_volume_status,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type)
  SENSITIVE = []
  include Aws::Structure
end