Class: Aws::RDS::Types::CloudwatchLogsExportConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::CloudwatchLogsExportConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
The configuration setting for the log types to be enabled for export to CloudWatch Logs for a specific DB instance or DB cluster.
The EnableLogTypes and DisableLogTypes arrays determine which logs
will be exported (or not exported) to CloudWatch Logs. The values
within these arrays depend on the DB engine being used.
For more information about exporting CloudWatch Logs for Amazon RDS DB instances, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon RDS User Guide.
For more information about exporting CloudWatch Logs for Amazon Aurora DB clusters, see Publishing Database Logs to Amazon CloudWatch Logs in the Amazon Aurora User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#disable_log_types ⇒ Array<String>
The list of log types to disable.
-
#enable_log_types ⇒ Array<String>
The list of log types to enable.
Instance Attribute Details
#disable_log_types ⇒ Array<String>
The list of log types to disable.
The following values are valid for each DB engine:
-
Aurora MySQL -
audit | error | general | slowquery -
Aurora PostgreSQL -
postgresql -
RDS for MySQL -
error | general | slowquery -
RDS for PostgreSQL -
postgresql | upgrade
1138 1139 1140 1141 1142 1143 |
# File 'lib/aws-sdk-rds/types.rb', line 1138 class CloudwatchLogsExportConfiguration < Struct.new( :enable_log_types, :disable_log_types) SENSITIVE = [] include Aws::Structure end |
#enable_log_types ⇒ Array<String>
The list of log types to enable.
The following values are valid for each DB engine:
-
Aurora MySQL -
audit | error | general | slowquery -
Aurora PostgreSQL -
postgresql -
RDS for MySQL -
error | general | slowquery -
RDS for PostgreSQL -
postgresql | upgrade
1138 1139 1140 1141 1142 1143 |
# File 'lib/aws-sdk-rds/types.rb', line 1138 class CloudwatchLogsExportConfiguration < Struct.new( :enable_log_types, :disable_log_types) SENSITIVE = [] include Aws::Structure end |