Class: Aws::RDS::Types::DBClusterAssociatedRole
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBClusterAssociatedRole
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains information about an Amazon Web Services Identity and Access
Management (IAM) role to associate with a DB cluster. You can specify
this structure in the AssociatedRoles parameter of CreateDBCluster,
RestoreDBClusterFromS3, RestoreDBClusterFromSnapshot, and
RestoreDBClusterToPointInTime.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#feature_name ⇒ String
The name of the feature associated with the IAM role.
-
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to associate with the DB cluster.
Instance Attribute Details
#feature_name ⇒ String
The name of the feature associated with the IAM role. For information about supported feature names, see DBEngineVersion.
8132 8133 8134 8135 8136 8137 |
# File 'lib/aws-sdk-rds/types.rb', line 8132 class DBClusterAssociatedRole < Struct.new( :role_arn, :feature_name) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
The Amazon Resource Name (ARN) of the IAM role to associate with the DB cluster.
8132 8133 8134 8135 8136 8137 |
# File 'lib/aws-sdk-rds/types.rb', line 8132 class DBClusterAssociatedRole < Struct.new( :role_arn, :feature_name) SENSITIVE = [] include Aws::Structure end |