Class: Aws::RDS::Types::DBEngineVersion

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

This data type is used as a response element in the action ‘DescribeDBEngineVersions`.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#create_timeTime

The creation time of the DB engine version.

Returns:

  • (Time)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#custom_db_engine_version_manifestString

JSON string that lists the installation files and parameters that RDS Custom uses to create a custom engine version (CEV). RDS Custom applies the patches in the order in which they’re listed in the manifest. You can set the Oracle home, Oracle base, and UNIX/Linux user and group using the installation parameters. For more information, see [JSON fields in the CEV manifest] in the *Amazon RDS User Guide*.

[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/custom-cev.preparing.html#custom-cev.preparing.manifest.fields

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#database_installation_filesArray<String>

The database installation files (ISO and EXE) that were uploaded to Amazon S3 and used to import the database engine version to Amazon RDS. Returned for RDS for SQL Server engine versions (‘sqlserver-ee`, `sqlserver-se`, and `sqlserver-dev-ee`) created from customer-supplied installation media.

Returns:

  • (Array<String>)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#database_installation_files_s3_bucket_nameString

The name of the Amazon S3 bucket that contains your database installation files.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#database_installation_files_s3_prefixString

The Amazon S3 directory that contains the database installation files. If not specified, then no prefix is assumed.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#db_engine_descriptionString

The description of the database engine.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#db_engine_media_typeString

The source of the installation media for this engine version. A value of ‘Customer Provided` indicates that the engine version was created from customer-supplied installation media using `CreateCustomDBEngineVersion`. Applicable to RDS Custom for SQL Server and to RDS for SQL Server engine versions (`sqlserver-ee` and `sqlserver-se` with the `bring-your-own-media` license model, and `sqlserver-dev-ee`).

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#db_engine_version_arnString

The ARN of the custom engine version.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#db_engine_version_descriptionString

The description of the database engine version.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#db_parameter_group_familyString

The name of the DB parameter group family for the database engine.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#default_character_setTypes::CharacterSet

The default character set for new instances of this engine version, if the ‘CharacterSetName` parameter of the CreateDBInstance API isn’t specified.

Returns:



9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The name of the database engine.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The version number of the database engine.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#exportable_log_typesArray<String>

The types of logs that the database engine has available for export to CloudWatch Logs.

Returns:

  • (Array<String>)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#failure_reasonString

The reason that the custom engine version creation failed with an ‘incompatible-installation-media` status. Applicable to RDS for SQL Server engine versions (`sqlserver-ee`, `sqlserver-se`, and `sqlserver-dev-ee`).

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#imageTypes::CustomDBEngineVersionAMI

The EC2 image



9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Web Services KMS key identifier for an encrypted CEV. This parameter is required for RDS Custom, but optional for Amazon RDS.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#major_engine_versionString

The major engine version of the CEV.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#serverless_v2_features_supportTypes::ServerlessV2FeaturesSupport

Specifies any Aurora Serverless v2 properties or limits that differ between Aurora engine versions. You can test the values of this attribute when deciding which Aurora version to use in a new or upgraded DB cluster. You can also retrieve the version of an existing DB cluster and check whether that version supports certain Aurora Serverless v2 features before you attempt to use those features.



9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The status of the DB engine version, either ‘available` or `deprecated`.

Returns:

  • (String)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_ca_certificate_identifiersArray<String>

A list of the supported CA certificate identifiers.

For more information, see [Using SSL/TLS to encrypt a connection to a DB instance] in the *Amazon RDS User Guide* and [ Using SSL/TLS to encrypt a connection to a DB cluster] in the *Amazon Aurora User Guide*.

[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/UsingWithRDS.SSL.html

Returns:

  • (Array<String>)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_character_setsArray<Types::CharacterSet>

A list of the character sets supported by this engine for the ‘CharacterSetName` parameter of the `CreateDBInstance` operation.

Returns:



9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_engine_modesArray<String>

A list of the supported DB engine modes.

Returns:

  • (Array<String>)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_feature_namesArray<String>

A list of features supported by the DB engine.

The supported features vary by DB engine and DB engine version.

To determine the supported features for a specific DB engine and DB engine version using the CLI, use the following command:

‘aws rds describe-db-engine-versions –engine <engine_name> –engine-version <engine_version>`

For example, to determine the supported features for RDS for PostgreSQL version 13.3 using the CLI, use the following command:

‘aws rds describe-db-engine-versions –engine postgres –engine-version 13.3`

The supported features are listed under ‘SupportedFeatureNames` in the output.

Returns:

  • (Array<String>)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_nchar_character_setsArray<Types::CharacterSet>

A list of the character sets supported by the Oracle DB engine for the ‘NcharCharacterSetName` parameter of the `CreateDBInstance` operation.

Returns:



9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supported_timezonesArray<Types::Timezone>

A list of the time zones supported by this engine for the ‘Timezone` parameter of the `CreateDBInstance` action.

Returns:



9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_babelfishBoolean

Indicates whether the engine version supports Babelfish for Aurora PostgreSQL.

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_certificate_rotation_without_restartBoolean

Indicates whether the engine version supports rotating the server certificate without rebooting the DB instance.

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_global_databasesBoolean

Indicates whether you can use Aurora global databases with a specific DB engine version.

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_integrationsBoolean

Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_limitless_databaseBoolean

Indicates whether the DB engine version supports Aurora Limitless Database.

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_local_write_forwardingBoolean

Indicates whether the DB engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster. By default, write operations aren’t allowed on reader DB instances.

Valid for: Aurora DB clusters only

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_log_exports_to_cloudwatch_logsBoolean

Indicates whether the engine version supports exporting the log types specified by ExportableLogTypes to CloudWatch Logs.

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_parallel_queryBoolean

Indicates whether you can use Aurora parallel query with a specific DB engine version.

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#supports_read_replicaBoolean

Indicates whether the database engine version supports read replicas.

Returns:

  • (Boolean)


9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#tag_listArray<Types::Tag>

A list of tags.

For more information, see [Tagging Amazon RDS resources] in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources] in the *Amazon Aurora User Guide*.

[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html

Returns:



9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end

#valid_upgrade_targetArray<Types::UpgradeTarget>

A list of engine versions that this database engine version can be upgraded to.

Returns:



9418
9419
9420
9421
9422
9423
9424
9425
9426
9427
9428
9429
9430
9431
9432
9433
9434
9435
9436
9437
9438
9439
9440
9441
9442
9443
9444
9445
9446
9447
9448
9449
9450
9451
9452
9453
9454
9455
9456
9457
9458
# File 'lib/aws-sdk-rds/types.rb', line 9418

class DBEngineVersion < Struct.new(
  :engine,
  :major_engine_version,
  :engine_version,
  :database_installation_files_s3_bucket_name,
  :database_installation_files_s3_prefix,
  :database_installation_files,
  :custom_db_engine_version_manifest,
  :db_parameter_group_family,
  :db_engine_description,
  :db_engine_version_arn,
  :db_engine_version_description,
  :default_character_set,
  :failure_reason,
  :image,
  :db_engine_media_type,
  :kms_key_id,
  :create_time,
  :supported_character_sets,
  :supported_nchar_character_sets,
  :valid_upgrade_target,
  :supported_timezones,
  :exportable_log_types,
  :supports_log_exports_to_cloudwatch_logs,
  :supports_read_replica,
  :supported_engine_modes,
  :supported_feature_names,
  :status,
  :supports_parallel_query,
  :supports_global_databases,
  :tag_list,
  :supports_babelfish,
  :supports_limitless_database,
  :supports_certificate_rotation_without_restart,
  :supported_ca_certificate_identifiers,
  :supports_local_write_forwarding,
  :supports_integrations,
  :serverless_v2_features_support)
  SENSITIVE = []
  include Aws::Structure
end