Class: Aws::RDS::Types::DBInstanceAutomatedBackup

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

An automated backup of a DB instance. It consists of system backups, transaction logs, and the database instance properties that existed at the time you deleted the source instance.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_storage_volumesArray<Types::AdditionalStorageVolume>

The additional storage volumes associated with the automated backup.

Valid Values: ‘GP3 | IO2`

Returns:



10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#allocated_storageInteger

The allocated storage size for the automated backup in gibibytes (GiB).

Returns:

  • (Integer)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#availability_zoneString

The Availability Zone that the automated backup was created in. For information on Amazon Web Services Regions and Availability Zones, see [Regions and Availability Zones].

[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.RegionsAndAvailabilityZones.html

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#aws_backup_recovery_point_arnString

The Amazon Resource Name (ARN) of the recovery point in Amazon Web Services Backup.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#backup_retention_periodInteger

The retention period for the automated backups.

Returns:

  • (Integer)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#backup_targetString

The location where automated backups are stored: Dedicated Local Zones, Amazon Web Services Outposts or the Amazon Web Services Region.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_arnString

The Amazon Resource Name (ARN) for the automated backups.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_automated_backups_arnString

The Amazon Resource Name (ARN) for the replicated automated backups.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_automated_backups_replicationsArray<Types::DBInstanceAutomatedBackupsReplication>

The list of replications to different Amazon Web Services Regions associated with the automated backup.



10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#db_instance_identifierString

The identifier for the source DB instance, which can’t be changed and which is unique to an Amazon Web Services Region.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#dbi_resource_idString

The resource ID for the source DB instance, which can’t be changed and which is unique to an Amazon Web Services Region.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#dedicated_log_volumeBoolean

Indicates whether the DB instance has a dedicated log volume (DLV) enabled.

Returns:

  • (Boolean)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#encryptedBoolean

Indicates whether the automated backup is encrypted.

Returns:

  • (Boolean)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#engineString

The name of the database engine for this automated backup.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#engine_versionString

The version of the database engine for the automated backup.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#iam_database_authentication_enabledBoolean

True if mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled, and otherwise false.

Returns:

  • (Boolean)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#instance_create_timeTime

The date and time when the DB instance was created.

Returns:

  • (Time)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

The IOPS (I/O operations per second) value for the automated backup.

Returns:

  • (Integer)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#kms_key_idString

The Amazon Web Services KMS key ID for an automated backup.

The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#license_modelString

The license model information for the automated backup.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#master_usernameString

The master user name of an automated backup.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#multi_tenantBoolean

Specifies whether the automatic backup is for a DB instance in the multi-tenant configuration (TRUE) or the single-tenant configuration (FALSE).

Returns:

  • (Boolean)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#option_group_nameString

The option group the automated backup is associated with. If omitted, the default option group for the engine specified is used.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#portInteger

The port number that the automated backup used for connections.

Default: Inherits from the source DB instance

Valid Values: ‘1150-65535`

Returns:

  • (Integer)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#preferred_backup_windowString

The daily time range during which automated backups are created if automated backups are enabled, as determined by the ‘BackupRetentionPeriod`.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#regionString

The Amazon Web Services Region associated with the automated backup.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#restore_windowTypes::RestoreWindow

The earliest and latest time a DB instance can be restored to.



10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

A list of status information for an automated backup:

  • ‘active` - Automated backups for current instances.

  • ‘retained` - Automated backups for deleted instances.

  • ‘creating` - Automated backups that are waiting for the first automated snapshot to be available.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#storage_encryption_typeString

The type of encryption used to protect data at rest in the automated backup. Possible values:

  • ‘none` - The automated backup is not encrypted.

  • ‘sse-rds` - The automated backup is encrypted using an Amazon Web Services owned KMS key.

  • ‘sse-kms` - The automated backup is encrypted using a customer managed KMS key or Amazon Web Services managed KMS key.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#storage_throughputInteger

The storage throughput for the automated backup.

Returns:

  • (Integer)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The storage type associated with the automated backup.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#tag_listArray<Types::Tag>

A list of tags.

For more information, see [Tagging Amazon RDS resources] in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources] in the *Amazon Aurora User Guide*.

[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html

Returns:



10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#tde_credential_arnString

The ARN from the key store with which the automated backup is associated for TDE encryption.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#timezoneString

The time zone of the automated backup. In most cases, the ‘Timezone` element is empty. `Timezone` content appears only for Microsoft SQL Server DB instances that were created with a time zone specified.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end

#vpc_idString

The VPC ID associated with the DB instance.

Returns:

  • (String)


10456
10457
10458
10459
10460
10461
10462
10463
10464
10465
10466
10467
10468
10469
10470
10471
10472
10473
10474
10475
10476
10477
10478
10479
10480
10481
10482
10483
10484
10485
10486
10487
10488
10489
10490
10491
10492
10493
10494
# File 'lib/aws-sdk-rds/types.rb', line 10456

class DBInstanceAutomatedBackup < Struct.new(
  :db_instance_arn,
  :dbi_resource_id,
  :region,
  :db_instance_identifier,
  :restore_window,
  :allocated_storage,
  :status,
  :port,
  :availability_zone,
  :vpc_id,
  :instance_create_time,
  :master_username,
  :engine,
  :engine_version,
  :license_model,
  :iops,
  :storage_throughput,
  :option_group_name,
  :tde_credential_arn,
  :encrypted,
  :storage_encryption_type,
  :storage_type,
  :kms_key_id,
  :timezone,
  :iam_database_authentication_enabled,
  :backup_retention_period,
  :preferred_backup_window,
  :db_instance_automated_backups_arn,
  :db_instance_automated_backups_replications,
  :backup_target,
  :multi_tenant,
  :aws_backup_recovery_point_arn,
  :tag_list,
  :dedicated_log_volume,
  :additional_storage_volumes)
  SENSITIVE = []
  include Aws::Structure
end