Class: Aws::RDS::Types::DBInstanceStatusInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBInstanceStatusInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Provides a list of status information for a DB instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
Details of the error if there is an error for the instance.
-
#normal ⇒ Boolean
Indicates whether the instance is operating normally (TRUE) or is in an error state (FALSE).
-
#status ⇒ String
The status of the DB instance.
-
#status_type ⇒ String
This value is currently "read replication.".
Instance Attribute Details
#message ⇒ String
Details of the error if there is an error for the instance. If the instance isn't in an error state, this value is blank.
10753 10754 10755 10756 10757 10758 10759 10760 |
# File 'lib/aws-sdk-rds/types.rb', line 10753 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#normal ⇒ Boolean
Indicates whether the instance is operating normally (TRUE) or is in an error state (FALSE).
10753 10754 10755 10756 10757 10758 10759 10760 |
# File 'lib/aws-sdk-rds/types.rb', line 10753 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the DB instance. For a StatusType of read replica, the values can be replicating, replication stop point set, replication stop point reached, error, stopped, or terminated.
10753 10754 10755 10756 10757 10758 10759 10760 |
# File 'lib/aws-sdk-rds/types.rb', line 10753 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |
#status_type ⇒ String
This value is currently "read replication."
10753 10754 10755 10756 10757 10758 10759 10760 |
# File 'lib/aws-sdk-rds/types.rb', line 10753 class DBInstanceStatusInfo < Struct.new( :status_type, :normal, :status, :message) SENSITIVE = [] include Aws::Structure end |