Class: Aws::RDS::Types::DBRecommendation
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBRecommendation
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
The recommendation for your DB instances, DB clusters, and DB parameter groups.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_info ⇒ String
Additional information about the recommendation.
-
#category ⇒ String
The category of the recommendation.
-
#created_time ⇒ Time
The time when the recommendation was created.
-
#description ⇒ String
A detailed description of the recommendation.
-
#detection ⇒ String
A short description of the issue identified for this recommendation.
-
#impact ⇒ String
A short description that explains the possible impact of an issue.
-
#issue_details ⇒ Types::IssueDetails
Details of the issue that caused the recommendation.
-
#links ⇒ Array<Types::DocLink>
A link to documentation that provides additional information about the recommendation.
-
#reason ⇒ String
The reason why this recommendation was created.
-
#recommendation ⇒ String
A short description of the recommendation to resolve an issue.
-
#recommendation_id ⇒ String
The unique identifier of the recommendation.
-
#recommended_actions ⇒ Array<Types::RecommendedAction>
A list of recommended actions.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the RDS resource associated with the recommendation.
-
#severity ⇒ String
The severity level of the recommendation.
-
#source ⇒ String
The Amazon Web Services service that generated the recommendations.
-
#status ⇒ String
The current status of the recommendation.
-
#type_detection ⇒ String
A short description of the recommendation type.
-
#type_id ⇒ String
A value that indicates the type of recommendation.
-
#type_recommendation ⇒ String
A short description that summarizes the recommendation to fix all the issues of the recommendation type.
-
#updated_time ⇒ Time
The time when the recommendation was last updated.
Instance Attribute Details
#additional_info ⇒ String
Additional information about the recommendation. The information might contain markdown.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#category ⇒ String
The category of the recommendation.
Valid values:
-
‘performance efficiency`
-
‘security`
-
‘reliability`
-
‘cost optimization`
-
‘operational excellence`
-
‘sustainability`
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#created_time ⇒ Time
The time when the recommendation was created. For example, ‘2023-09-28T01:13:53.931000+00:00`.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A detailed description of the recommendation. The description might contain markdown.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#detection ⇒ String
A short description of the issue identified for this recommendation. The description might contain markdown.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#impact ⇒ String
A short description that explains the possible impact of an issue.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#issue_details ⇒ Types::IssueDetails
Details of the issue that caused the recommendation.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#links ⇒ Array<Types::DocLink>
A link to documentation that provides additional information about the recommendation.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#reason ⇒ String
The reason why this recommendation was created. The information might contain markdown.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#recommendation ⇒ String
A short description of the recommendation to resolve an issue. The description might contain markdown.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#recommendation_id ⇒ String
The unique identifier of the recommendation.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#recommended_actions ⇒ Array<Types::RecommendedAction>
A list of recommended actions.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the RDS resource associated with the recommendation.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#severity ⇒ String
The severity level of the recommendation. The severity level can help you decide the urgency with which to address the recommendation.
Valid values:
-
‘high`
-
‘medium`
-
‘low`
-
‘informational`
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The Amazon Web Services service that generated the recommendations.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the recommendation.
Valid values:
-
‘active` - The recommendations which are ready for you to apply.
-
‘pending` - The applied or scheduled recommendations which are in progress.
-
‘resolved` - The recommendations which are completed.
-
‘dismissed` - The recommendations that you dismissed.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#type_detection ⇒ String
A short description of the recommendation type. The description might contain markdown.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#type_id ⇒ String
A value that indicates the type of recommendation. This value determines how the description is rendered.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#type_recommendation ⇒ String
A short description that summarizes the recommendation to fix all the issues of the recommendation type. The description might contain markdown.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |
#updated_time ⇒ Time
The time when the recommendation was last updated.
11445 11446 11447 11448 11449 11450 11451 11452 11453 11454 11455 11456 11457 11458 11459 11460 11461 11462 11463 11464 11465 11466 11467 11468 |
# File 'lib/aws-sdk-rds/types.rb', line 11445 class DBRecommendation < Struct.new( :recommendation_id, :type_id, :severity, :resource_arn, :status, :created_time, :updated_time, :detection, :recommendation, :description, :reason, :recommended_actions, :category, :source, :type_detection, :type_recommendation, :impact, :additional_info, :links, :issue_details) SENSITIVE = [] include Aws::Structure end |