Class: Aws::RDS::Types::DBSnapshotTenantDatabase
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DBSnapshotTenantDatabase
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the details of a tenant database in a snapshot of a DB instance.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#character_set_name ⇒ String
The name of the character set of a tenant database.
-
#db_instance_identifier ⇒ String
The ID for the DB instance that contains the tenant databases.
-
#db_snapshot_identifier ⇒ String
The identifier for the snapshot of the DB instance.
-
#db_snapshot_tenant_database_arn ⇒ String
The Amazon Resource Name (ARN) for the snapshot tenant database.
-
#dbi_resource_id ⇒ String
The resource identifier of the source CDB instance.
-
#engine_name ⇒ String
The name of the database engine.
-
#master_username ⇒ String
The master username of the tenant database.
-
#nchar_character_set_name ⇒ String
The
NCHARcharacter set name of the tenant database. -
#snapshot_type ⇒ String
The type of DB snapshot.
-
#tag_list ⇒ Array<Types::Tag>
A list of tags.
-
#tenant_database_create_time ⇒ Time
The time the DB snapshot was taken, specified in Coordinated Universal Time (UTC).
-
#tenant_database_resource_id ⇒ String
The resource ID of the tenant database.
-
#tenant_db_name ⇒ String
The name of the tenant database.
Instance Attribute Details
#character_set_name ⇒ String
The name of the character set of a tenant database.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#db_instance_identifier ⇒ String
The ID for the DB instance that contains the tenant databases.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#db_snapshot_identifier ⇒ String
The identifier for the snapshot of the DB instance.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#db_snapshot_tenant_database_arn ⇒ String
The Amazon Resource Name (ARN) for the snapshot tenant database.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#dbi_resource_id ⇒ String
The resource identifier of the source CDB instance. This identifier can't be changed and is unique to an Amazon Web Services Region.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#engine_name ⇒ String
The name of the database engine.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#master_username ⇒ String
The master username of the tenant database.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#nchar_character_set_name ⇒ String
The NCHAR character set name of the tenant database.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#snapshot_type ⇒ String
The type of DB snapshot.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tag_list ⇒ Array<Types::Tag>
A list of tags.
For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tenant_database_create_time ⇒ Time
The time the DB snapshot was taken, specified in Coordinated Universal Time (UTC). If you copy the snapshot, the creation time changes.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tenant_database_resource_id ⇒ String
The resource ID of the tenant database.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |
#tenant_db_name ⇒ String
The name of the tenant database.
12273 12274 12275 12276 12277 12278 12279 12280 12281 12282 12283 12284 12285 12286 12287 12288 12289 |
# File 'lib/aws-sdk-rds/types.rb', line 12273 class DBSnapshotTenantDatabase < Struct.new( :db_snapshot_identifier, :db_instance_identifier, :dbi_resource_id, :engine_name, :snapshot_type, :tenant_database_create_time, :tenant_db_name, :master_username, :tenant_database_resource_id, :character_set_name, :db_snapshot_tenant_database_arn, :nchar_character_set_name, :tag_list) SENSITIVE = [] include Aws::Structure end |