Class: Aws::RDS::Types::DeleteTenantDatabaseMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DeleteTenantDatabaseMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_instance_identifier ⇒ String
The user-supplied identifier for the DB instance that contains the tenant database that you want to delete.
-
#final_db_snapshot_identifier ⇒ String
The
DBSnapshotIdentifierof the newDBSnapshotcreated when theSkipFinalSnapshotparameter is disabled. -
#skip_final_snapshot ⇒ Boolean
Specifies whether to skip the creation of a final DB snapshot before removing the tenant database from your DB instance.
-
#tenant_db_name ⇒ String
The user-supplied name of the tenant database that you want to remove from your DB instance.
Instance Attribute Details
#db_instance_identifier ⇒ String
The user-supplied identifier for the DB instance that contains the tenant database that you want to delete.
12993 12994 12995 12996 12997 12998 12999 13000 |
# File 'lib/aws-sdk-rds/types.rb', line 12993 class DeleteTenantDatabaseMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :skip_final_snapshot, :final_db_snapshot_identifier) SENSITIVE = [] include Aws::Structure end |
#final_db_snapshot_identifier ⇒ String
The DBSnapshotIdentifier of the new DBSnapshot created when the SkipFinalSnapshot parameter is disabled.
<note markdown=“1”> If you enable this parameter and also enable SkipFinalShapshot, the command results in an error.
</note>
12993 12994 12995 12996 12997 12998 12999 13000 |
# File 'lib/aws-sdk-rds/types.rb', line 12993 class DeleteTenantDatabaseMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :skip_final_snapshot, :final_db_snapshot_identifier) SENSITIVE = [] include Aws::Structure end |
#skip_final_snapshot ⇒ Boolean
Specifies whether to skip the creation of a final DB snapshot before removing the tenant database from your DB instance. If you enable this parameter, RDS doesn’t create a DB snapshot. If you don’t enable this parameter, RDS creates a DB snapshot before it deletes the tenant database. By default, RDS doesn’t skip the final snapshot. If you don’t enable this parameter, you must specify the FinalDBSnapshotIdentifier parameter.
12993 12994 12995 12996 12997 12998 12999 13000 |
# File 'lib/aws-sdk-rds/types.rb', line 12993 class DeleteTenantDatabaseMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :skip_final_snapshot, :final_db_snapshot_identifier) SENSITIVE = [] include Aws::Structure end |
#tenant_db_name ⇒ String
The user-supplied name of the tenant database that you want to remove from your DB instance. Amazon RDS deletes the tenant database with this name. This parameter isn’t case-sensitive.
12993 12994 12995 12996 12997 12998 12999 13000 |
# File 'lib/aws-sdk-rds/types.rb', line 12993 class DeleteTenantDatabaseMessage < Struct.new( :db_instance_identifier, :tenant_db_name, :skip_final_snapshot, :final_db_snapshot_identifier) SENSITIVE = [] include Aws::Structure end |