Class: Aws::RDS::Types::DescribeCertificatesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeCertificatesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#certificate_identifier ⇒ String
The user-supplied certificate identifier.
-
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeCertificatesrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#certificate_identifier ⇒ String
The user-supplied certificate identifier. If this parameter is specified, information for only the identified certificate is returned. This parameter isn't case-sensitive.
Constraints:
- Must match an existing CertificateIdentifier.
^
13236 13237 13238 13239 13240 13241 13242 13243 |
# File 'lib/aws-sdk-rds/types.rb', line 13236 class DescribeCertificatesMessage < Struct.new( :certificate_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
13236 13237 13238 13239 13240 13241 13242 13243 |
# File 'lib/aws-sdk-rds/types.rb', line 13236 class DescribeCertificatesMessage < Struct.new( :certificate_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeCertificates request. If this parameter is specified, the
response includes only records beyond the marker, up to the value
specified by MaxRecords.
13236 13237 13238 13239 13240 13241 13242 13243 |
# File 'lib/aws-sdk-rds/types.rb', line 13236 class DescribeCertificatesMessage < Struct.new( :certificate_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so you can
retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
13236 13237 13238 13239 13240 13241 13242 13243 |
# File 'lib/aws-sdk-rds/types.rb', line 13236 class DescribeCertificatesMessage < Struct.new( :certificate_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |