Class: Aws::RDS::Types::DescribeDBClusterBacktracksMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBClusterBacktracksMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#backtrack_identifier ⇒ String
If specified, this value is the backtrack identifier of the backtrack to be described.
-
#db_cluster_identifier ⇒ String
The DB cluster identifier of the DB cluster to be described.
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB clusters to describe.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBClusterBacktracksrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#backtrack_identifier ⇒ String
If specified, this value is the backtrack identifier of the backtrack to be described.
Constraints:
- Must contain a valid universally unique identifier (UUID). For more information about UUIDs, see Universally unique identifier.
^
Example: 123e4567-e89b-12d3-a456-426655440000
13465 13466 13467 13468 13469 13470 13471 13472 13473 |
# File 'lib/aws-sdk-rds/types.rb', line 13465 class DescribeDBClusterBacktracksMessage < Struct.new( :db_cluster_identifier, :backtrack_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The DB cluster identifier of the DB cluster to be described. This parameter is stored as a lowercase string.
Constraints:
-
Must contain from 1 to 63 alphanumeric characters or hyphens.
-
First character must be a letter.
-
Can't end with a hyphen or contain two consecutive hyphens.
Example: my-cluster1
13465 13466 13467 13468 13469 13470 13471 13472 13473 |
# File 'lib/aws-sdk-rds/types.rb', line 13465 class DescribeDBClusterBacktracksMessage < Struct.new( :db_cluster_identifier, :backtrack_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB clusters to describe. Supported filters include the following:
-
db-cluster-backtrack-id- Accepts backtrack identifiers. The results list includes information about only the backtracks identified by these identifiers. -
db-cluster-backtrack-status- Accepts any of the following backtrack status values: -
applying -
completed -
failed -
pendingThe results list includes information about only the backtracks identified by these values.
13465 13466 13467 13468 13469 13470 13471 13472 13473 |
# File 'lib/aws-sdk-rds/types.rb', line 13465 class DescribeDBClusterBacktracksMessage < Struct.new( :db_cluster_identifier, :backtrack_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBClusterBacktracks request. If this parameter is
specified, the response includes only records beyond the marker, up
to the value specified by MaxRecords.
13465 13466 13467 13468 13469 13470 13471 13472 13473 |
# File 'lib/aws-sdk-rds/types.rb', line 13465 class DescribeDBClusterBacktracksMessage < Struct.new( :db_cluster_identifier, :backtrack_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so you can
retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
13465 13466 13467 13468 13469 13470 13471 13472 13473 |
# File 'lib/aws-sdk-rds/types.rb', line 13465 class DescribeDBClusterBacktracksMessage < Struct.new( :db_cluster_identifier, :backtrack_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |