Class: Aws::RDS::Types::DescribeDBClusterEndpointsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBClusterEndpointsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster_endpoint_identifier ⇒ String
The identifier of the endpoint to describe.
-
#db_cluster_identifier ⇒ String
The DB cluster identifier of the DB cluster associated with the endpoint.
-
#filters ⇒ Array<Types::Filter>
A set of name-value pairs that define which endpoints to include in the output.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBClusterEndpointsrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_cluster_endpoint_identifier ⇒ String
The identifier of the endpoint to describe. This parameter is stored as a lowercase string.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-rds/types.rb', line 13379 class DescribeDBClusterEndpointsMessage < Struct.new( :db_cluster_identifier, :db_cluster_endpoint_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#db_cluster_identifier ⇒ String
The DB cluster identifier of the DB cluster associated with the endpoint. This parameter is stored as a lowercase string.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-rds/types.rb', line 13379 class DescribeDBClusterEndpointsMessage < Struct.new( :db_cluster_identifier, :db_cluster_endpoint_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A set of name-value pairs that define which endpoints to include in the output. The filters are specified as name-value pairs, in the format ‘Name=endpoint_type,Values=endpoint_type1,endpoint_type2,…`. Name can be one of: db-cluster-endpoint-type, db-cluster-endpoint-custom-type, db-cluster-endpoint-id, db-cluster-endpoint-status. Values for the ` db-cluster-endpoint-type` filter can be one or more of: reader, writer, custom. Values for the db-cluster-endpoint-custom-type filter can be one or more of: reader, any. Values for the db-cluster-endpoint-status filter can be one or more of: available, creating, deleting, inactive, modifying.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-rds/types.rb', line 13379 class DescribeDBClusterEndpointsMessage < Struct.new( :db_cluster_identifier, :db_cluster_endpoint_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeDBClusterEndpoints request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-rds/types.rb', line 13379 class DescribeDBClusterEndpointsMessage < Struct.new( :db_cluster_identifier, :db_cluster_endpoint_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so you can retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
13379 13380 13381 13382 13383 13384 13385 13386 13387 |
# File 'lib/aws-sdk-rds/types.rb', line 13379 class DescribeDBClusterEndpointsMessage < Struct.new( :db_cluster_identifier, :db_cluster_endpoint_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |