Class: Aws::RDS::Types::DescribeDBMajorEngineVersionsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBMajorEngineVersionsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine ⇒ String
The database engine to return major version details for.
-
#major_engine_version ⇒ String
A specific database major engine version to return details for.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#engine ⇒ String
The database engine to return major version details for.
Valid Values:
-
aurora-mysql -
aurora-postgresql -
custom-sqlserver-ee -
custom-sqlserver-se -
custom-sqlserver-web -
db2-ae -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
14131 14132 14133 14134 14135 14136 14137 14138 |
# File 'lib/aws-sdk-rds/types.rb', line 14131 class DescribeDBMajorEngineVersionsRequest < Struct.new( :engine, :major_engine_version, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#major_engine_version ⇒ String
A specific database major engine version to return details for.
Example: 8.4
14131 14132 14133 14134 14135 14136 14137 14138 |
# File 'lib/aws-sdk-rds/types.rb', line 14131 class DescribeDBMajorEngineVersionsRequest < Struct.new( :engine, :major_engine_version, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
14131 14132 14133 14134 14135 14136 14137 14138 |
# File 'lib/aws-sdk-rds/types.rb', line 14131 class DescribeDBMajorEngineVersionsRequest < Struct.new( :engine, :major_engine_version, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so you can retrieve the remaining results.
Default: 100
14131 14132 14133 14134 14135 14136 14137 14138 |
# File 'lib/aws-sdk-rds/types.rb', line 14131 class DescribeDBMajorEngineVersionsRequest < Struct.new( :engine, :major_engine_version, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |