Class: Aws::RDS::Types::DescribeDBParameterGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBParameterGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_parameter_group_name ⇒ String
The name of a specific DB parameter group to return details for.
-
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBParameterGroupsrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_parameter_group_name ⇒ String
The name of a specific DB parameter group to return details for.
Constraints:
- If supplied, must match the name of an existing DBClusterParameterGroup.
^
14435 14436 14437 14438 14439 14440 14441 14442 |
# File 'lib/aws-sdk-rds/types.rb', line 14435 class DescribeDBParameterGroupsMessage < Struct.new( :db_parameter_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
14435 14436 14437 14438 14439 14440 14441 14442 |
# File 'lib/aws-sdk-rds/types.rb', line 14435 class DescribeDBParameterGroupsMessage < Struct.new( :db_parameter_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBParameterGroups request. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
14435 14436 14437 14438 14439 14440 14441 14442 |
# File 'lib/aws-sdk-rds/types.rb', line 14435 class DescribeDBParameterGroupsMessage < Struct.new( :db_parameter_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that you can
retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
14435 14436 14437 14438 14439 14440 14441 14442 |
# File 'lib/aws-sdk-rds/types.rb', line 14435 class DescribeDBParameterGroupsMessage < Struct.new( :db_parameter_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |