Class: Aws::RDS::Types::DescribeDBParametersMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBParametersMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
<zonbook />
<xhtml />
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_parameter_group_name ⇒ String
The name of a specific DB parameter group to return details for.
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB parameters to describe.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBParametersrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source ⇒ String
The parameter types to return.
Instance Attribute Details
#db_parameter_group_name ⇒ String
The name of a specific DB parameter group to return details for.
Constraints:
-
If supplied, must match the name of an existing DBParameterGroup.
^
14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-rds/types.rb', line 14336 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more DB parameters to describe.
The only supported filter is parameter-name. The results list only includes information about the DB parameters with these names.
14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-rds/types.rb', line 14336 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeDBParameters request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-rds/types.rb', line 14336 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-rds/types.rb', line 14336 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The parameter types to return.
Default: All parameter types returned
Valid Values: ‘user | system | engine-default`
14336 14337 14338 14339 14340 14341 14342 14343 14344 |
# File 'lib/aws-sdk-rds/types.rb', line 14336 class DescribeDBParametersMessage < Struct.new( :db_parameter_group_name, :source, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |