Class: Aws::RDS::Types::DescribeDBProxyTargetGroupsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBProxyTargetGroupsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_proxy_name ⇒ String
The identifier of the
DBProxyassociated with the target group. -
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#target_group_name ⇒ String
The identifier of the
DBProxyTargetGroupto describe.
Instance Attribute Details
#db_proxy_name ⇒ String
The identifier of the DBProxy associated with the target group.
14499 14500 14501 14502 14503 14504 14505 14506 14507 |
# File 'lib/aws-sdk-rds/types.rb', line 14499 class DescribeDBProxyTargetGroupsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
14499 14500 14501 14502 14503 14504 14505 14506 14507 |
# File 'lib/aws-sdk-rds/types.rb', line 14499 class DescribeDBProxyTargetGroupsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
14499 14500 14501 14502 14503 14504 14505 14506 14507 |
# File 'lib/aws-sdk-rds/types.rb', line 14499 class DescribeDBProxyTargetGroupsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
14499 14500 14501 14502 14503 14504 14505 14506 14507 |
# File 'lib/aws-sdk-rds/types.rb', line 14499 class DescribeDBProxyTargetGroupsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#target_group_name ⇒ String
The identifier of the DBProxyTargetGroup to describe.
14499 14500 14501 14502 14503 14504 14505 14506 14507 |
# File 'lib/aws-sdk-rds/types.rb', line 14499 class DescribeDBProxyTargetGroupsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |