Class: Aws::RDS::Types::DescribeDBProxyTargetsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBProxyTargetsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_proxy_name ⇒ String
The identifier of the
DBProxyTargetto describe. -
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#target_group_name ⇒ String
The identifier of the
DBProxyTargetGroupto describe.
Instance Attribute Details
#db_proxy_name ⇒ String
The identifier of the DBProxyTarget to describe.
14583 14584 14585 14586 14587 14588 14589 14590 14591 |
# File 'lib/aws-sdk-rds/types.rb', line 14583 class DescribeDBProxyTargetsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter is not currently supported.
14583 14584 14585 14586 14587 14588 14589 14590 14591 |
# File 'lib/aws-sdk-rds/types.rb', line 14583 class DescribeDBProxyTargetsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
14583 14584 14585 14586 14587 14588 14589 14590 14591 |
# File 'lib/aws-sdk-rds/types.rb', line 14583 class DescribeDBProxyTargetsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that the remaining results can be retrieved.
Default: 100
Constraints: Minimum 20, maximum 100.
14583 14584 14585 14586 14587 14588 14589 14590 14591 |
# File 'lib/aws-sdk-rds/types.rb', line 14583 class DescribeDBProxyTargetsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |
#target_group_name ⇒ String
The identifier of the DBProxyTargetGroup to describe.
14583 14584 14585 14586 14587 14588 14589 14590 14591 |
# File 'lib/aws-sdk-rds/types.rb', line 14583 class DescribeDBProxyTargetsRequest < Struct.new( :db_proxy_name, :target_group_name, :filters, :marker, :max_records) SENSITIVE = [] include Aws::Structure end |