Class: Aws::RDS::Types::DescribeDBSecurityGroupsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeDBSecurityGroupsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_security_group_name ⇒ String
The name of the DB security group to return details for.
-
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBSecurityGroupsrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#db_security_group_name ⇒ String
The name of the DB security group to return details for.
14844 14845 14846 14847 14848 14849 14850 14851 |
# File 'lib/aws-sdk-rds/types.rb', line 14844 class DescribeDBSecurityGroupsMessage < Struct.new( :db_security_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
14844 14845 14846 14847 14848 14849 14850 14851 |
# File 'lib/aws-sdk-rds/types.rb', line 14844 class DescribeDBSecurityGroupsMessage < Struct.new( :db_security_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeDBSecurityGroups request. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
14844 14845 14846 14847 14848 14849 14850 14851 |
# File 'lib/aws-sdk-rds/types.rb', line 14844 class DescribeDBSecurityGroupsMessage < Struct.new( :db_security_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that you can
retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
14844 14845 14846 14847 14848 14849 14850 14851 |
# File 'lib/aws-sdk-rds/types.rb', line 14844 class DescribeDBSecurityGroupsMessage < Struct.new( :db_security_group_name, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |