Class: Aws::RDS::Types::DescribeExportTasksMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeExportTasksMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#export_task_identifier ⇒ String
The identifier of the snapshot or cluster export task to be described.
-
#filters ⇒ Array<Types::Filter>
Filters specify one or more snapshot or cluster exports to describe.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeExportTasksrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
-
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot or cluster exported to Amazon S3.
-
#source_type ⇒ String
The type of source for the export.
Instance Attribute Details
#export_task_identifier ⇒ String
The identifier of the snapshot or cluster export task to be described.
15635 15636 15637 15638 15639 15640 15641 15642 15643 15644 |
# File 'lib/aws-sdk-rds/types.rb', line 15635 class DescribeExportTasksMessage < Struct.new( :export_task_identifier, :source_arn, :filters, :marker, :max_records, :source_type) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
Filters specify one or more snapshot or cluster exports to describe. The filters are specified as name-value pairs that define what to include in the output. Filter names and values are case-sensitive.
Supported filters include the following:
-
export-task-identifier- An identifier for the snapshot or cluster export task. -
s3-bucket- The Amazon S3 bucket the data is exported to. -
source-arn- The Amazon Resource Name (ARN) of the snapshot or cluster exported to Amazon S3. -
status- The status of the export task. Must be lowercase. Valid statuses are the following: -
canceled -
canceling -
complete -
failed -
in_progress -
starting
15635 15636 15637 15638 15639 15640 15641 15642 15643 15644 |
# File 'lib/aws-sdk-rds/types.rb', line 15635 class DescribeExportTasksMessage < Struct.new( :export_task_identifier, :source_arn, :filters, :marker, :max_records, :source_type) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous
DescribeExportTasks request. If you specify this parameter, the
response includes only records beyond the marker, up to the value
specified by the MaxRecords parameter.
15635 15636 15637 15638 15639 15640 15641 15642 15643 15644 |
# File 'lib/aws-sdk-rds/types.rb', line 15635 class DescribeExportTasksMessage < Struct.new( :export_task_identifier, :source_arn, :filters, :marker, :max_records, :source_type) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified value, a pagination token called a
marker is included in the response. You can use the marker in a
later DescribeExportTasks request to retrieve the remaining
results.
Default: 100
Constraints: Minimum 20, maximum 100.
15635 15636 15637 15638 15639 15640 15641 15642 15643 15644 |
# File 'lib/aws-sdk-rds/types.rb', line 15635 class DescribeExportTasksMessage < Struct.new( :export_task_identifier, :source_arn, :filters, :marker, :max_records, :source_type) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot or cluster exported to Amazon S3.
15635 15636 15637 15638 15639 15640 15641 15642 15643 15644 |
# File 'lib/aws-sdk-rds/types.rb', line 15635 class DescribeExportTasksMessage < Struct.new( :export_task_identifier, :source_arn, :filters, :marker, :max_records, :source_type) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of source for the export.
15635 15636 15637 15638 15639 15640 15641 15642 15643 15644 |
# File 'lib/aws-sdk-rds/types.rb', line 15635 class DescribeExportTasksMessage < Struct.new( :export_task_identifier, :source_arn, :filters, :marker, :max_records, :source_type) SENSITIVE = [] include Aws::Structure end |