Class: Aws::RDS::Types::DescribeIntegrationsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeIntegrationsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more resources to return.
-
#integration_identifier ⇒ String
The unique identifier of the integration.
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeIntegrationsrequest. -
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#filters ⇒ Array<Types::Filter>
A filter that specifies one or more resources to return.
15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-rds/types.rb', line 15682 class DescribeIntegrationsMessage < Struct.new( :integration_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#integration_identifier ⇒ String
The unique identifier of the integration.
15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-rds/types.rb', line 15682 class DescribeIntegrationsMessage < Struct.new( :integration_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous DescribeIntegrations request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.
15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-rds/types.rb', line 15682 class DescribeIntegrationsMessage < Struct.new( :integration_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
15682 15683 15684 15685 15686 15687 15688 15689 |
# File 'lib/aws-sdk-rds/types.rb', line 15682 class DescribeIntegrationsMessage < Struct.new( :integration_identifier, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |