Class: Aws::RDS::Types::DescribeOptionGroupOptionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::DescribeOptionGroupOptionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine_name ⇒ String
The name of the engine to describe options for.
-
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
-
#major_engine_version ⇒ String
If specified, filters the results to include only options for the specified major engine version.
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#max_records ⇒ Integer
The maximum number of records to include in the response.
Instance Attribute Details
#engine_name ⇒ String
The name of the engine to describe options for.
Valid Values:
-
db2-ae -
db2-ce -
db2-se -
mariadb -
mysql -
oracle-ee -
oracle-ee-cdb -
oracle-se2 -
oracle-se2-cdb -
postgres -
sqlserver-ee -
sqlserver-se -
sqlserver-ex -
sqlserver-web
15907 15908 15909 15910 15911 15912 15913 15914 15915 |
# File 'lib/aws-sdk-rds/types.rb', line 15907 class DescribeOptionGroupOptionsMessage < Struct.new( :engine_name, :major_engine_version, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#filters ⇒ Array<Types::Filter>
This parameter isn't currently supported.
15907 15908 15909 15910 15911 15912 15913 15914 15915 |
# File 'lib/aws-sdk-rds/types.rb', line 15907 class DescribeOptionGroupOptionsMessage < Struct.new( :engine_name, :major_engine_version, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#major_engine_version ⇒ String
If specified, filters the results to include only options for the specified major engine version.
15907 15908 15909 15910 15911 15912 15913 15914 15915 |
# File 'lib/aws-sdk-rds/types.rb', line 15907 class DescribeOptionGroupOptionsMessage < Struct.new( :engine_name, :major_engine_version, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
An optional pagination token provided by a previous request. If this
parameter is specified, the response includes only records beyond
the marker, up to the value specified by MaxRecords.
15907 15908 15909 15910 15911 15912 15913 15914 15915 |
# File 'lib/aws-sdk-rds/types.rb', line 15907 class DescribeOptionGroupOptionsMessage < Struct.new( :engine_name, :major_engine_version, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |
#max_records ⇒ Integer
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination
token called a marker is included in the response so that you can
retrieve the remaining results.
Default: 100
Constraints: Minimum 20, maximum 100.
15907 15908 15909 15910 15911 15912 15913 15914 15915 |
# File 'lib/aws-sdk-rds/types.rb', line 15907 class DescribeOptionGroupOptionsMessage < Struct.new( :engine_name, :major_engine_version, :filters, :max_records, :marker) SENSITIVE = [] include Aws::Structure end |