Class: Aws::RDS::Types::DescribeOptionGroupOptionsMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#engine_nameString

The name of the engine to describe options for.

Valid Values:

  • db2-ae

  • db2-se

  • mariadb

  • mysql

  • oracle-ee

  • oracle-ee-cdb

  • oracle-se2

  • oracle-se2-cdb

  • postgres

  • sqlserver-ee

  • sqlserver-se

  • sqlserver-ex

  • sqlserver-web



15746
15747
15748
15749
15750
15751
15752
15753
15754
# File 'lib/aws-sdk-rds/types.rb', line 15746

class DescribeOptionGroupOptionsMessage < Struct.new(
  :engine_name,
  :major_engine_version,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#filtersArray<Types::Filter>

This parameter isn’t currently supported.



15746
15747
15748
15749
15750
15751
15752
15753
15754
# File 'lib/aws-sdk-rds/types.rb', line 15746

class DescribeOptionGroupOptionsMessage < Struct.new(
  :engine_name,
  :major_engine_version,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#major_engine_versionString

If specified, filters the results to include only options for the specified major engine version.



15746
15747
15748
15749
15750
15751
15752
15753
15754
# File 'lib/aws-sdk-rds/types.rb', line 15746

class DescribeOptionGroupOptionsMessage < Struct.new(
  :engine_name,
  :major_engine_version,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.



15746
15747
15748
15749
15750
15751
15752
15753
15754
# File 'lib/aws-sdk-rds/types.rb', line 15746

class DescribeOptionGroupOptionsMessage < Struct.new(
  :engine_name,
  :major_engine_version,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end

#max_recordsInteger

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination token called a marker is included in the response so that you can retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 100.



15746
15747
15748
15749
15750
15751
15752
15753
15754
# File 'lib/aws-sdk-rds/types.rb', line 15746

class DescribeOptionGroupOptionsMessage < Struct.new(
  :engine_name,
  :major_engine_version,
  :filters,
  :max_records,
  :marker)
  SENSITIVE = []
  include Aws::Structure
end