Class: Aws::RDS::Types::ExportTask
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ExportTask
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the details of a snapshot or cluster export to Amazon S3.
This data type is used as a response element in the
DescribeExportTasks operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#export_only ⇒ Array<String>
The data exported from the snapshot or cluster.
-
#export_task_identifier ⇒ String
A unique identifier for the snapshot or cluster export task.
-
#failure_cause ⇒ String
The reason the export failed, if it failed.
-
#iam_role_arn ⇒ String
The name of the IAM role that is used to write to Amazon S3 when exporting a snapshot or cluster.
-
#kms_key_id ⇒ String
The key identifier of the Amazon Web Services KMS key that is used to encrypt the data when it's exported to Amazon S3.
-
#percent_progress ⇒ Integer
The progress of the snapshot or cluster export task as a percentage.
-
#s3_bucket ⇒ String
The Amazon S3 bucket where the snapshot or cluster is exported to.
-
#s3_prefix ⇒ String
The Amazon S3 bucket prefix that is the file name and path of the exported data.
-
#snapshot_time ⇒ Time
The time when the snapshot was created.
-
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot or cluster exported to Amazon S3.
-
#source_type ⇒ String
The type of source for the export.
-
#status ⇒ String
The progress status of the export task.
-
#task_end_time ⇒ Time
The time when the snapshot or cluster export task ended.
-
#task_start_time ⇒ Time
The time when the snapshot or cluster export task started.
-
#total_extracted_data_in_gb ⇒ Integer
The total amount of data exported, in gigabytes.
-
#warning_message ⇒ String
A warning about the snapshot or cluster export task.
Instance Attribute Details
#export_only ⇒ Array<String>
The data exported from the snapshot or cluster.
Valid Values:
-
database- Export all the data from a specified database. -
database.tabletable-name - Export a table of the snapshot or cluster. This format is valid only for RDS for MySQL, RDS for MariaDB, and Aurora MySQL. -
database.schemaschema-name - Export a database schema of the snapshot or cluster. This format is valid only for RDS for PostgreSQL and Aurora PostgreSQL. -
database.schema.tabletable-name - Export a table of the database schema. This format is valid only for RDS for PostgreSQL and Aurora PostgreSQL.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#export_task_identifier ⇒ String
A unique identifier for the snapshot or cluster export task. This ID isn't an identifier for the Amazon S3 bucket where the data is exported.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#failure_cause ⇒ String
The reason the export failed, if it failed.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#iam_role_arn ⇒ String
The name of the IAM role that is used to write to Amazon S3 when exporting a snapshot or cluster.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The key identifier of the Amazon Web Services KMS key that is used to encrypt the data when it's exported to Amazon S3. The KMS key identifier is its key ARN, key ID, alias ARN, or alias name. The IAM role used for the export must have encryption and decryption permissions to use this KMS key.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#percent_progress ⇒ Integer
The progress of the snapshot or cluster export task as a percentage.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#s3_bucket ⇒ String
The Amazon S3 bucket where the snapshot or cluster is exported to.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#s3_prefix ⇒ String
The Amazon S3 bucket prefix that is the file name and path of the exported data.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#snapshot_time ⇒ Time
The time when the snapshot was created.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the snapshot or cluster exported to Amazon S3.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#source_type ⇒ String
The type of source for the export.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The progress status of the export task. The status can be one of the following:
-
CANCELED -
CANCELING -
COMPLETE -
FAILED -
IN_PROGRESS -
STARTING
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#task_end_time ⇒ Time
The time when the snapshot or cluster export task ended.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#task_start_time ⇒ Time
The time when the snapshot or cluster export task started.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#total_extracted_data_in_gb ⇒ Integer
The total amount of data exported, in gigabytes.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |
#warning_message ⇒ String
A warning about the snapshot or cluster export task.
17135 17136 17137 17138 17139 17140 17141 17142 17143 17144 17145 17146 17147 17148 17149 17150 17151 17152 17153 17154 |
# File 'lib/aws-sdk-rds/types.rb', line 17135 class ExportTask < Struct.new( :export_task_identifier, :source_arn, :export_only, :snapshot_time, :task_start_time, :task_end_time, :s3_bucket, :s3_prefix, :iam_role_arn, :kms_key_id, :status, :percent_progress, :total_extracted_data_in_gb, :failure_cause, :warning_message, :source_type) SENSITIVE = [] include Aws::Structure end |