Class: Aws::RDS::Types::ExportTasksMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#export_tasksArray<Types::ExportTask>

Information about an export of a snapshot or cluster to Amazon S3.

Returns:



17227
17228
17229
17230
17231
17232
# File 'lib/aws-sdk-rds/types.rb', line 17227

class ExportTasksMessage < Struct.new(
  :marker,
  :export_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

A pagination token that can be used in a later DescribeExportTasks request. A marker is used for pagination to identify the location to begin output for the next response of DescribeExportTasks.

Returns:

  • (String)


17227
17228
17229
17230
17231
17232
# File 'lib/aws-sdk-rds/types.rb', line 17227

class ExportTasksMessage < Struct.new(
  :marker,
  :export_tasks)
  SENSITIVE = []
  include Aws::Structure
end