Class: Aws::RDS::Types::ExportTasksMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#export_tasksArray<Types::ExportTask>

Information about an export of a snapshot or cluster to Amazon S3.

Returns:



17180
17181
17182
17183
17184
17185
# File 'lib/aws-sdk-rds/types.rb', line 17180

class ExportTasksMessage < Struct.new(
  :marker,
  :export_tasks)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

A pagination token that can be used in a later DescribeExportTasks request. A marker is used for pagination to identify the location to begin output for the next response of DescribeExportTasks.

Returns:

  • (String)


17180
17181
17182
17183
17184
17185
# File 'lib/aws-sdk-rds/types.rb', line 17180

class ExportTasksMessage < Struct.new(
  :marker,
  :export_tasks)
  SENSITIVE = []
  include Aws::Structure
end