Class: Aws::RDS::Types::Integration
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::Integration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
A zero-ETL integration with Amazon Redshift.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#additional_encryption_context ⇒ Hash<String,String>
The encryption context for the integration.
-
#create_time ⇒ Time
The time when the integration was created, in Universal Coordinated Time (UTC).
-
#data_filter ⇒ String
Data filters for the integration.
-
#description ⇒ String
A description of the integration.
-
#errors ⇒ Array<Types::IntegrationError>
Any errors associated with the integration.
-
#integration_arn ⇒ String
The ARN of the integration.
-
#integration_name ⇒ String
The name of the integration.
-
#kms_key_id ⇒ String
The Amazon Web Services Key Management System (Amazon Web Services KMS) key identifier for the key used to to encrypt the integration.
-
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the database used as the source for replication.
-
#status ⇒ String
The current status of the integration.
-
#tags ⇒ Array<Types::Tag>
A list of tags.
-
#target_arn ⇒ String
The ARN of the Redshift data warehouse used as the target for replication.
Instance Attribute Details
#additional_encryption_context ⇒ Hash<String,String>
The encryption context for the integration. For more information, see [Encryption context] in the *Amazon Web Services Key Management Service Developer Guide*.
[1]: docs.aws.amazon.com/kms/latest/developerguide/concepts.html#encrypt_context
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#create_time ⇒ Time
The time when the integration was created, in Universal Coordinated Time (UTC).
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#data_filter ⇒ String
Data filters for the integration. These filters determine which tables from the source database are sent to the target Amazon Redshift data warehouse.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the integration.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::IntegrationError>
Any errors associated with the integration.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#integration_arn ⇒ String
The ARN of the integration.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#integration_name ⇒ String
The name of the integration.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services Key Management System (Amazon Web Services KMS) key identifier for the key used to to encrypt the integration.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#source_arn ⇒ String
The Amazon Resource Name (ARN) of the database used as the source for replication.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The current status of the integration.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Array<Types::Tag>
A list of tags.
For more information, see [Tagging Amazon RDS resources] in the *Amazon RDS User Guide* or [Tagging Amazon Aurora and Amazon RDS resources] in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/USER_Tagging.html
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |
#target_arn ⇒ String
The ARN of the Redshift data warehouse used as the target for replication.
17687 17688 17689 17690 17691 17692 17693 17694 17695 17696 17697 17698 17699 17700 17701 17702 |
# File 'lib/aws-sdk-rds/types.rb', line 17687 class Integration < Struct.new( :source_arn, :target_arn, :integration_name, :integration_arn, :kms_key_id, :additional_encryption_context, :status, :tags, :data_filter, :description, :create_time, :errors) SENSITIVE = [] include Aws::Structure end |