Class: Aws::RDS::Types::ModifyAdditionalStorageVolume

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Contains details about the modification of an additional storage volume.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allocated_storageInteger

The amount of storage allocated for the additional storage volume, in gibibytes (GiB). The minimum is 20 GiB. The maximum is 65,536 GiB (64 TiB).

Returns:

  • (Integer)


18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
# File 'lib/aws-sdk-rds/types.rb', line 18407

class ModifyAdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type,
  :set_for_delete)
  SENSITIVE = []
  include Aws::Structure
end

#iopsInteger

The number of I/O operations per second (IOPS) provisioned for the additional storage volume. This setting is only supported for Provisioned IOPS SSD (io1 and io2) storage types.

Returns:

  • (Integer)


18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
# File 'lib/aws-sdk-rds/types.rb', line 18407

class ModifyAdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type,
  :set_for_delete)
  SENSITIVE = []
  include Aws::Structure
end

#max_allocated_storageInteger

The upper limit in gibibytes (GiB) to which RDS can automatically scale the storage of the additional storage volume. You must provide a value greater than or equal to AllocatedStorage.

Returns:

  • (Integer)


18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
# File 'lib/aws-sdk-rds/types.rb', line 18407

class ModifyAdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type,
  :set_for_delete)
  SENSITIVE = []
  include Aws::Structure
end

#set_for_deleteBoolean

Indicates whether to delete the additional storage volume. The value true schedules the volume for deletion. You can delete an additional storage volume only when it doesn't contain database files or other data.

Returns:

  • (Boolean)


18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
# File 'lib/aws-sdk-rds/types.rb', line 18407

class ModifyAdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type,
  :set_for_delete)
  SENSITIVE = []
  include Aws::Structure
end

#storage_throughputInteger

The storage throughput value for the additional storage volume, in mebibytes per second (MiBps). This setting applies only to the General Purpose SSD (gp3) storage type.

Returns:

  • (Integer)


18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
# File 'lib/aws-sdk-rds/types.rb', line 18407

class ModifyAdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type,
  :set_for_delete)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The new storage type for the additional storage volume.

Valid Values: GP3 | IO2

Returns:

  • (String)


18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
# File 'lib/aws-sdk-rds/types.rb', line 18407

class ModifyAdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type,
  :set_for_delete)
  SENSITIVE = []
  include Aws::Structure
end

#volume_nameString

The name of the additional storage volume that you want to modify.

Valid Values: RDSDBDATA2 | RDSDBDATA3 | RDSDBDATA4

Returns:

  • (String)


18407
18408
18409
18410
18411
18412
18413
18414
18415
18416
18417
# File 'lib/aws-sdk-rds/types.rb', line 18407

class ModifyAdditionalStorageVolume < Struct.new(
  :volume_name,
  :allocated_storage,
  :iops,
  :max_allocated_storage,
  :storage_throughput,
  :storage_type,
  :set_for_delete)
  SENSITIVE = []
  include Aws::Structure
end