Class: Aws::RDS::Types::ModifyDBClusterEndpointMessage

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#db_cluster_endpoint_identifierString

The identifier of the endpoint to modify. This parameter is stored as a lowercase string.

Returns:

  • (String)


18629
18630
18631
18632
18633
18634
18635
18636
# File 'lib/aws-sdk-rds/types.rb', line 18629

class ModifyDBClusterEndpointMessage < Struct.new(
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members)
  SENSITIVE = []
  include Aws::Structure
end

#endpoint_typeString

The type of the endpoint. One of: READER, WRITER, ANY.

Returns:

  • (String)


18629
18630
18631
18632
18633
18634
18635
18636
# File 'lib/aws-sdk-rds/types.rb', line 18629

class ModifyDBClusterEndpointMessage < Struct.new(
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members)
  SENSITIVE = []
  include Aws::Structure
end

#excluded_membersArray<String>

List of DB instance identifiers that aren't part of the custom endpoint group. All other eligible instances are reachable through the custom endpoint. Only relevant if the list of static members is empty.

Returns:

  • (Array<String>)


18629
18630
18631
18632
18633
18634
18635
18636
# File 'lib/aws-sdk-rds/types.rb', line 18629

class ModifyDBClusterEndpointMessage < Struct.new(
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members)
  SENSITIVE = []
  include Aws::Structure
end

#static_membersArray<String>

List of DB instance identifiers that are part of the custom endpoint group.

Returns:

  • (Array<String>)


18629
18630
18631
18632
18633
18634
18635
18636
# File 'lib/aws-sdk-rds/types.rb', line 18629

class ModifyDBClusterEndpointMessage < Struct.new(
  :db_cluster_endpoint_identifier,
  :endpoint_type,
  :static_members,
  :excluded_members)
  SENSITIVE = []
  include Aws::Structure
end