Class: Aws::RDS::Types::ModifyDBClusterEndpointMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ModifyDBClusterEndpointMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_cluster_endpoint_identifier ⇒ String
The identifier of the endpoint to modify.
-
#endpoint_type ⇒ String
The type of the endpoint.
-
#excluded_members ⇒ Array<String>
List of DB instance identifiers that aren't part of the custom endpoint group.
-
#static_members ⇒ Array<String>
List of DB instance identifiers that are part of the custom endpoint group.
Instance Attribute Details
#db_cluster_endpoint_identifier ⇒ String
The identifier of the endpoint to modify. This parameter is stored as a lowercase string.
18620 18621 18622 18623 18624 18625 18626 18627 |
# File 'lib/aws-sdk-rds/types.rb', line 18620 class ModifyDBClusterEndpointMessage < Struct.new( :db_cluster_endpoint_identifier, :endpoint_type, :static_members, :excluded_members) SENSITIVE = [] include Aws::Structure end |
#endpoint_type ⇒ String
The type of the endpoint. One of: READER, WRITER, ANY.
18620 18621 18622 18623 18624 18625 18626 18627 |
# File 'lib/aws-sdk-rds/types.rb', line 18620 class ModifyDBClusterEndpointMessage < Struct.new( :db_cluster_endpoint_identifier, :endpoint_type, :static_members, :excluded_members) SENSITIVE = [] include Aws::Structure end |
#excluded_members ⇒ Array<String>
List of DB instance identifiers that aren't part of the custom endpoint group. All other eligible instances are reachable through the custom endpoint. Only relevant if the list of static members is empty.
18620 18621 18622 18623 18624 18625 18626 18627 |
# File 'lib/aws-sdk-rds/types.rb', line 18620 class ModifyDBClusterEndpointMessage < Struct.new( :db_cluster_endpoint_identifier, :endpoint_type, :static_members, :excluded_members) SENSITIVE = [] include Aws::Structure end |
#static_members ⇒ Array<String>
List of DB instance identifiers that are part of the custom endpoint group.
18620 18621 18622 18623 18624 18625 18626 18627 |
# File 'lib/aws-sdk-rds/types.rb', line 18620 class ModifyDBClusterEndpointMessage < Struct.new( :db_cluster_endpoint_identifier, :endpoint_type, :static_members, :excluded_members) SENSITIVE = [] include Aws::Structure end |