Class: Aws::RDS::Types::ModifyDBProxyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authArray<Types::UserAuthConfig>

The new authentication settings for the ‘DBProxy`.

Returns:



21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#db_proxy_nameString

The identifier for the ‘DBProxy` to modify.

Returns:

  • (String)


21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#debug_loggingBoolean

Specifies whether the proxy logs detailed connection and query information. When you enable ‘DebugLogging`, the proxy captures connection details and connection pool behavior from your queries. Debug logging increases CloudWatch costs and can impact proxy performance. Enable this option only when you need to troubleshoot connection or performance issues.

Returns:

  • (Boolean)


21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#default_auth_schemeString

The default authentication scheme that the proxy uses for client connections to the proxy and connections from the proxy to the underlying database. Valid values are ‘NONE` and `IAM_AUTH`. When set to `IAM_AUTH`, the proxy uses end-to-end IAM authentication to connect to the database.

Returns:

  • (String)


21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#idle_client_timeoutInteger

The number of seconds that a connection to the proxy can be inactive before the proxy disconnects it. You can set this value higher or lower than the connection timeout limit for the associated database.

Returns:

  • (Integer)


21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#new_db_proxy_nameString

The new identifier for the ‘DBProxy`. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can’t end with a hyphen or contain two consecutive hyphens.

Returns:

  • (String)


21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#require_tlsBoolean

Whether Transport Layer Security (TLS) encryption is required for connections to the proxy. By enabling this setting, you can enforce encrypted TLS connections to the proxy, even if the associated database doesn’t use TLS.

Returns:

  • (Boolean)


21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

The Amazon Resource Name (ARN) of the IAM role that the proxy uses to access secrets in Amazon Web Services Secrets Manager.

Returns:

  • (String)


21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end

#security_groupsArray<String>

The new list of security groups for the ‘DBProxy`.

Returns:

  • (Array<String>)


21045
21046
21047
21048
21049
21050
21051
21052
21053
21054
21055
21056
21057
# File 'lib/aws-sdk-rds/types.rb', line 21045

class ModifyDBProxyRequest < Struct.new(
  :db_proxy_name,
  :new_db_proxy_name,
  :default_auth_scheme,
  :auth,
  :require_tls,
  :idle_client_timeout,
  :debug_logging,
  :role_arn,
  :security_groups)
  SENSITIVE = []
  include Aws::Structure
end