Class: Aws::RDS::Types::ModifyOptionGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ModifyOptionGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
Specifies whether to apply the change immediately or during the next maintenance window for each instance associated with the option group.
-
#option_group_name ⇒ String
The name of the option group to be modified.
-
#options_to_include ⇒ Array<Types::OptionConfiguration>
Options in this list are added to the option group or, if already present, the specified configuration is used to update the existing configuration.
-
#options_to_remove ⇒ Array<String>
Options in this list are removed from the option group.
Instance Attribute Details
#apply_immediately ⇒ Boolean
Specifies whether to apply the change immediately or during the next maintenance window for each instance associated with the option group.
21757 21758 21759 21760 21761 21762 21763 21764 |
# File 'lib/aws-sdk-rds/types.rb', line 21757 class ModifyOptionGroupMessage < Struct.new( :option_group_name, :options_to_include, :options_to_remove, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#option_group_name ⇒ String
The name of the option group to be modified.
Permanent options, such as the TDE option for Oracle Advanced Security TDE, can't be removed from an option group, and that option group can't be removed from a DB instance once it is associated with a DB instance
21757 21758 21759 21760 21761 21762 21763 21764 |
# File 'lib/aws-sdk-rds/types.rb', line 21757 class ModifyOptionGroupMessage < Struct.new( :option_group_name, :options_to_include, :options_to_remove, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#options_to_include ⇒ Array<Types::OptionConfiguration>
Options in this list are added to the option group or, if already present, the specified configuration is used to update the existing configuration.
21757 21758 21759 21760 21761 21762 21763 21764 |
# File 'lib/aws-sdk-rds/types.rb', line 21757 class ModifyOptionGroupMessage < Struct.new( :option_group_name, :options_to_include, :options_to_remove, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#options_to_remove ⇒ Array<String>
Options in this list are removed from the option group.
21757 21758 21759 21760 21761 21762 21763 21764 |
# File 'lib/aws-sdk-rds/types.rb', line 21757 class ModifyOptionGroupMessage < Struct.new( :option_group_name, :options_to_include, :options_to_remove, :apply_immediately) SENSITIVE = [] include Aws::Structure end |