Class: Aws::RDS::Types::OptionGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::OptionGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allows_vpc_and_non_vpc_instance_memberships ⇒ Boolean
Indicates whether this option group can be applied to both VPC and non-VPC instances.
-
#copy_timestamp ⇒ Time
Indicates when the option group was copied.
-
#engine_name ⇒ String
Indicates the name of the engine that this option group can be applied to.
-
#major_engine_version ⇒ String
Indicates the major engine version associated with this option group.
-
#option_group_arn ⇒ String
Specifies the Amazon Resource Name (ARN) for the option group.
-
#option_group_description ⇒ String
Provides a description of the option group.
-
#option_group_name ⇒ String
Specifies the name of the option group.
-
#options ⇒ Array<Types::Option>
Indicates what options are available in the option group.
-
#source_account_id ⇒ String
Specifies the Amazon Web Services account ID for the option group from which this option group is copied.
-
#source_option_group ⇒ String
Specifies the name of the option group from which this option group is copied.
-
#vpc_id ⇒ String
If AllowsVpcAndNonVpcInstanceMemberships is ‘false`, this field is blank.
Instance Attribute Details
#allows_vpc_and_non_vpc_instance_memberships ⇒ Boolean
Indicates whether this option group can be applied to both VPC and non-VPC instances. The value ‘true` indicates the option group can be applied to both VPC and non-VPC instances.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#copy_timestamp ⇒ Time
Indicates when the option group was copied.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#engine_name ⇒ String
Indicates the name of the engine that this option group can be applied to.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#major_engine_version ⇒ String
Indicates the major engine version associated with this option group.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#option_group_arn ⇒ String
Specifies the Amazon Resource Name (ARN) for the option group.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#option_group_description ⇒ String
Provides a description of the option group.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#option_group_name ⇒ String
Specifies the name of the option group.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#options ⇒ Array<Types::Option>
Indicates what options are available in the option group.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#source_account_id ⇒ String
Specifies the Amazon Web Services account ID for the option group from which this option group is copied.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#source_option_group ⇒ String
Specifies the name of the option group from which this option group is copied.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |
#vpc_id ⇒ String
If AllowsVpcAndNonVpcInstanceMemberships is ‘false`, this field is blank. If AllowsVpcAndNonVpcInstanceMemberships is `true` and this field is blank, then this option group can be applied to both VPC and non-VPC instances. If this field contains a value, then this option group can only be applied to instances that are in the VPC indicated by this field.
21915 21916 21917 21918 21919 21920 21921 21922 21923 21924 21925 21926 21927 21928 21929 |
# File 'lib/aws-sdk-rds/types.rb', line 21915 class OptionGroup < Struct.new( :option_group_name, :option_group_description, :engine_name, :major_engine_version, :options, :allows_vpc_and_non_vpc_instance_memberships, :vpc_id, :option_group_arn, :source_option_group, :source_account_id, :copy_timestamp) SENSITIVE = [] include Aws::Structure end |