Class: Aws::RDS::Types::OptionGroupOptionSetting

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Option group option settings are used to display settings available for each option with their default values and other information. These values are used with the DescribeOptionGroupOptions action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_valuesString

Indicates the acceptable values for the option group option.

Returns:

  • (String)


22308
22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
# File 'lib/aws-sdk-rds/types.rb', line 22308

class OptionGroupOptionSetting < Struct.new(
  :setting_name,
  :setting_description,
  :default_value,
  :apply_type,
  :allowed_values,
  :is_modifiable,
  :is_required,
  :minimum_engine_version_per_allowed_value)
  SENSITIVE = []
  include Aws::Structure
end

#apply_typeString

The DB engine specific parameter type for the option group option.

Returns:

  • (String)


22308
22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
# File 'lib/aws-sdk-rds/types.rb', line 22308

class OptionGroupOptionSetting < Struct.new(
  :setting_name,
  :setting_description,
  :default_value,
  :apply_type,
  :allowed_values,
  :is_modifiable,
  :is_required,
  :minimum_engine_version_per_allowed_value)
  SENSITIVE = []
  include Aws::Structure
end

#default_valueString

The default value for the option group option.

Returns:

  • (String)


22308
22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
# File 'lib/aws-sdk-rds/types.rb', line 22308

class OptionGroupOptionSetting < Struct.new(
  :setting_name,
  :setting_description,
  :default_value,
  :apply_type,
  :allowed_values,
  :is_modifiable,
  :is_required,
  :minimum_engine_version_per_allowed_value)
  SENSITIVE = []
  include Aws::Structure
end

#is_modifiableBoolean

Indicates whether this option group option can be changed from the default value.

Returns:

  • (Boolean)


22308
22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
# File 'lib/aws-sdk-rds/types.rb', line 22308

class OptionGroupOptionSetting < Struct.new(
  :setting_name,
  :setting_description,
  :default_value,
  :apply_type,
  :allowed_values,
  :is_modifiable,
  :is_required,
  :minimum_engine_version_per_allowed_value)
  SENSITIVE = []
  include Aws::Structure
end

#is_requiredBoolean

Indicates whether a value must be specified for this option setting of the option group option.

Returns:

  • (Boolean)


22308
22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
# File 'lib/aws-sdk-rds/types.rb', line 22308

class OptionGroupOptionSetting < Struct.new(
  :setting_name,
  :setting_description,
  :default_value,
  :apply_type,
  :allowed_values,
  :is_modifiable,
  :is_required,
  :minimum_engine_version_per_allowed_value)
  SENSITIVE = []
  include Aws::Structure
end

#minimum_engine_version_per_allowed_valueArray<Types::MinimumEngineVersionPerAllowedValue>

The minimum DB engine version required for the corresponding allowed value for this option setting.



22308
22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
# File 'lib/aws-sdk-rds/types.rb', line 22308

class OptionGroupOptionSetting < Struct.new(
  :setting_name,
  :setting_description,
  :default_value,
  :apply_type,
  :allowed_values,
  :is_modifiable,
  :is_required,
  :minimum_engine_version_per_allowed_value)
  SENSITIVE = []
  include Aws::Structure
end

#setting_descriptionString

The description of the option group option.

Returns:

  • (String)


22308
22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
# File 'lib/aws-sdk-rds/types.rb', line 22308

class OptionGroupOptionSetting < Struct.new(
  :setting_name,
  :setting_description,
  :default_value,
  :apply_type,
  :allowed_values,
  :is_modifiable,
  :is_required,
  :minimum_engine_version_per_allowed_value)
  SENSITIVE = []
  include Aws::Structure
end

#setting_nameString

The name of the option group option.

Returns:

  • (String)


22308
22309
22310
22311
22312
22313
22314
22315
22316
22317
22318
22319
# File 'lib/aws-sdk-rds/types.rb', line 22308

class OptionGroupOptionSetting < Struct.new(
  :setting_name,
  :setting_description,
  :default_value,
  :apply_type,
  :allowed_values,
  :is_modifiable,
  :is_required,
  :minimum_engine_version_per_allowed_value)
  SENSITIVE = []
  include Aws::Structure
end