Class: Aws::RDS::Types::OptionGroupOptionSetting
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::OptionGroupOptionSetting
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Option group option settings are used to display settings available for each option with their default values and other information. These values are used with the DescribeOptionGroupOptions action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ String
Indicates the acceptable values for the option group option.
-
#apply_type ⇒ String
The DB engine specific parameter type for the option group option.
-
#default_value ⇒ String
The default value for the option group option.
-
#is_modifiable ⇒ Boolean
Indicates whether this option group option can be changed from the default value.
-
#is_required ⇒ Boolean
Indicates whether a value must be specified for this option setting of the option group option.
-
#minimum_engine_version_per_allowed_value ⇒ Array<Types::MinimumEngineVersionPerAllowedValue>
The minimum DB engine version required for the corresponding allowed value for this option setting.
-
#setting_description ⇒ String
The description of the option group option.
-
#setting_name ⇒ String
The name of the option group option.
Instance Attribute Details
#allowed_values ⇒ String
Indicates the acceptable values for the option group option.
22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 |
# File 'lib/aws-sdk-rds/types.rb', line 22308 class OptionGroupOptionSetting < Struct.new( :setting_name, :setting_description, :default_value, :apply_type, :allowed_values, :is_modifiable, :is_required, :minimum_engine_version_per_allowed_value) SENSITIVE = [] include Aws::Structure end |
#apply_type ⇒ String
The DB engine specific parameter type for the option group option.
22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 |
# File 'lib/aws-sdk-rds/types.rb', line 22308 class OptionGroupOptionSetting < Struct.new( :setting_name, :setting_description, :default_value, :apply_type, :allowed_values, :is_modifiable, :is_required, :minimum_engine_version_per_allowed_value) SENSITIVE = [] include Aws::Structure end |
#default_value ⇒ String
The default value for the option group option.
22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 |
# File 'lib/aws-sdk-rds/types.rb', line 22308 class OptionGroupOptionSetting < Struct.new( :setting_name, :setting_description, :default_value, :apply_type, :allowed_values, :is_modifiable, :is_required, :minimum_engine_version_per_allowed_value) SENSITIVE = [] include Aws::Structure end |
#is_modifiable ⇒ Boolean
Indicates whether this option group option can be changed from the default value.
22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 |
# File 'lib/aws-sdk-rds/types.rb', line 22308 class OptionGroupOptionSetting < Struct.new( :setting_name, :setting_description, :default_value, :apply_type, :allowed_values, :is_modifiable, :is_required, :minimum_engine_version_per_allowed_value) SENSITIVE = [] include Aws::Structure end |
#is_required ⇒ Boolean
Indicates whether a value must be specified for this option setting of the option group option.
22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 |
# File 'lib/aws-sdk-rds/types.rb', line 22308 class OptionGroupOptionSetting < Struct.new( :setting_name, :setting_description, :default_value, :apply_type, :allowed_values, :is_modifiable, :is_required, :minimum_engine_version_per_allowed_value) SENSITIVE = [] include Aws::Structure end |
#minimum_engine_version_per_allowed_value ⇒ Array<Types::MinimumEngineVersionPerAllowedValue>
The minimum DB engine version required for the corresponding allowed value for this option setting.
22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 |
# File 'lib/aws-sdk-rds/types.rb', line 22308 class OptionGroupOptionSetting < Struct.new( :setting_name, :setting_description, :default_value, :apply_type, :allowed_values, :is_modifiable, :is_required, :minimum_engine_version_per_allowed_value) SENSITIVE = [] include Aws::Structure end |
#setting_description ⇒ String
The description of the option group option.
22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 |
# File 'lib/aws-sdk-rds/types.rb', line 22308 class OptionGroupOptionSetting < Struct.new( :setting_name, :setting_description, :default_value, :apply_type, :allowed_values, :is_modifiable, :is_required, :minimum_engine_version_per_allowed_value) SENSITIVE = [] include Aws::Structure end |
#setting_name ⇒ String
The name of the option group option.
22308 22309 22310 22311 22312 22313 22314 22315 22316 22317 22318 22319 |
# File 'lib/aws-sdk-rds/types.rb', line 22308 class OptionGroupOptionSetting < Struct.new( :setting_name, :setting_description, :default_value, :apply_type, :allowed_values, :is_modifiable, :is_required, :minimum_engine_version_per_allowed_value) SENSITIVE = [] include Aws::Structure end |