Class: Aws::RDS::Types::OptionSetting

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Option settings are the actual settings being applied or configured for that option. It is used when you modify an option group or describe option groups. For example, the NATIVE_NETWORK_ENCRYPTION option has a setting called SQLNET.ENCRYPTION_SERVER that can have several different values.

Constant Summary collapse

SENSITIVE =
[:value]

Instance Attribute Summary collapse

Instance Attribute Details

#allowed_valuesString

The allowed values of the option setting.

Returns:

  • (String)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end

#apply_typeString

The DB engine specific parameter type.

Returns:

  • (String)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end

#data_typeString

The data type of the option setting.

Returns:

  • (String)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end

#default_valueString

The default value of the option setting.

Returns:

  • (String)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end

#descriptionString

The description of the option setting.

Returns:

  • (String)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end

#is_collectionBoolean

Indicates whether the option setting is part of a collection.

Returns:

  • (Boolean)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end

#is_modifiableBoolean

Indicates whether the option setting can be modified from the default.

Returns:

  • (Boolean)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end

#nameString

The name of the option that has settings that you can set.

Returns:

  • (String)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end

#valueString

The current value of the option setting.

Returns:

  • (String)


22366
22367
22368
22369
22370
22371
22372
22373
22374
22375
22376
22377
22378
# File 'lib/aws-sdk-rds/types.rb', line 22366

class OptionSetting < Struct.new(
  :name,
  :value,
  :default_value,
  :description,
  :apply_type,
  :data_type,
  :allowed_values,
  :is_modifiable,
  :is_collection)
  SENSITIVE = [:value]
  include Aws::Structure
end