Class: Aws::RDS::Types::Parameter
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::Parameter
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type is used as a request parameter in the ModifyDBParameterGroup and ResetDBParameterGroup actions.
This data type is used as a response element in the DescribeEngineDefaultParameters and DescribeDBParameters actions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#allowed_values ⇒ String
Specifies the valid range of values for the parameter.
-
#apply_method ⇒ String
Indicates when to apply parameter updates.
-
#apply_type ⇒ String
Specifies the engine specific parameters type.
-
#data_type ⇒ String
Specifies the valid data type for the parameter.
-
#description ⇒ String
Provides a description of the parameter.
-
#is_modifiable ⇒ Boolean
Indicates whether (
true) or not (false) the parameter can be modified. -
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
-
#parameter_name ⇒ String
The name of the parameter.
-
#parameter_value ⇒ String
The value of the parameter.
-
#source ⇒ String
The source of the parameter value.
-
#supported_engine_modes ⇒ Array<String>
The valid DB engine modes.
Instance Attribute Details
#allowed_values ⇒ String
Specifies the valid range of values for the parameter.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#apply_method ⇒ String
Indicates when to apply parameter updates.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#apply_type ⇒ String
Specifies the engine specific parameters type.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#data_type ⇒ String
Specifies the valid data type for the parameter.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Provides a description of the parameter.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#is_modifiable ⇒ Boolean
Indicates whether (true) or not (false) the parameter can be modified. Some parameters have security or operational implications that prevent them from being changed.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#minimum_engine_version ⇒ String
The earliest engine version to which the parameter can apply.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#parameter_name ⇒ String
The name of the parameter.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#parameter_value ⇒ String
The value of the parameter.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source of the parameter value.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |
#supported_engine_modes ⇒ Array<String>
The valid DB engine modes.
22537 22538 22539 22540 22541 22542 22543 22544 22545 22546 22547 22548 22549 22550 22551 |
# File 'lib/aws-sdk-rds/types.rb', line 22537 class Parameter < Struct.new( :parameter_name, :parameter_value, :description, :source, :apply_type, :data_type, :allowed_values, :is_modifiable, :minimum_engine_version, :apply_method, :supported_engine_modes) SENSITIVE = [] include Aws::Structure end |