Class: Aws::RDS::Types::PendingModifiedValues
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::PendingModifiedValues
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type is used as a response element in the ‘ModifyDBInstance` operation and contains changes that will be applied during the next maintenance window.
Constant Summary collapse
- SENSITIVE =
[:master_user_password]
Instance Attribute Summary collapse
-
#additional_storage_volumes ⇒ Array<Types::AdditionalStorageVolume>
The additional storage volume modifications that are pending for the DB instance.
-
#allocated_storage ⇒ Integer
The allocated storage size for the DB instance specified in gibibytes (GiB).
-
#automation_mode ⇒ String
The automation mode of the RDS Custom DB instance: ‘full` or `all-paused`.
-
#backup_retention_period ⇒ Integer
The number of days for which automated backups are retained.
-
#ca_certificate_identifier ⇒ String
The identifier of the CA certificate for the DB instance.
-
#db_instance_class ⇒ String
The name of the compute and memory capacity class for the DB instance.
-
#db_instance_identifier ⇒ String
The database identifier for the DB instance.
-
#db_subnet_group_name ⇒ String
The DB subnet group for the DB instance.
-
#dedicated_log_volume ⇒ Boolean
Indicates whether the DB instance has a dedicated log volume (DLV) enabled.>.
-
#engine ⇒ String
The database engine of the DB instance.
-
#engine_version ⇒ String
The database engine version.
-
#iam_database_authentication_enabled ⇒ Boolean
Indicates whether mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.
-
#iops ⇒ Integer
The Provisioned IOPS value for the DB instance.
-
#license_model ⇒ String
The license model for the DB instance.
-
#master_user_password ⇒ String
The master credentials for the DB instance.
-
#multi_az ⇒ Boolean
Indicates whether the Single-AZ DB instance will change to a Multi-AZ deployment.
-
#multi_tenant ⇒ Boolean
Indicates whether the DB instance will change to the multi-tenant configuration (TRUE) or the single-tenant configuration (FALSE).
-
#pending_cloudwatch_logs_exports ⇒ Types::PendingCloudwatchLogsExports
A list of the log types whose configuration is still pending.
-
#port ⇒ Integer
The port for the DB instance.
-
#processor_features ⇒ Array<Types::ProcessorFeature>
The number of CPU cores and the number of threads per core for the DB instance class of the DB instance.
-
#resume_full_automation_mode_time ⇒ Time
The number of minutes to pause the automation.
-
#storage_throughput ⇒ Integer
The storage throughput of the DB instance.
-
#storage_type ⇒ String
The storage type of the DB instance.
Instance Attribute Details
#additional_storage_volumes ⇒ Array<Types::AdditionalStorageVolume>
The additional storage volume modifications that are pending for the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#allocated_storage ⇒ Integer
The allocated storage size for the DB instance specified in gibibytes (GiB).
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#automation_mode ⇒ String
The automation mode of the RDS Custom DB instance: ‘full` or `all-paused`. If `full`, the DB instance automates monitoring and instance recovery. If `all-paused`, the instance pauses automation for the duration set by `–resume-full-automation-mode-minutes`.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#backup_retention_period ⇒ Integer
The number of days for which automated backups are retained.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#ca_certificate_identifier ⇒ String
The identifier of the CA certificate for the DB instance.
For more information, see [Using SSL/TLS to encrypt a connection to a DB instance] in the *Amazon RDS User Guide* and [ Using SSL/TLS to encrypt a connection to a DB cluster] in the *Amazon Aurora User Guide*.
[1]: docs.aws.amazon.com/AmazonRDS/latest/UserGuide/UsingWithRDS.SSL.html [2]: docs.aws.amazon.com/AmazonRDS/latest/AuroraUserGuide/UsingWithRDS.SSL.html
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#db_instance_class ⇒ String
The name of the compute and memory capacity class for the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#db_instance_identifier ⇒ String
The database identifier for the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#db_subnet_group_name ⇒ String
The DB subnet group for the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#dedicated_log_volume ⇒ Boolean
Indicates whether the DB instance has a dedicated log volume (DLV) enabled.>
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#engine ⇒ String
The database engine of the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#engine_version ⇒ String
The database engine version.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#iam_database_authentication_enabled ⇒ Boolean
Indicates whether mapping of Amazon Web Services Identity and Access Management (IAM) accounts to database accounts is enabled.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#iops ⇒ Integer
The Provisioned IOPS value for the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#license_model ⇒ String
The license model for the DB instance.
Valid values: ‘license-included` | `bring-your-own-license` | `general-public-license`
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#master_user_password ⇒ String
The master credentials for the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#multi_az ⇒ Boolean
Indicates whether the Single-AZ DB instance will change to a Multi-AZ deployment.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#multi_tenant ⇒ Boolean
Indicates whether the DB instance will change to the multi-tenant configuration (TRUE) or the single-tenant configuration (FALSE).
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#pending_cloudwatch_logs_exports ⇒ Types::PendingCloudwatchLogsExports
A list of the log types whose configuration is still pending. In other words, these log types are in the process of being activated or deactivated.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#port ⇒ Integer
The port for the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#processor_features ⇒ Array<Types::ProcessorFeature>
The number of CPU cores and the number of threads per core for the DB instance class of the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#resume_full_automation_mode_time ⇒ Time
The number of minutes to pause the automation. When the time period ends, RDS Custom resumes full automation. The minimum value is 60 (default). The maximum value is 1,440.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#storage_throughput ⇒ Integer
The storage throughput of the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |
#storage_type ⇒ String
The storage type of the DB instance.
22867 22868 22869 22870 22871 22872 22873 22874 22875 22876 22877 22878 22879 22880 22881 22882 22883 22884 22885 22886 22887 22888 22889 22890 22891 22892 22893 |
# File 'lib/aws-sdk-rds/types.rb', line 22867 class PendingModifiedValues < Struct.new( :db_instance_class, :allocated_storage, :master_user_password, :port, :backup_retention_period, :multi_az, :engine_version, :license_model, :iops, :storage_throughput, :db_instance_identifier, :storage_type, :ca_certificate_identifier, :db_subnet_group_name, :pending_cloudwatch_logs_exports, :processor_features, :automation_mode, :resume_full_automation_mode_time, :multi_tenant, :iam_database_authentication_enabled, :dedicated_log_volume, :engine, :additional_storage_volumes) SENSITIVE = [:master_user_password] include Aws::Structure end |