Class: Aws::RDS::Types::PerformanceInsightsMetricDimensionGroup
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::PerformanceInsightsMetricDimensionGroup
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
A logical grouping of Performance Insights metrics for a related subject area. For example, the db.sql dimension group consists of the following dimensions:
-
db.sql.id- The hash of a running SQL statement, generated by Performance Insights. -
db.sql.db_id- Either the SQL ID generated by the database engine, or a value generated by Performance Insights that begins withpi-. -
db.sql.statement- The full text of the SQL statement that is running, for example, ‘SELECT * FROM employees`. -
db.sql_tokenized.id- The hash of the SQL digest generated by Performance Insights.
<note markdown=“1”> Each response element returns a maximum of 500 bytes. For larger elements, such as SQL statements, only the first 500 bytes are returned.
</note>
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#dimensions ⇒ Array<String>
A list of specific dimensions from a dimension group.
-
#group ⇒ String
The available dimension groups for Performance Insights metric type.
-
#limit ⇒ Integer
The maximum number of items to fetch for this dimension group.
Instance Attribute Details
#dimensions ⇒ Array<String>
A list of specific dimensions from a dimension group. If this list isn’t included, then all of the dimensions in the group were requested, or are present in the response.
22846 22847 22848 22849 22850 22851 22852 |
# File 'lib/aws-sdk-rds/types.rb', line 22846 class PerformanceInsightsMetricDimensionGroup < Struct.new( :dimensions, :group, :limit) SENSITIVE = [] include Aws::Structure end |
#group ⇒ String
The available dimension groups for Performance Insights metric type.
22846 22847 22848 22849 22850 22851 22852 |
# File 'lib/aws-sdk-rds/types.rb', line 22846 class PerformanceInsightsMetricDimensionGroup < Struct.new( :dimensions, :group, :limit) SENSITIVE = [] include Aws::Structure end |
#limit ⇒ Integer
The maximum number of items to fetch for this dimension group.
22846 22847 22848 22849 22850 22851 22852 |
# File 'lib/aws-sdk-rds/types.rb', line 22846 class PerformanceInsightsMetricDimensionGroup < Struct.new( :dimensions, :group, :limit) SENSITIVE = [] include Aws::Structure end |