Class: Aws::RDS::Types::ReservedDBInstance
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ReservedDBInstance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type is used as a response element in the ‘DescribeReservedDBInstances` and `PurchaseReservedDBInstancesOffering` actions.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#currency_code ⇒ String
The currency code for the reserved DB instance.
-
#db_instance_class ⇒ String
The DB instance class for the reserved DB instance.
-
#db_instance_count ⇒ Integer
The number of reserved DB instances.
-
#duration ⇒ Integer
The duration of the reservation in seconds.
-
#fixed_price ⇒ Float
The fixed price charged for this reserved DB instance.
-
#lease_id ⇒ String
The unique identifier for the lease associated with the reserved DB instance.
-
#multi_az ⇒ Boolean
Indicates whether the reservation applies to Multi-AZ deployments.
-
#offering_type ⇒ String
The offering type of this reserved DB instance.
-
#product_description ⇒ String
The description of the reserved DB instance.
-
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring price charged to run this reserved DB instance.
-
#reserved_db_instance_arn ⇒ String
The Amazon Resource Name (ARN) for the reserved DB instance.
-
#reserved_db_instance_id ⇒ String
The unique identifier for the reservation.
-
#reserved_db_instances_offering_id ⇒ String
The offering identifier.
-
#start_time ⇒ Time
The time the reservation started.
-
#state ⇒ String
The state of the reserved DB instance.
-
#usage_price ⇒ Float
The hourly price charged for this reserved DB instance.
Instance Attribute Details
#currency_code ⇒ String
The currency code for the reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#db_instance_class ⇒ String
The DB instance class for the reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#db_instance_count ⇒ Integer
The number of reserved DB instances.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#duration ⇒ Integer
The duration of the reservation in seconds.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#fixed_price ⇒ Float
The fixed price charged for this reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#lease_id ⇒ String
The unique identifier for the lease associated with the reserved DB instance.
<note markdown=“1”> Amazon Web Services Support might request the lease ID for an issue related to a reserved DB instance.
</note>
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#multi_az ⇒ Boolean
Indicates whether the reservation applies to Multi-AZ deployments.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#offering_type ⇒ String
The offering type of this reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#product_description ⇒ String
The description of the reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#recurring_charges ⇒ Array<Types::RecurringCharge>
The recurring price charged to run this reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#reserved_db_instance_arn ⇒ String
The Amazon Resource Name (ARN) for the reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#reserved_db_instance_id ⇒ String
The unique identifier for the reservation.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#reserved_db_instances_offering_id ⇒ String
The offering identifier.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
The time the reservation started.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#state ⇒ String
The state of the reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |
#usage_price ⇒ Float
The hourly price charged for this reserved DB instance.
23966 23967 23968 23969 23970 23971 23972 23973 23974 23975 23976 23977 23978 23979 23980 23981 23982 23983 23984 23985 |
# File 'lib/aws-sdk-rds/types.rb', line 23966 class ReservedDBInstance < Struct.new( :reserved_db_instance_id, :reserved_db_instances_offering_id, :db_instance_class, :start_time, :duration, :fixed_price, :usage_price, :currency_code, :db_instance_count, :product_description, :offering_type, :multi_az, :state, :recurring_charges, :reserved_db_instance_arn, :lease_id) SENSITIVE = [] include Aws::Structure end |