Class: Aws::RDS::Types::ResetDBParameterGroupMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ResetDBParameterGroupMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#db_parameter_group_name ⇒ String
The name of the DB parameter group.
-
#parameters ⇒ Array<Types::Parameter>
To reset the entire DB parameter group, specify the
DBParameterGroupname andResetAllParametersparameters. -
#reset_all_parameters ⇒ Boolean
Specifies whether to reset all parameters in the DB parameter group to default values.
Instance Attribute Details
#db_parameter_group_name ⇒ String
The name of the DB parameter group.
Constraints:
-
Must match the name of an existing
DBParameterGroup.
^
24066 24067 24068 24069 24070 24071 24072 |
# File 'lib/aws-sdk-rds/types.rb', line 24066 class ResetDBParameterGroupMessage < Struct.new( :db_parameter_group_name, :reset_all_parameters, :parameters) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Array<Types::Parameter>
To reset the entire DB parameter group, specify the DBParameterGroup name and ResetAllParameters parameters. To reset specific parameters, provide a list of the following: ParameterName and ApplyMethod. A maximum of 20 parameters can be modified in a single request.
MySQL
Valid Values (for Apply method): immediate \| pending-reboot
You can use the immediate value with dynamic parameters only. You can use the pending-reboot value for both dynamic and static parameters, and changes are applied when DB instance reboots.
MariaDB
Valid Values (for Apply method): immediate \| pending-reboot
You can use the immediate value with dynamic parameters only. You can use the pending-reboot value for both dynamic and static parameters, and changes are applied when DB instance reboots.
Oracle
Valid Values (for Apply method): pending-reboot
24066 24067 24068 24069 24070 24071 24072 |
# File 'lib/aws-sdk-rds/types.rb', line 24066 class ResetDBParameterGroupMessage < Struct.new( :db_parameter_group_name, :reset_all_parameters, :parameters) SENSITIVE = [] include Aws::Structure end |
#reset_all_parameters ⇒ Boolean
Specifies whether to reset all parameters in the DB parameter group to default values. By default, all parameters in the DB parameter group are reset to default values.
24066 24067 24068 24069 24070 24071 24072 |
# File 'lib/aws-sdk-rds/types.rb', line 24066 class ResetDBParameterGroupMessage < Struct.new( :db_parameter_group_name, :reset_all_parameters, :parameters) SENSITIVE = [] include Aws::Structure end |