Class: Aws::RDS::Types::RevokeDBSecurityGroupIngressMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::RevokeDBSecurityGroupIngressMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cidrip ⇒ String
The IP range to revoke access from.
-
#db_security_group_name ⇒ String
The name of the DB security group to revoke ingress from.
-
#ec2_security_group_id ⇒ String
The id of the EC2 security group to revoke access from.
-
#ec2_security_group_name ⇒ String
The name of the EC2 security group to revoke access from.
-
#ec2_security_group_owner_id ⇒ String
The Amazon Web Services account number of the owner of the EC2 security group specified in the
EC2SecurityGroupNameparameter.
Instance Attribute Details
#cidrip ⇒ String
The IP range to revoke access from. Must be a valid CIDR range. If CIDRIP is specified, EC2SecurityGroupName, EC2SecurityGroupId and EC2SecurityGroupOwnerId can’t be provided.
28125 28126 28127 28128 28129 28130 28131 28132 28133 |
# File 'lib/aws-sdk-rds/types.rb', line 28125 class RevokeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#db_security_group_name ⇒ String
The name of the DB security group to revoke ingress from.
28125 28126 28127 28128 28129 28130 28131 28132 28133 |
# File 'lib/aws-sdk-rds/types.rb', line 28125 class RevokeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#ec2_security_group_id ⇒ String
The id of the EC2 security group to revoke access from. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.
28125 28126 28127 28128 28129 28130 28131 28132 28133 |
# File 'lib/aws-sdk-rds/types.rb', line 28125 class RevokeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#ec2_security_group_name ⇒ String
The name of the EC2 security group to revoke access from. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.
28125 28126 28127 28128 28129 28130 28131 28132 28133 |
# File 'lib/aws-sdk-rds/types.rb', line 28125 class RevokeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |
#ec2_security_group_owner_id ⇒ String
The Amazon Web Services account number of the owner of the EC2 security group specified in the EC2SecurityGroupName parameter. The Amazon Web Services access key ID isn’t an acceptable value. For VPC DB security groups, EC2SecurityGroupId must be provided. Otherwise, EC2SecurityGroupOwnerId and either EC2SecurityGroupName or EC2SecurityGroupId must be provided.
28125 28126 28127 28128 28129 28130 28131 28132 28133 |
# File 'lib/aws-sdk-rds/types.rb', line 28125 class RevokeDBSecurityGroupIngressMessage < Struct.new( :db_security_group_name, :cidrip, :ec2_security_group_name, :ec2_security_group_id, :ec2_security_group_owner_id) SENSITIVE = [] include Aws::Structure end |