Class: Aws::RDS::Types::ServerlessV2PlatformVersionInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ServerlessV2PlatformVersionInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type is used as a response element in the action ‘DescribeServerlessV2PlatformVersions`.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#engine ⇒ String
The name of the database engine.
-
#is_default ⇒ Boolean
Indicates whether this platform version is the default version for the engine.
-
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Aurora Serverless v2 properties or limits that differ between Aurora Serverless v2 platform versions.
-
#serverless_v2_platform_version ⇒ String
The version number of the serverless platform.
-
#serverless_v2_platform_version_description ⇒ String
The description of the serverless platform.
-
#status ⇒ String
The status of the serverless platform.
Instance Attribute Details
#engine ⇒ String
The name of the database engine.
28900 28901 28902 28903 28904 28905 28906 28907 28908 28909 |
# File 'lib/aws-sdk-rds/types.rb', line 28900 class ServerlessV2PlatformVersionInfo < Struct.new( :serverless_v2_platform_version, :serverless_v2_platform_version_description, :engine, :serverless_v2_features_support, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#is_default ⇒ Boolean
Indicates whether this platform version is the default version for the engine. The default platform version is the version used for new DB clusters.
28900 28901 28902 28903 28904 28905 28906 28907 28908 28909 |
# File 'lib/aws-sdk-rds/types.rb', line 28900 class ServerlessV2PlatformVersionInfo < Struct.new( :serverless_v2_platform_version, :serverless_v2_platform_version_description, :engine, :serverless_v2_features_support, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_features_support ⇒ Types::ServerlessV2FeaturesSupport
Specifies any Aurora Serverless v2 properties or limits that differ between Aurora Serverless v2 platform versions. You can retrieve the platform version of an existing DB cluster and check whether that version supports certain Aurora Serverless v2 features before you attempt to use those features.
28900 28901 28902 28903 28904 28905 28906 28907 28908 28909 |
# File 'lib/aws-sdk-rds/types.rb', line 28900 class ServerlessV2PlatformVersionInfo < Struct.new( :serverless_v2_platform_version, :serverless_v2_platform_version_description, :engine, :serverless_v2_features_support, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_platform_version ⇒ String
The version number of the serverless platform.
28900 28901 28902 28903 28904 28905 28906 28907 28908 28909 |
# File 'lib/aws-sdk-rds/types.rb', line 28900 class ServerlessV2PlatformVersionInfo < Struct.new( :serverless_v2_platform_version, :serverless_v2_platform_version_description, :engine, :serverless_v2_features_support, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_platform_version_description ⇒ String
The description of the serverless platform.
28900 28901 28902 28903 28904 28905 28906 28907 28908 28909 |
# File 'lib/aws-sdk-rds/types.rb', line 28900 class ServerlessV2PlatformVersionInfo < Struct.new( :serverless_v2_platform_version, :serverless_v2_platform_version_description, :engine, :serverless_v2_features_support, :status, :is_default) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the serverless platform. Valid statuses are the following:
-
‘enabled` - The platform version is in use.
-
‘disabled` - The platform version is not in use.
28900 28901 28902 28903 28904 28905 28906 28907 28908 28909 |
# File 'lib/aws-sdk-rds/types.rb', line 28900 class ServerlessV2PlatformVersionInfo < Struct.new( :serverless_v2_platform_version, :serverless_v2_platform_version_description, :engine, :serverless_v2_features_support, :status, :is_default) SENSITIVE = [] include Aws::Structure end |