Class: Aws::RDS::Types::ServerlessV2PlatformVersionsMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::ServerlessV2PlatformVersionsMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the result of a successful invocation of the ‘DescribeServerlessV2PlatformVersions` action.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional pagination token provided by a previous request.
-
#serverless_v2_platform_versions ⇒ Array<Types::ServerlessV2PlatformVersionInfo>
A list of ‘ServerlessV2PlatformVersionInfo` elements.
Instance Attribute Details
#marker ⇒ String
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by ‘MaxRecords`.
28926 28927 28928 28929 28930 28931 |
# File 'lib/aws-sdk-rds/types.rb', line 28926 class ServerlessV2PlatformVersionsMessage < Struct.new( :marker, :serverless_v2_platform_versions) SENSITIVE = [] include Aws::Structure end |
#serverless_v2_platform_versions ⇒ Array<Types::ServerlessV2PlatformVersionInfo>
A list of ‘ServerlessV2PlatformVersionInfo` elements.
28926 28927 28928 28929 28930 28931 |
# File 'lib/aws-sdk-rds/types.rb', line 28926 class ServerlessV2PlatformVersionsMessage < Struct.new( :marker, :serverless_v2_platform_versions) SENSITIVE = [] include Aws::Structure end |