Class: Aws::RDS::Types::StartActivityStreamResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::StartActivityStreamResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#apply_immediately ⇒ Boolean
Indicates whether or not the database activity stream will start as soon as possible, regardless of the maintenance window for the database.
-
#engine_native_audit_fields_included ⇒ Boolean
Indicates whether engine-native audit fields are included in the database activity stream.
-
#kinesis_stream_name ⇒ String
The name of the Amazon Kinesis data stream to be used for the database activity stream.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for encryption of messages in the database activity stream.
-
#mode ⇒ String
The mode of the database activity stream.
-
#status ⇒ String
The status of the database activity stream.
Instance Attribute Details
#apply_immediately ⇒ Boolean
Indicates whether or not the database activity stream will start as soon as possible, regardless of the maintenance window for the database.
29382 29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-rds/types.rb', line 29382 class StartActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status, :mode, :engine_native_audit_fields_included, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#engine_native_audit_fields_included ⇒ Boolean
Indicates whether engine-native audit fields are included in the database activity stream.
29382 29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-rds/types.rb', line 29382 class StartActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status, :mode, :engine_native_audit_fields_included, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#kinesis_stream_name ⇒ String
The name of the Amazon Kinesis data stream to be used for the database activity stream.
29382 29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-rds/types.rb', line 29382 class StartActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status, :mode, :engine_native_audit_fields_included, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier for encryption of messages in the database activity stream.
29382 29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-rds/types.rb', line 29382 class StartActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status, :mode, :engine_native_audit_fields_included, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#mode ⇒ String
The mode of the database activity stream.
29382 29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-rds/types.rb', line 29382 class StartActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status, :mode, :engine_native_audit_fields_included, :apply_immediately) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the database activity stream.
29382 29383 29384 29385 29386 29387 29388 29389 29390 29391 |
# File 'lib/aws-sdk-rds/types.rb', line 29382 class StartActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status, :mode, :engine_native_audit_fields_included, :apply_immediately) SENSITIVE = [] include Aws::Structure end |