Class: Aws::RDS::Types::StopActivityStreamResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::StopActivityStreamResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kinesis_stream_name ⇒ String
The name of the Amazon Kinesis data stream used for the database activity stream.
-
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier used for encrypting messages in the database activity stream.
-
#status ⇒ String
The status of the database activity stream.
Instance Attribute Details
#kinesis_stream_name ⇒ String
The name of the Amazon Kinesis data stream used for the database activity stream.
29755 29756 29757 29758 29759 29760 29761 |
# File 'lib/aws-sdk-rds/types.rb', line 29755 class StopActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status) SENSITIVE = [] include Aws::Structure end |
#kms_key_id ⇒ String
The Amazon Web Services KMS key identifier used for encrypting messages in the database activity stream.
The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key.
29755 29756 29757 29758 29759 29760 29761 |
# File 'lib/aws-sdk-rds/types.rb', line 29755 class StopActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the database activity stream.
29755 29756 29757 29758 29759 29760 29761 |
# File 'lib/aws-sdk-rds/types.rb', line 29755 class StopActivityStreamResponse < Struct.new( :kms_key_id, :kinesis_stream_name, :status) SENSITIVE = [] include Aws::Structure end |