Class: Aws::RDS::Types::Subnet
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::Subnet
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
This data type is used as a response element for the
DescribeDBSubnetGroups operation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#subnet_availability_zone ⇒ Types::AvailabilityZone
Contains Availability Zone information.
-
#subnet_identifier ⇒ String
The identifier of the subnet.
-
#subnet_outpost ⇒ Types::Outpost
If the subnet is associated with an Outpost, this value specifies the Outpost.
-
#subnet_status ⇒ String
The status of the subnet.
Instance Attribute Details
#subnet_availability_zone ⇒ Types::AvailabilityZone
Contains Availability Zone information.
This data type is used as an element in the
OrderableDBInstanceOption data type.
29924 29925 29926 29927 29928 29929 29930 29931 |
# File 'lib/aws-sdk-rds/types.rb', line 29924 class Subnet < Struct.new( :subnet_identifier, :subnet_availability_zone, :subnet_outpost, :subnet_status) SENSITIVE = [] include Aws::Structure end |
#subnet_identifier ⇒ String
The identifier of the subnet.
29924 29925 29926 29927 29928 29929 29930 29931 |
# File 'lib/aws-sdk-rds/types.rb', line 29924 class Subnet < Struct.new( :subnet_identifier, :subnet_availability_zone, :subnet_outpost, :subnet_status) SENSITIVE = [] include Aws::Structure end |
#subnet_outpost ⇒ Types::Outpost
If the subnet is associated with an Outpost, this value specifies the Outpost.
For more information about RDS on Outposts, see Amazon RDS on Amazon Web Services Outposts in the Amazon RDS User Guide.
29924 29925 29926 29927 29928 29929 29930 29931 |
# File 'lib/aws-sdk-rds/types.rb', line 29924 class Subnet < Struct.new( :subnet_identifier, :subnet_availability_zone, :subnet_outpost, :subnet_status) SENSITIVE = [] include Aws::Structure end |