Class: Aws::RDS::Types::SwitchoverDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::SwitchoverDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Contains the details about a blue/green deployment.
For more information, see Using Amazon RDS Blue/Green Deployments for database updates in the Amazon RDS User Guide and Using Amazon RDS Blue/Green Deployments for database updates in the Amazon Aurora User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#source_member ⇒ String
The Amazon Resource Name (ARN) of a resource in the blue environment.
-
#status ⇒ String
The switchover status of a resource in a blue/green deployment.
-
#target_member ⇒ String
The Amazon Resource Name (ARN) of a resource in the green environment.
Instance Attribute Details
#source_member ⇒ String
The Amazon Resource Name (ARN) of a resource in the blue environment.
29944 29945 29946 29947 29948 29949 29950 |
# File 'lib/aws-sdk-rds/types.rb', line 29944 class SwitchoverDetail < Struct.new( :source_member, :target_member, :status) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The switchover status of a resource in a blue/green deployment.
Values:
-
PROVISIONING- The resource is being prepared to switch over. -
AVAILABLE- The resource is ready to switch over. -
SWITCHOVER_IN_PROGRESS- The resource is being switched over. -
SWITCHOVER_COMPLETED- The resource has been switched over. -
SWITCHOVER_FAILED- The resource attempted to switch over but failed. -
MISSING_SOURCE- The source resource has been deleted. -
MISSING_TARGET- The target resource has been deleted.
29944 29945 29946 29947 29948 29949 29950 |
# File 'lib/aws-sdk-rds/types.rb', line 29944 class SwitchoverDetail < Struct.new( :source_member, :target_member, :status) SENSITIVE = [] include Aws::Structure end |
#target_member ⇒ String
The Amazon Resource Name (ARN) of a resource in the green environment.
29944 29945 29946 29947 29948 29949 29950 |
# File 'lib/aws-sdk-rds/types.rb', line 29944 class SwitchoverDetail < Struct.new( :source_member, :target_member, :status) SENSITIVE = [] include Aws::Structure end |