Class: Aws::RDS::Types::TenantDatabasesMessage
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::TenantDatabasesMessage
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
An optional pagination token provided by a previous
DescribeTenantDatabasesrequest. -
#tenant_databases ⇒ Array<Types::TenantDatabase>
An array of the tenant databases requested by the
DescribeTenantDatabasesoperation.
Instance Attribute Details
#marker ⇒ String
An optional pagination token provided by a previous
DescribeTenantDatabases request. If this parameter is specified,
the response includes only records beyond the marker, up to the
value specified by MaxRecords.
30430 30431 30432 30433 30434 30435 |
# File 'lib/aws-sdk-rds/types.rb', line 30430 class TenantDatabasesMessage < Struct.new( :marker, :tenant_databases) SENSITIVE = [] include Aws::Structure end |
#tenant_databases ⇒ Array<Types::TenantDatabase>
An array of the tenant databases requested by the
DescribeTenantDatabases operation.
30430 30431 30432 30433 30434 30435 |
# File 'lib/aws-sdk-rds/types.rb', line 30430 class TenantDatabasesMessage < Struct.new( :marker, :tenant_databases) SENSITIVE = [] include Aws::Structure end |