Class: Aws::RDS::Types::UpgradeTarget
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::UpgradeTarget
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
The version of the database engine that a DB instance can be upgraded to.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auto_upgrade ⇒ Boolean
Indicates whether the target version is applied to any source DB instances that have
AutoMinorVersionUpgradeset to true. -
#description ⇒ String
The version of the database engine that a DB instance can be upgraded to.
-
#engine ⇒ String
The name of the upgrade target database engine.
-
#engine_version ⇒ String
The version number of the upgrade target database engine.
-
#is_major_version_upgrade ⇒ Boolean
Indicates whether upgrading to the target version requires upgrading the major version of the database engine.
-
#supported_engine_modes ⇒ Array<String>
A list of the supported DB engine modes for the target engine version.
-
#supports_babelfish ⇒ Boolean
Indicates whether you can use Babelfish for Aurora PostgreSQL with the target engine version.
-
#supports_global_databases ⇒ Boolean
Indicates whether you can use Aurora global databases with the target engine version.
-
#supports_integrations ⇒ Boolean
Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.
-
#supports_limitless_database ⇒ Boolean
Indicates whether the DB engine version supports Aurora Limitless Database.
-
#supports_local_write_forwarding ⇒ Boolean
Indicates whether the target engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster.
-
#supports_parallel_query ⇒ Boolean
Indicates whether you can use Aurora parallel query with the target engine version.
Instance Attribute Details
#auto_upgrade ⇒ Boolean
Indicates whether the target version is applied to any source DB instances that have AutoMinorVersionUpgrade set to true.
This parameter is dynamic, and is set by RDS.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The version of the database engine that a DB instance can be upgraded to.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#engine ⇒ String
The name of the upgrade target database engine.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#engine_version ⇒ String
The version number of the upgrade target database engine.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#is_major_version_upgrade ⇒ Boolean
Indicates whether upgrading to the target version requires upgrading the major version of the database engine.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#supported_engine_modes ⇒ Array<String>
A list of the supported DB engine modes for the target engine version.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#supports_babelfish ⇒ Boolean
Indicates whether you can use Babelfish for Aurora PostgreSQL with the target engine version.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#supports_global_databases ⇒ Boolean
Indicates whether you can use Aurora global databases with the target engine version.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#supports_integrations ⇒ Boolean
Indicates whether the DB engine version supports zero-ETL integrations with Amazon Redshift.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#supports_limitless_database ⇒ Boolean
Indicates whether the DB engine version supports Aurora Limitless Database.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#supports_local_write_forwarding ⇒ Boolean
Indicates whether the target engine version supports forwarding write operations from reader DB instances to the writer DB instance in the DB cluster. By default, write operations aren’t allowed on reader DB instances.
Valid for: Aurora DB clusters only
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |
#supports_parallel_query ⇒ Boolean
Indicates whether you can use Aurora parallel query with the target engine version.
30127 30128 30129 30130 30131 30132 30133 30134 30135 30136 30137 30138 30139 30140 30141 30142 |
# File 'lib/aws-sdk-rds/types.rb', line 30127 class UpgradeTarget < Struct.new( :engine, :engine_version, :description, :auto_upgrade, :is_major_version_upgrade, :supported_engine_modes, :supports_parallel_query, :supports_global_databases, :supports_babelfish, :supports_limitless_database, :supports_local_write_forwarding, :supports_integrations) SENSITIVE = [] include Aws::Structure end |