Class: Aws::RDS::Types::UserAuthConfig

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Specifies the details of authentication used by a proxy to log in as a specific database user.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#auth_schemeString

The type of authentication that the proxy uses for connections from the proxy to the underlying database.

Returns:

  • (String)


30646
30647
30648
30649
30650
30651
30652
30653
30654
30655
# File 'lib/aws-sdk-rds/types.rb', line 30646

class UserAuthConfig < Struct.new(
  :description,
  :user_name,
  :auth_scheme,
  :secret_arn,
  :iam_auth,
  :client_password_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#client_password_auth_typeString

The type of authentication the proxy uses for connections from clients. The following values are defaults for the corresponding engines:

  • RDS for MySQL: MYSQL_CACHING_SHA2_PASSWORD

  • RDS for SQL Server: SQL_SERVER_AUTHENTICATION

  • RDS for PostgreSQL: POSTGRES_SCRAM_SHA2_256

Returns:

  • (String)


30646
30647
30648
30649
30650
30651
30652
30653
30654
30655
# File 'lib/aws-sdk-rds/types.rb', line 30646

class UserAuthConfig < Struct.new(
  :description,
  :user_name,
  :auth_scheme,
  :secret_arn,
  :iam_auth,
  :client_password_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A user-specified description about the authentication used by a proxy to log in as a specific database user.

Returns:

  • (String)


30646
30647
30648
30649
30650
30651
30652
30653
30654
30655
# File 'lib/aws-sdk-rds/types.rb', line 30646

class UserAuthConfig < Struct.new(
  :description,
  :user_name,
  :auth_scheme,
  :secret_arn,
  :iam_auth,
  :client_password_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#iam_authString

A value that indicates whether to require or disallow Amazon Web Services Identity and Access Management (IAM) authentication for connections to the proxy. The ENABLED value is valid only for proxies with RDS for Microsoft SQL Server.

Returns:

  • (String)


30646
30647
30648
30649
30650
30651
30652
30653
30654
30655
# File 'lib/aws-sdk-rds/types.rb', line 30646

class UserAuthConfig < Struct.new(
  :description,
  :user_name,
  :auth_scheme,
  :secret_arn,
  :iam_auth,
  :client_password_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#secret_arnString

The Amazon Resource Name (ARN) representing the secret that the proxy uses to authenticate to the RDS DB instance or Aurora DB cluster. These secrets are stored within Amazon Secrets Manager.

Returns:

  • (String)


30646
30647
30648
30649
30650
30651
30652
30653
30654
30655
# File 'lib/aws-sdk-rds/types.rb', line 30646

class UserAuthConfig < Struct.new(
  :description,
  :user_name,
  :auth_scheme,
  :secret_arn,
  :iam_auth,
  :client_password_auth_type)
  SENSITIVE = []
  include Aws::Structure
end

#user_nameString

The name of the database user to which the proxy connects.

Returns:

  • (String)


30646
30647
30648
30649
30650
30651
30652
30653
30654
30655
# File 'lib/aws-sdk-rds/types.rb', line 30646

class UserAuthConfig < Struct.new(
  :description,
  :user_name,
  :auth_scheme,
  :secret_arn,
  :iam_auth,
  :client_password_auth_type)
  SENSITIVE = []
  include Aws::Structure
end