Class: Aws::RDS::Types::UserAuthConfigInfo
- Inherits:
-
Struct
- Object
- Struct
- Aws::RDS::Types::UserAuthConfigInfo
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-rds/types.rb
Overview
Returns the details of authentication used by a proxy to log in as a specific database user.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#auth_scheme ⇒ String
The type of authentication that the proxy uses for connections from the proxy to the underlying database.
-
#client_password_auth_type ⇒ String
The type of authentication the proxy uses for connections from clients.
-
#description ⇒ String
A user-specified description about the authentication used by a proxy to log in as a specific database user.
-
#iam_auth ⇒ String
Whether to require or disallow Amazon Web Services Identity and Access Management (IAM) authentication for connections to the proxy.
-
#secret_arn ⇒ String
The Amazon Resource Name (ARN) representing the secret that the proxy uses to authenticate to the RDS DB instance or Aurora DB cluster.
-
#user_name ⇒ String
The name of the database user to which the proxy connects.
Instance Attribute Details
#auth_scheme ⇒ String
The type of authentication that the proxy uses for connections from the proxy to the underlying database.
30683 30684 30685 30686 30687 30688 30689 30690 30691 30692 |
# File 'lib/aws-sdk-rds/types.rb', line 30683 class UserAuthConfigInfo < Struct.new( :description, :user_name, :auth_scheme, :secret_arn, :iam_auth, :client_password_auth_type) SENSITIVE = [] include Aws::Structure end |
#client_password_auth_type ⇒ String
The type of authentication the proxy uses for connections from clients.
30683 30684 30685 30686 30687 30688 30689 30690 30691 30692 |
# File 'lib/aws-sdk-rds/types.rb', line 30683 class UserAuthConfigInfo < Struct.new( :description, :user_name, :auth_scheme, :secret_arn, :iam_auth, :client_password_auth_type) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A user-specified description about the authentication used by a proxy to log in as a specific database user.
30683 30684 30685 30686 30687 30688 30689 30690 30691 30692 |
# File 'lib/aws-sdk-rds/types.rb', line 30683 class UserAuthConfigInfo < Struct.new( :description, :user_name, :auth_scheme, :secret_arn, :iam_auth, :client_password_auth_type) SENSITIVE = [] include Aws::Structure end |
#iam_auth ⇒ String
Whether to require or disallow Amazon Web Services Identity and Access Management (IAM) authentication for connections to the proxy.
30683 30684 30685 30686 30687 30688 30689 30690 30691 30692 |
# File 'lib/aws-sdk-rds/types.rb', line 30683 class UserAuthConfigInfo < Struct.new( :description, :user_name, :auth_scheme, :secret_arn, :iam_auth, :client_password_auth_type) SENSITIVE = [] include Aws::Structure end |
#secret_arn ⇒ String
The Amazon Resource Name (ARN) representing the secret that the proxy uses to authenticate to the RDS DB instance or Aurora DB cluster. These secrets are stored within Amazon Secrets Manager.
30683 30684 30685 30686 30687 30688 30689 30690 30691 30692 |
# File 'lib/aws-sdk-rds/types.rb', line 30683 class UserAuthConfigInfo < Struct.new( :description, :user_name, :auth_scheme, :secret_arn, :iam_auth, :client_password_auth_type) SENSITIVE = [] include Aws::Structure end |
#user_name ⇒ String
The name of the database user to which the proxy connects.
30683 30684 30685 30686 30687 30688 30689 30690 30691 30692 |
# File 'lib/aws-sdk-rds/types.rb', line 30683 class UserAuthConfigInfo < Struct.new( :description, :user_name, :auth_scheme, :secret_arn, :iam_auth, :client_password_auth_type) SENSITIVE = [] include Aws::Structure end |