Class: Aws::RDS::Types::ValidStorageOptions

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-rds/types.rb

Overview

Information about valid modifications that you can make to your DB instance. Contains the result of a successful call to the DescribeValidDBInstanceModifications action.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#iops_to_storage_ratioArray<Types::DoubleRange>

The valid range of Provisioned IOPS to gibibytes of storage multiplier. For example, 3-10, which means that provisioned IOPS can be between 3 and 10 times storage.



30340
30341
30342
30343
30344
30345
30346
30347
30348
30349
30350
# File 'lib/aws-sdk-rds/types.rb', line 30340

class ValidStorageOptions < Struct.new(
  :storage_type,
  :storage_size,
  :provisioned_iops,
  :iops_to_storage_ratio,
  :provisioned_storage_throughput,
  :storage_throughput_to_iops_ratio,
  :supports_storage_autoscaling)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_iopsArray<Types::Range>

The valid range of provisioned IOPS. For example, 1000-256,000.



30340
30341
30342
30343
30344
30345
30346
30347
30348
30349
30350
# File 'lib/aws-sdk-rds/types.rb', line 30340

class ValidStorageOptions < Struct.new(
  :storage_type,
  :storage_size,
  :provisioned_iops,
  :iops_to_storage_ratio,
  :provisioned_storage_throughput,
  :storage_throughput_to_iops_ratio,
  :supports_storage_autoscaling)
  SENSITIVE = []
  include Aws::Structure
end

#provisioned_storage_throughputArray<Types::Range>

The valid range of provisioned storage throughput. For example, 500-4,000 mebibytes per second (MiBps).



30340
30341
30342
30343
30344
30345
30346
30347
30348
30349
30350
# File 'lib/aws-sdk-rds/types.rb', line 30340

class ValidStorageOptions < Struct.new(
  :storage_type,
  :storage_size,
  :provisioned_iops,
  :iops_to_storage_ratio,
  :provisioned_storage_throughput,
  :storage_throughput_to_iops_ratio,
  :supports_storage_autoscaling)
  SENSITIVE = []
  include Aws::Structure
end

#storage_sizeArray<Types::Range>

The valid range of storage in gibibytes (GiB). For example, 100 to 16,384.



30340
30341
30342
30343
30344
30345
30346
30347
30348
30349
30350
# File 'lib/aws-sdk-rds/types.rb', line 30340

class ValidStorageOptions < Struct.new(
  :storage_type,
  :storage_size,
  :provisioned_iops,
  :iops_to_storage_ratio,
  :provisioned_storage_throughput,
  :storage_throughput_to_iops_ratio,
  :supports_storage_autoscaling)
  SENSITIVE = []
  include Aws::Structure
end

#storage_throughput_to_iops_ratioArray<Types::DoubleRange>

The valid range of storage throughput to provisioned IOPS ratios. For example, 0-0.25.



30340
30341
30342
30343
30344
30345
30346
30347
30348
30349
30350
# File 'lib/aws-sdk-rds/types.rb', line 30340

class ValidStorageOptions < Struct.new(
  :storage_type,
  :storage_size,
  :provisioned_iops,
  :iops_to_storage_ratio,
  :provisioned_storage_throughput,
  :storage_throughput_to_iops_ratio,
  :supports_storage_autoscaling)
  SENSITIVE = []
  include Aws::Structure
end

#storage_typeString

The valid storage types for your DB instance. For example: gp2, gp3, io1, io2.



30340
30341
30342
30343
30344
30345
30346
30347
30348
30349
30350
# File 'lib/aws-sdk-rds/types.rb', line 30340

class ValidStorageOptions < Struct.new(
  :storage_type,
  :storage_size,
  :provisioned_iops,
  :iops_to_storage_ratio,
  :provisioned_storage_throughput,
  :storage_throughput_to_iops_ratio,
  :supports_storage_autoscaling)
  SENSITIVE = []
  include Aws::Structure
end

#supports_storage_autoscalingBoolean

Indicates whether or not Amazon RDS can automatically scale storage for DB instances that use the new instance class.



30340
30341
30342
30343
30344
30345
30346
30347
30348
30349
30350
# File 'lib/aws-sdk-rds/types.rb', line 30340

class ValidStorageOptions < Struct.new(
  :storage_type,
  :storage_size,
  :provisioned_iops,
  :iops_to_storage_ratio,
  :provisioned_storage_throughput,
  :storage_throughput_to_iops_ratio,
  :supports_storage_autoscaling)
  SENSITIVE = []
  include Aws::Structure
end